// Auto generated SWIG file for Python interface of DOLFIN
//
// Copyright (C) 2012-2016 Kristian B. Oelgaard, Tormod Landet
//
// This file is part of DOLFIN.
//
// DOLFIN is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// DOLFIN is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
//

// SWIG docstrings generated by doxygen and generate_api_rst.py / parse_doxygen.py

%feature("docstring") dolfin::AdaptiveLinearVariationalSolver "
A class for goal-oriented adaptive solution of linear variational problems.
For a linear variational problem of the form: find u in V satisfying 

::
   
   a(u, v) = L(v) for all v in :math:`\\hat V`
   
and a corresponding conforming discrete problem: find u_h in V_h satisfying 

::
   
   a(u_h, v) = L(v) for all v in :math:`\\hat V_h`
   
and a given goal functional M and tolerance tol, the aim is to find a V_H and a u_H in V_H satisfying the discrete problem such that 

::
   
   \\|M(u) - M(u_H)\\| < tol
   
This strategy is based on dual-weighted residual error estimators designed and automatically generated for the primal problem and subsequent h-adaptivity.
";

%feature("docstring") dolfin::AdaptiveLinearVariationalSolver::AdaptiveLinearVariationalSolver(std::shared_ptr< LinearVariationalProblem > problem, std::shared_ptr< Form > goal, std::shared_ptr< ErrorControl > control) "
Create :cpp:any:`AdaptiveLinearVariationalSolver`  from variational problem, goal form and error control instance
Arguments problem (:cpp:any:`LinearVariationalProblem` ) The primal problem goal (:cpp:any:`Form` ) The goal functional control (:cpp:any:`ErrorControl` ) An error controller object 

:param std\\:\\:shared_ptr< LinearVariationalProblem > problem: 
:param std\\:\\:shared_ptr< Form > goal: 
:param std\\:\\:shared_ptr< ErrorControl > control:
";

%feature("docstring") dolfin::AdaptiveLinearVariationalSolver::AdaptiveLinearVariationalSolver(std::shared_ptr< LinearVariationalProblem > problem, std::shared_ptr< GoalFunctional > goal) "
Create :cpp:any:`AdaptiveLinearVariationalSolver`  (shared ptr version)
Arguments problem (:cpp:any:`LinearVariationalProblem` ) The primal problem goal (:cpp:any:`GoalFunctional` ) The goal functional 

:param std\\:\\:shared_ptr< LinearVariationalProblem > problem: 
:param std\\:\\:shared_ptr< GoalFunctional > goal:
";

%feature("docstring") dolfin::AdaptiveLinearVariationalSolver::adapt_problem(std::shared_ptr< const Mesh > mesh) "
Adapt the problem to other mesh.
Arguments mesh (:cpp:any:`Mesh` ) The other mesh 

:param std\\:\\:shared_ptr< const Mesh > mesh: 
:rtype: void
";

%feature("docstring") dolfin::AdaptiveLinearVariationalSolver::evaluate_goal(Form &M, std::shared_ptr< const Function > u) const "
Evaluate the goal functional.
Arguments M (:cpp:any:`Form` ) The functional to be evaluated u (:cpp:any:`Function` ) The function at which to evaluate the functional
Returns double The value of M evaluated at u 

:param Form & M: 
:param std\\:\\:shared_ptr< const Function > u: 
:rtype: double
";

%feature("docstring") dolfin::AdaptiveLinearVariationalSolver::extract_bcs() const "
Extract the boundary conditions for the primal problem.
Returns std::vector<:cpp:any:`DirichletBC` > The primal boundary conditions 

:rtype: std::vector< std::shared_ptr< const DirichletBC > >
";

%feature("docstring") dolfin::AdaptiveLinearVariationalSolver::init(std::shared_ptr< LinearVariationalProblem > problem, std::shared_ptr< GoalFunctional > goal) "
Helper function for instance initialization
Arguments problem (:cpp:any:`LinearVariationalProblem` ) The primal problem u (:cpp:any:`GoalFunctional` ) The goal functional 

:param std\\:\\:shared_ptr< LinearVariationalProblem > problem: 
:param std\\:\\:shared_ptr< GoalFunctional > goal: 
:rtype: void
";

%feature("docstring") dolfin::AdaptiveLinearVariationalSolver::num_dofs_primal() "
Return the number of degrees of freedom for primal problem
Returnsstd::size_t The number of degrees of freedom 

:rtype: std::size_t
";

%feature("docstring") dolfin::AdaptiveLinearVariationalSolver::solve_primal() "
Solve the primal problem.
Returns:cpp:any:`Function`  The solution to the primal problem 

:rtype: std::shared_ptr< const Function >
";

%feature("docstring") dolfin::AdaptiveLinearVariationalSolver::~AdaptiveLinearVariationalSolver() "
Destructor.
";

%feature("docstring") dolfin::AdaptiveNonlinearVariationalSolver "
A class for goal-oriented adaptive solution of nonlinear variational problems.
For a nonlinear variational problem of the form: find u in V satisfying 

::
   
   F(u; v) = 0 for all v in :math:`\\hat V`
   
and a corresponding conforming discrete problem: find u_h in V_h satisfying (at least approximately) 

::
   
   F(u_h; v) = 0 for all v in :math:`\\hat V_h`
   
and a given goal functional M and tolerance tol, the aim is to find a V_H and a u_H in V_H satisfying the discrete problem such that 

::
   
   \\|M(u) - M(u_H)\\| < tol
   
This strategy is based on dual-weighted residual error estimators designed and automatically generated for the primal problem and subsequent h-adaptivity.
";

%feature("docstring") dolfin::AdaptiveNonlinearVariationalSolver::AdaptiveNonlinearVariationalSolver(std::shared_ptr< NonlinearVariationalProblem > problem, std::shared_ptr< Form > goal, std::shared_ptr< ErrorControl > control) "
Create :cpp:any:`AdaptiveLinearVariationalSolver`  from variational problem, goal form and error control instance
Arguments problem (:cpp:any:`NonlinearVariationalProblem` ) The primal problem goal (:cpp:any:`Form` ) The goal functional control (:cpp:any:`ErrorControl` ) An error controller object 

:param std\\:\\:shared_ptr< NonlinearVariationalProblem > problem: 
:param std\\:\\:shared_ptr< Form > goal: 
:param std\\:\\:shared_ptr< ErrorControl > control:
";

%feature("docstring") dolfin::AdaptiveNonlinearVariationalSolver::AdaptiveNonlinearVariationalSolver(std::shared_ptr< NonlinearVariationalProblem > problem, std::shared_ptr< GoalFunctional > goal) "
Create :cpp:any:`AdaptiveNonlinearVariationalSolver`  (shared ptr version)
Arguments problem (:cpp:any:`NonlinearVariationalProblem` ) The primal problem goal (:cpp:any:`GoalFunctional` ) The goal functional 

:param std\\:\\:shared_ptr< NonlinearVariationalProblem > problem: 
:param std\\:\\:shared_ptr< GoalFunctional > goal:
";

%feature("docstring") dolfin::AdaptiveNonlinearVariationalSolver::adapt_problem(std::shared_ptr< const Mesh > mesh) "
Adapt the problem to other mesh.
Arguments mesh (:cpp:any:`Mesh` ) The other mesh 

:param std\\:\\:shared_ptr< const Mesh > mesh: 
:rtype: void
";

%feature("docstring") dolfin::AdaptiveNonlinearVariationalSolver::evaluate_goal(Form &M, std::shared_ptr< const Function > u) const "
Evaluate the goal functional.
Arguments M (:cpp:any:`Form` ) The functional to be evaluated u (:cpp:any:`Function` ) The function at which to evaluate the functional
Returns double The value of M evaluated at u 

:param Form & M: 
:param std\\:\\:shared_ptr< const Function > u: 
:rtype: double
";

%feature("docstring") dolfin::AdaptiveNonlinearVariationalSolver::extract_bcs() const "
Extract the boundary conditions for the primal problem.
Returns std::vector<:cpp:any:`DirichletBC` > The primal boundary conditions 

:rtype: std::vector< std::shared_ptr< const DirichletBC > >
";

%feature("docstring") dolfin::AdaptiveNonlinearVariationalSolver::init(std::shared_ptr< NonlinearVariationalProblem > problem, std::shared_ptr< GoalFunctional > goal) "
Helper function for instance initialization
Arguments problem (:cpp:any:`NonlinearVariationalProblem` ) The primal problem u (:cpp:any:`GoalFunctional` ) The goal functional 

:param std\\:\\:shared_ptr< NonlinearVariationalProblem > problem: 
:param std\\:\\:shared_ptr< GoalFunctional > goal: 
:rtype: void
";

%feature("docstring") dolfin::AdaptiveNonlinearVariationalSolver::num_dofs_primal() "
Return the number of degrees of freedom for primal problem
Returnsstd::size_t The number of degrees of freedom 

:rtype: std::size_t
";

%feature("docstring") dolfin::AdaptiveNonlinearVariationalSolver::solve_primal() "
Solve the primal problem.
Returns:cpp:any:`Function`  The solution to the primal problem 

:rtype: std::shared_ptr< const Function >
";

%feature("docstring") dolfin::AdaptiveNonlinearVariationalSolver::~AdaptiveNonlinearVariationalSolver() "
Destructor.
";

%feature("docstring") dolfin::ErrorControl "
(Goal-oriented) Error Control class. 
The notation used here follows the notation in \"Automated
goal-oriented error control I: stationary variational problems\", ME Rognes and A Logg, 2010-2011. 

Friends: :cpp:any:`adapt`.
";

%feature("docstring") dolfin::ErrorControl::ErrorControl(std::shared_ptr< Form > a_star, std::shared_ptr< Form > L_star, std::shared_ptr< Form > residual, std::shared_ptr< Form > a_R_T, std::shared_ptr< Form > L_R_T, std::shared_ptr< Form > a_R_dT, std::shared_ptr< Form > L_R_dT, std::shared_ptr< Form > eta_T, bool is_linear) "
Create error control object

:param std\\:\\:shared_ptr< Form > a_star:  (:cpp:any:`Form` ) the bilinear form for the dual problem
:param std\\:\\:shared_ptr< Form > L_star:  (:cpp:any:`Form` ) the linear form for the dual problem
:param std\\:\\:shared_ptr< Form > residual:  (:cpp:any:`Form` ) a functional for the residual (error estimate)
:param std\\:\\:shared_ptr< Form > a_R_T:  (:cpp:any:`Form` ) the bilinear form for the strong cell residual problem
:param std\\:\\:shared_ptr< Form > L_R_T:  (:cpp:any:`Form` ) the linear form for the strong cell residual problem
:param std\\:\\:shared_ptr< Form > a_R_dT:  (:cpp:any:`Form` ) the bilinear form for the strong facet residual problem
:param std\\:\\:shared_ptr< Form > L_R_dT:  (:cpp:any:`Form` ) the linear form for the strong facet residual problem
:param std\\:\\:shared_ptr< Form > eta_T:  (:cpp:any:`Form` ) a linear form over DG_0 for error indicators
:param bool is_linear:  (bool) true iff primal problem is linear
";

%feature("docstring") dolfin::ErrorControl::apply_bcs_to_extrapolation(const std::vector< std::shared_ptr< const DirichletBC > > bcs) "
:param const std\\:\\:vector< std\\:\\:shared_ptr< const DirichletBC > > bcs: 
:rtype: void
";

%feature("docstring") dolfin::ErrorControl::compute_cell_residual(Function &R_T, const Function &u) "
Compute representation for the strong cell residual from the weak residual

:param Function & R_T:  (:cpp:any:`Function` ) the strong cell residual (to be computed)
:param const Function & u:  (:cpp:any:`Function` ) the primal approximation
:rtype: void
";

%feature("docstring") dolfin::ErrorControl::compute_dual(Function &z, const std::vector< std::shared_ptr< const DirichletBC > > bcs) "
Compute dual approximation defined by dual variational problem and dual boundary conditions given by homogenized primal boundary conditions.

:param Function & z:  (:cpp:any:`Function` ) the dual approximation (to be computed)
:param const std\\:\\:vector< std\\:\\:shared_ptr< const DirichletBC > > bcs:  (std::vector<DirichletBC>) the primal boundary conditions
:rtype: void
";

%feature("docstring") dolfin::ErrorControl::compute_extrapolation(const Function &z, const std::vector< std::shared_ptr< const DirichletBC > > bcs) "
Compute extrapolation with boundary conditions

:param const Function & z:  (:cpp:any:`Function` ) the extrapolated function (to be computed)
:param const std\\:\\:vector< std\\:\\:shared_ptr< const DirichletBC > > bcs:  (std::vector<:cpp:any:`DirichletBC` >) the dual boundary conditions
:rtype: void
";

%feature("docstring") dolfin::ErrorControl::compute_facet_residual(SpecialFacetFunction &R_dT, const Function &u, const Function &R_T) "
Compute representation for the strong facet residual from the weak residual and the strong cell residual

:param SpecialFacetFunction & R_dT:  (:cpp:any:`SpecialFacetFunction` ) the strong facet residual (to be computed)
:param const Function & u:  (:cpp:any:`Function` ) the primal approximation
:param const Function & R_T:  (:cpp:any:`Function` ) the strong cell residual
:rtype: void
";

%feature("docstring") dolfin::ErrorControl::compute_indicators(MeshFunction< double > &indicators, const Function &u) "
Compute error indicators

:param MeshFunction< double > & indicators:  (MeshFunction<double>) the error indicators (to be computed)
:param const Function & u:  (:cpp:any:`Function` ) the primal approximation
:rtype: void
";

%feature("docstring") dolfin::ErrorControl::estimate_error(const Function &u, const std::vector< std::shared_ptr< const DirichletBC > > bcs) "
Estimate the error relative to the goal M of the discrete approximation 'u' relative to the variational formulation by evaluating the weak residual at an approximation to the dual solution.

:param const Function & u:  (:cpp:any:`Function` ) the primal approximation
:param const std\\:\\:vector< std\\:\\:shared_ptr< const DirichletBC > > bcs:  (std::vector<:cpp:any:`DirichletBC` >) the primal boundary conditions
:rtype: double
:returns: double error estimate
";

%feature("docstring") dolfin::ErrorControl::residual_representation(Function &R_T, SpecialFacetFunction &R_dT, const Function &u) "
Compute strong representation (strong cell and facet residuals) of the weak residual.

:param Function & R_T:  (:cpp:any:`Function` ) the strong cell residual (to be computed)
:param SpecialFacetFunction & R_dT:  (:cpp:any:`SpecialFacetFunction` ) the strong facet residual (to be computed)
:param const Function & u:  (:cpp:any:`Function` ) the primal approximation
:rtype: void
";

%feature("docstring") dolfin::ErrorControl::~ErrorControl() "
Destructor.
";

%feature("docstring") dolfin::Extrapolation "
This class implements an algorithm for extrapolating a function on a given function space from an approximation of that function on a possibly lower-order function space.
This can be used to obtain a higher-order approximation of a computed dual solution, which is necessary when the computed dual approximation is in the test space of the primal problem, thereby being orthogonal to the residual.
It is assumed that the extrapolation is computed on the same mesh as the original function.
";

%feature("docstring") dolfin::Extrapolation::add_cell_equations(Eigen::MatrixXd &A, Eigen::VectorXd &b, const Cell &cell0, const Cell &cell1, const std::vector< double > &coordinate_dofs0, const std::vector< double > &coordinate_dofs1, const ufc::cell &c0, const ufc::cell &c1, const FunctionSpace &V, const FunctionSpace &W, const Function &v, std::map< std::size_t, std::size_t > &dof2row) "
:param Eigen\\:\\:MatrixXd & A: 
:param Eigen\\:\\:VectorXd & b: 
:param const Cell & cell0: 
:param const Cell & cell1: 
:param const std\\:\\:vector< double > & coordinate_dofs0: 
:param const std\\:\\:vector< double > & coordinate_dofs1: 
:param const ufc\\:\\:cell & c0: 
:param const ufc\\:\\:cell & c1: 
:param const FunctionSpace & V: 
:param const FunctionSpace & W: 
:param const Function & v: 
:param std\\:\\:map< std\\:\\:size_t, std\\:\\:size_t > & dof2row: 
:rtype: void
";

%feature("docstring") dolfin::Extrapolation::average_coefficients(Function &w, std::vector< std::vector< double > > &coefficients) "
:param Function & w: 
:param std\\:\\:vector< std\\:\\:vector< double > > & coefficients: 
:rtype: void
";

%feature("docstring") dolfin::Extrapolation::build_unique_dofs(std::set< std::size_t > &unique_dofs, std::map< std::size_t, std::map< std::size_t, std::size_t > > &cell2dof2row, const Cell &cell0, const FunctionSpace &V) "
:param std\\:\\:set< std\\:\\:size_t > & unique_dofs: 
:param std\\:\\:map< std\\:\\:size_t, std\\:\\:map< std\\:\\:size_t, std\\:\\:size_t > > & cell2dof2row: 
:param const Cell & cell0: 
:param const FunctionSpace & V: 
:rtype: void
";

%feature("docstring") dolfin::Extrapolation::compute_coefficients(std::vector< std::vector< double > > &coefficients, const Function &v, const FunctionSpace &V, const FunctionSpace &W, const Cell &cell0, const std::vector< double > &coordinate_dofs0, const ufc::cell &c0, const ArrayView< const dolfin::la_index > &dofs, std::size_t &offset) "
:param std\\:\\:vector< std\\:\\:vector< double > > & coefficients: 
:param const Function & v: 
:param const FunctionSpace & V: 
:param const FunctionSpace & W: 
:param const Cell & cell0: 
:param const std\\:\\:vector< double > & coordinate_dofs0: 
:param const ufc\\:\\:cell & c0: 
:param const ArrayView< const dolfin\\:\\:la_index > & dofs: 
:param std\\:\\:size_t & offset: 
:rtype: void
";

%feature("docstring") dolfin::Extrapolation::compute_unique_dofs(const Cell &cell, const FunctionSpace &V, std::size_t &row, std::set< std::size_t > &unique_dofs) "
:param const Cell & cell: 
:param const FunctionSpace & V: 
:param std\\:\\:size_t & row: 
:param std\\:\\:set< std\\:\\:size_t > & unique_dofs: 
:rtype: std::map< std::size_t, std::size_t >
";

%feature("docstring") dolfin::Extrapolation::extrapolate(Function &w, const Function &v) "
Compute extrapolation w from v. 

:param Function & w: 
:param const Function & v: 
:rtype: void
";

%feature("docstring") dolfin::GenericAdaptiveVariationalSolver "
An abstract class for goal-oriented adaptive solution of variational problems.
";

%feature("docstring") dolfin::GenericAdaptiveVariationalSolver::adapt_problem(std::shared_ptr< const Mesh > mesh) "
Adapt the problem to other mesh. Must be overloaded in subclass.
Arguments mesh (:cpp:any:`Mesh` ) The other mesh 

:param std\\:\\:shared_ptr< const Mesh > mesh: 
:rtype: void
";

%feature("docstring") dolfin::GenericAdaptiveVariationalSolver::adaptive_data() const "
Return stored adaptive data
Returns std::vector<:cpp:any:`Parameters` > The data stored in the adaptive loop 

:rtype: std::vector< std::shared_ptr< Parameters > >
";

%feature("docstring") dolfin::GenericAdaptiveVariationalSolver::control "
Error control object. 

:rtype: std::shared_ptr< ErrorControl >
";

%feature("docstring") dolfin::GenericAdaptiveVariationalSolver::evaluate_goal(Form &M, std::shared_ptr< const Function > u) const  "
Evaluate the goal functional. Must be overloaded in subclass.
Arguments M (:cpp:any:`Form` ) The functional to be evaluated u (:cpp:any:`Function` ) The function of which to evaluate the functional
Returns double The value of M evaluated at u 

:param Form & M: 
:param std\\:\\:shared_ptr< const Function > u: 
:rtype: double
";

%feature("docstring") dolfin::GenericAdaptiveVariationalSolver::extract_bcs() const  "
Extract the boundary conditions for the primal problem. Must be overloaded in subclass.
Returns std::vector<:cpp:any:`DirichletBC` > The primal boundary conditions 

:rtype: std::vector< std::shared_ptr< const DirichletBC > >
";

%feature("docstring") dolfin::GenericAdaptiveVariationalSolver::goal "
The goal functional. 

:rtype: std::shared_ptr< Form >
";

%feature("docstring") dolfin::GenericAdaptiveVariationalSolver::num_dofs_primal() "
Return the number of degrees of freedom for primal problem
Returnsstd::size_t The number of degrees of freedom 

:rtype: std::size_t
";

%feature("docstring") dolfin::GenericAdaptiveVariationalSolver::solve(const double tol) "
Solve such that the functional error is less than the given tolerance. Note that each call to solve is based on the leaf-node of the variational problem
Arguments tol (double) The error tolerance 

:param const double tol: 
:rtype: void
";

%feature("docstring") dolfin::GenericAdaptiveVariationalSolver::solve_primal() "
Solve the primal problem. Must be overloaded in subclass.
Returns:cpp:any:`Function`  The solution to the primal problem 

:rtype: std::shared_ptr< const Function >
";

%feature("docstring") dolfin::GenericAdaptiveVariationalSolver::summary() "
Present summary of all adaptive data and parameters. 

:rtype: void
";

%feature("docstring") dolfin::GenericAdaptiveVariationalSolver::~GenericAdaptiveVariationalSolver() "

";

%feature("docstring") dolfin::GoalFunctional "
A :cpp:any:`GoalFunctional`  is a :cpp:any:`Form`  of rank 0 with an associated :cpp:any:`ErrorControl` .
";

%feature("docstring") dolfin::GoalFunctional::GoalFunctional(std::size_t rank, std::size_t num_coefficients) "
Create :cpp:any:`GoalFunctional` 
Arguments rank (int) the rank of the functional (should be 0) num_coefficients (int) the number of coefficients in functional 

:param std\\:\\:size_t rank: 
:param std\\:\\:size_t num_coefficients:
";

%feature("docstring") dolfin::GoalFunctional::update_ec(const Form &a, const Form &L) "
Update error control instance with given forms
Arguments a (:cpp:any:`Form` ) a bilinear form L (:cpp:any:`Form` ) a linear form 

:param const Form & a: 
:param const Form & L: 
:rtype: void
";

%feature("docstring") dolfin::MeshFunction "
A :cpp:any:`MeshFunction`  is a function that can be evaluated at a set of mesh entities. A :cpp:any:`MeshFunction`  is discrete and is only defined at the set of mesh entities of a fixed topological dimension. A :cpp:any:`MeshFunction`  may for example be used to store a global numbering scheme for the entities of a (parallel) mesh, marking sub domains or boolean markers for mesh refinement.
";

%feature("docstring") dolfin::MeshFunction::MeshFunction() "
Create empty mesh function.
";

%feature("docstring") dolfin::MeshFunction::MeshFunction(const MeshFunction< T > &f) "
Copy constructor

:param const MeshFunction< T > & f:  (:cpp:any:`MeshFunction` ) The object to be copied.
";

%feature("docstring") dolfin::MeshFunction::MeshFunction(std::shared_ptr< const Mesh > mesh) "
Create empty mesh function on given mesh

:param std\\:\\:shared_ptr< const Mesh > mesh:  (:cpp:any:`Mesh` ) The mesh to create mesh function on.
";

%feature("docstring") dolfin::MeshFunction::MeshFunction(std::shared_ptr< const Mesh > mesh, const MeshValueCollection< T > &value_collection) "
Create function from a MeshValueCollecion (shared_ptr version)

:param std\\:\\:shared_ptr< const Mesh > mesh:  (:cpp:any:`Mesh` ) The mesh to create mesh function on.
:param const MeshValueCollection< T > & value_collection:  (:cpp:any:`MeshValueCollection` ) The mesh value collection for the mesh function data.
";

%feature("docstring") dolfin::MeshFunction::MeshFunction(std::shared_ptr< const Mesh > mesh, const std::string filename) "
Create function from data file (shared_ptr version)

:param std\\:\\:shared_ptr< const Mesh > mesh:  (:cpp:any:`Mesh` ) The mesh to create mesh function on.
:param const std\\:\\:string filename:  (std::string) The filename to create mesh function from.
";

%feature("docstring") dolfin::MeshFunction::MeshFunction(std::shared_ptr< const Mesh > mesh, std::size_t dim) "
Create mesh function of given dimension on given mesh

:param std\\:\\:shared_ptr< const Mesh > mesh:  (:cpp:any:`Mesh` ) The mesh to create mesh function on.
:param std\\:\\:size_t dim:  (std::size_t) The mesh entity dimension for the mesh function.
";

%feature("docstring") dolfin::MeshFunction::MeshFunction(std::shared_ptr< const Mesh > mesh, std::size_t dim, const MeshDomains &domains) "
Create function from :cpp:any:`MeshDomains` 

:param std\\:\\:shared_ptr< const Mesh > mesh:  (:cpp:any:`Mesh` ) The mesh to create mesh function on.
:param std\\:\\:size_t dim:  (std::size_t) The dimension of the :cpp:any:`MeshFunction`
:param const MeshDomains & domains:  (_MeshDomains) The domains from which to extract the domain markers
";

%feature("docstring") dolfin::MeshFunction::MeshFunction(std::shared_ptr< const Mesh > mesh, std::size_t dim, const T &value) "
Create mesh of given dimension on given mesh and initialize to a value

:param std\\:\\:shared_ptr< const Mesh > mesh:  (:cpp:any:`Mesh` ) The mesh to create mesh function on.
:param std\\:\\:size_t dim:  (std::size_t) The mesh entity dimension.
:param const T & value:  (T) The value.
";

%feature("docstring") dolfin::MeshFunction::dim() const "
Return topological dimension

:rtype: std::size_t
:returns: std::size_t The dimension.
";

%feature("docstring") dolfin::MeshFunction::empty() const "
Return true if empty

:rtype: bool
:returns: bool True if empty.
";

%feature("docstring") dolfin::MeshFunction::init(std::shared_ptr< const Mesh > mesh, std::size_t dim) "
Initialize mesh function for given topological dimension

:param std\\:\\:shared_ptr< const Mesh > mesh:  (:cpp:any:`Mesh` ) The mesh.
:param std\\:\\:size_t dim:  (std::size_t) The dimension.
:rtype: void
";

%feature("docstring") dolfin::MeshFunction::init(std::shared_ptr< const Mesh > mesh, std::size_t dim, std::size_t size) "
Initialize mesh function for given topological dimension of given size (shared_ptr version)

:param std\\:\\:shared_ptr< const Mesh > mesh:  (:cpp:any:`Mesh` ) The mesh.
:param std\\:\\:size_t dim:  (std::size_t) The dimension.
:param std\\:\\:size_t size:  (std::size_t) The size.
:rtype: void
";

%feature("docstring") dolfin::MeshFunction::init(std::size_t dim) "
Initialize mesh function for given topological dimension

:param std\\:\\:size_t dim:  (std::size_t) The dimension.
:rtype: void
";

%feature("docstring") dolfin::MeshFunction::init(std::size_t dim, std::size_t size) "
Initialize mesh function for given topological dimension of given size

:param std\\:\\:size_t dim:  (std::size_t) The dimension.
:param std\\:\\:size_t size:  (std::size_t) The size.
:rtype: void
";

%feature("docstring") dolfin::MeshFunction::mesh() const "
Return mesh associated with mesh function

:rtype: std::shared_ptr< const Mesh >
:returns: :cpp:any:`Mesh`  The mesh.
";

%feature("docstring") dolfin::MeshFunction::operator=(const MeshFunction< T > &f) "
Assign mesh function to other mesh function Assignment operator

:param const MeshFunction< T > & f:  (:cpp:any:`MeshFunction` ) A :cpp:any:`MeshFunction`  object to assign to another :cpp:any:`MeshFunction` .
:rtype: MeshFunction< T > &
";

%feature("docstring") dolfin::MeshFunction::operator=(const MeshValueCollection< T > &mesh) "
Assignment operator

:param const MeshValueCollection< T > & mesh:  (:cpp:any:`MeshValueCollection` ) A :cpp:any:`MeshValueCollection`  object used to construct a :cpp:any:`MeshFunction` .
:rtype: MeshFunction< T > &
";

%feature("docstring") dolfin::MeshFunction::operator=(const T &value) "
:cpp:any:`Set`  all values to given value 

:param const T & value:  (T)
:rtype: const MeshFunction< T > &
";

%feature("docstring") dolfin::MeshFunction::operator[](const MeshEntity &entity) "
Return value at given mesh entity

return T The value at the given entity. 

:param const MeshEntity & entity:  (:cpp:any:`MeshEntity` ) The mesh entity.
:rtype: T &
";

%feature("docstring") dolfin::MeshFunction::operator[](const MeshEntity &entity) const "
Return value at given mesh entity (const version)

:param const MeshEntity & entity:  (:cpp:any:`MeshEntity` ) The mesh entity.
:rtype: const T &
:returns: T The value at the given entity.
";

%feature("docstring") dolfin::MeshFunction::operator[](std::size_t index) "
Return value at given index

:param std\\:\\:size_t index:  (std::size_t) The index.
:rtype: T &
:returns: T The value at the given index.
";

%feature("docstring") dolfin::MeshFunction::operator[](std::size_t index) const "
Return value at given index (const version)

:param std\\:\\:size_t index:  (std::size_t) The index.
:rtype: const T &
:returns: T The value at the given index.
";

%feature("docstring") dolfin::MeshFunction::set_all(const T &value) "
:cpp:any:`Set`  all values to given value

:param const T & value:  (T) The value to set all values to.
:rtype: void
";

%feature("docstring") dolfin::MeshFunction::set_value(std::size_t index, const T &value) "
:cpp:any:`Set`  value at given index

:param std\\:\\:size_t index:  (std::size_t) The index.
:param const T & value:  (T) The value.
:rtype: void
";

%feature("docstring") dolfin::MeshFunction::set_value(std::size_t index, const T &value, const Mesh &mesh) "
Compatibility function for use in SubDomains. 

:param std\\:\\:size_t index: 
:param const T & value: 
:param const Mesh & mesh: 
:rtype: void
";

%feature("docstring") dolfin::MeshFunction::set_values(const std::vector< T > &values) "
:cpp:any:`Set`  values

:param const std\\:\\:vector< T > & values:  (std::vector<T>) The values.
:rtype: void
";

%feature("docstring") dolfin::MeshFunction::size() const "
Return size (number of entities)

:rtype: std::size_t
:returns: std::size_t The size.
";

%feature("docstring") dolfin::MeshFunction::str(bool verbose) const "
Return informal string representation (pretty-print) 

:param bool verbose: 
:rtype: std::string
";

%feature("docstring") dolfin::MeshFunction::values() "
Return array of values
return T The values. 

:rtype: T *
";

%feature("docstring") dolfin::MeshFunction::values() const "
Return array of values (const. version)
return T The values. 

:rtype: const T *
";

%feature("docstring") dolfin::MeshFunction::where_equal(T value) "
Get indices where meshfunction is equal to given value
Arguments value (T) The value. Returns std::vector<T> The indices. 

:param T value: 
:rtype: std::vector< std::size_t >
";

%feature("docstring") dolfin::MeshFunction::~MeshFunction() "
Destructor.
";

%feature("docstring") dolfin::adapt(const DirichletBC &bc, std::shared_ptr< const Mesh > adapted_mesh, const FunctionSpace &S) "
Refine Dirichlet bc based on refined mesh. 

:param const DirichletBC & bc: 
:param std\\:\\:shared_ptr< const Mesh > adapted_mesh: 
:param const FunctionSpace & S: 
:rtype: std::shared_ptr< DirichletBC >
";

%feature("docstring") dolfin::adapt(const ErrorControl &ec, std::shared_ptr< const Mesh > adapted_mesh, bool adapt_coefficients=true) "
Adapt error control object based on adapted mesh

:param const ErrorControl & ec:  (:cpp:any:`ErrorControl` ) The error control object to be adapted
:param std\\:\\:shared_ptr< const Mesh > adapted_mesh:  (:cpp:any:`Mesh` ) The new mesh
:param bool adapt_coefficients:  (bool) Optional argument, default is true. If false, any form coefficients are not explicitly adapted, but pre-adapted coefficients will be transferred.
:rtype: std::shared_ptr< ErrorControl >
:returns: :cpp:any:`ErrorControl`  The adapted error control object
";

%feature("docstring") dolfin::adapt(const Form &form, std::shared_ptr< const Mesh > adapted_mesh, bool adapt_coefficients=true) "
Adapt form based on adapted mesh

:param const Form & form:  (:cpp:any:`Form` ) The form that should be adapted [direction=in]
:param std\\:\\:shared_ptr< const Mesh > adapted_mesh:  (:cpp:any:`Mesh` ) The new mesh [direction=in]
:param bool adapt_coefficients:  (bool) Optional argument, default is true. If false, the form coefficients are not explicitly adapted, but pre-adapted coefficients will be transferred. [direction=in]
:rtype: std::shared_ptr< Form >
:returns: :cpp:any:`Form`  The adapted form
";

%feature("docstring") dolfin::adapt(const Function &function, std::shared_ptr< const Mesh > adapted_mesh, bool interpolate=true) "
Adapt :cpp:any:`Function`  based on adapted mesh

:param const Function & function:  (:cpp:any:`Function` &) The function that should be adapted [direction=in]
:param std\\:\\:shared_ptr< const Mesh > adapted_mesh:  (std::shared_ptr<const Mesh>) The new mesh [direction=in]
:param bool interpolate:  (bool) Optional argument, default is true. If false, the function's function space is adapted, but the values are not interpolated. [direction=in]
:rtype: std::shared_ptr< Function >
:returns: :cpp:any:`Function`  The adapted function
";

%feature("docstring") dolfin::adapt(const FunctionSpace &space) "
Refine function space uniformly 

:param const FunctionSpace & space:  (:cpp:any:`FunctionSpace` ) [direction=in]
:rtype: std::shared_ptr< FunctionSpace >
:returns: :cpp:any:`FunctionSpace`
";

%feature("docstring") dolfin::adapt(const FunctionSpace &space, const MeshFunction< bool > &cell_markers) "
Refine function space based on cell markers 

:param const FunctionSpace & space:  (:cpp:any:`FunctionSpace` &) [direction=in]
:param const MeshFunction< bool > & cell_markers:  (MehsFunction<bool>&) [direction=in]
:rtype: std::shared_ptr< FunctionSpace >
:returns: :cpp:any:`FunctionSpace`
";

%feature("docstring") dolfin::adapt(const FunctionSpace &space, std::shared_ptr< const Mesh > adapted_mesh) "
Refine function space based on refined mesh 

:param const FunctionSpace & space:  (:cpp:any:`FunctionSpace` &) [direction=in]
:param std\\:\\:shared_ptr< const Mesh > adapted_mesh:  (std::sahred_ptr<const Mesh>) [direction=in]
:rtype: std::shared_ptr< FunctionSpace >
:returns: :cpp:any:`FunctionSpace`
";

%feature("docstring") dolfin::adapt(const LinearVariationalProblem &problem, std::shared_ptr< const Mesh > adapted_mesh) "
Refine linear variational problem based on mesh. 

:param const LinearVariationalProblem & problem: 
:param std\\:\\:shared_ptr< const Mesh > adapted_mesh: 
:rtype: std::shared_ptr< LinearVariationalProblem >
";

%feature("docstring") dolfin::adapt(const Mesh &mesh) "
Refine mesh uniformly 

:param const Mesh & mesh:  (:cpp:any:`Mesh` ) Input mesh [direction=in]
:rtype: std::shared_ptr< Mesh >
:returns: std::shared_ptr<Mesh> adapted mesh
";

%feature("docstring") dolfin::adapt(const Mesh &mesh, const MeshFunction< bool > &cell_markers) "
Refine mesh based on cell markers 

:param const Mesh & mesh:  (:cpp:any:`Mesh` ) Input mesh [direction=in]
:param const MeshFunction< bool > & cell_markers:  (MeshFunction<bool>) Markers denoting cells to be refined [direction=in]
:rtype: std::shared_ptr< Mesh >
";

%feature("docstring") dolfin::adapt(const MeshFunction< std::size_t > &mesh_function, std::shared_ptr< const Mesh > adapted_mesh) "
Refine mesh function<std::size_t> based on mesh. 

:param const MeshFunction< std\\:\\:size_t > & mesh_function: 
:param std\\:\\:shared_ptr< const Mesh > adapted_mesh: 
:rtype: std::shared_ptr< MeshFunction< std::size_t > >
";

%feature("docstring") dolfin::adapt(const NonlinearVariationalProblem &problem, std::shared_ptr< const Mesh > adapted_mesh) "
Refine nonlinear variational problem based on mesh. 

:param const NonlinearVariationalProblem & problem: 
:param std\\:\\:shared_ptr< const Mesh > adapted_mesh: 
:rtype: std::shared_ptr< NonlinearVariationalProblem >
";

%feature("docstring") dolfin::adapt(std::shared_ptr< const GenericFunction > function, std::shared_ptr< const Mesh > adapted_mesh) "
Refine :cpp:any:`GenericFunction`  based on refined mesh

:param std\\:\\:shared_ptr< const GenericFunction > function:  (GeericFunction) The function that should be adapted [direction=in]
:param std\\:\\:shared_ptr< const Mesh > adapted_mesh:  (Mehs) The new mesh [direction=in]
:rtype: std::shared_ptr< GenericFunction >
:returns: :cpp:any:`GenericFunction`  The adapted function
";

%feature("docstring") dolfin::adapt_markers(std::vector< std::size_t > &refined_markers, const Mesh &adapted_mesh, const std::vector< std::size_t > &markers, const Mesh &mesh) "
Helper function for refinement of boundary conditions. 

:param std\\:\\:vector< std\\:\\:size_t > & refined_markers: 
:param const Mesh & adapted_mesh: 
:param const std\\:\\:vector< std\\:\\:size_t > & markers: 
:param const Mesh & mesh: 
:rtype: void
";

%feature("docstring") dolfin::dorfler_mark(MeshFunction< bool > &markers, const dolfin::MeshFunction< double > &indicators, const double fraction) "
Mark cells using Dorfler marking

:param MeshFunction< bool > & markers:  (MeshFunction<bool>) the cell markers (to be computed)
:param const dolfin\\:\\:MeshFunction< double > & indicators:  (MeshFunction<double>) error indicators (one per cell)
:param const double fraction:  (double) the marking fraction
:rtype: void
";

%feature("docstring") dolfin::mark(MeshFunction< bool > &markers, const dolfin::MeshFunction< double > &indicators, const std::string strategy, const double fraction) "
Mark cells based on indicators and given marking strategy

:param MeshFunction< bool > & markers:  (MeshFunction<bool>) the cell markers (to be computed)
:param const dolfin\\:\\:MeshFunction< double > & indicators:  (MeshFunction<double>) error indicators (one per cell)
:param const std\\:\\:string strategy:  (std::string) the marking strategy
:param const double fraction:  (double) the marking fraction
:rtype: void
";

%feature("docstring") dolfin::solve(const Equation &equation, Function &u, const DirichletBC &bc, const Form &J, const double tol, GoalFunctional &M) "
Solve linear variational problem F(u; v) = 0 with single boundary condition 

:param const Equation & equation: 
:param Function & u: 
:param const DirichletBC & bc: 
:param const Form & J: 
:param const double tol: 
:param GoalFunctional & M: 
:rtype: void
";

%feature("docstring") dolfin::solve(const Equation &equation, Function &u, const DirichletBC &bc, const double tol, GoalFunctional &M) "
Solve linear variational problem a(u, v) == L(v) with single boundary condition 

:param const Equation & equation: 
:param Function & u: 
:param const DirichletBC & bc: 
:param const double tol: 
:param GoalFunctional & M: 
:rtype: void
";

%feature("docstring") dolfin::solve(const Equation &equation, Function &u, const Form &J, const double tol, GoalFunctional &M) "
Solve nonlinear variational problem F(u; v) = 0 without essential boundary conditions 

:param const Equation & equation: 
:param Function & u: 
:param const Form & J: 
:param const double tol: 
:param GoalFunctional & M: 
:rtype: void
";

%feature("docstring") dolfin::solve(const Equation &equation, Function &u, const double tol, GoalFunctional &M) "
Solve linear variational problem a(u, v) == L(v) without essential boundary conditions 

:param const Equation & equation: 
:param Function & u: 
:param const double tol: 
:param GoalFunctional & M: 
:rtype: void
";

%feature("docstring") dolfin::solve(const Equation &equation, Function &u, std::vector< const DirichletBC *> bcs, const Form &J, const double tol, GoalFunctional &M) "
Solve linear variational problem F(u; v) = 0 with list of boundary conditions 

:param const Equation & equation: 
:param Function & u: 
:param std\\:\\:vector< const DirichletBC *> bcs: 
:param const Form & J: 
:param const double tol: 
:param GoalFunctional & M: 
:rtype: void
";

%feature("docstring") dolfin::solve(const Equation &equation, Function &u, std::vector< const DirichletBC *> bcs, const double tol, GoalFunctional &M) "
Solve linear variational problem a(u, v) == L(v) with list of boundary conditions 

:param const Equation & equation: 
:param Function & u: 
:param std\\:\\:vector< const DirichletBC *> bcs: 
:param const double tol: 
:param GoalFunctional & M: 
:rtype: void
";

