// Auto generated SWIG file for Python interface of DOLFIN
//
// Copyright (C) 2012-2016 Kristian B. Oelgaard, Tormod Landet
//
// This file is part of DOLFIN.
//
// DOLFIN is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// DOLFIN is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
//

// SWIG docstrings generated by doxygen and generate_api_rst.py / parse_doxygen.py

%feature("docstring") dolfin::ALE "
This class provides functionality useful for implementation of :cpp:any:`ALE`  (Arbitrary Lagrangian-Eulerian) methods, in particular moving the boundary vertices of a mesh and then interpolating the new coordinates for the interior vertices accordingly.
";

%feature("docstring") dolfin::ALE::move(Mesh &mesh, const Function &displacement) "
Move coordinates of mesh according to displacement function.

:param Mesh & mesh:  (:cpp:any:`Mesh` ) The mesh to move.
:param const Function & displacement:  (:cpp:any:`Function` ) A vectorial :cpp:any:`Lagrange`  function of matching degree.
:rtype: void
";

%feature("docstring") dolfin::ALE::move(Mesh &mesh, const GenericFunction &displacement) "
Move coordinates of mesh according to displacement function. This works only for affine meshes.
NOTE: This cannot be implemented for higher-order geometries as there is no way of constructing function space for position unless supplied as an argument.

:param Mesh & mesh:  (:cpp:any:`Mesh` ) The affine mesh to move.
:param const GenericFunction & displacement:  (:cpp:any:`GenericFunction` ) A vectorial generic function.
:rtype: void
";

%feature("docstring") dolfin::ALE::move(std::shared_ptr< Mesh > mesh, const BoundaryMesh &new_boundary) "
Move coordinates of mesh according to new boundary coordinates. Works only for affine meshes.

:param std\\:\\:shared_ptr< Mesh > mesh:  (:cpp:any:`Mesh` ) The affine mesh to move.
:param const BoundaryMesh & new_boundary:  (:cpp:any:`BoundaryMesh` ) An affine mesh containing just the boundary cells.
:rtype: std::shared_ptr< MeshDisplacement >
:returns: :cpp:any:`MeshDisplacement`  Displacement encapsulated in :cpp:any:`Expression`  subclass :cpp:any:`MeshDisplacement` .
";

%feature("docstring") dolfin::ALE::move(std::shared_ptr< Mesh > mesh0, const Mesh &mesh1) "
Move coordinates of mesh according to adjacent mesh with common global vertices. Works only for affine meshes. 

:param std\\:\\:shared_ptr< Mesh > mesh0:  (:cpp:any:`Mesh` ) The affine mesh to move.
:param const Mesh & mesh1:  (:cpp:any:`Mesh` ) The affine mesh to be fit.
:rtype: std::shared_ptr< MeshDisplacement >
:returns: :cpp:any:`MeshDisplacement`  Displacement encapsulated in :cpp:any:`Expression`  subclass
";

%feature("docstring") dolfin::HarmonicSmoothing "
This class implements harmonic mesh smoothing. Poisson's equation is solved with zero right-hand side (Laplace's equation) for each coordinate direction to compute new coordinates for all vertices, given new locations for the coordinates of the boundary.
";

%feature("docstring") dolfin::HarmonicSmoothing::move(std::shared_ptr< Mesh > mesh, const BoundaryMesh &new_boundary) "
Move coordinates of mesh according to new boundary coordinates and return the displacement

:param std\\:\\:shared_ptr< Mesh > mesh:  (:cpp:any:`Mesh` ) :cpp:any:`Mesh`
:param const BoundaryMesh & new_boundary:  (:cpp:any:`BoundaryMesh` ) Boundary mesh
:rtype: std::shared_ptr< MeshDisplacement >
:returns: :cpp:any:`MeshDisplacement`  Displacement
";

%feature("docstring") dolfin::MeshDisplacement "
This class encapsulates the CG1 representation of the displacement of a mesh as an :cpp:any:`Expression` . This is particularly useful for the displacement returned by mesh smoothers which can subsequently be used in evaluating forms. The value rank is 1 and the value shape is equal to the geometric dimension of the mesh.
";

%feature("docstring") dolfin::MeshDisplacement::MeshDisplacement(const MeshDisplacement &mesh_displacement) "
Copy constructor

:param const MeshDisplacement & mesh_displacement:  (:cpp:any:`MeshDisplacement` ) Object to be copied.
";

%feature("docstring") dolfin::MeshDisplacement::MeshDisplacement(std::shared_ptr< const Mesh > mesh) "
Create :cpp:any:`MeshDisplacement`  of given mesh

:param std\\:\\:shared_ptr< const Mesh > mesh:  (:cpp:any:`Mesh` ) :cpp:any:`Mesh`  to be displacement defined on.
";

%feature("docstring") dolfin::MeshDisplacement::compute_vertex_values(std::vector< double > &vertex_values, const Mesh &mesh) const "
Compute values at all mesh vertices.

:param std\\:\\:vector< double > & vertex_values:  (Array<double>) The values at all vertices.
:param const Mesh & mesh:  (:cpp:any:`Mesh` ) The mesh.
:rtype: void
";

%feature("docstring") dolfin::MeshDisplacement::eval(Array< double > &values, const Array< double > &x, const ufc::cell &cell) const "
Evaluate at given point in given cell.

:param Array< double > & values:  (Array<double>) The values at the point.
:param const Array< double > & x:  (Array<double>) The coordinates of the point.
:param const ufc\\:\\:cell & cell:  (ufc::cell) The cell which contains the given point.
:rtype: void
";

%feature("docstring") dolfin::MeshDisplacement::operator[](const std::size_t i) "
Extract subfunction In python available as MeshDisplacement.sub(i)

:param const std\\:\\:size_t i:  (std::size_t) Index of subfunction.
:rtype: Function &
";

%feature("docstring") dolfin::MeshDisplacement::operator[](const std::size_t i) const "
Extract subfunction. Const version

:param const std\\:\\:size_t i:  (std::size_t) Index of subfunction.
:rtype: const Function &
";

%feature("docstring") dolfin::MeshDisplacement::~MeshDisplacement() "
Destructor.
";

