// Auto generated SWIG file for Python interface of DOLFIN
//
// Copyright (C) 2012-2016 Kristian B. Oelgaard, Tormod Landet
//
// This file is part of DOLFIN.
//
// DOLFIN is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// DOLFIN is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
//

// SWIG docstrings generated by doxygen and generate_api_rst.py / parse_doxygen.py

%feature("docstring") dolfin::CoefficientAssigner "
This class is used for assignment of coefficients to forms, which allows magic like
a.f = f a.g = g
which will insert the coefficients f and g in the correct positions in the list of coefficients for the form.
";

%feature("docstring") dolfin::CoefficientAssigner::CoefficientAssigner(Form &form, std::size_t number) "
Create coefficient assigner for coefficient with given number. 

:param Form & form: 
:param std\\:\\:size_t number:
";

%feature("docstring") dolfin::CoefficientAssigner::operator=(std::shared_ptr< const GenericFunction > coefficient) "
Assign coefficient. 

:param std\\:\\:shared_ptr< const GenericFunction > coefficient: 
:rtype: void
";

%feature("docstring") dolfin::CoefficientAssigner::~CoefficientAssigner() "
Destructor.
";

%feature("docstring") dolfin::Constant "
This class represents a constant-valued expression.
";

%feature("docstring") dolfin::Constant::Constant(const Constant &constant) "
Copy constructor

:param const Constant & constant:  (:cpp:any:`Constant` ) Object to be copied.
";

%feature("docstring") dolfin::Constant::Constant(double value) "
Create scalar constant

::
   
   Constant c(1.0);

:param double value:  (double) The scalar to create a :cpp:any:`Constant`  object from.
";

%feature("docstring") dolfin::Constant::Constant(double value0, double value1) "
Create vector constant (dim = 2)

::
   
   Constant B(0.0, 1.0);

:param double value0:  (double) The first vector element.
:param double value1:  (double) The second vector element.
";

%feature("docstring") dolfin::Constant::Constant(double value0, double value1, double value2) "
Create vector constant (dim = 3)

::
   
   Constant T(0.0, 1.0, 0.0);

:param double value0:  (double) The first vector element.
:param double value1:  (double) The second vector element.
:param double value2:  (double) The third vector element.
";

%feature("docstring") dolfin::Constant::Constant(std::vector< double > values) "
Create vector-valued constant

:param std\\:\\:vector< double > values:  (std::vector<double>) Values to create a vector-valued constant from.
";

%feature("docstring") dolfin::Constant::Constant(std::vector< std::size_t > value_shape, std::vector< double > values) "
Create tensor-valued constant for flattened array of values

:param std\\:\\:vector< std\\:\\:size_t > value_shape:  (std::vector<std::size_t>) Shape of tensor.
:param std\\:\\:vector< double > values:  (std::vector<double>) Values to create tensor-valued constant from.
";

%feature("docstring") dolfin::Constant::eval(Array< double > &values, const Array< double > &x) const "
Evaluate at given point.

:param Array< double > & values:  (Array<double>) The values at the point.
:param const Array< double > & x:  (Array<double>) The coordinates of the point.
:rtype: void
";

%feature("docstring") dolfin::Constant::operator double() const "
Cast to double (for scalar constants)

:returns: double The scalar value.
";

%feature("docstring") dolfin::Constant::operator=(const Constant &constant) "
Assignment operator

:param const Constant & constant:  (:cpp:any:`Constant` ) Another constant.
:rtype: const Constant &
";

%feature("docstring") dolfin::Constant::operator=(double constant) "
Assignment operator

:param double constant:  (double) Another constant.
:rtype: const Constant &
";

%feature("docstring") dolfin::Constant::str(bool verbose) const "
Return informal string representation (pretty-print) 

:param bool verbose: 
:rtype: std::string
";

%feature("docstring") dolfin::Constant::values() const "
Return copy of this :cpp:any:`Constant` 's current values

:rtype: std::vector< double >
:returns: std::vector<double> The vector of scalar values of the constant.
";

%feature("docstring") dolfin::Constant::~Constant() "
Destructor.
";

%feature("docstring") dolfin::Expression "
This class represents a user-defined expression. Expressions can be used as coefficients in variational forms or interpolated into finite element spaces.
An expression is defined by overloading the :cpp:any:`eval()`  method. Users may choose to overload either a simple version of :cpp:any:`eval()` , in the case of expressions only depending on the coordinate x, or an optional version for expressions depending on x and mesh data like cell indices or facet normals.
The geometric dimension (the size of x) and the value rank and dimensions of an expression must supplied as arguments to the constructor.
";

%feature("docstring") dolfin::Expression::Expression() "
Create scalar expression.
";

%feature("docstring") dolfin::Expression::Expression(const Expression &expression) "
Copy constructor

:param const Expression & expression:  (:cpp:any:`Expression` ) Object to be copied.
";

%feature("docstring") dolfin::Expression::Expression(std::size_t dim) "
Create vector-valued expression with given dimension.

:param std\\:\\:size_t dim:  (std::size_t) Dimension of the vector-valued expression.
";

%feature("docstring") dolfin::Expression::Expression(std::size_t dim0, std::size_t dim1) "
Create matrix-valued expression with given dimensions.

:param std\\:\\:size_t dim0:  (std::size_t) Dimension (rows).
:param std\\:\\:size_t dim1:  (std::size_t) Dimension (columns).
";

%feature("docstring") dolfin::Expression::Expression(std::vector< std::size_t > value_shape) "
Create tensor-valued expression with given shape.

:param std\\:\\:vector< std\\:\\:size_t > value_shape:  (std::vector<std::size_t>) Shape of expression.
";

%feature("docstring") dolfin::Expression::compute_vertex_values(std::vector< double > &vertex_values, const Mesh &mesh) const "
Compute values at all mesh vertices.

:param std\\:\\:vector< double > & vertex_values:  (Array<double>) The values at all vertices.
:param const Mesh & mesh:  (:cpp:any:`Mesh` ) The mesh.
:rtype: void
";

%feature("docstring") dolfin::Expression::eval(Array< double > &values, const Array< double > &x) const "
Evaluate at given point.

:param Array< double > & values:  (Array<double>) The values at the point.
:param const Array< double > & x:  (Array<double>) The coordinates of the point.
:rtype: void
";

%feature("docstring") dolfin::Expression::eval(Array< double > &values, const Array< double > &x, const ufc::cell &cell) const "
Note: The reimplementation of eval is needed for the Python interface. 
Evaluate at given point in given cell.

:param Array< double > & values:  (Array<double>) The values at the point.
:param const Array< double > & x:  (Array<double>) The coordinates of the point.
:param const ufc\\:\\:cell & cell:  (ufc::cell) The cell which contains the given point.
:rtype: void
";

%feature("docstring") dolfin::Expression::function_space() const "
Return shared pointer to function space (NULL) :cpp:any:`Expression`  does not have a :cpp:any:`FunctionSpace` 

:rtype: std::shared_ptr< const FunctionSpace >
:returns: :cpp:any:`FunctionSpace`  Return the shared pointer.
";

%feature("docstring") dolfin::Expression::restrict(double *w, const FiniteElement &element, const Cell &dolfin_cell, const double *coordinate_dofs, const ufc::cell &ufc_cell) const "
Restrict function to local cell (compute expansion coefficients w).

:param double * w:  (list of doubles) Expansion coefficients.
:param const FiniteElement & element:  (:cpp:any:`FiniteElement` ) The element.
:param const Cell & dolfin_cell:  (:cpp:any:`Cell` ) The cell.
:param const double * coordinate_dofs:  (double*) The coordinates
:param const ufc\\:\\:cell & ufc_cell:  (ufc::cell) The ufc::cell.
:rtype: void
";

%feature("docstring") dolfin::Expression::value_dimension(std::size_t i) const "
Return value dimension for given axis.

:param std\\:\\:size_t i:  (std::size_t) Integer denoting the axis to use.
:rtype: std::size_t
:returns: std::size_t The value dimension (for the given axis).
";

%feature("docstring") dolfin::Expression::value_rank() const "
Return value rank.

:rtype: std::size_t
:returns: std::size_t The value rank.
";

%feature("docstring") dolfin::Expression::~Expression() "
Destructor.
";

%feature("docstring") dolfin::FacetArea "
This function represents the area/length of a cell facet on a given mesh.
";

%feature("docstring") dolfin::FacetArea::FacetArea(std::shared_ptr< const Mesh > mesh) "
Constructor. 

:param std\\:\\:shared_ptr< const Mesh > mesh:
";

%feature("docstring") dolfin::FacetArea::eval(Array< double > &values, const Array< double > &x, const ufc::cell &cell) const "
Evaluate function. 

:param Array< double > & values: 
:param const Array< double > & x: 
:param const ufc\\:\\:cell & cell: 
:rtype: void
";

%feature("docstring") dolfin::FacetArea::not_on_boundary "
:rtype: Event
";

%feature("docstring") dolfin::Function "
This class represents a function :math:`u_h`  in a finite element function space :math:`V_h` , given by
.. math:: 

::
   
   u_h = \\sum_{i=1}^{n} U_i \\phi_i
   
where :math:`\\phi_i\\}_{i=1}^{n}`  is a basis for :math:`V_h` , and :math:`U`  is a vector of expansion coefficients for :math:`u_h` . 

Friends: :cpp:any:`FunctionAssigner`, :cpp:any:`FunctionSpace`.
";

%feature("docstring") dolfin::Function::Function(const Function &v) "
Copy constructor
Arguments v (:cpp:any:`Function` ) The object to be copied. 

:param const Function & v:
";

%feature("docstring") dolfin::Function::Function(const Function &v, std::size_t i) "
Sub-function constructor with shallow copy of vector (used in Python interface)
Arguments v (:cpp:any:`Function` ) The function to be copied. i (std::size_t) Index of subfunction. 

:param const Function & v: 
:param std\\:\\:size_t i:
";

%feature("docstring") dolfin::Function::Function(std::shared_ptr< const FunctionSpace > V) "
Create function on given function space (shared data)
Arguments V (:cpp:any:`FunctionSpace` ) The function space. 

:param std\\:\\:shared_ptr< const FunctionSpace > V:
";

%feature("docstring") dolfin::Function::Function(std::shared_ptr< const FunctionSpace > V, std::shared_ptr< GenericVector > x) "
Create function on given function space with a given vector (shared data)
Warning: This constructor is intended for internal library use only
Arguments V (:cpp:any:`FunctionSpace` ) The function space. x (:cpp:any:`GenericVector` ) The vector. 

:param std\\:\\:shared_ptr< const FunctionSpace > V: 
:param std\\:\\:shared_ptr< GenericVector > x:
";

%feature("docstring") dolfin::Function::Function(std::shared_ptr< const FunctionSpace > V, std::string filename) "
Create function from vector of dofs stored to file (shared data)
Arguments V (:cpp:any:`FunctionSpace` ) The function space. filename_dofdata (std::string) The name of the file containing the dofmap data. 

:param std\\:\\:shared_ptr< const FunctionSpace > V: 
:param std\\:\\:string filename:
";

%feature("docstring") dolfin::Function::compute_vertex_values(std::vector< double > &vertex_values) "
Compute values at all mesh vertices

:param std\\:\\:vector< double > & vertex_values:  (Array<double>) The values at all vertices.
:rtype: void
";

%feature("docstring") dolfin::Function::compute_vertex_values(std::vector< double > &vertex_values, const Mesh &mesh) const "
Compute values at all mesh vertices

:param std\\:\\:vector< double > & vertex_values:  (Array<double>) The values at all vertices.
:param const Mesh & mesh:  (:cpp:any:`Mesh` ) The mesh.
:rtype: void
";

%feature("docstring") dolfin::Function::eval(Array< double > &values, const Array< double > &x) const "
Evaluate function at given coordinates

:param Array< double > & values:  (Array<double>) The values.
:param const Array< double > & x:  (Array<double>) The coordinates.
:rtype: void
";

%feature("docstring") dolfin::Function::eval(Array< double > &values, const Array< double > &x, const Cell &dolfin_cell, const ufc::cell &ufc_cell) const "
Evaluate function at given coordinates in given cell
Arguments

:param Array< double > & values:  (Array<double>) The values.
:param const Array< double > & x:  (Array<double>) The coordinates.
:param const Cell & dolfin_cell:  (:cpp:any:`Cell` ) The cell.
:param const ufc\\:\\:cell & ufc_cell:  (ufc::cell) The ufc::cell.
:rtype: void
";

%feature("docstring") dolfin::Function::eval(Array< double > &values, const Array< double > &x, const ufc::cell &cell) const "
Evaluate at given point in given cell

:param Array< double > & values:  (Array<double>) The values at the point.
:param const Array< double > & x:  (Array<double>) The coordinates of the point.
:param const ufc\\:\\:cell & cell:  (ufc::cell) The cell which contains the given point.
:rtype: void
";

%feature("docstring") dolfin::Function::extrapolate(const Function &v) "
Extrapolate function (from a possibly lower-degree function space)
Arguments v (:cpp:any:`Function` ) The function to be extrapolated. 

:param const Function & v: 
:rtype: void
";

%feature("docstring") dolfin::Function::function_space() const "
Return shared pointer to function space
Returns:cpp:any:`FunctionSpace`  Return the shared pointer. 

:rtype: std::shared_ptr< const FunctionSpace >
";

%feature("docstring") dolfin::Function::geometric_dimension() const "
Return geometric dimension
Returns std::size_t The geometric dimension. 

:rtype: std::size_t
";

%feature("docstring") dolfin::Function::get_allow_extrapolation() const "
Check if extrapolation is permitted when evaluating the :cpp:any:`Function` 

:rtype: bool
:returns: bool True if extrapolation is permitted, otherwise false
";

%feature("docstring") dolfin::Function::in(const FunctionSpace &V) const "
Check if function is a member of the given function space
Arguments V (:cpp:any:`FunctionSpace` ) The function space.
Returns bool True if the function is in the function space. 

:param const FunctionSpace & V: 
:rtype: bool
";

%feature("docstring") dolfin::Function::init_vector() "
:rtype: void
";

%feature("docstring") dolfin::Function::interpolate(const GenericFunction &v) "
Interpolate function (on possibly non-matching meshes)

:param const GenericFunction & v:  (:cpp:any:`GenericFunction` ) The function to be interpolated.
:rtype: void
";

%feature("docstring") dolfin::Function::operator=(const Expression &v) "
Assignment from expression using interpolation
Arguments v (:cpp:any:`Expression` ) The expression. 

:param const Expression & v: 
:rtype: const Function &
";

%feature("docstring") dolfin::Function::operator=(const Function &v) "
Assignment from function
Arguments v (:cpp:any:`Function` ) Another function. 

:param const Function & v: 
:rtype: const Function &
";

%feature("docstring") dolfin::Function::operator=(const FunctionAXPY &axpy) "
Assignment from linear combination of function
Arguments v (:cpp:any:`FunctionAXPY` ) A linear combination of other Functions 

:param const FunctionAXPY & axpy: 
:rtype: void
";

%feature("docstring") dolfin::Function::operator[](std::size_t i) const "
Extract subfunction
Arguments i (std::size_t) Index of subfunction. Returns:cpp:any:`Function`  The subfunction. 

:param std\\:\\:size_t i: 
:rtype: Function &
";

%feature("docstring") dolfin::Function::restrict(double *w, const FiniteElement &element, const Cell &dolfin_cell, const double *coordinate_dofs, const ufc::cell &ufc_cell) const "
Restrict function to local cell (compute expansion coefficients w)

:param double * w:  (list of doubles) Expansion coefficients.
:param const FiniteElement & element:  (:cpp:any:`FiniteElement` ) The element.
:param const Cell & dolfin_cell:  (:cpp:any:`Cell` ) The cell.
:param const double * coordinate_dofs:  (double *) The coordinates
:param const ufc\\:\\:cell & ufc_cell:  (ufc::cell). The ufc::cell.
:rtype: void
";

%feature("docstring") dolfin::Function::set_allow_extrapolation(bool allow_extrapolation) "
Allow extrapolation when evaluating the :cpp:any:`Function` 

:param bool allow_extrapolation:  (bool) Whether or not permit extrapolation.
:rtype: void
";

%feature("docstring") dolfin::Function::value_dimension(std::size_t i) const "
Return value dimension for given axis
Arguments i (std::size_t) The index of the axis.
Returns std::size_t The value dimension. 

:param std\\:\\:size_t i: 
:rtype: std::size_t
";

%feature("docstring") dolfin::Function::value_rank() const "
Return value rank
Returns std::size_t The value rank. 

:rtype: std::size_t
";

%feature("docstring") dolfin::Function::vector() "
Return vector of expansion coefficients (non-const version)
Returns:cpp:any:`GenericVector`  The vector of expansion coefficients. 

:rtype: std::shared_ptr< GenericVector >
";

%feature("docstring") dolfin::Function::vector() const "
Return vector of expansion coefficients (const version)
Returns:cpp:any:`GenericVector`  The vector of expansion coefficients (const). 

:rtype: std::shared_ptr< const GenericVector >
";

%feature("docstring") dolfin::Function::~Function() "
Destructor.
";

%feature("docstring") dolfin::FunctionAXPY "
This class represents a linear combination of functions. It is mostly used as an intermediate class for operations such as u = 3*u0 + 4*u1; where the rhs generates an :cpp:any:`FunctionAXPY` .
";

%feature("docstring") dolfin::FunctionAXPY::Direction "
Enum to decide what way AXPY is constructed. 

.. cpp:enumerator:: dolfin::FunctionAXPY::Direction::ADD_ADD =0

.. cpp:enumerator:: dolfin::FunctionAXPY::Direction::SUB_ADD =1

.. cpp:enumerator:: dolfin::FunctionAXPY::Direction::ADD_SUB =2

.. cpp:enumerator:: dolfin::FunctionAXPY::Direction::SUB_SUB =3
";

%feature("docstring") dolfin::FunctionAXPY::FunctionAXPY(const FunctionAXPY &axpy) "
Copy constructor. 

:param const FunctionAXPY & axpy:
";

%feature("docstring") dolfin::FunctionAXPY::FunctionAXPY(const FunctionAXPY &axpy, double scalar) "
Constructor. 

:param const FunctionAXPY & axpy: 
:param double scalar:
";

%feature("docstring") dolfin::FunctionAXPY::FunctionAXPY(const FunctionAXPY &axpy, std::shared_ptr< const Function > func, Direction direction) "
Constructor. 

:param const FunctionAXPY & axpy: 
:param std\\:\\:shared_ptr< const Function > func: 
:param Direction direction:
";

%feature("docstring") dolfin::FunctionAXPY::FunctionAXPY(const FunctionAXPY &axpy0, const FunctionAXPY &axpy1, Direction direction) "
Constructor. 

:param const FunctionAXPY & axpy0: 
:param const FunctionAXPY & axpy1: 
:param Direction direction:
";

%feature("docstring") dolfin::FunctionAXPY::FunctionAXPY(std::shared_ptr< const Function > func, double scalar) "
Constructor. 

:param std\\:\\:shared_ptr< const Function > func: 
:param double scalar:
";

%feature("docstring") dolfin::FunctionAXPY::FunctionAXPY(std::shared_ptr< const Function > func0, std::shared_ptr< const Function > func1, Direction direction) "
Constructor. 

:param std\\:\\:shared_ptr< const Function > func0: 
:param std\\:\\:shared_ptr< const Function > func1: 
:param Direction direction:
";

%feature("docstring") dolfin::FunctionAXPY::FunctionAXPY(std::vector< std::pair< double, std::shared_ptr< const Function >>> pairs) "
Constructor. 

:param std\\:\\:vector< std\\:\\:pair< double, std\\:\\:shared_ptr< const Function >>> pairs:
";

%feature("docstring") dolfin::FunctionAXPY::operator*(double scale) const "
Scale operator. 

:param double scale: 
:rtype: FunctionAXPY
";

%feature("docstring") dolfin::FunctionAXPY::operator+(const FunctionAXPY &axpy) const "
Addition operator. 

:param const FunctionAXPY & axpy: 
:rtype: FunctionAXPY
";

%feature("docstring") dolfin::FunctionAXPY::operator+(std::shared_ptr< const Function > func) const "
Addition operator. 

:param std\\:\\:shared_ptr< const Function > func: 
:rtype: FunctionAXPY
";

%feature("docstring") dolfin::FunctionAXPY::operator-(const FunctionAXPY &axpy) const "
Subtraction operator. 

:param const FunctionAXPY & axpy: 
:rtype: FunctionAXPY
";

%feature("docstring") dolfin::FunctionAXPY::operator-(std::shared_ptr< const Function > func) const "
Subtraction operator. 

:param std\\:\\:shared_ptr< const Function > func: 
:rtype: FunctionAXPY
";

%feature("docstring") dolfin::FunctionAXPY::operator/(double scale) const "
Scale operator. 

:param double scale: 
:rtype: FunctionAXPY
";

%feature("docstring") dolfin::FunctionAXPY::pairs() const "
Return the scalar and :cpp:any:`Function`  pairs. 

:rtype: const std::vector< std::pair< double, std::shared_ptr< const Function > > > &
";

%feature("docstring") dolfin::FunctionAXPY::~FunctionAXPY() "
Destructor.
";

%feature("docstring") dolfin::FunctionAssigner "
This class facilitate assignments between :cpp:any:`Function`  and sub Functions. It builds and caches maps between compatible dofs. These maps are used in the assignment methods which perform the actual assignment. Optionally can a :cpp:any:`MeshFunction`  be passed together with a label, facilitating FunctionAssignment over sub domains.
";

%feature("docstring") dolfin::FunctionAssigner::FunctionAssigner(std::shared_ptr< const FunctionSpace > receiving_space, std::shared_ptr< const FunctionSpace > assigning_space) "
Create a :cpp:any:`FunctionAssigner`  between functions residing in the same type of :cpp:any:`FunctionSpace` . One or both functions can be sub functions.
Arguments receiving_space (:cpp:any:`FunctionSpace` ) The function space of the receiving function assigning_space (:cpp:any:`FunctionSpace` ) The function space of the assigning function 

:param std\\:\\:shared_ptr< const FunctionSpace > receiving_space: 
:param std\\:\\:shared_ptr< const FunctionSpace > assigning_space:
";

%feature("docstring") dolfin::FunctionAssigner::FunctionAssigner(std::shared_ptr< const FunctionSpace > receiving_space, std::vector< std::shared_ptr< const FunctionSpace >> assigning_spaces) "
Create a :cpp:any:`FunctionAssigner`  between several functions (assigning) and one mixed function (receiving). The number of sub functions in the assigning mixed function must sum up to the number of receiving functions. The sub spaces of the receiving mixed space must be of the same type ans size as the assigning spaces.
Arguments receiving_space (std::shared_ptr<:cpp:any:`FunctionSpace` >) The receiving function space assigning_spaces (std::vector<std::shared_ptr<:cpp:any:`FunctionSpace` > >) The assigning function spaces 

:param std\\:\\:shared_ptr< const FunctionSpace > receiving_space: 
:param std\\:\\:vector< std\\:\\:shared_ptr< const FunctionSpace >> assigning_spaces:
";

%feature("docstring") dolfin::FunctionAssigner::FunctionAssigner(std::vector< std::shared_ptr< const FunctionSpace >> receiving_spaces, std::shared_ptr< const FunctionSpace > assigning_space) "
Create a :cpp:any:`FunctionAssigner`  between one mixed function (assigning) and several functions (receiving). The number of receiving functions must sum up to the number of sub functions in the assigning mixed function. The sub spaces of the assigning mixed space must be of the same type ans size as the receiving spaces.
Arguments receiving_spaces (std::vector<:cpp:any:`FunctionSpace` >) The receiving function spaces assigning_space (:cpp:any:`FunctionSpace` ) The assigning function space 

:param std\\:\\:vector< std\\:\\:shared_ptr< const FunctionSpace >> receiving_spaces: 
:param std\\:\\:shared_ptr< const FunctionSpace > assigning_space:
";

%feature("docstring") dolfin::FunctionAssigner::assign(std::shared_ptr< Function > receiving_func, std::shared_ptr< const Function > assigning_func) const "
Assign one function to another
Arguments receiving_func (std::shared_ptr<:cpp:any:`Function` >) The receiving function assigning_func (std::shared_ptr<:cpp:any:`Function` >) The assigning function 

:param std\\:\\:shared_ptr< Function > receiving_func: 
:param std\\:\\:shared_ptr< const Function > assigning_func: 
:rtype: void
";

%feature("docstring") dolfin::FunctionAssigner::assign(std::shared_ptr< Function > receiving_func, std::vector< std::shared_ptr< const Function >> assigning_funcs) const "
Assign several functions to sub functions of a mixed receiving function
Arguments receiving_func (std::shared_ptr<:cpp:any:`Function` >) The receiving mixed function assigning_funcs (std::vector<std::shared_ptr<:cpp:any:`Function` > >) The assigning functions 

:param std\\:\\:shared_ptr< Function > receiving_func: 
:param std\\:\\:vector< std\\:\\:shared_ptr< const Function >> assigning_funcs: 
:rtype: void
";

%feature("docstring") dolfin::FunctionAssigner::assign(std::vector< std::shared_ptr< Function >> receiving_funcs, std::shared_ptr< const Function > assigning_func) const "
Assign sub functions of a single mixed function to single receiving functions
Arguments receiving_funcs (std::vector<std::shared_ptr<:cpp:any:`Function` > >) The receiving functions assigning_func (std::shared_ptr<:cpp:any:`Function` >) The assigning mixed function 

:param std\\:\\:vector< std\\:\\:shared_ptr< Function >> receiving_funcs: 
:param std\\:\\:shared_ptr< const Function > assigning_func: 
:rtype: void
";

%feature("docstring") dolfin::FunctionAssigner::num_assigning_functions() const "
Return the number of assigning functions. 

:rtype: std::size_t
";

%feature("docstring") dolfin::FunctionAssigner::num_receiving_functions() const "
Return the number of receiving functions. 

:rtype: std::size_t
";

%feature("docstring") dolfin::FunctionAssigner::~FunctionAssigner() "
Destructor.
";

%feature("docstring") dolfin::FunctionSpace "
This class represents a finite element function space defined by a mesh, a finite element, and a local-to-global mapping of the degrees of freedom (dofmap).
";

%feature("docstring") dolfin::FunctionSpace::FunctionSpace(const FunctionSpace &V) "
Copy constructor
Arguments V (:cpp:any:`FunctionSpace` ) The object to be copied. 

:param const FunctionSpace & V:
";

%feature("docstring") dolfin::FunctionSpace::FunctionSpace(std::shared_ptr< const Mesh > mesh) "
Create empty function space for later initialization. This constructor is intended for use by any sub-classes which need to construct objects before the initialisation of the base class. Data can be attached to the base class using :cpp:any:`FunctionSpace::attach` (...).
Arguments mesh (:cpp:any:`Mesh` ) The mesh. 

:param std\\:\\:shared_ptr< const Mesh > mesh:
";

%feature("docstring") dolfin::FunctionSpace::FunctionSpace(std::shared_ptr< const Mesh > mesh, std::shared_ptr< const FiniteElement > element, std::shared_ptr< const GenericDofMap > dofmap) "
Create function space for given mesh, element and dofmap (shared data)
Arguments mesh (:cpp:any:`Mesh` ) The mesh. element (:cpp:any:`FiniteElement` ) The element. dofmap (:cpp:any:`GenericDofMap` ) The dofmap. 

:param std\\:\\:shared_ptr< const Mesh > mesh: 
:param std\\:\\:shared_ptr< const FiniteElement > element: 
:param std\\:\\:shared_ptr< const GenericDofMap > dofmap:
";

%feature("docstring") dolfin::FunctionSpace::attach(std::shared_ptr< const FiniteElement > element, std::shared_ptr< const GenericDofMap > dofmap) "
Attach data to an empty function space
Arguments element (:cpp:any:`FiniteElement` ) The element. dofmap (:cpp:any:`GenericDofMap` ) The dofmap. 

:param std\\:\\:shared_ptr< const FiniteElement > element: 
:param std\\:\\:shared_ptr< const GenericDofMap > dofmap: 
:rtype: void
";

%feature("docstring") dolfin::FunctionSpace::collapse() const "
Collapse a subspace and return a new function space
Returns:cpp:any:`FunctionSpace`  The new function space. 

:rtype: std::shared_ptr< FunctionSpace >
";

%feature("docstring") dolfin::FunctionSpace::collapse(std::unordered_map< std::size_t, std::size_t > &collapsed_dofs) const "
Collapse a subspace and return a new function space and a map from new to old dofs
Arguments collapsed_dofs (std::unordered_map<std::size_t, std::size_t>) The map from new to old dofs.
Returns:cpp:any:`FunctionSpace`  The new function space. 

:param std\\:\\:unordered_map< std\\:\\:size_t, std\\:\\:size_t > & collapsed_dofs: 
:rtype: std::shared_ptr< FunctionSpace >
";

%feature("docstring") dolfin::FunctionSpace::component() const "
Return component w.r.t. to root superspace, i.e. W.sub(1).sub(0) == [1, 0].
Returns std::vector<std::size_t> The component (w.r.t to root superspace). 

:rtype: std::vector< std::size_t >
";

%feature("docstring") dolfin::FunctionSpace::contains(const FunctionSpace &V) const "
Check whether V is subspace of this, or this itself
Arguments V (:cpp:any:`FunctionSpace` ) The space to be tested for inclusion.
Returns bool True if V is contained or equal to this. 

:param const FunctionSpace & V: 
:rtype: bool
";

%feature("docstring") dolfin::FunctionSpace::dim() const "
Return dimension of function space
Returns std::size_t The dimension of the function space. 

:rtype: std::size_t
";

%feature("docstring") dolfin::FunctionSpace::dofmap() const "
Return dofmap
Returns:cpp:any:`GenericDofMap`  The dofmap. 

:rtype: std::shared_ptr< const GenericDofMap >
";

%feature("docstring") dolfin::FunctionSpace::element() const "
Return finite element
Returns:cpp:any:`FiniteElement`  The finite element. 

:rtype: std::shared_ptr< const FiniteElement >
";

%feature("docstring") dolfin::FunctionSpace::extract_sub_space(const std::vector< std::size_t > &component) const "
Extract subspace for component
Arguments component (std::vector<std::size_t>) The component.
Returns:cpp:any:`FunctionSpace`  The subspace. 

:param const std\\:\\:vector< std\\:\\:size_t > & component: 
:rtype: std::shared_ptr< FunctionSpace >
";

%feature("docstring") dolfin::FunctionSpace::has_cell(const Cell &cell) const "
Check if function space has given cell
Arguments cell (:cpp:any:`Cell` ) The cell.
Returns bool True if the function space has the given cell. 

:param const Cell & cell: 
:rtype: bool
";

%feature("docstring") dolfin::FunctionSpace::has_element(const FiniteElement &element) const "
Check if function space has given element
Arguments element (:cpp:any:`FiniteElement` ) The finite element.
Returns bool True if the function space has the given element. 

:param const FiniteElement & element: 
:rtype: bool
";

%feature("docstring") dolfin::FunctionSpace::interpolate(GenericVector &expansion_coefficients, const GenericFunction &v) const "
Interpolate function v into function space, returning the vector of expansion coefficients
Arguments expansion_coefficients (:cpp:any:`GenericVector` ) The expansion coefficients. v (:cpp:any:`GenericFunction` ) The function to be interpolated. 

:param GenericVector & expansion_coefficients: 
:param const GenericFunction & v: 
:rtype: void
";

%feature("docstring") dolfin::FunctionSpace::interpolate_from_any(GenericVector &expansion_coefficients, const GenericFunction &v) const "
:param GenericVector & expansion_coefficients: 
:param const GenericFunction & v: 
:rtype: void
";

%feature("docstring") dolfin::FunctionSpace::interpolate_from_parent(GenericVector &expansion_coefficients, const GenericFunction &v) const "
:param GenericVector & expansion_coefficients: 
:param const GenericFunction & v: 
:rtype: void
";

%feature("docstring") dolfin::FunctionSpace::mesh() const "
Return mesh
Returns:cpp:any:`Mesh`  The mesh. 

:rtype: std::shared_ptr< const Mesh >
";

%feature("docstring") dolfin::FunctionSpace::operator!=(const FunctionSpace &V) const "
Inequality operator
Arguments V (:cpp:any:`FunctionSpace` ) Another function space. 

:param const FunctionSpace & V: 
:rtype: bool
";

%feature("docstring") dolfin::FunctionSpace::operator=(const FunctionSpace &V) "
Assignment operator
Arguments V (:cpp:any:`FunctionSpace` ) Another function space. 

:param const FunctionSpace & V: 
:rtype: const FunctionSpace &
";

%feature("docstring") dolfin::FunctionSpace::operator==(const FunctionSpace &V) const "
Equality operator
Arguments V (:cpp:any:`FunctionSpace` ) Another function space. 

:param const FunctionSpace & V: 
:rtype: bool
";

%feature("docstring") dolfin::FunctionSpace::operator[](std::size_t i) const "
Extract subspace for component
Arguments i (std::size_t) Index of the subspace. Returns:cpp:any:`FunctionSpace`  The subspace. 

:param std\\:\\:size_t i: 
:rtype: std::shared_ptr< FunctionSpace >
";

%feature("docstring") dolfin::FunctionSpace::print_dofmap() const "
Print dofmap (useful for debugging) 

:rtype: void
";

%feature("docstring") dolfin::FunctionSpace::set_x(GenericVector &x, double value, std::size_t component) const "
:cpp:any:`Set`  dof entries in vector to value*x[i], where [x][i] is the coordinate of the dof spatial coordinate. Parallel layout of vector must be consistent with dof map range This function is typically used to construct the null space of a matrix operator, e.g. rigid body rotations.
Arguments vector (:cpp:any:`GenericVector` ) The vector to set. value (double) The value to multiply to coordinate by. component (std::size_t) The coordinate index. mesh (:cpp:any:`Mesh` ) The mesh. 

:param GenericVector & x: 
:param double value: 
:param std\\:\\:size_t component: 
:rtype: void
";

%feature("docstring") dolfin::FunctionSpace::str(bool verbose) const "
Return informal string representation (pretty-print)
Arguments verbose (bool) Flag to turn on additional output.
Returns std::string An informal representation of the function space. 

:param bool verbose: 
:rtype: std::string
";

%feature("docstring") dolfin::FunctionSpace::sub(const std::vector< std::size_t > &component) const "
Extract subspace for component
Arguments component (std::vector<std::size_t>) The component. Returns:cpp:any:`FunctionSpace`  The subspace. 

:param const std\\:\\:vector< std\\:\\:size_t > & component: 
:rtype: std::shared_ptr< FunctionSpace >
";

%feature("docstring") dolfin::FunctionSpace::sub(std::size_t component) const "
Extract subspace for component
Arguments component (std::size_t) Index of the subspace. Returns:cpp:any:`FunctionSpace`  The subspace. 

:param std\\:\\:size_t component: 
:rtype: std::shared_ptr< FunctionSpace >
";

%feature("docstring") dolfin::FunctionSpace::tabulate_dof_coordinates() const "
Tabulate the coordinates of all dofs on this process. This function is typically used by preconditioners that require the spatial coordinates of dofs, for example for re-partitioning or nullspace computations.
Arguments mesh (:cpp:any:`Mesh` ) The mesh.
Returns std::vector<double> The dof coordinates (x0, y0, x1, y1, . . .) 

:rtype: std::vector< double >
";

%feature("docstring") dolfin::FunctionSpace::~FunctionSpace() "
Destructor.
";

%feature("docstring") dolfin::GenericFunction "
This is a common base class for functions. Functions can be evaluated at a given point and they can be restricted to a given cell in a finite element mesh. This functionality is implemented by sub-classes that implement the :cpp:any:`eval()`  and :cpp:any:`restrict()`  functions.
DOLFIN provides two implementations of the :cpp:any:`GenericFunction`  interface in the form of the classes :cpp:any:`Function`  and :cpp:any:`Expression` .
Sub-classes may optionally implement the :cpp:any:`update()`  function that will be called prior to restriction when running in parallel.
";

%feature("docstring") dolfin::GenericFunction::GenericFunction() "
Constructor.
";

%feature("docstring") dolfin::GenericFunction::compute_vertex_values(std::vector< double > &vertex_values, const Mesh &mesh) const  "
Compute values at all mesh vertices. 

:param std\\:\\:vector< double > & vertex_values: 
:param const Mesh & mesh: 
:rtype: void
";

%feature("docstring") dolfin::GenericFunction::eval(Array< double > &values, const Array< double > &x) const "
Evaluate at given point. 

:param Array< double > & values: 
:param const Array< double > & x: 
:rtype: void
";

%feature("docstring") dolfin::GenericFunction::eval(Array< double > &values, const Array< double > &x, const ufc::cell &cell) const "
Evaluate at given point in given cell. 

:param Array< double > & values: 
:param const Array< double > & x: 
:param const ufc\\:\\:cell & cell: 
:rtype: void
";

%feature("docstring") dolfin::GenericFunction::evaluate(double *values, const double *coordinates, const ufc::cell &cell) const "
Evaluate function at given point in cell 

:param double * values:  (double*)
:param const double * coordinates:  (const double*)
:param const ufc\\:\\:cell & cell:  (ufc::cell&)
:rtype: void
";

%feature("docstring") dolfin::GenericFunction::function_space() const  "
Pointer to :cpp:any:`FunctionSpace` , if appropriate, otherwise NULL. 

:rtype: std::shared_ptr< const FunctionSpace >
";

%feature("docstring") dolfin::GenericFunction::operator()(Array< double > &values, const Point &p) const "
Evaluation at given point (vector-valued function) 

:param Array< double > & values: 
:param const Point & p: 
:rtype: void
";

%feature("docstring") dolfin::GenericFunction::operator()(Array< double > &values, double x) const "
Evaluation at given point (vector-valued function) 

:param Array< double > & values: 
:param double x: 
:rtype: void
";

%feature("docstring") dolfin::GenericFunction::operator()(Array< double > &values, double x, double y) const "
Evaluation at given point (vector-valued function) 

:param Array< double > & values: 
:param double x: 
:param double y: 
:rtype: void
";

%feature("docstring") dolfin::GenericFunction::operator()(Array< double > &values, double x, double y, double z) const "
Evaluation at given point (vector-valued function) 

:param Array< double > & values: 
:param double x: 
:param double y: 
:param double z: 
:rtype: void
";

%feature("docstring") dolfin::GenericFunction::operator()(const Point &p) const "
Evaluation at given point (scalar function) 

:param const Point & p: 
:rtype: double
";

%feature("docstring") dolfin::GenericFunction::operator()(double x) const "
Evaluation at given point (scalar function) 

:param double x: 
:rtype: double
";

%feature("docstring") dolfin::GenericFunction::operator()(double x, double y) const "
Evaluation at given point (scalar function) 

:param double x: 
:param double y: 
:rtype: double
";

%feature("docstring") dolfin::GenericFunction::operator()(double x, double y, double z) const "
Evaluation at given point (scalar function) 

:param double x: 
:param double y: 
:param double z: 
:rtype: double
";

%feature("docstring") dolfin::GenericFunction::restrict(double *w, const FiniteElement &element, const Cell &dolfin_cell, const double *coordinate_dofs, const ufc::cell &ufc_cell) const  "
Restrict function to local cell (compute expansion coefficients w) 

:param double * w: 
:param const FiniteElement & element: 
:param const Cell & dolfin_cell: 
:param const double * coordinate_dofs: 
:param const ufc\\:\\:cell & ufc_cell: 
:rtype: void
";

%feature("docstring") dolfin::GenericFunction::restrict_as_ufc_function(double *w, const FiniteElement &element, const Cell &dolfin_cell, const double *coordinate_dofs, const ufc::cell &ufc_cell) const "
Restrict as :cpp:any:`UFC`  function (by calling eval) 

:param double * w: 
:param const FiniteElement & element: 
:param const Cell & dolfin_cell: 
:param const double * coordinate_dofs: 
:param const ufc\\:\\:cell & ufc_cell: 
:rtype: void
";

%feature("docstring") dolfin::GenericFunction::update() const "
Update off-process ghost coefficients. 

:rtype: void
";

%feature("docstring") dolfin::GenericFunction::value_dimension(std::size_t i) const  "
Return value dimension for given axis. 

:param std\\:\\:size_t i: 
:rtype: std::size_t
";

%feature("docstring") dolfin::GenericFunction::value_rank() const  "
Return value rank. 

:rtype: std::size_t
";

%feature("docstring") dolfin::GenericFunction::value_size() const "
Evaluation at given point. 
Return value size (product of value dimensions) 

:rtype: std::size_t
";

%feature("docstring") dolfin::GenericFunction::~GenericFunction() "
Destructor.
";

%feature("docstring") dolfin::LagrangeInterpolator "
This class interpolates efficiently from a :cpp:any:`GenericFunction`  to a :cpp:any:`Lagrange` :cpp:any:`Function`
";

%feature("docstring") dolfin::LagrangeInterpolator::extract_dof_component_map(std::unordered_map< std::size_t, std::size_t > &dof_component_map, const FunctionSpace &V, int *component) "
:param std\\:\\:unordered_map< std\\:\\:size_t, std\\:\\:size_t > & dof_component_map: 
:param const FunctionSpace & V: 
:param int * component: 
:rtype: void
";

%feature("docstring") dolfin::LagrangeInterpolator::in_bounding_box(const std::vector< double > &point, const std::vector< double > &bounding_box, const double tol) "
:param const std\\:\\:vector< double > & point: 
:param const std\\:\\:vector< double > & bounding_box: 
:param const double tol: 
:rtype: bool
";

%feature("docstring") dolfin::LagrangeInterpolator::interpolate(Function &u, const Expression &u0) "
Interpolate :cpp:any:`Expression` 
Arguments u (:cpp:any:`Function` ) The resulting :cpp:any:`Function`  u0 (:cpp:any:`Expression` ) The :cpp:any:`Expression`  to be interpolated. 

:param Function & u: 
:param const Expression & u0: 
:rtype: void
";

%feature("docstring") dolfin::LagrangeInterpolator::interpolate(Function &u, const Function &u0) "
Interpolate function (on possibly non-matching meshes)
Arguments u (:cpp:any:`Function` ) The resulting :cpp:any:`Function`  u0 (:cpp:any:`Function` ) The :cpp:any:`Function`  to be interpolated. 

:param Function & u: 
:param const Function & u0: 
:rtype: void
";

%feature("docstring") dolfin::LagrangeInterpolator::tabulate_coordinates_to_dofs(const FunctionSpace &V) "
:param const FunctionSpace & V: 
:rtype: std::map< std::vector< double >, std::vector< std::size_t >, lt_coordinate >
";

%feature("docstring") dolfin::MeshCoordinates "
This :cpp:any:`Function`  represents the mesh coordinates on a given mesh.
";

%feature("docstring") dolfin::MeshCoordinates::MeshCoordinates(std::shared_ptr< const Mesh > mesh) "
Constructor. 

:param std\\:\\:shared_ptr< const Mesh > mesh:
";

%feature("docstring") dolfin::MeshCoordinates::eval(Array< double > &values, const Array< double > &x, const ufc::cell &cell) const "
Evaluate function. 

:param Array< double > & values: 
:param const Array< double > & x: 
:param const ufc\\:\\:cell & cell: 
:rtype: void
";

%feature("docstring") dolfin::MultiMeshCoefficientAssigner "
This class is used for assignment of multimesh coefficients to forms, which allows magic like
a.f = f a.g = g
which will insert the coefficients f and g in the correct positions in the list of coefficients for the form.
Note that coefficients can also be assigned manually to the individual parts of a multimesh form. Assigning to a multimesh coefficient assigner will assign the same coefficient to all parts of a form.
";

%feature("docstring") dolfin::MultiMeshCoefficientAssigner::MultiMeshCoefficientAssigner(MultiMeshForm &form, std::size_t number) "
Create multimesh coefficient assigner for coefficient with given number. 

:param MultiMeshForm & form: 
:param std\\:\\:size_t number:
";

%feature("docstring") dolfin::MultiMeshCoefficientAssigner::operator=(const MultiMeshFunction &coefficient) "
Assign coefficient from :cpp:any:`MultiMeshFunction` . 

:param const MultiMeshFunction & coefficient: 
:rtype: void
";

%feature("docstring") dolfin::MultiMeshCoefficientAssigner::operator=(std::shared_ptr< const GenericFunction > coefficient) "
Assign coefficient from :cpp:any:`GenericFunction` . 

:param std\\:\\:shared_ptr< const GenericFunction > coefficient: 
:rtype: void
";

%feature("docstring") dolfin::MultiMeshCoefficientAssigner::~MultiMeshCoefficientAssigner() "
Destructor.
";

%feature("docstring") dolfin::MultiMeshFunction "
This class represents a function on a cut and composite finite element function space (:cpp:any:`MultiMesh` ) defined on one or more possibly intersecting meshes.
";

%feature("docstring") dolfin::MultiMeshFunction::MultiMeshFunction() "
Constructor.
";

%feature("docstring") dolfin::MultiMeshFunction::MultiMeshFunction(std::shared_ptr< const MultiMeshFunctionSpace > V) "
Create :cpp:any:`MultiMesh`  function on given :cpp:any:`MultiMesh`  function space
Arguments V (:cpp:any:`MultiMeshFunctionSpace` ) The :cpp:any:`MultiMesh`  function space. 

:param std\\:\\:shared_ptr< const MultiMeshFunctionSpace > V:
";

%feature("docstring") dolfin::MultiMeshFunction::MultiMeshFunction(std::shared_ptr< const MultiMeshFunctionSpace > V, std::shared_ptr< GenericVector > x) "
Create :cpp:any:`MultiMesh`  function on given :cpp:any:`MultiMesh`  function space with a given vector (shared data)
Warning: This constructor is intended for internal library use only
Arguments V (:cpp:any:`MultiMeshFunctionSpace` ) The multimesh function space. x (:cpp:any:`GenericVector` ) The vector. 

:param std\\:\\:shared_ptr< const MultiMeshFunctionSpace > V: 
:param std\\:\\:shared_ptr< GenericVector > x:
";

%feature("docstring") dolfin::MultiMeshFunction::compute_ghost_indices(std::pair< std::size_t, std::size_t > range, std::vector< la_index > &ghost_indices) const "
:param std\\:\\:pair< std\\:\\:size_t, std\\:\\:size_t > range: 
:param std\\:\\:vector< la_index > & ghost_indices: 
:rtype: void
";

%feature("docstring") dolfin::MultiMeshFunction::function_space() const "
Return shared pointer to multi mesh function space
Returns:cpp:any:`MultiMeshFunctionSpace`  Return the shared pointer. 

:rtype: std::shared_ptr< const MultiMeshFunctionSpace >
";

%feature("docstring") dolfin::MultiMeshFunction::init_vector() "
:rtype: void
";

%feature("docstring") dolfin::MultiMeshFunction::part(std::size_t i) const "
Return function (part) number i
Returns:cpp:any:`Function` :cpp:any:`Function`  (part) number i 

:param std\\:\\:size_t i: 
:rtype: std::shared_ptr< const Function >
";

%feature("docstring") dolfin::MultiMeshFunction::vector() "
Return vector of expansion coefficients (non-const version)
Returns:cpp:any:`GenericVector`  The vector of expansion coefficients. 

:rtype: std::shared_ptr< GenericVector >
";

%feature("docstring") dolfin::MultiMeshFunction::vector() const "
Return vector of expansion coefficients (const version)
Returns:cpp:any:`GenericVector`  The vector of expansion coefficients (const). 

:rtype: std::shared_ptr< const GenericVector >
";

%feature("docstring") dolfin::MultiMeshFunction::~MultiMeshFunction() "
Destructor.
";

%feature("docstring") dolfin::MultiMeshFunctionSpace "
This class represents a function space on a multimesh. It may may be created from a set of standard function spaces by repeatedly calling :cpp:any:`add()` , followed by a call to :cpp:any:`build()` . Note that a multimesh function space is not useful and its data structures are empty until :cpp:any:`build()`  has been called. 

Friends: :cpp:any:`MultiMeshSubSpace`.
";

%feature("docstring") dolfin::MultiMeshFunctionSpace::MultiMeshFunctionSpace(std::shared_ptr< const MultiMesh > multimesh) "
Create multimesh function space on multimesh (shared pointer version) 

:param std\\:\\:shared_ptr< const MultiMesh > multimesh:
";

%feature("docstring") dolfin::MultiMeshFunctionSpace::add(std::shared_ptr< const FunctionSpace > function_space) "
Add function space
Arguments function_space (:cpp:any:`FunctionSpace` ) The function space. 

:param std\\:\\:shared_ptr< const FunctionSpace > function_space: 
:rtype: void
";

%feature("docstring") dolfin::MultiMeshFunctionSpace::build() "
Build multimesh function space. 

:rtype: void
";

%feature("docstring") dolfin::MultiMeshFunctionSpace::build(const std::vector< dolfin::la_index > &offsets) "
Build multimesh function space. This function uses offsets computed from the full function spaces on each part. 

:param const std\\:\\:vector< dolfin\\:\\:la_index > & offsets: 
:rtype: void
";

%feature("docstring") dolfin::MultiMeshFunctionSpace::dim() const "
Return dimension of the multimesh function space
Returns std::size_t The dimension of the multimesh function space. 

:rtype: std::size_t
";

%feature("docstring") dolfin::MultiMeshFunctionSpace::dofmap() const "
Return multimesh dofmap
Returns:cpp:any:`MultiMeshDofMap`  The dofmap. 

:rtype: std::shared_ptr< const MultiMeshDofMap >
";

%feature("docstring") dolfin::MultiMeshFunctionSpace::multimesh() const "
Return multimesh
Returns:cpp:any:`MultiMesh`  The multimesh. 

:rtype: std::shared_ptr< const MultiMesh >
";

%feature("docstring") dolfin::MultiMeshFunctionSpace::num_parts() const "
Return the number of function spaces (parts) of the multimesh function space
Returns std::size_t The number of function spaces (parts) of the multimesh function space. 

:rtype: std::size_t
";

%feature("docstring") dolfin::MultiMeshFunctionSpace::part(std::size_t i) const "
Return function space (part) number i
Arguments i (std::size_t) The part number
Returns:cpp:any:`FunctionSpace` :cpp:any:`Function`  space (part) number i 

:param std\\:\\:size_t i: 
:rtype: std::shared_ptr< const FunctionSpace >
";

%feature("docstring") dolfin::MultiMeshFunctionSpace::view(std::size_t i) const "
Return view of multimesh function space for part number i. This function differs from the :cpp:any:`part()`  function in that it does not return the original function space for a part, but rather a view of the common multimesh function space (dofs global to the collection of parts).
Arguments i (std::size_t) The part number
Returns:cpp:any:`FunctionSpace` :cpp:any:`Function`  space (part) number i 

:param std\\:\\:size_t i: 
:rtype: std::shared_ptr< const FunctionSpace >
";

%feature("docstring") dolfin::MultiMeshFunctionSpace::~MultiMeshFunctionSpace() "
Destructor.
";

%feature("docstring") dolfin::MultiMeshSubSpace "
This class represents a subspace (component) of a multimesh function space.
The subspace is specified by an array of indices. For example, the array [3, 0, 2] specifies subspace 2 of subspace 0 of subspace 3.
A typical example is the function space W = V x P for Stokes. Here, V = W[0] is the subspace for the velocity component and P = W[1] is the subspace for the pressure component. Furthermore, W[0][0] = V[0] is the first component of the velocity space etc.
";

%feature("docstring") dolfin::MultiMeshSubSpace::MultiMeshSubSpace(MultiMeshFunctionSpace &V, const std::vector< std::size_t > &component) "
Create subspace for given component (n levels) 

:param MultiMeshFunctionSpace & V: 
:param const std\\:\\:vector< std\\:\\:size_t > & component:
";

%feature("docstring") dolfin::MultiMeshSubSpace::MultiMeshSubSpace(MultiMeshFunctionSpace &V, std::size_t component) "
Create subspace for given component (one level) 

:param MultiMeshFunctionSpace & V: 
:param std\\:\\:size_t component:
";

%feature("docstring") dolfin::MultiMeshSubSpace::MultiMeshSubSpace(MultiMeshFunctionSpace &V, std::size_t component, std::size_t sub_component) "
Create subspace for given component (two levels) 

:param MultiMeshFunctionSpace & V: 
:param std\\:\\:size_t component: 
:param std\\:\\:size_t sub_component:
";

%feature("docstring") dolfin::SpecialFacetFunction "
A :cpp:any:`SpecialFacetFunction`  is a representation of a global function that is in P(f) for each :cpp:any:`Facet`  f in a :cpp:any:`Mesh`  for some :cpp:any:`FunctionSpace`  P
";

%feature("docstring") dolfin::SpecialFacetFunction::SpecialFacetFunction(std::vector< Function > &f_e) "
Create (scalar-valued) :cpp:any:`SpecialFacetFunction` 
Arguments f_e (std::vector<:cpp:any:`Function` >) Separate _Function_s for each facet 

:param std\\:\\:vector< Function > & f_e:
";

%feature("docstring") dolfin::SpecialFacetFunction::SpecialFacetFunction(std::vector< Function > &f_e, std::size_t dim) "
Create (vector-valued) :cpp:any:`SpecialFacetFunction` 
Arguments f_e (std::vector<:cpp:any:`Function` >) Separate _Function_s for each facet
dim (int) The value-dimension of the Functions 

:param std\\:\\:vector< Function > & f_e: 
:param std\\:\\:size_t dim:
";

%feature("docstring") dolfin::SpecialFacetFunction::SpecialFacetFunction(std::vector< Function > &f_e, std::vector< std::size_t > value_shape) "
Create (tensor-valued) :cpp:any:`SpecialFacetFunction` 
Arguments f_e (std::vector<:cpp:any:`Function` >) Separate _Function_s for each facet
value_shape (std::vector<std::size_t>) The values-shape of the Functions 

:param std\\:\\:vector< Function > & f_e: 
:param std\\:\\:vector< std\\:\\:size_t > value_shape:
";

%feature("docstring") dolfin::SpecialFacetFunction::eval(Array< double > &values, const Array< double > &x, const ufc::cell &cell) const "
Evaluate :cpp:any:`SpecialFacetFunction`  (cf :cpp:any:`Expression` .eval) Evaluate function for given cell 

:param Array< double > & values: 
:param const Array< double > & x: 
:param const ufc\\:\\:cell & cell: 
:rtype: void
";

%feature("docstring") dolfin::SpecialFacetFunction::operator[](std::size_t i) const "
Extract sub-function i
Arguments i (int) component
Returns:cpp:any:`Function` 

:param std\\:\\:size_t i: 
:rtype: Function &
";

%feature("docstring") dolfin::assign(std::shared_ptr< Function > receiving_func, std::shared_ptr< const Function > assigning_func) "
Assign one function to another. The functions must reside in the same type of :cpp:any:`FunctionSpace` . One or both functions can be sub functions.

:param std\\:\\:shared_ptr< Function > receiving_func:  (std::shared_ptr<:cpp:any:`Function` >) The receiving function
:param std\\:\\:shared_ptr< const Function > assigning_func:  (std::shared_ptr<:cpp:any:`Function` >) The assigning function
:rtype: void
";

%feature("docstring") dolfin::assign(std::shared_ptr< Function > receiving_func, std::vector< std::shared_ptr< const Function >> assigning_funcs) "
Assign several functions to sub functions of a mixed receiving function. The number of receiving functions must sum up to the number of sub functions in the assigning mixed function. The sub spaces of the assigning mixed space must be of the same type ans size as the receiving spaces. 

:param std\\:\\:shared_ptr< Function > receiving_func:  (std::shared_ptr<:cpp:any:`Function` >) The receiving function
:param std\\:\\:vector< std\\:\\:shared_ptr< const Function >> assigning_funcs:  (std::vector<std::shared_ptr<:cpp:any:`Function` >>) The assigning functions
:rtype: void
";

%feature("docstring") dolfin::assign(std::vector< std::shared_ptr< Function >> receiving_funcs, std::shared_ptr< const Function > assigning_func) "
Assign sub functions of a single mixed function to single receiving functions. The number of sub functions in the assigning mixed function must sum up to the number of receiving functions. The sub spaces of the receiving mixed space must be of the same type ans size as the assigning spaces. 

:param std\\:\\:vector< std\\:\\:shared_ptr< Function >> receiving_funcs:  (std::vector<std::shared_ptr<:cpp:any:`Function` >>) The receiving functions
:param std\\:\\:shared_ptr< const Function > assigning_func:  (std::shared_ptr<:cpp:any:`Function` >) The assigning function
:rtype: void
";

