// Auto generated SWIG file for Python interface of DOLFIN
//
// Copyright (C) 2012-2016 Kristian B. Oelgaard, Tormod Landet
//
// This file is part of DOLFIN.
//
// DOLFIN is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// DOLFIN is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
//

// SWIG docstrings generated by doxygen and generate_api_rst.py / parse_doxygen.py

%feature("docstring") dolfin::BoxMesh "
Tetrahedral mesh of the 3D rectangular prism spanned by two points p0 and p1. Given the number of cells (nx, ny, nz) in each direction, the total number of tetrahedra will be 6*nx*ny*nz and the total number of vertices will be (nx + 1)*(ny + 1)*(nz + 1).
";

%feature("docstring") dolfin::BoxMesh::BoxMesh(MPI_Comm comm, const Point &p0, const Point &p1, std::size_t nx, std::size_t ny, std::size_t nz) "
Create a uniform finite element :cpp:any:`Mesh`  over the rectangular prism spanned by the two _Point_s p0 and p1. The order of the two points is not important in terms of minimum and maximum coordinates.

::
   
   // Mesh with 8 cells in each direction on the
   // set [-1,2] x [-1,2] x [-1,2].
   Point p0(-1, -1, -1);
   Point p1(2, 2, 2);
   BoxMesh mesh(MPI_COMM_WORLD, p0, p1, 8, 8, 8);

:param MPI_Comm comm:  (MPI_Comm) :cpp:any:`MPI`  communicator
:param const Point & p0:  (:cpp:any:`Point` ) First point.
:param const Point & p1:  (:cpp:any:`Point` ) Second point.
:param std\\:\\:size_t nx:  (double) Number of cells in x-direction.
:param std\\:\\:size_t ny:  (double) Number of cells in y-direction.
:param std\\:\\:size_t nz:  (double) Number of cells in z-direction.
";

%feature("docstring") dolfin::BoxMesh::BoxMesh(const Point &p0, const Point &p1, std::size_t nx, std::size_t ny, std::size_t nz) "
Create a uniform finite element :cpp:any:`Mesh`  over the rectangular prism spanned by the two _Point_s p0 and p1. The order of the two points is not important in terms of minimum and maximum coordinates.

::
   
   // Mesh with 8 cells in each direction on the
   // set [-1,2] x [-1,2] x [-1,2].
   Point p0(-1, -1, -1);
   Point p1(2, 2, 2);
   BoxMesh mesh(p0, p1, 8, 8, 8);

:param const Point & p0:  (:cpp:any:`Point` ) First point.
:param const Point & p1:  (:cpp:any:`Point` ) Second point.
:param std\\:\\:size_t nx:  (double) Number of cells in x-direction.
:param std\\:\\:size_t ny:  (double) Number of cells in y-direction.
:param std\\:\\:size_t nz:  (double) Number of cells in z-direction.
";

%feature("docstring") dolfin::BoxMesh::build(const Point &p0, const Point &p1, std::size_t nx, std::size_t ny, std::size_t nz) "
:param const Point & p0: 
:param const Point & p1: 
:param std\\:\\:size_t nx: 
:param std\\:\\:size_t ny: 
:param std\\:\\:size_t nz: 
:rtype: void
";

%feature("docstring") dolfin::IntervalMesh "
Interval mesh of the 1D line [a,b]. Given the number of cells (nx) in the axial direction, the total number of intervals will be nx and the total number of vertices will be (nx + 1).
";

%feature("docstring") dolfin::IntervalMesh::IntervalMesh(MPI_Comm comm, std::size_t nx, double a, double b) "
Constructor

::
   
   // Create a mesh of 25 cells in the interval [-1,1]
   IntervalMesh mesh(MPI_COMM_WORLD, 25, -1.0, 1.0);

:param MPI_Comm comm:  (MPI_Comm) :cpp:any:`MPI`  communicator
:param std\\:\\:size_t nx:  (std::size_t) The number of cells.
:param double a:  (double) The minimum point (inclusive).
:param double b:  (double) The maximum point (inclusive).
";

%feature("docstring") dolfin::IntervalMesh::IntervalMesh(std::size_t nx, double a, double b) "
Constructor

::
   
   // Create a mesh of 25 cells in the interval [-1,1]
   IntervalMesh mesh(25, -1.0, 1.0);

:param std\\:\\:size_t nx:  (std::size_t) The number of cells.
:param double a:  (double) The minimum point (inclusive).
:param double b:  (double) The maximum point (inclusive).
";

%feature("docstring") dolfin::IntervalMesh::build(std::size_t nx, double a, double b) "
:param std\\:\\:size_t nx: 
:param double a: 
:param double b: 
:rtype: void
";

%feature("docstring") dolfin::RectangleMesh "
Triangular mesh of the 2D rectangle spanned by two points p0 and p1. Given the number of cells (nx, ny) in each direction, the total number of triangles will be 2*nx*ny and the total number of vertices will be (nx + 1)*(ny + 1).
";

%feature("docstring") dolfin::RectangleMesh::RectangleMesh(MPI_Comm comm, const Point &p0, const Point &p1, std::size_t nx, std::size_t ny, std::string diagonal="right") "
::
   
   // Mesh with 8 cells in each direction on the
   // set [-1,2] x [-1,2]
   Point p0(-1, -1);
   Point p1(2, 2);
   RectangleMesh mesh(MPI_COMM_WORLD, p0, p1, 8, 8);

:param MPI_Comm comm:  (MPI_Comm) :cpp:any:`MPI`  communicator
:param const Point & p0:  (:cpp:any:`Point` ) First point.
:param const Point & p1:  (:cpp:any:`Point` ) Second point.
:param std\\:\\:size_t nx:  (double) Number of cells in :math:`x` -direction.
:param std\\:\\:size_t ny:  (double) Number of cells in :math:`y` -direction.
:param std\\:\\:string diagonal:  (string) Direction of diagonals: \"left\", \"right\", \"left/right\", \"crossed\"
";

%feature("docstring") dolfin::RectangleMesh::RectangleMesh(const Point &p0, const Point &p1, std::size_t nx, std::size_t ny, std::string diagonal="right") "
::
   
   // Mesh with 8 cells in each direction on the
   // set [-1,2] x [-1,2]
   Point p0(-1, -1);
   Point p1(2, 2);
   RectangleMesh mesh(p0, p1, 8, 8);

:param const Point & p0:  (:cpp:any:`Point` ) First point.
:param const Point & p1:  (:cpp:any:`Point` ) Second point.
:param std\\:\\:size_t nx:  (double) Number of cells in :math:`x` -direction.
:param std\\:\\:size_t ny:  (double) Number of cells in :math:`y` -direction.
:param std\\:\\:string diagonal:  (string) Direction of diagonals: \"left\", \"right\", \"left/right\", \"crossed\"
";

%feature("docstring") dolfin::RectangleMesh::build(const Point &p0, const Point &p1, std::size_t nx, std::size_t ny, std::string diagonal="right") "
:param const Point & p0: 
:param const Point & p1: 
:param std\\:\\:size_t nx: 
:param std\\:\\:size_t ny: 
:param std\\:\\:string diagonal: 
:rtype: void
";

%feature("docstring") dolfin::SphericalShellMesh "
Spherical shell approximation, icosahedral mesh, with degree=1 or degree=2.
";

%feature("docstring") dolfin::SphericalShellMesh::SphericalShellMesh(MPI_Comm comm, std::size_t degree) "
Create a spherical shell manifold for testing. 

:param MPI_Comm comm: 
:param std\\:\\:size_t degree:
";

%feature("docstring") dolfin::UnitCubeMesh "
Tetrahedral mesh of the 3D unit cube [0,1] x [0,1] x [0,1]. Given the number of cells (nx, ny, nz) in each direction, the total number of tetrahedra will be 6*nx*ny*nz and the total number of vertices will be (nx + 1)*(ny + 1)*(nz + 1).
";

%feature("docstring") dolfin::UnitCubeMesh::UnitCubeMesh(MPI_Comm comm, std::size_t nx, std::size_t ny, std::size_t nz) "
Create a uniform finite element :cpp:any:`Mesh`  over the unit cube [0,1] x [0,1] x [0,1].

::
   
   UnitCubeMesh mesh(MPI_COMM_WORLD, 32, 32, 32);

:param MPI_Comm comm:  (MPI_Comm) :cpp:any:`MPI`  communicator
:param std\\:\\:size_t nx:  (std::size_t) Number of cells in :math:`x`  direction.
:param std\\:\\:size_t ny:  (std::size_t) Number of cells in :math:`y`  direction.
:param std\\:\\:size_t nz:  (std::size_t) Number of cells in :math:`z`  direction.
";

%feature("docstring") dolfin::UnitCubeMesh::UnitCubeMesh(std::size_t nx, std::size_t ny, std::size_t nz) "
Create a uniform finite element :cpp:any:`Mesh`  over the unit cube [0,1] x [0,1] x [0,1].

::
   
   UnitCubeMesh mesh(32, 32, 32);

:param std\\:\\:size_t nx:  (std::size_t) Number of cells in :math:`x`  direction.
:param std\\:\\:size_t ny:  (std::size_t) Number of cells in :math:`y`  direction.
:param std\\:\\:size_t nz:  (std::size_t) Number of cells in :math:`z`  direction.
";

%feature("docstring") dolfin::UnitDiscMesh "
A unit disc mesh in 2D or 3D geometry.
";

%feature("docstring") dolfin::UnitDiscMesh::UnitDiscMesh(MPI_Comm comm, std::size_t n, std::size_t degree, std::size_t gdim) "
Create a unit disc mesh in 2D or 3D geometry with n steps, and given degree polynomial mesh 

:param MPI_Comm comm: 
:param std\\:\\:size_t n: 
:param std\\:\\:size_t degree: 
:param std\\:\\:size_t gdim:
";

%feature("docstring") dolfin::UnitHexMesh "
NB: this code is experimental, just for testing, and will generally not work with anything else
";

%feature("docstring") dolfin::UnitHexMesh::UnitHexMesh(MPI_Comm comm, std::size_t nx, std::size_t ny, std::size_t nz) "
NB: this code is experimental, just for testing, and will generally not work with anything else 

:param MPI_Comm comm: 
:param std\\:\\:size_t nx: 
:param std\\:\\:size_t ny: 
:param std\\:\\:size_t nz:
";

%feature("docstring") dolfin::UnitIntervalMesh "
A mesh of the unit interval (0, 1) with a given number of cells (nx) in the axial direction. The total number of intervals will be nx and the total number of vertices will be (nx + 1).
";

%feature("docstring") dolfin::UnitIntervalMesh::UnitIntervalMesh(MPI_Comm comm, std::size_t nx) "
Constructor

::
   
   // Create a mesh of 25 cells in the interval [0,1]
   UnitIntervalMesh mesh(MPI_COMM_WORLD, 25);

:param MPI_Comm comm:  (MPI_Comm) :cpp:any:`MPI`  communicator
:param std\\:\\:size_t nx:  (std::size_t) The number of cells.
";

%feature("docstring") dolfin::UnitIntervalMesh::UnitIntervalMesh(std::size_t nx) "
Constructor

::
   
   // Create a mesh of 25 cells in the interval [0,1]
   UnitIntervalMesh mesh(25);

:param std\\:\\:size_t nx:  (std::size_t) The number of cells.
";

%feature("docstring") dolfin::UnitQuadMesh "
NB: this code is experimental, just for testing, and will generally not work with anything else
";

%feature("docstring") dolfin::UnitQuadMesh::UnitQuadMesh(MPI_Comm comm, std::size_t nx, std::size_t ny) "
NB: this code is experimental, just for testing, and will generally not work with anything else 

:param MPI_Comm comm: 
:param std\\:\\:size_t nx: 
:param std\\:\\:size_t ny:
";

%feature("docstring") dolfin::UnitSquareMesh "
Triangular mesh of the 2D unit square [0,1] x [0,1]. Given the number of cells (nx, ny) in each direction, the total number of triangles will be 2*nx*ny and the total number of vertices will be (nx + 1)*(ny + 1).
std::string diagonal (\"left\", \"right\", \"right/left\", \"left/right\", or \"crossed\") indicates the direction of the diagonals.
";

%feature("docstring") dolfin::UnitSquareMesh::UnitSquareMesh(MPI_Comm comm, std::size_t nx, std::size_t ny, std::string diagonal="right") "
Create a uniform finite element :cpp:any:`Mesh`  over the unit square [0,1] x [0,1].

::
   
   UnitSquareMesh mesh1(MPI_COMM_WORLD, 32, 32);
   UnitSquareMesh mesh2(MPI_COMM_WORLD, 32, 32, \"crossed\");

:param MPI_Comm comm:  (MPI_Comm) :cpp:any:`MPI`  communicator
:param std\\:\\:size_t nx:  (std::size_t) Number of cells in horizontal direction.
:param std\\:\\:size_t ny:  (std::size_t) Number of cells in vertical direction.
:param std\\:\\:string diagonal:  (std::string) Optional argument: A std::string indicating the direction of the diagonals.
";

%feature("docstring") dolfin::UnitSquareMesh::UnitSquareMesh(std::size_t nx, std::size_t ny, std::string diagonal="right") "
Create a uniform finite element :cpp:any:`Mesh`  over the unit square [0,1] x [0,1].

::
   
   UnitSquareMesh mesh1(32, 32);
   UnitSquareMesh mesh2(32, 32, \"crossed\");

:param std\\:\\:size_t nx:  (std::size_t) Number of cells in horizontal direction.
:param std\\:\\:size_t ny:  (std::size_t) Number of cells in vertical direction.
:param std\\:\\:string diagonal:  (std::string) Optional argument: A std::string indicating the direction of the diagonals.
";

%feature("docstring") dolfin::UnitTetrahedronMesh "
A mesh consisting of a single tetrahedron with vertices at
(0, 0, 0) (1, 0, 0) (0, 1, 0) (0, 0, 1)
This class is useful for testing.
";

%feature("docstring") dolfin::UnitTetrahedronMesh::UnitTetrahedronMesh() "
Create mesh of unit tetrahedron.
";

%feature("docstring") dolfin::UnitTriangleMesh "
A mesh consisting of a single triangle with vertices at
(0, 0) (1, 0) (0, 1)
This class is useful for testing.
";

%feature("docstring") dolfin::UnitTriangleMesh::UnitTriangleMesh() "
Create mesh of unit triangle.
";

