// Auto generated SWIG file for Python interface of DOLFIN
//
// Copyright (C) 2012-2016 Kristian B. Oelgaard, Tormod Landet
//
// This file is part of DOLFIN.
//
// DOLFIN is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// DOLFIN is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
//

// SWIG docstrings generated by doxygen and generate_api_rst.py / parse_doxygen.py

%feature("docstring") dolfin::BoundingBoxTree "
This class implements a (distributed) axis aligned bounding box tree (AABB tree). Bounding box trees can be created from meshes and [other data structures, to be filled in].
";

%feature("docstring") dolfin::BoundingBoxTree::BoundingBoxTree() "
Create empty bounding box tree.
";

%feature("docstring") dolfin::BoundingBoxTree::build(const Mesh &mesh) "
Build bounding box tree for cells of mesh.
Arguments mesh (:cpp:any:`Mesh` ) The mesh for which to compute the bounding box tree. 

:param const Mesh & mesh: 
:rtype: void
";

%feature("docstring") dolfin::BoundingBoxTree::build(const Mesh &mesh, std::size_t tdim) "
Build bounding box tree for mesh entities of given dimension.
Arguments mesh (:cpp:any:`Mesh` ) The mesh for which to compute the bounding box tree. dimension (std::size_t) The entity dimension (topological dimension) for which to compute the bounding box tree. 

:param const Mesh & mesh: 
:param std\\:\\:size_t tdim: 
:rtype: void
";

%feature("docstring") dolfin::BoundingBoxTree::build(const std::vector< Point > &points, std::size_t gdim) "
Build bounding box tree for point cloud.
Arguments points (std::vector<:cpp:any:`Point` >) The list of points. gdim (std::size_t) The geometric dimension. 

:param const std\\:\\:vector< Point > & points: 
:param std\\:\\:size_t gdim: 
:rtype: void
";

%feature("docstring") dolfin::BoundingBoxTree::collides(const Point &point) const "
Check whether given point collides with the bounding box tree. This is equivalent to calling compute_first_collision and checking whether any collision was detected.
Returns bool True iff the point is inside the tree. 

:param const Point & point: 
:rtype: bool
";

%feature("docstring") dolfin::BoundingBoxTree::collides_entity(const Point &point) const "
Check whether given point collides with any entity contained in the bounding box tree. This is equivalent to calling compute_first_entity_collision and checking whether any collision was detected.
Returns bool True iff the point is inside the tree. 

:param const Point & point: 
:rtype: bool
";

%feature("docstring") dolfin::BoundingBoxTree::compute_closest_entity(const Point &point) const "
Compute closest entity to :cpp:any:`Point` .
Returns unsigned int The local index for the entity that is closest to the point. If more than one entity is at the same distance (or point contained in entity), then the first entity is returned. double The distance to the closest entity.
Arguments point (:cpp:any:`Point` ) The point. 

:param const Point & point: 
:rtype: std::pair< unsigned int, double >
";

%feature("docstring") dolfin::BoundingBoxTree::compute_closest_point(const Point &point) const "
Compute closest point to :cpp:any:`Point` . This function assumes that the tree has been built for a point cloud.
Developer note: This function should not be confused with computing the closest point in all entities of a mesh. That function could be added with relative ease since we actually compute the closest points to get the distance in the above function (compute_closest_entity) inside the specialized implementations in TetrahedronCell.cpp etc.
Returns unsigned int The local index for the point that is closest to the point. If more than one point is at the same distance (or point contained in entity), then the first point is returned. double The distance to the closest point.
Arguments point (:cpp:any:`Point` ) The point. 

:param const Point & point: 
:rtype: std::pair< unsigned int, double >
";

%feature("docstring") dolfin::BoundingBoxTree::compute_collisions(const BoundingBoxTree &tree) const "
Compute all collisions between bounding boxes and :cpp:any:`BoundingBoxTree` .
Returns std::vector<unsigned int> A list of local indices for entities in this tree that collide with (intersect) entities in other tree. std::vector<unsigned int> A list of local indices for entities in other tree that collide with (intersect) entities in this tree.
The two lists have equal length and contain matching entities, such that entity ``i``  in the first list collides with entity ``i``  in the second list.
Note that this means that the entity lists may contain duplicate entities since a single entity may collide with several different entities.
Arguments tree (:cpp:any:`BoundingBoxTree` ) The bounding box tree.
Note that this function only checks collisions between bounding boxes of entities. It does not check that the entities themselves actually collide. To compute entity collisions, use the function compute_entity_collisions. 

:param const BoundingBoxTree & tree: 
:rtype: std::pair< std::vector< unsigned int >, std::vector< unsigned int > >
";

%feature("docstring") dolfin::BoundingBoxTree::compute_collisions(const Point &point) const "
Compute all collisions between bounding boxes and :cpp:any:`Point` .
Returns std::vector<unsigned int> A list of local indices for entities contained in (leaf) bounding boxes that collide with (intersect) the given point.
Arguments point (:cpp:any:`Point` ) The point. 

:param const Point & point: 
:rtype: std::vector< unsigned int >
";

%feature("docstring") dolfin::BoundingBoxTree::compute_entity_collisions(const BoundingBoxTree &tree) const "
Compute all collisions between entities and :cpp:any:`BoundingBoxTree` .
Returns std::vector<unsigned int> A list of local indices for entities in this tree that collide with (intersect) entities in other tree. std::vector<unsigned int> A list of local indices for entities in other tree that collide with (intersect) entities in this tree.
The two lists have equal length and contain matching entities, such that entity ``i``  in the first list collides with entity ``i``  in the second list.
Note that this means that the entity lists may contain duplicate entities since a single entity may collide with several different entities.
Arguments tree (:cpp:any:`BoundingBoxTree` ) The bounding box tree. 

:param const BoundingBoxTree & tree: 
:rtype: std::pair< std::vector< unsigned int >, std::vector< unsigned int > >
";

%feature("docstring") dolfin::BoundingBoxTree::compute_entity_collisions(const Point &point) const "
Compute all collisions between entities and :cpp:any:`Point` .
Returns std::vector<unsigned int> A list of local indices for entities that collide with (intersect) the given point.
Arguments point (:cpp:any:`Point` ) The point. 

:param const Point & point: 
:rtype: std::vector< unsigned int >
";

%feature("docstring") dolfin::BoundingBoxTree::compute_first_collision(const Point &point) const "
Compute first collision between bounding boxes and :cpp:any:`Point` .
Returns unsigned int The local index for the first found entity contained in a (leaf) bounding box that collides with (intersects) the given point. If not found, std::numeric_limits<unsigned int>::max() is returned.
Arguments point (:cpp:any:`Point` ) The point. 

:param const Point & point: 
:rtype: unsigned int
";

%feature("docstring") dolfin::BoundingBoxTree::compute_first_entity_collision(const Point &point) const "
Compute first collision between entities and :cpp:any:`Point` .
Returns unsigned int The local index for the first found entity that collides with (intersects) the given point. If not found, std::numeric_limits<unsigned int>::max() is returned.
Arguments point (:cpp:any:`Point` ) The point. 

:param const Point & point: 
:rtype: unsigned int
";

%feature("docstring") dolfin::BoundingBoxTree::compute_process_collisions(const Point &point) const "
Compute all collisions between process bounding boxes and :cpp:any:`Point` . Effectively a list of processes which may contain the :cpp:any:`Point` .
Returns std::vector<unsigned int> A list of process numbers where the :cpp:any:`Mesh`  may collide with (intersect) the given point.
Arguments point (:cpp:any:`Point` ) The point. 

:param const Point & point: 
:rtype: std::vector< unsigned int >
";

%feature("docstring") dolfin::BoundingBoxTree::~BoundingBoxTree() "
Destructor.
";

%feature("docstring") dolfin::BoundingBoxTree1D "
Specialization of bounding box implementation to 1D.
";

%feature("docstring") dolfin::BoundingBoxTree1D::bbox_in_bbox(const double *a, unsigned int node) const "
Check whether bounding box (a) collides with bounding box (node) 

:param const double * a: 
:param unsigned int node: 
:rtype: bool
";

%feature("docstring") dolfin::BoundingBoxTree1D::compute_bbox_of_bboxes(double *bbox, std::size_t &axis, const std::vector< double > &leaf_bboxes, const std::vector< unsigned int >::iterator &begin, const std::vector< unsigned int >::iterator &end) "
Compute bounding box of bounding boxes. 

:param double * bbox: 
:param std\\:\\:size_t & axis: 
:param const std\\:\\:vector< double > & leaf_bboxes: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & begin: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & end: 
:rtype: void
";

%feature("docstring") dolfin::BoundingBoxTree1D::compute_bbox_of_points(double *bbox, std::size_t &axis, const std::vector< Point > &points, const std::vector< unsigned int >::iterator &begin, const std::vector< unsigned int >::iterator &end) "
Compute bounding box of points. 

:param double * bbox: 
:param std\\:\\:size_t & axis: 
:param const std\\:\\:vector< Point > & points: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & begin: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & end: 
:rtype: void
";

%feature("docstring") dolfin::BoundingBoxTree1D::compute_squared_distance_bbox(const double *x, unsigned int node) const "
Compute squared distance between point and bounding box. 

:param const double * x: 
:param unsigned int node: 
:rtype: double
";

%feature("docstring") dolfin::BoundingBoxTree1D::compute_squared_distance_point(const double *x, unsigned int node) const "
Compute squared distance between point and point. 

:param const double * x: 
:param unsigned int node: 
:rtype: double
";

%feature("docstring") dolfin::BoundingBoxTree1D::gdim() const "
Return geometric dimension. 

:rtype: std::size_t
";

%feature("docstring") dolfin::BoundingBoxTree1D::get_bbox_coordinates(unsigned int node) const "
Return bounding box coordinates for node. 

:param unsigned int node: 
:rtype: const double *
";

%feature("docstring") dolfin::BoundingBoxTree1D::point_in_bbox(const double *x, unsigned int node) const "
Check whether point (x) is in bounding box (node) 

:param const double * x: 
:param unsigned int node: 
:rtype: bool
";

%feature("docstring") dolfin::BoundingBoxTree1D::sort_bboxes(std::size_t axis, const std::vector< double > &leaf_bboxes, const std::vector< unsigned int >::iterator &begin, const std::vector< unsigned int >::iterator &middle, const std::vector< unsigned int >::iterator &end) "
Sort leaf bounding boxes along given axis. 

:param std\\:\\:size_t axis: 
:param const std\\:\\:vector< double > & leaf_bboxes: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & begin: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & middle: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & end: 
:rtype: void
";

%feature("docstring") dolfin::BoundingBoxTree2D "
Specialization of bounding box implementation to 2D.
";

%feature("docstring") dolfin::BoundingBoxTree2D::bbox_in_bbox(const double *a, unsigned int node) const "
Check whether bounding box (a) collides with bounding box (node) 

:param const double * a: 
:param unsigned int node: 
:rtype: bool
";

%feature("docstring") dolfin::BoundingBoxTree2D::compute_bbox_of_bboxes(double *bbox, std::size_t &axis, const std::vector< double > &leaf_bboxes, const std::vector< unsigned int >::iterator &begin, const std::vector< unsigned int >::iterator &end) "
Compute bounding box of bounding boxes. 

:param double * bbox: 
:param std\\:\\:size_t & axis: 
:param const std\\:\\:vector< double > & leaf_bboxes: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & begin: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & end: 
:rtype: void
";

%feature("docstring") dolfin::BoundingBoxTree2D::compute_bbox_of_points(double *bbox, std::size_t &axis, const std::vector< Point > &points, const std::vector< unsigned int >::iterator &begin, const std::vector< unsigned int >::iterator &end) "
Compute bounding box of points. 

:param double * bbox: 
:param std\\:\\:size_t & axis: 
:param const std\\:\\:vector< Point > & points: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & begin: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & end: 
:rtype: void
";

%feature("docstring") dolfin::BoundingBoxTree2D::compute_squared_distance_bbox(const double *x, unsigned int node) const "
Compute squared distance between point and bounding box. 

:param const double * x: 
:param unsigned int node: 
:rtype: double
";

%feature("docstring") dolfin::BoundingBoxTree2D::compute_squared_distance_point(const double *x, unsigned int node) const "
Compute squared distance between point and point. 

:param const double * x: 
:param unsigned int node: 
:rtype: double
";

%feature("docstring") dolfin::BoundingBoxTree2D::gdim() const "
Return geometric dimension. 

:rtype: std::size_t
";

%feature("docstring") dolfin::BoundingBoxTree2D::get_bbox_coordinates(unsigned int node) const "
Return bounding box coordinates for node. 

:param unsigned int node: 
:rtype: const double *
";

%feature("docstring") dolfin::BoundingBoxTree2D::point_in_bbox(const double *x, unsigned int node) const "
Check whether point (x) is in bounding box (node) 

:param const double * x: 
:param unsigned int node: 
:rtype: bool
";

%feature("docstring") dolfin::BoundingBoxTree2D::sort_bboxes(std::size_t axis, const std::vector< double > &leaf_bboxes, const std::vector< unsigned int >::iterator &begin, const std::vector< unsigned int >::iterator &middle, const std::vector< unsigned int >::iterator &end) "
Sort leaf bounding boxes along given axis. 

:param std\\:\\:size_t axis: 
:param const std\\:\\:vector< double > & leaf_bboxes: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & begin: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & middle: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & end: 
:rtype: void
";

%feature("docstring") dolfin::BoundingBoxTree3D "
Specialization of bounding box implementation to 3D.
";

%feature("docstring") dolfin::BoundingBoxTree3D::bbox_in_bbox(const double *a, unsigned int node) const "
Check whether bounding box (a) collides with bounding box (node) 

:param const double * a: 
:param unsigned int node: 
:rtype: bool
";

%feature("docstring") dolfin::BoundingBoxTree3D::compute_bbox_of_bboxes(double *bbox, std::size_t &axis, const std::vector< double > &leaf_bboxes, const std::vector< unsigned int >::iterator &begin, const std::vector< unsigned int >::iterator &end) "
Compute bounding box of bounding boxes. 

:param double * bbox: 
:param std\\:\\:size_t & axis: 
:param const std\\:\\:vector< double > & leaf_bboxes: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & begin: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & end: 
:rtype: void
";

%feature("docstring") dolfin::BoundingBoxTree3D::compute_bbox_of_points(double *bbox, std::size_t &axis, const std::vector< Point > &points, const std::vector< unsigned int >::iterator &begin, const std::vector< unsigned int >::iterator &end) "
Compute bounding box of points. 

:param double * bbox: 
:param std\\:\\:size_t & axis: 
:param const std\\:\\:vector< Point > & points: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & begin: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & end: 
:rtype: void
";

%feature("docstring") dolfin::BoundingBoxTree3D::compute_squared_distance_bbox(const double *x, unsigned int node) const "
Compute squared distance between point and bounding box. 

:param const double * x: 
:param unsigned int node: 
:rtype: double
";

%feature("docstring") dolfin::BoundingBoxTree3D::compute_squared_distance_point(const double *x, unsigned int node) const "
Compute squared distance between point and point. 

:param const double * x: 
:param unsigned int node: 
:rtype: double
";

%feature("docstring") dolfin::BoundingBoxTree3D::gdim() const "
Return geometric dimension. 

:rtype: std::size_t
";

%feature("docstring") dolfin::BoundingBoxTree3D::get_bbox_coordinates(unsigned int node) const "
Return bounding box coordinates for node. 

:param unsigned int node: 
:rtype: const double *
";

%feature("docstring") dolfin::BoundingBoxTree3D::point_in_bbox(const double *x, const unsigned int node) const "
Check whether point (x) is in bounding box (node) 

:param const double * x: 
:param const unsigned int node: 
:rtype: bool
";

%feature("docstring") dolfin::BoundingBoxTree3D::sort_bboxes(std::size_t axis, const std::vector< double > &leaf_bboxes, const std::vector< unsigned int >::iterator &begin, const std::vector< unsigned int >::iterator &middle, const std::vector< unsigned int >::iterator &end) "
Sort leaf bounding boxes along given axis. 

:param std\\:\\:size_t axis: 
:param const std\\:\\:vector< double > & leaf_bboxes: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & begin: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & middle: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & end: 
:rtype: void
";

%feature("docstring") dolfin::CollisionDetection "
This class implements algorithms for detecting pairwise collisions between mesh entities of varying dimensions.
";

%feature("docstring") dolfin::CollisionDetection::collides(const MeshEntity &entity, const Point &point) "
Check whether entity collides with point.

:param const MeshEntity & entity:  (:cpp:any:`MeshEntity` ) The entity.
:param const Point & point:  (:cpp:any:`Point` ) The point.
:rtype: bool
:returns: bool True iff entity collides with cell.
";

%feature("docstring") dolfin::CollisionDetection::collides(const MeshEntity &entity_0, const MeshEntity &entity_1) "
Check whether two entities collide.

:param const MeshEntity & entity_0:  (:cpp:any:`MeshEntity` ) The first entity.
:param const MeshEntity & entity_1:  (:cpp:any:`MeshEntity` ) The second entity.
:rtype: bool
:returns: bool True iff entity collides with cell.
";

%feature("docstring") dolfin::CollisionDetection::collides_edge_edge(const Point &a, const Point &b, const Point &c, const Point &d) "
Check whether edge a-b collides with edge c-d. 

:param const Point & a: 
:param const Point & b: 
:param const Point & c: 
:param const Point & d: 
:rtype: bool
";

%feature("docstring") dolfin::CollisionDetection::collides_interval_interval(const MeshEntity &interval_0, const MeshEntity &interval_1) "
Check whether interval collides with interval.

:param const MeshEntity & interval_0:  (:cpp:any:`MeshEntity` ) The first interval.
:param const MeshEntity & interval_1:  (:cpp:any:`MeshEntity` ) The second interval.
:rtype: bool
:returns: bool True iff objects collide.
";

%feature("docstring") dolfin::CollisionDetection::collides_interval_point(const MeshEntity &interval, const Point &point) "
Check whether interval collides with point.

:param const MeshEntity & interval:  (:cpp:any:`MeshEntity` ) The interval.
:param const Point & point:  (:cpp:any:`Point` ) The point.
:rtype: bool
:returns: bool True iff objects collide.
";

%feature("docstring") dolfin::CollisionDetection::collides_interval_point(const Point &p0, const Point &p1, const Point &point) "
The implementation of collides_interval_point. 

:param const Point & p0: 
:param const Point & p1: 
:param const Point & point: 
:rtype: bool
";

%feature("docstring") dolfin::CollisionDetection::collides_tetrahedron_point(const MeshEntity &tetrahedron, const Point &point) "
Check whether tetrahedron collides with point.

:param const MeshEntity & tetrahedron:  (:cpp:any:`MeshEntity` ) The tetrahedron.
:param const Point & point:  (:cpp:any:`Point` ) The point.
:rtype: bool
:returns: bool True iff objects collide.
";

%feature("docstring") dolfin::CollisionDetection::collides_tetrahedron_point(const Point &p0, const Point &p1, const Point &p2, const Point &p3, const Point &point) "
The implementation of collides_tetrahedron_point. 

:param const Point & p0: 
:param const Point & p1: 
:param const Point & p2: 
:param const Point & p3: 
:param const Point & point: 
:rtype: bool
";

%feature("docstring") dolfin::CollisionDetection::collides_tetrahedron_tetrahedron(const MeshEntity &tetrahedron_0, const MeshEntity &tetrahedron_1) "
Check whether tetrahedron collides with tetrahedron.

:param const MeshEntity & tetrahedron_0:  (:cpp:any:`MeshEntity` ) The first tetrahedron.
:param const MeshEntity & tetrahedron_1:  (:cpp:any:`MeshEntity` ) The second tetrahedron.
:rtype: bool
:returns: bool True iff objects collide.
";

%feature("docstring") dolfin::CollisionDetection::collides_tetrahedron_triangle(const MeshEntity &tetrahedron, const MeshEntity &triangle) "
Check whether tetrahedron collides with triangle.

:param const MeshEntity & tetrahedron:  (:cpp:any:`MeshEntity` ) The tetrahedron.
:param const MeshEntity & triangle:  (:cpp:any:`MeshEntity` ) The triangle.
:rtype: bool
:returns: bool True iff objects collide.
";

%feature("docstring") dolfin::CollisionDetection::collides_tetrahedron_triangle(const Point &p0, const Point &p1, const Point &p2, const Point &p3, const Point &q0, const Point &q1, const Point &q2) "
:param const Point & p0: 
:param const Point & p1: 
:param const Point & p2: 
:param const Point & p3: 
:param const Point & q0: 
:param const Point & q1: 
:param const Point & q2: 
:rtype: bool
";

%feature("docstring") dolfin::CollisionDetection::collides_triangle_point(const MeshEntity &triangle, const Point &point) "
Check whether triangle collides with point.

:param const MeshEntity & triangle:  (:cpp:any:`MeshEntity` ) The triangle.
:param const Point & point:  (:cpp:any:`Point` ) The point.
:rtype: bool
:returns: bool True iff objects collide.
";

%feature("docstring") dolfin::CollisionDetection::collides_triangle_point(const Point &p0, const Point &p1, const Point &p2, const Point &point) "
The implementation of collides_triangle_point. 

:param const Point & p0: 
:param const Point & p1: 
:param const Point & p2: 
:param const Point & point: 
:rtype: bool
";

%feature("docstring") dolfin::CollisionDetection::collides_triangle_point_2d(const Point &p0, const Point &p1, const Point &p2, const Point &point) "
Specialised implementation of collides_triangle_point in 2D. 

:param const Point & p0: 
:param const Point & p1: 
:param const Point & p2: 
:param const Point & point: 
:rtype: bool
";

%feature("docstring") dolfin::CollisionDetection::collides_triangle_triangle(const MeshEntity &triangle_0, const MeshEntity &triangle_1) "
Check whether triangle collides with triangle.

:param const MeshEntity & triangle_0:  (:cpp:any:`MeshEntity` ) The first triangle.
:param const MeshEntity & triangle_1:  (:cpp:any:`MeshEntity` ) The second triangle.
:rtype: bool
:returns: bool True iff objects collide.
";

%feature("docstring") dolfin::CollisionDetection::collides_triangle_triangle(const Point &p0, const Point &p1, const Point &p2, const Point &q0, const Point &q1, const Point &q2) "
:param const Point & p0: 
:param const Point & p1: 
:param const Point & p2: 
:param const Point & q0: 
:param const Point & q1: 
:param const Point & q2: 
:rtype: bool
";

%feature("docstring") dolfin::CollisionDetection::compute_intervals(double VV0, double VV1, double VV2, double D0, double D1, double D2, double D0D1, double D0D2, double &A, double &B, double &C, double &X0, double &X1) "
:param double VV0: 
:param double VV1: 
:param double VV2: 
:param double D0: 
:param double D1: 
:param double D2: 
:param double D0D1: 
:param double D0D2: 
:param double & A: 
:param double & B: 
:param double & C: 
:param double & X0: 
:param double & X1: 
:rtype: bool
";

%feature("docstring") dolfin::CollisionDetection::coplanar_tri_tri(const Point &N, const Point &V0, const Point &V1, const Point &V2, const Point &U0, const Point &U1, const Point &U2) "
:param const Point & N: 
:param const Point & V0: 
:param const Point & V1: 
:param const Point & V2: 
:param const Point & U0: 
:param const Point & U1: 
:param const Point & U2: 
:rtype: bool
";

%feature("docstring") dolfin::CollisionDetection::edge_against_tri_edges(int i0, int i1, const Point &V0, const Point &V1, const Point &U0, const Point &U1, const Point &U2) "
:param int i0: 
:param int i1: 
:param const Point & V0: 
:param const Point & V1: 
:param const Point & U0: 
:param const Point & U1: 
:param const Point & U2: 
:rtype: bool
";

%feature("docstring") dolfin::CollisionDetection::edge_edge_test(int i0, int i1, double Ax, double Ay, const Point &V0, const Point &U0, const Point &U1) "
:param int i0: 
:param int i1: 
:param double Ax: 
:param double Ay: 
:param const Point & V0: 
:param const Point & U0: 
:param const Point & U1: 
:rtype: bool
";

%feature("docstring") dolfin::CollisionDetection::point_in_tri(int i0, int i1, const Point &V0, const Point &U0, const Point &U1, const Point &U2) "
:param int i0: 
:param int i1: 
:param const Point & V0: 
:param const Point & U0: 
:param const Point & U1: 
:param const Point & U2: 
:rtype: bool
";

%feature("docstring") dolfin::CollisionDetection::separating_plane_edge_A(const std::vector< std::vector< double > > &coord_1, const std::vector< int > &masks, int f0, int f1) "
:param const std\\:\\:vector< std\\:\\:vector< double > > & coord_1: 
:param const std\\:\\:vector< int > & masks: 
:param int f0: 
:param int f1: 
:rtype: bool
";

%feature("docstring") dolfin::CollisionDetection::separating_plane_face_A_1(const std::vector< Point > &pv1, const Point &n, std::vector< double > &bc, int &mask_edges) "
:param const std\\:\\:vector< Point > & pv1: 
:param const Point & n: 
:param std\\:\\:vector< double > & bc: 
:param int & mask_edges: 
:rtype: bool
";

%feature("docstring") dolfin::CollisionDetection::separating_plane_face_A_2(const std::vector< Point > &v1, const std::vector< Point > &v2, const Point &n, std::vector< double > &bc, int &mask_edges) "
:param const std\\:\\:vector< Point > & v1: 
:param const std\\:\\:vector< Point > & v2: 
:param const Point & n: 
:param std\\:\\:vector< double > & bc: 
:param int & mask_edges: 
:rtype: bool
";

%feature("docstring") dolfin::CollisionDetection::separating_plane_face_B_1(const std::vector< Point > &P_V2, const Point &n) "
:param const std\\:\\:vector< Point > & P_V2: 
:param const Point & n: 
:rtype: bool
";

%feature("docstring") dolfin::CollisionDetection::separating_plane_face_B_2(const std::vector< Point > &V1, const std::vector< Point > &V2, const Point &n) "
:param const std\\:\\:vector< Point > & V1: 
:param const std\\:\\:vector< Point > & V2: 
:param const Point & n: 
:rtype: bool
";

%feature("docstring") dolfin::GenericBoundingBoxTree "
Base class for bounding box implementations (envelope-letter design)
";

%feature("docstring") dolfin::GenericBoundingBoxTree::GenericBoundingBoxTree() "
Constructor.
";

%feature("docstring") dolfin::GenericBoundingBoxTree::add_bbox(const BBox &bbox, const double *b, std::size_t gdim) "
Add bounding box and coordinates. 

:param const BBox & bbox: 
:param const double * b: 
:param std\\:\\:size_t gdim: 
:rtype: unsigned int
";

%feature("docstring") dolfin::GenericBoundingBoxTree::add_point(const BBox &bbox, const Point &point, std::size_t gdim) "
Add bounding box and point coordinates. 

:param const BBox & bbox: 
:param const Point & point: 
:param std\\:\\:size_t gdim: 
:rtype: unsigned int
";

%feature("docstring") dolfin::GenericBoundingBoxTree::bbox_in_bbox(const double *a, unsigned int node) const  "
Check whether bounding box (a) collides with bounding box (node) 

:param const double * a: 
:param unsigned int node: 
:rtype: bool
";

%feature("docstring") dolfin::GenericBoundingBoxTree::build(const Mesh &mesh, std::size_t tdim) "
Build bounding box tree for mesh entities of given dimension. 

:param const Mesh & mesh: 
:param std\\:\\:size_t tdim: 
:rtype: void
";

%feature("docstring") dolfin::GenericBoundingBoxTree::build(const std::vector< Point > &points) "
Build bounding box tree for point cloud. 

:param const std\\:\\:vector< Point > & points: 
:rtype: void
";

%feature("docstring") dolfin::GenericBoundingBoxTree::build_point_search_tree(const Mesh &mesh) const "
Compute point search tree if not already done. 

:param const Mesh & mesh: 
:rtype: void
";

%feature("docstring") dolfin::GenericBoundingBoxTree::clear() "
Clear existing data if any. 

:rtype: void
";

%feature("docstring") dolfin::GenericBoundingBoxTree::compute_bbox_of_bboxes(double *bbox, std::size_t &axis, const std::vector< double > &leaf_bboxes, const std::vector< unsigned int >::iterator &begin, const std::vector< unsigned int >::iterator &end) "
Compute bounding box of bounding boxes. 

:param double * bbox: 
:param std\\:\\:size_t & axis: 
:param const std\\:\\:vector< double > & leaf_bboxes: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & begin: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & end: 
:rtype: void
";

%feature("docstring") dolfin::GenericBoundingBoxTree::compute_bbox_of_entity(double *b, const MeshEntity &entity, std::size_t gdim) const "
Compute bounding box of mesh entity. 

:param double * b: 
:param const MeshEntity & entity: 
:param std\\:\\:size_t gdim: 
:rtype: void
";

%feature("docstring") dolfin::GenericBoundingBoxTree::compute_bbox_of_points(double *bbox, std::size_t &axis, const std::vector< Point > &points, const std::vector< unsigned int >::iterator &begin, const std::vector< unsigned int >::iterator &end) "
Compute bounding box of points. 

:param double * bbox: 
:param std\\:\\:size_t & axis: 
:param const std\\:\\:vector< Point > & points: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & begin: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & end: 
:rtype: void
";

%feature("docstring") dolfin::GenericBoundingBoxTree::compute_closest_entity(const Point &point, const Mesh &mesh) const "
Compute closest entity and distance to :cpp:any:`Point` 

:param const Point & point: 
:param const Mesh & mesh: 
:rtype: std::pair< unsigned int, double >
";

%feature("docstring") dolfin::GenericBoundingBoxTree::compute_closest_point(const Point &point) const "
Compute closest point and distance to :cpp:any:`Point` 

:param const Point & point: 
:rtype: std::pair< unsigned int, double >
";

%feature("docstring") dolfin::GenericBoundingBoxTree::compute_collisions(const GenericBoundingBoxTree &tree) const "
Compute all collisions between bounding boxes and :cpp:any:`BoundingBoxTree` 

:param const GenericBoundingBoxTree & tree: 
:rtype: std::pair< std::vector< unsigned int >, std::vector< unsigned int > >
";

%feature("docstring") dolfin::GenericBoundingBoxTree::compute_collisions(const Point &point) const "
Compute all collisions between bounding boxes and :cpp:any:`Point` 

:param const Point & point: 
:rtype: std::vector< unsigned int >
";

%feature("docstring") dolfin::GenericBoundingBoxTree::compute_entity_collisions(const GenericBoundingBoxTree &tree, const Mesh &mesh_A, const Mesh &mesh_B) const "
Compute all collisions between entities and :cpp:any:`BoundingBoxTree` 

:param const GenericBoundingBoxTree & tree: 
:param const Mesh & mesh_A: 
:param const Mesh & mesh_B: 
:rtype: std::pair< std::vector< unsigned int >, std::vector< unsigned int > >
";

%feature("docstring") dolfin::GenericBoundingBoxTree::compute_entity_collisions(const Point &point, const Mesh &mesh) const "
Compute all collisions between entities and :cpp:any:`Point` 

:param const Point & point: 
:param const Mesh & mesh: 
:rtype: std::vector< unsigned int >
";

%feature("docstring") dolfin::GenericBoundingBoxTree::compute_first_collision(const Point &point) const "
Compute first collision between bounding boxes and :cpp:any:`Point` 

:param const Point & point: 
:rtype: unsigned int
";

%feature("docstring") dolfin::GenericBoundingBoxTree::compute_first_entity_collision(const Point &point, const Mesh &mesh) const "
Compute first collision between entities and :cpp:any:`Point` 

:param const Point & point: 
:param const Mesh & mesh: 
:rtype: unsigned int
";

%feature("docstring") dolfin::GenericBoundingBoxTree::compute_process_collisions(const Point &point) const "
Compute all collisions between processes and :cpp:any:`Point` 

:param const Point & point: 
:rtype: std::vector< unsigned int >
";

%feature("docstring") dolfin::GenericBoundingBoxTree::compute_squared_distance_bbox(const double *x, unsigned int node) const  "
Compute squared distance between point and bounding box. 

:param const double * x: 
:param unsigned int node: 
:rtype: double
";

%feature("docstring") dolfin::GenericBoundingBoxTree::compute_squared_distance_point(const double *x, unsigned int node) const  "
Compute squared distance between point and point. 

:param const double * x: 
:param unsigned int node: 
:rtype: double
";

%feature("docstring") dolfin::GenericBoundingBoxTree::create(unsigned int dim) "
Factory function returning (empty) tree of appropriate dimension. 

:param unsigned int dim: 
:rtype: std::shared_ptr< GenericBoundingBoxTree >
";

%feature("docstring") dolfin::GenericBoundingBoxTree::gdim() const  "
Return geometric dimension. 

:rtype: std::size_t
";

%feature("docstring") dolfin::GenericBoundingBoxTree::get_bbox(unsigned int node) const "
Return bounding box for given node. 

:param unsigned int node: 
:rtype: const BBox &
";

%feature("docstring") dolfin::GenericBoundingBoxTree::get_bbox_coordinates(unsigned int node) const  "
Return bounding box coordinates for node. 

:param unsigned int node: 
:rtype: const double *
";

%feature("docstring") dolfin::GenericBoundingBoxTree::is_leaf(const BBox &bbox, unsigned int node) const "
Check whether bounding box is a leaf node. 

:param const BBox & bbox: 
:param unsigned int node: 
:rtype: bool
";

%feature("docstring") dolfin::GenericBoundingBoxTree::num_bboxes() const "
Return number of bounding boxes. 

:rtype: unsigned int
";

%feature("docstring") dolfin::GenericBoundingBoxTree::point_in_bbox(const double *x, unsigned int node) const  "
Check whether point (x) is in bounding box (node) 

:param const double * x: 
:param unsigned int node: 
:rtype: bool
";

%feature("docstring") dolfin::GenericBoundingBoxTree::sort_bboxes(std::size_t axis, const std::vector< double > &leaf_bboxes, const std::vector< unsigned int >::iterator &begin, const std::vector< unsigned int >::iterator &middle, const std::vector< unsigned int >::iterator &end) "
Sort leaf bounding boxes along given axis. 

:param std\\:\\:size_t axis: 
:param const std\\:\\:vector< double > & leaf_bboxes: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & begin: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & middle: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & end: 
:rtype: void
";

%feature("docstring") dolfin::GenericBoundingBoxTree::sort_points(std::size_t axis, const std::vector< Point > &points, const std::vector< unsigned int >::iterator &begin, const std::vector< unsigned int >::iterator &middle, const std::vector< unsigned int >::iterator &end) "
Sort points along given axis. 

:param std\\:\\:size_t axis: 
:param const std\\:\\:vector< Point > & points: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & begin: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & middle: 
:param const std\\:\\:vector< unsigned int >\\:\\:iterator & end: 
:rtype: void
";

%feature("docstring") dolfin::GenericBoundingBoxTree::str(bool verbose=false) "
Print out for debugging. 

:param bool verbose: 
:rtype: std::string
";

%feature("docstring") dolfin::GenericBoundingBoxTree::tree_print(std::stringstream &s, unsigned int i) "
Print out recursively, for debugging. 

:param std\\:\\:stringstream & s: 
:param unsigned int i: 
:rtype: void
";

%feature("docstring") dolfin::GenericBoundingBoxTree::~GenericBoundingBoxTree() "
Destructor.
";

%feature("docstring") dolfin::IntersectionTriangulation "
This class implements algorithms for computing triangulations of pairwise intersections of simplices.
";

%feature("docstring") dolfin::IntersectionTriangulation::intersection_edge_edge(const Point &a, const Point &b, const Point &c, const Point &d, Point &pt) "
:param const Point & a: 
:param const Point & b: 
:param const Point & c: 
:param const Point & d: 
:param Point & pt: 
:rtype: bool
";

%feature("docstring") dolfin::IntersectionTriangulation::intersection_face_edge(const Point &r, const Point &s, const Point &t, const Point &a, const Point &b, Point &pt) "
:param const Point & r: 
:param const Point & s: 
:param const Point & t: 
:param const Point & a: 
:param const Point & b: 
:param Point & pt: 
:rtype: bool
";

%feature("docstring") dolfin::IntersectionTriangulation::triangulate_intersection(const MeshEntity &cell, const std::vector< double > &triangulation, const std::vector< Point > &normals, std::vector< double > &intersection_triangulation, std::vector< Point > &intersection_normals, std::size_t tdim) "
:cpp:any:`Function`  for computing the intersection of a cell with a flat vector of simplices with topological dimension tdim. The geometrical dimension is assumed to be the same as for the cell. The corresponding normals are also saved. 

:param const MeshEntity & cell: 
:param const std\\:\\:vector< double > & triangulation: 
:param const std\\:\\:vector< Point > & normals: 
:param std\\:\\:vector< double > & intersection_triangulation: 
:param std\\:\\:vector< Point > & intersection_normals: 
:param std\\:\\:size_t tdim: 
:rtype: void
";

%feature("docstring") dolfin::IntersectionTriangulation::triangulate_intersection(const MeshEntity &cell, const std::vector< double > &triangulation, std::size_t tdim) "
:cpp:any:`Function`  for computing the intersection of a cell with a flat vector of simplices with topological dimension tdim. The geometrical dimension is assumed to be the same as for the cell. 

:param const MeshEntity & cell: 
:param const std\\:\\:vector< double > & triangulation: 
:param std\\:\\:size_t tdim: 
:rtype: std::vector< double >
";

%feature("docstring") dolfin::IntersectionTriangulation::triangulate_intersection(const MeshEntity &entity_0, const MeshEntity &entity_1) "
Compute triangulation of intersection of two entities

:param const MeshEntity & entity_0:  (:cpp:any:`MeshEntity` ) The first entity.
:param const MeshEntity & entity_1:  (:cpp:any:`MeshEntity` ) The second entity.
:rtype: std::vector< double >
:returns: std::vector<double> A flattened array of simplices of dimension num_simplices x num_vertices x gdim = num_simplices x (tdim + 1) x gdim
";

%feature("docstring") dolfin::IntersectionTriangulation::triangulate_intersection(const std::vector< Point > &s0, std::size_t tdim0, const std::vector< Point > &s1, std::size_t tdim1, std::size_t gdim) "
:cpp:any:`Function`  for general intersection computation of two simplices with different topological dimension but the same geometrical dimension 

:param const std\\:\\:vector< Point > & s0: 
:param std\\:\\:size_t tdim0: 
:param const std\\:\\:vector< Point > & s1: 
:param std\\:\\:size_t tdim1: 
:param std\\:\\:size_t gdim: 
:rtype: std::vector< double >
";

%feature("docstring") dolfin::IntersectionTriangulation::triangulate_intersection_interval_interval(const MeshEntity &interval_0, const MeshEntity &interval_1) "
Compute triangulation of intersection of two intervals

:param const MeshEntity & interval_0:  (:cpp:any:`MeshEntity` ) The first interval.
:param const MeshEntity & interval_1:  (:cpp:any:`MeshEntity` ) The second interval.
:rtype: std::vector< double >
:returns: std::vector<double> A flattened array of simplices of dimension num_simplices x num_vertices x gdim = num_simplices x (tdim + 1) x gdim
";

%feature("docstring") dolfin::IntersectionTriangulation::triangulate_intersection_interval_interval(const std::vector< Point > &interval_0, const std::vector< Point > &interval_1, std::size_t gdim) "
:param const std\\:\\:vector< Point > & interval_0: 
:param const std\\:\\:vector< Point > & interval_1: 
:param std\\:\\:size_t gdim: 
:rtype: std::vector< double >
";

%feature("docstring") dolfin::IntersectionTriangulation::triangulate_intersection_tetrahedron_tetrahedron(const MeshEntity &tetrahedron_0, const MeshEntity &tetrahedron_1) "
Compute triangulation of intersection of two tetrahedra

:param const MeshEntity & tetrahedron_0:  (:cpp:any:`MeshEntity` ) The first tetrahedron.
:param const MeshEntity & tetrahedron_1:  (:cpp:any:`MeshEntity` ) The second tetrahedron.
:rtype: std::vector< double >
:returns: std::vector<double> A flattened array of simplices of dimension num_simplices x num_vertices x gdim = num_simplices x (tdim + 1) x gdim
";

%feature("docstring") dolfin::IntersectionTriangulation::triangulate_intersection_tetrahedron_tetrahedron(const std::vector< Point > &tet_0, const std::vector< Point > &tet_1) "
:param const std\\:\\:vector< Point > & tet_0: 
:param const std\\:\\:vector< Point > & tet_1: 
:rtype: std::vector< double >
";

%feature("docstring") dolfin::IntersectionTriangulation::triangulate_intersection_tetrahedron_triangle(const MeshEntity &tetrahedron, const MeshEntity &triangle) "
Compute triangulation of intersection of a tetrahedron and a triangle

:param const MeshEntity & tetrahedron:  (:cpp:any:`MeshEntity` ) The tetrahedron.
:param const MeshEntity & triangle:  (:cpp:any:`MeshEntity` ) The triangle
:rtype: std::vector< double >
:returns: std::vector<double> A flattened array of simplices of dimension num_simplices x num_vertices x gdim = num_simplices x (tdim + 1) x gdim
";

%feature("docstring") dolfin::IntersectionTriangulation::triangulate_intersection_tetrahedron_triangle(const std::vector< Point > &tet, const std::vector< Point > &tri) "
:param const std\\:\\:vector< Point > & tet: 
:param const std\\:\\:vector< Point > & tri: 
:rtype: std::vector< double >
";

%feature("docstring") dolfin::IntersectionTriangulation::triangulate_intersection_triangle_interval(const MeshEntity &triangle, const MeshEntity &interval) "
Compute triangulation of intersection of a triangle and an interval

:param const MeshEntity & triangle:  (:cpp:any:`MeshEntity` ) The triangle.
:param const MeshEntity & interval:  (:cpp:any:`MeshEntity` ) The interval.
:rtype: std::vector< double >
:returns: std::vector<double> A flattened array of simplices of dimension num_simplices x num_vertices x gdim = num_simplices x (tdim + 1) x gdim
";

%feature("docstring") dolfin::IntersectionTriangulation::triangulate_intersection_triangle_interval(const std::vector< Point > &triangle, const std::vector< Point > &interval, std::size_t gdim) "
:param const std\\:\\:vector< Point > & triangle: 
:param const std\\:\\:vector< Point > & interval: 
:param std\\:\\:size_t gdim: 
:rtype: std::vector< double >
";

%feature("docstring") dolfin::IntersectionTriangulation::triangulate_intersection_triangle_triangle(const MeshEntity &triangle_0, const MeshEntity &triangle_1) "
Compute triangulation of intersection of two triangles

:param const MeshEntity & triangle_0:  (:cpp:any:`MeshEntity` ) The first triangle.
:param const MeshEntity & triangle_1:  (:cpp:any:`MeshEntity` ) The second triangle.
:rtype: std::vector< double >
:returns: std::vector<double> A flattened array of simplices of dimension num_simplices x num_vertices x gdim = num_simplices x (tdim + 1) x gdim
";

%feature("docstring") dolfin::IntersectionTriangulation::triangulate_intersection_triangle_triangle(const std::vector< Point > &tri_0, const std::vector< Point > &tri_1) "
:param const std\\:\\:vector< Point > & tri_0: 
:param const std\\:\\:vector< Point > & tri_1: 
:rtype: std::vector< double >
";

%feature("docstring") dolfin::MeshPointIntersection "
This class represents an intersection between a :cpp:any:`Mesh`  and a :cpp:any:`Point` . The resulting intersection is stored as a list of zero or more cells.
";

%feature("docstring") dolfin::MeshPointIntersection::MeshPointIntersection(const Mesh &mesh, const Point &point) "
Compute intersection between mesh and point. 

:param const Mesh & mesh: 
:param const Point & point:
";

%feature("docstring") dolfin::MeshPointIntersection::intersected_cells() const "
Return the list of (local) indices for intersected cells. 

:rtype: const std::vector< unsigned int > &
";

%feature("docstring") dolfin::MeshPointIntersection::~MeshPointIntersection() "
Destructor.
";

%feature("docstring") dolfin::Point "
A :cpp:any:`Point`  represents a point in :math:`\\mathbb{R}^3`  with coordinates :math:`x, y, z,`  or alternatively, a vector in :math:`\\mathbb{R}^3` , supporting standard operations like the norm, distances, scalar and vector products etc.
";

%feature("docstring") dolfin::Point::Point(const Array< double > &x) "
Create point from :cpp:any:`Array` 

:param const Array< double > & x:  (Array<double>) :cpp:any:`Array`  of coordinates.
";

%feature("docstring") dolfin::Point::Point(const Point &p) "
Copy constructor

:param const Point & p:  (:cpp:any:`Point` ) The object to be copied.
";

%feature("docstring") dolfin::Point::Point(const double x=0.0, const double y=0.0, const double z=0.0) "
Create a point at (x, y, z). Default value (0, 0, 0).

:param const double x:  (double) The x-coordinate.
:param const double y:  (double) The y-coordinate.
:param const double z:  (double) The z-coordinate.
";

%feature("docstring") dolfin::Point::Point(std::size_t dim, const double *x) "
Create point from array

:param std\\:\\:size_t dim:  (std::size_t) Dimension of the array.
:param const double * x:  (double) The array to create a :cpp:any:`Point`  from.
";

%feature("docstring") dolfin::Point::array() const "
Return copy of coordinate array
Returns list of double The coordinates. 

:rtype: std::array< double, 3 >
";

%feature("docstring") dolfin::Point::coordinates() "
Return coordinate array

:rtype: double *
:returns: double* The coordinates.
";

%feature("docstring") dolfin::Point::coordinates() const "
Return coordinate array (const. version)

:rtype: const double *
:returns: double* The coordinates.
";

%feature("docstring") dolfin::Point::cross(const Point &p) const "
Compute cross product with given vector

:param const Point & p:  (:cpp:any:`Point` ) Another point.
:rtype: const Point
:returns: :cpp:any:`Point`  The cross product.
";

%feature("docstring") dolfin::Point::distance(const Point &p) const "
Compute distance to given point

::
   
   Point p1(0, 4, 0);
   Point p2(2, 0, 4);
   info(\"%g\", p1.distance(p2));

:param const Point & p:  (:cpp:any:`Point` ) The point to compute distance to.
:rtype: double
:returns: double The distance.
";

%feature("docstring") dolfin::Point::dot(const Point &p) const "
Compute dot product with given vector

::
   
   Point p1(1.0, 4.0, 8.0);
   Point p2(2.0, 0.0, 0.0);
   info(\"%g\", p1.dot(p2));

:param const Point & p:  (:cpp:any:`Point` ) Another point.
:rtype: double
:returns: double The dot product.
";

%feature("docstring") dolfin::Point::norm() const "
Compute norm of point representing a vector from the origin

::
   
   Point p(1.0, 2.0, 2.0);
   info(\"%g\", p.norm());

:rtype: double
:returns: double The (Euclidean) norm of the vector from the origin to the point.
";

%feature("docstring") dolfin::Point::operator*(double a) const "
Multiplication with scalar. 

:param double a: 
:rtype: Point
";

%feature("docstring") dolfin::Point::operator*=(double a) "
Incremental multiplication with scalar. 

:param double a: 
:rtype: const Point &
";

%feature("docstring") dolfin::Point::operator+(const Point &p) const "
Compute sum of two points 

:param const Point & p:  (:cpp:any:`Point` )
:rtype: Point
:returns: :cpp:any:`Point`
";

%feature("docstring") dolfin::Point::operator+=(const Point &p) "
Add given point. 

:param const Point & p: 
:rtype: const Point &
";

%feature("docstring") dolfin::Point::operator-() "
Unary minus. 

:rtype: Point
";

%feature("docstring") dolfin::Point::operator-(const Point &p) const "
Compute difference of two points 

:param const Point & p:  (:cpp:any:`Point` )
:rtype: Point
:returns: :cpp:any:`Point`
";

%feature("docstring") dolfin::Point::operator-=(const Point &p) "
Subtract given point. 

:param const Point & p: 
:rtype: const Point &
";

%feature("docstring") dolfin::Point::operator/(double a) const "
Division by scalar. 

:param double a: 
:rtype: Point
";

%feature("docstring") dolfin::Point::operator/=(double a) "
Incremental division by scalar. 

:param double a: 
:rtype: const Point &
";

%feature("docstring") dolfin::Point::operator=(const Point &p) "
Assignment operator. 

:param const Point & p: 
:rtype: const Point &
";

%feature("docstring") dolfin::Point::operator[](std::size_t i) "
Return address of coordinate in direction i
Returns

:param std\\:\\:size_t i:  (std::size_t) Direction.
:rtype: double &
:returns: double Address of coordinate in the given direction.
";

%feature("docstring") dolfin::Point::operator[](std::size_t i) const "
Return coordinate in direction i

:param std\\:\\:size_t i:  (std::size_t) Direction.
:rtype: double
:returns: double The coordinate in the given direction.
";

%feature("docstring") dolfin::Point::rotate(const Point &a, double theta) const "
Rotate around a given axis

:param const Point & a:  (:cpp:any:`Point` ) The axis to rotate around. Must be unit length.
:param double theta:  (double) The rotation angle.
:rtype: Point
:returns: :cpp:any:`Point`  The rotated point.
";

%feature("docstring") dolfin::Point::squared_distance(const Point &p) const "
Compute squared distance to given point

:param const Point & p:  (:cpp:any:`Point` ) The point to compute distance to.
:rtype: double
:returns: double The squared distance.
";

%feature("docstring") dolfin::Point::squared_norm() const "
Compute norm of point representing a vector from the origin

::
   
   Point p(1.0, 2.0, 2.0);
   info(\"%g\", p.squared_norm());

:rtype: double
:returns: double The squared (Euclidean) norm of the vector from the origin of the point.
";

%feature("docstring") dolfin::Point::str(bool verbose=false) const "
Return informal string representation (pretty-print)

:param bool verbose:  (bool) Flag to turn on additional output.
:rtype: std::string
:returns: std::string An informal representation of the function space.
";

%feature("docstring") dolfin::Point::x() const "
Return x-coordinate

:rtype: double
:returns: double The x-coordinate.
";

%feature("docstring") dolfin::Point::y() const "
Return y-coordinate

:rtype: double
:returns: double The y-coordinate.
";

%feature("docstring") dolfin::Point::z() const "
Return z-coordinate

:rtype: double
:returns: double The z-coordinate.
";

%feature("docstring") dolfin::Point::~Point() "
Destructor.
";

%feature("docstring") dolfin::SimplexQuadrature "
Quadrature on simplices.
";

%feature("docstring") dolfin::SimplexQuadrature::compute_quadrature_rule(const Cell &cell, std::size_t order) "
Compute quadrature rule for cell.
Arguments cell (:cpp:any:`Cell` ) The cell. order (std::size_t) The order of convergence of the quadrature rule.
Returns std::pair<std::vector<double>, std::vector<double> > A flattened array of quadrature points and a corresponding array of quadrature weights. 

:param const Cell & cell: 
:param std\\:\\:size_t order: 
:rtype: std::pair< std::vector< double >, std::vector< double > >
";

%feature("docstring") dolfin::SimplexQuadrature::compute_quadrature_rule(const double *coordinates, std::size_t tdim, std::size_t gdim, std::size_t order) "
Compute quadrature rule for simplex.
Arguments coordinates (double *) A flattened array of simplex coordinates of dimension num_vertices x gdim = (tdim + 1)*gdim. tdim (std::size_t) The topological dimension of the simplex. gdim (std::size_t) The geometric dimension. order (std::size_t) The order of convergence of the quadrature rule.
Returns std::pair<std::vector<double>, std::vector<double> > A flattened array of quadrature points and a corresponding array of quadrature weights. 

:param const double * coordinates: 
:param std\\:\\:size_t tdim: 
:param std\\:\\:size_t gdim: 
:param std\\:\\:size_t order: 
:rtype: std::pair< std::vector< double >, std::vector< double > >
";

%feature("docstring") dolfin::SimplexQuadrature::compute_quadrature_rule_interval(const double *coordinates, std::size_t gdim, std::size_t order) "
Compute quadrature rule for interval.
Arguments coordinates (double *) A flattened array of simplex coordinates of dimension num_vertices x gdim = 2*gdim. gdim (std::size_t) The geometric dimension. order (std::size_t) The order of convergence of the quadrature rule.
Returns std::pair<std::vector<double>, std::vector<double> > A flattened array of quadrature points and a corresponding array of quadrature weights. 

:param const double * coordinates: 
:param std\\:\\:size_t gdim: 
:param std\\:\\:size_t order: 
:rtype: std::pair< std::vector< double >, std::vector< double > >
";

%feature("docstring") dolfin::SimplexQuadrature::compute_quadrature_rule_tetrahedron(const double *coordinates, std::size_t gdim, std::size_t order) "
Compute quadrature rule for tetrahedron.
Arguments coordinates (double *) A flattened array of simplex coordinates of dimension num_vertices x gdim = 4*gdim. gdim (std::size_t) The geometric dimension. order (std::size_t) The order of convergence of the quadrature rule.
Returns std::pair<std::vector<double>, std::vector<double> > A flattened array of quadrature points and a corresponding array of quadrature weights. 

:param const double * coordinates: 
:param std\\:\\:size_t gdim: 
:param std\\:\\:size_t order: 
:rtype: std::pair< std::vector< double >, std::vector< double > >
";

%feature("docstring") dolfin::SimplexQuadrature::compute_quadrature_rule_triangle(const double *coordinates, std::size_t gdim, std::size_t order) "
Compute quadrature rule for triangle.
Arguments coordinates (double *) A flattened array of simplex coordinates of dimension num_vertices x gdim = 3*gdim. gdim (std::size_t) The geometric dimension. order (std::size_t) The order of convergence of the quadrature rule.
Returns std::pair<std::vector<double>, std::vector<double> > A flattened array of quadrature points and a corresponding array of quadrature weights. 

:param const double * coordinates: 
:param std\\:\\:size_t gdim: 
:param std\\:\\:size_t order: 
:rtype: std::pair< std::vector< double >, std::vector< double > >
";

%feature("docstring") dolfin::intersect(const Mesh &mesh, const Point &point) "
Compute and return intersection between :cpp:any:`Mesh`  and :cpp:any:`Point` .
Arguments mesh (:cpp:any:`Mesh` ) The mesh to be intersected. point (:cpp:any:`Point` ) The point to be intersected.
Returns:cpp:any:`MeshPointIntersection`  The intersection data. 

:param const Mesh & mesh: 
:param const Point & point: 
:rtype: std::shared_ptr< const MeshPointIntersection >
";

%feature("docstring") dolfin::operator*(double a, const Point &p) "
Multiplication with scalar. 

:param double a: 
:param const Point & p: 
:rtype: Point
";

%feature("docstring") dolfin::operator<<(std::ostream &stream, const Point &point) "
Output of :cpp:any:`Point`  to stream. 

:param std\\:\\:ostream & stream: 
:param const Point & point: 
:rtype: std::ostream &
";

