// Auto generated SWIG file for Python interface of DOLFIN
//
// Copyright (C) 2012-2016 Kristian B. Oelgaard, Tormod Landet
//
// This file is part of DOLFIN.
//
// DOLFIN is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// DOLFIN is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
//

// SWIG docstrings generated by doxygen and generate_api_rst.py / parse_doxygen.py

%feature("docstring") dolfin::File "
A :cpp:any:`File`  represents a data file for reading and writing objects. Unless specified explicitly, the format is determined by the file name suffix. A list of objects that can be read/written to file can be found in GenericFile.h. Compatible file formats include:

*  Binary (.bin)
*  RAW (.raw)
*  SVG (.svg)
*  XD3 (.xd3)
*  XML (.xml)
*  XYZ (.xyz)
*  VTK (.pvd)
";

%feature("docstring") dolfin::File::File(MPI_Comm comm, const std::string filename, Type type, std::string encoding="ascii") "
Create a file with given name and type (format) with :cpp:any:`MPI`  communicator
Arguments communicator (MPI_Comm) The :cpp:any:`MPI`  communicator. filename (std::string) Name of file. type (Type) :cpp:any:`File`  format. encoding (std::string) Optional argument specifying encoding, ascii is default.
Example .. code-block:: c++ 

::
   
   File file(MPI_COMM_WORLD, \"solution\", vtk);

:param MPI_Comm comm: 
:param const std\\:\\:string filename: 
:param Type type: 
:param std\\:\\:string encoding:
";

%feature("docstring") dolfin::File::File(MPI_Comm comm, const std::string filename, std::string encoding="ascii") "
Create a file with given name with :cpp:any:`MPI`  communicator
Arguments communicator (MPI_Comm) The :cpp:any:`MPI`  communicator. filename (std::string) Name of file. encoding (std::string) Optional argument specifying encoding, ascii is default.
Example .. code-block:: c++ 

::
   
    // Save solution to file
    File file(u.mesh()->mpi_comm(), \"solution.pvd\");
    file << u;
   
    // Read mesh data from file
    File mesh_file(MPI_COMM_WORLD, \"mesh.xml\");
    mesh_file >> mesh;
   
    // Using compressed binary format
    File comp_file(u.mesh()->mpi_comm(), \"solution.pvd\",
                   \"compressed\");

:param MPI_Comm comm: 
:param const std\\:\\:string filename: 
:param std\\:\\:string encoding:
";

%feature("docstring") dolfin::File::File(const std::string filename, Type type, std::string encoding="ascii") "
Create a file with given name and type (format)
Arguments filename (std::string) Name of file. type (Type) :cpp:any:`File`  format. encoding (std::string) Optional argument specifying encoding, ascii is default.
Example .. code-block:: c++ 

::
   
   File file(\"solution\", vtk);

:param const std\\:\\:string filename: 
:param Type type: 
:param std\\:\\:string encoding:
";

%feature("docstring") dolfin::File::File(const std::string filename, std::string encoding="ascii") "
Create a file with given name
Arguments filename (std::string) Name of file. encoding (std::string) Optional argument specifying encoding, ASCII is default.
Example .. code-block:: c++ 

::
   
    // Save solution to file
    File file(\"solution.pvd\");
    file << u;
   
    // Read mesh data from file
    File mesh_file(\"mesh.xml\");
    mesh_file >> mesh;
   
    // Using compressed binary format
    File comp_file(\"solution.pvd\", \"compressed\");

:param const std\\:\\:string filename: 
:param std\\:\\:string encoding:
";

%feature("docstring") dolfin::File::File(std::ostream &outstream) "
Create an outfile object writing to stream
Arguments outstream (std::ostream) The stream. 

:param std\\:\\:ostream & outstream:
";

%feature("docstring") dolfin::File::Type "
:cpp:any:`File`  formats. 

.. cpp:enumerator:: dolfin::File::Type::x3d 

.. cpp:enumerator:: dolfin::File::Type::xml 

.. cpp:enumerator:: dolfin::File::Type::vtk 

.. cpp:enumerator:: dolfin::File::Type::raw 

.. cpp:enumerator:: dolfin::File::Type::xyz 

.. cpp:enumerator:: dolfin::File::Type::binary 

.. cpp:enumerator:: dolfin::File::Type::svg
";

%feature("docstring") dolfin::File::create_parent_path(std::string filename) "
Arguments filename (std::string) Name of file / path. 

:param std\\:\\:string filename: 
:rtype: void
";

%feature("docstring") dolfin::File::exists(std::string filename) "
Check if file exists
Arguments filename (std::string) Name of file.
Returns bool True if the file exists. 

:param std\\:\\:string filename: 
:rtype: bool
";

%feature("docstring") dolfin::File::file "
:rtype: std::unique_ptr< GenericFile >
";

%feature("docstring") dolfin::File::init(MPI_Comm comm, const std::string filename, Type type, std::string encoding) "
:param MPI_Comm comm: 
:param const std\\:\\:string filename: 
:param Type type: 
:param std\\:\\:string encoding: 
:rtype: void
";

%feature("docstring") dolfin::File::init(MPI_Comm comm, const std::string filename, std::string encoding) "
:param MPI_Comm comm: 
:param const std\\:\\:string filename: 
:param std\\:\\:string encoding: 
:rtype: void
";

%feature("docstring") dolfin::File::operator<<(const T &t) "
Write object to file. 

:param const T & t: 
:rtype: void
";

%feature("docstring") dolfin::File::operator<<(const std::pair< const Function *, double > u) "
Write :cpp:any:`Function`  to file with time
Example .. code-block:: c++ 

::
   
   File file(\"solution.pvd\", \"compressed\");
   file << std::make_pair<const Function*, double>(&u, t);

:param const std\\:\\:pair< const Function *, double > u: 
:rtype: void
";

%feature("docstring") dolfin::File::operator<<(const std::pair< const Mesh *, double > mesh) "
Write :cpp:any:`Function`  to file. 
Write :cpp:any:`Mesh`  to file with time
Example .. code-block:: c++ 

::
   
   File file(\"mesh.pvd\", \"compressed\");
   file << std::make_pair<const Mesh*, double>(&mesh, t);

:param const std\\:\\:pair< const Mesh *, double > mesh: 
:rtype: void
";

%feature("docstring") dolfin::File::operator<<(const std::pair< const MeshFunction< bool > *, double > f) "
Write :cpp:any:`MeshFunction`  to file with time
Example .. code-block:: c++ 

::
   
   File file(\"markers.pvd\", \"compressed\");
   file << std::make_pair<const MeshFunction<bool>*, double>(&f, t);

:param const std\\:\\:pair< const MeshFunction< bool > *, double > f: 
:rtype: void
";

%feature("docstring") dolfin::File::operator<<(const std::pair< const MeshFunction< double > *, double > f) "
Write :cpp:any:`MeshFunction`  to file with time
Example .. code-block:: c++ 

::
   
   File file(\"markers.pvd\", \"compressed\");
   file << std::make_pair<const MeshFunction<double>*, double>(&f, t);

:param const std\\:\\:pair< const MeshFunction< double > *, double > f: 
:rtype: void
";

%feature("docstring") dolfin::File::operator<<(const std::pair< const MeshFunction< int > *, double > f) "
Write :cpp:any:`MeshFunction`  to file with time
Example .. code-block:: c++ 

::
   
   File file(\"markers.pvd\", \"compressed\");
   file << std::make_pair<const MeshFunction<int>*, double>(&f, t);

:param const std\\:\\:pair< const MeshFunction< int > *, double > f: 
:rtype: void
";

%feature("docstring") dolfin::File::operator<<(const std::pair< const MeshFunction< std::size_t > *, double > f) "
Write :cpp:any:`MeshFunction`  to file with time
Example .. code-block:: c++ 

::
   
   File file(\"markers.pvd\", \"compressed\");
   file << std::make_pair<const MeshFunction<std::size_t>*, double>(&f, t);

:param const std\\:\\:pair< const MeshFunction< std\\:\\:size_t > *, double > f: 
:rtype: void
";

%feature("docstring") dolfin::File::operator>>(T &t) "
Read from file. 

:param T & t: 
:rtype: void
";

%feature("docstring") dolfin::File::~File() "
Destructor.
";

%feature("docstring") dolfin::MeshValueCollection "
The :cpp:any:`MeshValueCollection`  class can be used to store data associated with a subset of the entities of a mesh of a given topological dimension. It differs from the :cpp:any:`MeshFunction`  class in two ways. First, data does not need to be associated with all entities (only a subset). Second, data is associated with entities through the corresponding cell index and local entity number (relative to the cell), not by global entity index, which means that data may be stored robustly to file.
";

%feature("docstring") dolfin::MeshValueCollection::MeshValueCollection() "
Create empty mesh value collection
";

%feature("docstring") dolfin::MeshValueCollection::MeshValueCollection(const MeshFunction< T > &mesh_function) "
Create a mesh value collection from a :cpp:any:`MeshFunction` 

:param const MeshFunction< T > & mesh_function:  (MeshFunction<T>) The mesh function for creating a :cpp:any:`MeshValueCollection` .
";

%feature("docstring") dolfin::MeshValueCollection::MeshValueCollection(std::shared_ptr< const Mesh > mesh) "
Create an empty mesh value collection on a given mesh

:param std\\:\\:shared_ptr< const Mesh > mesh:  (:cpp:any:`Mesh` ) The mesh.
";

%feature("docstring") dolfin::MeshValueCollection::MeshValueCollection(std::shared_ptr< const Mesh > mesh, const std::string filename) "
Create a mesh value collection from a file.

:param std\\:\\:shared_ptr< const Mesh > mesh:  (:cpp:any:`Mesh` ) A mesh associated with the collection. The mesh is used to map collection values to the appropriate process.
:param const std\\:\\:string filename:  (std::string) The XML file name.
";

%feature("docstring") dolfin::MeshValueCollection::MeshValueCollection(std::shared_ptr< const Mesh > mesh, std::size_t dim) "
Create a mesh value collection of entities of given dimension on a given mesh

:param std\\:\\:shared_ptr< const Mesh > mesh:  (:cpp:any:`Mesh` ) The mesh associated with the collection.
:param std\\:\\:size_t dim:  (std::size_t) The mesh entity dimension for the mesh value collection.
";

%feature("docstring") dolfin::MeshValueCollection::clear() "
Clear all values. 

:rtype: void
";

%feature("docstring") dolfin::MeshValueCollection::dim() const "
Return topological dimension

:rtype: std::size_t
:returns: std::size_t The dimension.
";

%feature("docstring") dolfin::MeshValueCollection::empty() const "
Return true if the subset is empty

:rtype: bool
:returns: bool True if the subset is empty.
";

%feature("docstring") dolfin::MeshValueCollection::get_value(std::size_t cell_index, std::size_t local_entity) "
Get marker value for given entity defined by a cell index and a local entity index

:param std\\:\\:size_t cell_index:  (std::size_t) The index of the cell.
:param std\\:\\:size_t local_entity:  (std::size_t) The local index of the entity relative to the cell.
:rtype: T
:returns: marker_value (T) The value of the marker.
";

%feature("docstring") dolfin::MeshValueCollection::init(std::shared_ptr< const Mesh > mesh, std::size_t dim) "
Initialise :cpp:any:`MeshValueCollection`  with mesh and dimension

:param std\\:\\:shared_ptr< const Mesh > mesh:  (_mesh)) The mesh on which the value collection is defined
:param std\\:\\:size_t dim:  (std::size_t) The mesh entity dimension for the mesh value collection.
:rtype: void
";

%feature("docstring") dolfin::MeshValueCollection::init(std::size_t dim) "
:cpp:any:`Set`  dimension. This function should not generally be used. It is for reading MeshValueCollections as the dimension is not generally known at construction.

:param std\\:\\:size_t dim:  (std::size_t) The mesh entity dimension for the mesh value collection.
:rtype: void
";

%feature("docstring") dolfin::MeshValueCollection::mesh() const "
Return associated mesh

:rtype: std::shared_ptr< const Mesh >
:returns: :cpp:any:`Mesh`  The mesh.
";

%feature("docstring") dolfin::MeshValueCollection::operator=(const MeshFunction< T > &mesh_function) "
Assignment operator

:param const MeshFunction< T > & mesh_function:  (:cpp:any:`MeshFunction` ) A :cpp:any:`MeshFunction`  object used to construct a :cpp:any:`MeshValueCollection` .
:rtype: MeshValueCollection< T > &
";

%feature("docstring") dolfin::MeshValueCollection::operator=(const MeshValueCollection< T > &mesh_value_collection) "
Assignment operator

:param const MeshValueCollection< T > & mesh_value_collection:  (:cpp:any:`MeshValueCollection` ) A :cpp:any:`MeshValueCollection`  object used to construct a :cpp:any:`MeshValueCollection` .
:rtype: MeshValueCollection< T > &
";

%feature("docstring") dolfin::MeshValueCollection::set_value(std::size_t cell_index, std::size_t local_entity, const T &value) "
:cpp:any:`Set`  marker value for given entity defined by a cell index and a local entity index

:param std\\:\\:size_t cell_index:  (std::size_t) The index of the cell.
:param std\\:\\:size_t local_entity:  (std::size_t) The local index of the entity relative to the cell.
:param const T & value:  (T) The value of the marker.
:rtype: bool
:returns: bool True is a new value is inserted, false if overwriting an existing value.
";

%feature("docstring") dolfin::MeshValueCollection::set_value(std::size_t entity_index, const T &value) "
:cpp:any:`Set`  value for given entity index

:param std\\:\\:size_t entity_index:  (std::size_t) Index of the entity.
:param const T & value:  (T). The value of the marker.
:rtype: bool
:returns: bool True is a new value is inserted, false if overwriting an existing value.
";

%feature("docstring") dolfin::MeshValueCollection::size() const "
Return size (number of entities in subset)

:rtype: std::size_t
:returns: std::size_t The size.
";

%feature("docstring") dolfin::MeshValueCollection::str(bool verbose) const "
Return informal string representation (pretty-print)

:param bool verbose:  (bool) Flag to turn on additional output.
:rtype: std::string
:returns: std::string An informal representation.
";

%feature("docstring") dolfin::MeshValueCollection::values() "
Get all values

:rtype: std::map< std::pair< std::size_t, std::size_t >, T > &
:returns: std::map<std::pair<std::size_t, std::size_t>, T> A map from positions to values.
";

%feature("docstring") dolfin::MeshValueCollection::values() const "
Get all values (const version)

:rtype: const std::map< std::pair< std::size_t, std::size_t >, T > &
:returns: std::map<std::pair<std::size_t, std::size_t>, T> A map from positions to values.
";

%feature("docstring") dolfin::MeshValueCollection::~MeshValueCollection() "
Destructor.
";

%feature("docstring") dolfin::RAWFile "
Output of data in raw binary format.
";

%feature("docstring") dolfin::RAWFile::MeshFunctionWrite(T &meshfunction) "
:param T & meshfunction: 
:rtype: void
";

%feature("docstring") dolfin::RAWFile::RAWFile(const std::string filename) "
Constructor. 

:param const std\\:\\:string filename:
";

%feature("docstring") dolfin::RAWFile::ResultsWrite(const Function &u) const "
:param const Function & u: 
:rtype: void
";

%feature("docstring") dolfin::RAWFile::operator<<(const Function &u) "
Output :cpp:any:`Function` 

:param const Function & u:  :cpp:any:`Function`
:rtype: void
";

%feature("docstring") dolfin::RAWFile::operator<<(const MeshFunction< double > &meshfunction) "
Output :cpp:any:`MeshFunction`  (double) 

:param const MeshFunction< double > & meshfunction:  :cpp:any:`MeshFunction`
:rtype: void
";

%feature("docstring") dolfin::RAWFile::operator<<(const MeshFunction< int > &meshfunction) "
Output :cpp:any:`MeshFunction`  (int) 

:param const MeshFunction< int > & meshfunction:  :cpp:any:`MeshFunction`
:rtype: void
";

%feature("docstring") dolfin::RAWFile::rawNameUpdate(const int counter) "
:param const int counter: 
:rtype: void
";

%feature("docstring") dolfin::RAWFile::raw_filename "
:rtype: std::string
";

%feature("docstring") dolfin::RAWFile::~RAWFile() "
Destructor.
";

%feature("docstring") dolfin::SVGFile "
This class implements output of meshes to scalable vector graphics format (SVG).
";

%feature("docstring") dolfin::SVGFile::SVGFile(const std::string filename) "
Constructor. 

:param const std\\:\\:string filename:
";

%feature("docstring") dolfin::SVGFile::operator<<(const Mesh &mesh) "
Store mesh to file. 

:param const Mesh & mesh: 
:rtype: void
";

%feature("docstring") dolfin::SVGFile::~SVGFile() "
Destructor.
";

%feature("docstring") dolfin::VTKFile "
Output of meshes and functions in VTK format. 
XML format for visualisation purposes. It is not suitable to checkpointing as it may decimate some data.
";

%feature("docstring") dolfin::VTKFile::VTKFile(const std::string filename, std::string encoding) "
Create VTK file. 

:param const std\\:\\:string filename: 
:param std\\:\\:string encoding:
";

%feature("docstring") dolfin::VTKFile::binary "
:rtype: bool
";

%feature("docstring") dolfin::VTKFile::clear_file(std::string file) const "
:param std\\:\\:string file: 
:rtype: void
";

%feature("docstring") dolfin::VTKFile::compress "
:rtype: bool
";

%feature("docstring") dolfin::VTKFile::encode_string "
:rtype: std::string
";

%feature("docstring") dolfin::VTKFile::finalize(std::string vtu_filename, double time) "
:param std\\:\\:string vtu_filename: 
:param double time: 
:rtype: void
";

%feature("docstring") dolfin::VTKFile::init(const Mesh &mesh, std::size_t dim) const "
:param const Mesh & mesh: 
:param std\\:\\:size_t dim: 
:rtype: std::string
";

%feature("docstring") dolfin::VTKFile::mesh_function_write(T &meshfunction, double time) "
:param T & meshfunction: 
:param double time: 
:rtype: void
";

%feature("docstring") dolfin::VTKFile::operator<<(const Function &u) "
Output :cpp:any:`Function` 

:param const Function & u:  (:cpp:any:`Function` )
:rtype: void
";

%feature("docstring") dolfin::VTKFile::operator<<(const Mesh &mesh) "
Output mesh. 

:param const Mesh & mesh: 
:rtype: void
";

%feature("docstring") dolfin::VTKFile::operator<<(const MeshFunction< bool > &meshfunction) "
Output MeshFunction<bool>

:param const MeshFunction< bool > & meshfunction:  
:rtype: void
";

%feature("docstring") dolfin::VTKFile::operator<<(const MeshFunction< double > &meshfunction) "
Output MeshFunction<double>

:param const MeshFunction< double > & meshfunction:  
:rtype: void
";

%feature("docstring") dolfin::VTKFile::operator<<(const MeshFunction< int > &meshfunction) "
Output MeshFunction<int>

:param const MeshFunction< int > & meshfunction:  
:rtype: void
";

%feature("docstring") dolfin::VTKFile::operator<<(const MeshFunction< std::size_t > &meshfunction) "
Output MeshFunction<std::size_t>

:param const MeshFunction< std\\:\\:size_t > & meshfunction:  
:rtype: void
";

%feature("docstring") dolfin::VTKFile::operator<<(const std::pair< const Function *, double > u) "
Output :cpp:any:`Function`  and timestep 

:param const std\\:\\:pair< const Function *, double > u:  :cpp:any:`Function`  and time
:rtype: void
";

%feature("docstring") dolfin::VTKFile::operator<<(const std::pair< const Mesh *, double > mesh) "
Output :cpp:any:`Mesh`  and timestep 

:param const std\\:\\:pair< const Mesh *, double > mesh:  :cpp:any:`Mesh`  and time
:rtype: void
";

%feature("docstring") dolfin::VTKFile::operator<<(const std::pair< const MeshFunction< bool > *, double > f) "
Output :cpp:any:`MeshFunction`  and timestep 

:param const std\\:\\:pair< const MeshFunction< bool > *, double > f:  :cpp:any:`MeshFunction`  and time
:rtype: void
";

%feature("docstring") dolfin::VTKFile::operator<<(const std::pair< const MeshFunction< double > *, double > f) "
Output :cpp:any:`MeshFunction`  and timestep 

:param const std\\:\\:pair< const MeshFunction< double > *, double > f:  :cpp:any:`MeshFunction`  and time
:rtype: void
";

%feature("docstring") dolfin::VTKFile::operator<<(const std::pair< const MeshFunction< int > *, double > f) "
Output :cpp:any:`MeshFunction`  and timestep 

:param const std\\:\\:pair< const MeshFunction< int > *, double > f:  :cpp:any:`MeshFunction`  and time
:rtype: void
";

%feature("docstring") dolfin::VTKFile::operator<<(const std::pair< const MeshFunction< std::size_t > *, double > f) "
Output :cpp:any:`MeshFunction`  and timestep 

:param const std\\:\\:pair< const MeshFunction< std\\:\\:size_t > *, double > f:  :cpp:any:`MeshFunction`  and time
:rtype: void
";

%feature("docstring") dolfin::VTKFile::pvd_file_write(std::size_t step, double time, std::string file) "
:param std\\:\\:size_t step: 
:param double time: 
:param std\\:\\:string file: 
:rtype: void
";

%feature("docstring") dolfin::VTKFile::pvtu_write(const Function &u, const std::string pvtu_filename) const "
:param const Function & u: 
:param const std\\:\\:string pvtu_filename: 
:rtype: void
";

%feature("docstring") dolfin::VTKFile::pvtu_write_function(std::size_t dim, std::size_t rank, const std::string data_location, const std::string name, const std::string filename, std::size_t num_processes) const "
:param std\\:\\:size_t dim: 
:param std\\:\\:size_t rank: 
:param const std\\:\\:string data_location: 
:param const std\\:\\:string name: 
:param const std\\:\\:string filename: 
:param std\\:\\:size_t num_processes: 
:rtype: void
";

%feature("docstring") dolfin::VTKFile::pvtu_write_mesh(const std::string pvtu_filename, const std::size_t num_processes) const "
:param const std\\:\\:string pvtu_filename: 
:param const std\\:\\:size_t num_processes: 
:rtype: void
";

%feature("docstring") dolfin::VTKFile::pvtu_write_mesh(pugi::xml_node xml_node) const "
:param pugi\\:\\:xml_node xml_node: 
:rtype: void
";

%feature("docstring") dolfin::VTKFile::results_write(const Function &u, std::string file) const "
:param const Function & u: 
:param std\\:\\:string file: 
:rtype: void
";

%feature("docstring") dolfin::VTKFile::strip_path(std::string file) const "
:param std\\:\\:string file: 
:rtype: std::string
";

%feature("docstring") dolfin::VTKFile::vtk_header_close(std::string file) const "
:param std\\:\\:string file: 
:rtype: void
";

%feature("docstring") dolfin::VTKFile::vtk_header_open(std::size_t num_vertices, std::size_t num_cells, std::string file) const "
:param std\\:\\:size_t num_vertices: 
:param std\\:\\:size_t num_cells: 
:param std\\:\\:string file: 
:rtype: void
";

%feature("docstring") dolfin::VTKFile::vtu_name(const int process, const int num_processes, const int counter, std::string ext) const "
:param const int process: 
:param const int num_processes: 
:param const int counter: 
:param std\\:\\:string ext: 
:rtype: std::string
";

%feature("docstring") dolfin::VTKFile::write_function(const Function &u, double time) "
:param const Function & u: 
:param double time: 
:rtype: void
";

%feature("docstring") dolfin::VTKFile::write_mesh(const Mesh &mesh, double time) "
:param const Mesh & mesh: 
:param double time: 
:rtype: void
";

%feature("docstring") dolfin::VTKFile::write_point_data(const GenericFunction &u, const Mesh &mesh, std::string file) const "
:param const GenericFunction & u: 
:param const Mesh & mesh: 
:param std\\:\\:string file: 
:rtype: void
";

%feature("docstring") dolfin::VTKFile::~VTKFile() "

";

%feature("docstring") dolfin::VTKWriter "
Write VTK :cpp:any:`Mesh`  representation.
";

%feature("docstring") dolfin::VTKWriter::ascii_cell_data(const Mesh &mesh, const std::vector< std::size_t > &offset, const std::vector< double > &values, std::size_t dim, std::size_t rank) "
:param const Mesh & mesh: 
:param const std\\:\\:vector< std\\:\\:size_t > & offset: 
:param const std\\:\\:vector< double > & values: 
:param std\\:\\:size_t dim: 
:param std\\:\\:size_t rank: 
:rtype: std::string
";

%feature("docstring") dolfin::VTKWriter::base64_cell_data(const Mesh &mesh, const std::vector< std::size_t > &offset, const std::vector< double > &values, std::size_t dim, std::size_t rank, bool compress) "
:param const Mesh & mesh: 
:param const std\\:\\:vector< std\\:\\:size_t > & offset: 
:param const std\\:\\:vector< double > & values: 
:param std\\:\\:size_t dim: 
:param std\\:\\:size_t rank: 
:param bool compress: 
:rtype: std::string
";

%feature("docstring") dolfin::VTKWriter::encode_inline_base64(const std::vector< T > &data) "
:param const std\\:\\:vector< T > & data: 
:rtype: std::string
";

%feature("docstring") dolfin::VTKWriter::encode_inline_compressed_base64(const std::vector< T > &data) "
:param const std\\:\\:vector< T > & data: 
:rtype: std::string
";

%feature("docstring") dolfin::VTKWriter::encode_stream(const std::vector< T > &data, bool compress) "
:cpp:any:`Form`  (compressed) base64 encoded string for VTK. 

:param const std\\:\\:vector< T > & data: 
:param bool compress: 
:rtype: std::string
";

%feature("docstring") dolfin::VTKWriter::vtk_cell_type(const Mesh &mesh, std::size_t cell_dim) "
:param const Mesh & mesh: 
:param std\\:\\:size_t cell_dim: 
:rtype: std::uint8_t
";

%feature("docstring") dolfin::VTKWriter::write_ascii_mesh(const Mesh &mesh, std::size_t cell_dim, std::string file) "
:param const Mesh & mesh: 
:param std\\:\\:size_t cell_dim: 
:param std\\:\\:string file: 
:rtype: void
";

%feature("docstring") dolfin::VTKWriter::write_base64_mesh(const Mesh &mesh, std::size_t cell_dim, std::string file, bool compress) "
:param const Mesh & mesh: 
:param std\\:\\:size_t cell_dim: 
:param std\\:\\:string file: 
:param bool compress: 
:rtype: void
";

%feature("docstring") dolfin::VTKWriter::write_cell_data(const Function &u, std::string file, bool binary, bool compress) "
:cpp:any:`Cell`  data writer. 

:param const Function & u: 
:param std\\:\\:string file: 
:param bool binary: 
:param bool compress: 
:rtype: void
";

%feature("docstring") dolfin::VTKWriter::write_mesh(const Mesh &mesh, std::size_t cell_dim, std::string file, bool binary, bool compress) "
:cpp:any:`Mesh`  writer. 

:param const Mesh & mesh: 
:param std\\:\\:size_t cell_dim: 
:param std\\:\\:string file: 
:param bool binary: 
:param bool compress: 
:rtype: void
";

%feature("docstring") dolfin::X3DFile "
This class implements output of meshes to X3D (successor to VRML) graphics format (`http://www.web3d.org/x3d/ <http://www.web3d.org/x3d/>`_ ). It is suitable for output of small to medium size meshes for 3D visualisation via browsers, and can also do basic :cpp:any:`Function`  and :cpp:any:`MeshFunction`  output (on the surface) X3D files can be included on web pages with WebGL functionality (see www.x3dom.org).
";

%feature("docstring") dolfin::X3DFile::X3DFile(const std::string filename) "
Constructor. 

:param const std\\:\\:string filename:
";

%feature("docstring") dolfin::X3DFile::color_palette(const int pal) const "
:param const int pal: 
:rtype: std::string
";

%feature("docstring") dolfin::X3DFile::facet_type "
:rtype: const std::string
";

%feature("docstring") dolfin::X3DFile::mesh_min_max(const Mesh &mesh) const "
:param const Mesh & mesh: 
:rtype: std::vector< double >
";

%feature("docstring") dolfin::X3DFile::operator<<(const Function &function) "
Output :cpp:any:`Function`  to X3D format - for a 3D mesh, only producing surface facets 

:param const Function & function: 
:rtype: void
";

%feature("docstring") dolfin::X3DFile::operator<<(const Mesh &mesh) "
Output :cpp:any:`Mesh`  to X3D format - for a 3D mesh, only producing surface facets 

:param const Mesh & mesh: 
:rtype: void
";

%feature("docstring") dolfin::X3DFile::operator<<(const MeshFunction< std::size_t > &meshfunction) "
Output :cpp:any:`MeshFunction`  to X3D format - for a 3D mesh, only producing surface facets 

:param const MeshFunction< std\\:\\:size_t > & meshfunction: 
:rtype: void
";

%feature("docstring") dolfin::X3DFile::output_xml_header(pugi::xml_document &xml_doc, const std::vector< double > &xpos) "
:param pugi\\:\\:xml_document & xml_doc: 
:param const std\\:\\:vector< double > & xpos: 
:rtype: void
";

%feature("docstring") dolfin::X3DFile::vertex_index(const Mesh &mesh) const "
:param const Mesh & mesh: 
:rtype: std::vector< std::size_t >
";

%feature("docstring") dolfin::X3DFile::write_meshfunction(const MeshFunction< std::size_t > &meshfunction) "
:param const MeshFunction< std\\:\\:size_t > & meshfunction: 
:rtype: void
";

%feature("docstring") dolfin::X3DFile::write_vertices(pugi::xml_document &xml_doc, const Mesh &mesh, const std::vector< std::size_t > vecindex) "
:param pugi\\:\\:xml_document & xml_doc: 
:param const Mesh & mesh: 
:param const std\\:\\:vector< std\\:\\:size_t > vecindex: 
:rtype: void
";

%feature("docstring") dolfin::X3DFile::~X3DFile() "
Destructor.
";

%feature("docstring") dolfin::X3DOM "
This class implements output of meshes to :cpp:any:`X3DOM`  XML or HTML5 with :cpp:any:`X3DOM`  strings. The latter can be used for interactive visualisation
";

%feature("docstring") dolfin::X3DOM::Viewpoint "
.. cpp:enumerator:: dolfin::X3DOM::Viewpoint::top 

.. cpp:enumerator:: dolfin::X3DOM::Viewpoint::bottom 

.. cpp:enumerator:: dolfin::X3DOM::Viewpoint::left 

.. cpp:enumerator:: dolfin::X3DOM::Viewpoint::right 

.. cpp:enumerator:: dolfin::X3DOM::Viewpoint::back 

.. cpp:enumerator:: dolfin::X3DOM::Viewpoint::front 

.. cpp:enumerator:: dolfin::X3DOM::Viewpoint::default_view
";

%feature("docstring") dolfin::X3DOM::add_html_doctype(pugi::xml_node &xml_node) "
:param pugi\\:\\:xml_node & xml_node: 
:rtype: void
";

%feature("docstring") dolfin::X3DOM::add_html_preamble(pugi::xml_node &xml_node) "
:param pugi\\:\\:xml_node & xml_node: 
:rtype: pugi::xml_node
";

%feature("docstring") dolfin::X3DOM::add_menu_color_tab(pugi::xml_node &xml_node) "
:param pugi\\:\\:xml_node & xml_node: 
:rtype: void
";

%feature("docstring") dolfin::X3DOM::add_menu_display(pugi::xml_node &xml_node, const Mesh &mesh, const X3DOMParameters &parameters) "
:param pugi\\:\\:xml_node & xml_node: 
:param const Mesh & mesh: 
:param const X3DOMParameters & parameters: 
:rtype: void
";

%feature("docstring") dolfin::X3DOM::add_menu_options_option(pugi::xml_node &xml_node, std::string name) "
:param pugi\\:\\:xml_node & xml_node: 
:param std\\:\\:string name: 
:rtype: void
";

%feature("docstring") dolfin::X3DOM::add_menu_options_tab(pugi::xml_node &xml_node) "
:param pugi\\:\\:xml_node & xml_node: 
:rtype: void
";

%feature("docstring") dolfin::X3DOM::add_menu_summary_tab(pugi::xml_node &xml_node, const Mesh &mesh) "
:param pugi\\:\\:xml_node & xml_node: 
:param const Mesh & mesh: 
:rtype: void
";

%feature("docstring") dolfin::X3DOM::add_menu_tab_button(pugi::xml_node &xml_node, std::string name, bool checked) "
:param pugi\\:\\:xml_node & xml_node: 
:param std\\:\\:string name: 
:param bool checked: 
:rtype: void
";

%feature("docstring") dolfin::X3DOM::add_menu_viewpoint_button(pugi::xml_node &xml_node, std::string name) "
:param pugi\\:\\:xml_node & xml_node: 
:param std\\:\\:string name: 
:rtype: void
";

%feature("docstring") dolfin::X3DOM::add_menu_viewpoint_tab(pugi::xml_node &xml_node) "
:param pugi\\:\\:xml_node & xml_node: 
:rtype: void
";

%feature("docstring") dolfin::X3DOM::add_menu_warp_tab(pugi::xml_node &xml_node) "
:param pugi\\:\\:xml_node & xml_node: 
:rtype: void
";

%feature("docstring") dolfin::X3DOM::add_mesh_data(pugi::xml_node &xml_node, const Mesh &mesh, const std::vector< double > &vertex_values, const std::vector< double > &facet_values, const X3DOMParameters &parameters, bool surface) "
:param pugi\\:\\:xml_node & xml_node: 
:param const Mesh & mesh: 
:param const std\\:\\:vector< double > & vertex_values: 
:param const std\\:\\:vector< double > & facet_values: 
:param const X3DOMParameters & parameters: 
:param bool surface: 
:rtype: void
";

%feature("docstring") dolfin::X3DOM::add_viewpoint_node(pugi::xml_node &xml_scene, Viewpoint viewpoint, const Point p, const double s) "
:param pugi\\:\\:xml_node & xml_scene: 
:param Viewpoint viewpoint: 
:param const Point p: 
:param const double s: 
:rtype: void
";

%feature("docstring") dolfin::X3DOM::add_viewpoint_nodes(pugi::xml_node &xml_scene, const Point p, double d, bool show_viewpoint_buttons) "
:param pugi\\:\\:xml_node & xml_scene: 
:param const Point p: 
:param double d: 
:param bool show_viewpoint_buttons: 
:rtype: void
";

%feature("docstring") dolfin::X3DOM::add_x3d_node(pugi::xml_node &xml_node, std::array< double, 2 > size, bool show_stats) "
:param pugi\\:\\:xml_node & xml_node: 
:param std\\:\\:array< double, 2 > size: 
:param bool show_stats: 
:rtype: pugi::xml_node
";

%feature("docstring") dolfin::X3DOM::add_x3dom_data(pugi::xml_node &xml_node, const Mesh &mesh, const std::vector< double > &vertex_values, const std::vector< double > &facet_values, const X3DOMParameters &parameters) "
:param pugi\\:\\:xml_node & xml_node: 
:param const Mesh & mesh: 
:param const std\\:\\:vector< double > & vertex_values: 
:param const std\\:\\:vector< double > & facet_values: 
:param const X3DOMParameters & parameters: 
:rtype: void
";

%feature("docstring") dolfin::X3DOM::add_x3dom_doctype(pugi::xml_node &xml_node) "
:param pugi\\:\\:xml_node & xml_node: 
:rtype: void
";

%feature("docstring") dolfin::X3DOM::array_to_string3(std::array< double, 3 > x) "
:param std\\:\\:array< double, 3 > x: 
:rtype: std::string
";

%feature("docstring") dolfin::X3DOM::build_mesh_data(std::vector< int > &topology, std::vector< double > &geometry, std::vector< double > &value_data, const Mesh &mesh, const std::vector< double > &vertex_values, const std::vector< double > &facet_values, bool surface) "
:param std\\:\\:vector< int > & topology: 
:param std\\:\\:vector< double > & geometry: 
:param std\\:\\:vector< double > & value_data: 
:param const Mesh & mesh: 
:param const std\\:\\:vector< double > & vertex_values: 
:param const std\\:\\:vector< double > & facet_values: 
:param bool surface: 
:rtype: void
";

%feature("docstring") dolfin::X3DOM::build_x3dom_tree(pugi::xml_document &xml_doc, const Function &u, const X3DOMParameters &parameters=X3DOMParameters()) "
Build :cpp:any:`X3DOM`  pugixml tree for a :cpp:any:`Function` . 

:param pugi\\:\\:xml_document & xml_doc: 
:param const Function & u: 
:param const X3DOMParameters & parameters: 
:rtype: void
";

%feature("docstring") dolfin::X3DOM::build_x3dom_tree(pugi::xml_document &xml_doc, const Mesh &mesh, const X3DOMParameters &parameters=X3DOMParameters()) "
Build :cpp:any:`X3DOM`  pugixml tree for a :cpp:any:`Mesh` . 

:param pugi\\:\\:xml_document & xml_doc: 
:param const Mesh & mesh: 
:param const X3DOMParameters & parameters: 
:rtype: void
";

%feature("docstring") dolfin::X3DOM::create_menu_content_node(pugi::xml_node &xml_node, std::string name, bool show) "
:param pugi\\:\\:xml_node & xml_node: 
:param std\\:\\:string name: 
:param bool show: 
:rtype: pugi::xml_node
";

%feature("docstring") dolfin::X3DOM::get_function_values(const Function &u, std::vector< double > &vertex_values, std::vector< double > &facet_values) "
:param const Function & u: 
:param std\\:\\:vector< double > & vertex_values: 
:param std\\:\\:vector< double > & facet_values: 
:rtype: void
";

%feature("docstring") dolfin::X3DOM::html(const Function &u, X3DOMParameters parameters=X3DOMParameters()) "
Return HTML5 string with embedded X3D for a :cpp:any:`Function` . 

:param const Function & u: 
:param X3DOMParameters parameters: 
:rtype: std::string
";

%feature("docstring") dolfin::X3DOM::html(const Mesh &mesh, X3DOMParameters parameters=X3DOMParameters()) "
Return HTML5 string with embedded X3D for a :cpp:any:`Mesh` . 

:param const Mesh & mesh: 
:param X3DOMParameters parameters: 
:rtype: std::string
";

%feature("docstring") dolfin::X3DOM::html(pugi::xml_document &xml_doc, const Mesh &mesh, const std::vector< double > &vertex_values, const std::vector< double > &facet_values, const X3DOMParameters &parameters) "
:param pugi\\:\\:xml_document & xml_doc: 
:param const Mesh & mesh: 
:param const std\\:\\:vector< double > & vertex_values: 
:param const std\\:\\:vector< double > & facet_values: 
:param const X3DOMParameters & parameters: 
:rtype: void
";

%feature("docstring") dolfin::X3DOM::mesh_centre_and_distance(const Mesh &mesh) "
:param const Mesh & mesh: 
:rtype: std::pair< Point, double >
";

%feature("docstring") dolfin::X3DOM::str(const Function &u, X3DOMParameters parameters=X3DOMParameters()) "
Return X3D string for a :cpp:any:`Function` . 

:param const Function & u: 
:param X3DOMParameters parameters: 
:rtype: std::string
";

%feature("docstring") dolfin::X3DOM::str(const Mesh &mesh, X3DOMParameters parameters=X3DOMParameters()) "
Return X3D string for a :cpp:any:`Mesh` . 

:param const Mesh & mesh: 
:param X3DOMParameters parameters: 
:rtype: std::string
";

%feature("docstring") dolfin::X3DOM::surface_vertex_indices(const Mesh &mesh) "
:param const Mesh & mesh: 
:rtype: std::set< int >
";

%feature("docstring") dolfin::X3DOM::to_string(pugi::xml_document &xml_doc, unsigned int flags) "
:param pugi\\:\\:xml_document & xml_doc: 
:param unsigned int flags: 
:rtype: std::string
";

%feature("docstring") dolfin::X3DOM::x3dom(pugi::xml_document &xml_doc, const Mesh &mesh, const std::vector< double > &vertex_values, const std::vector< double > &facet_values, const X3DOMParameters &parameters) "
:param pugi\\:\\:xml_document & xml_doc: 
:param const Mesh & mesh: 
:param const std\\:\\:vector< double > & vertex_values: 
:param const std\\:\\:vector< double > & facet_values: 
:param const X3DOMParameters & parameters: 
:rtype: void
";

%feature("docstring") dolfin::X3DOMParameters "
Class data to store :cpp:any:`X3DOM`  view parameters.
";

%feature("docstring") dolfin::X3DOMParameters::Representation "
:cpp:any:`X3DOM`  representation type. 

.. cpp:enumerator:: dolfin::X3DOMParameters::Representation::surface 

.. cpp:enumerator:: dolfin::X3DOMParameters::Representation::surface_with_edges 

.. cpp:enumerator:: dolfin::X3DOMParameters::Representation::wireframe
";

%feature("docstring") dolfin::X3DOMParameters::X3DOMParameters() "
Constructor (with default parameter settings)
";

%feature("docstring") dolfin::X3DOMParameters::check_rgb(std::array< double, 3 > &rgb) "
:param std\\:\\:array< double, 3 > & rgb: 
:rtype: void
";

%feature("docstring") dolfin::X3DOMParameters::check_value_range(double value, double lower, double upper) "
:param double value: 
:param double lower: 
:param double upper: 
:rtype: void
";

%feature("docstring") dolfin::X3DOMParameters::get_ambient_intensity() const "
Get the ambient lighting intensity. 

:rtype: double
";

%feature("docstring") dolfin::X3DOMParameters::get_background_color() const "
Get background RGB color. 

:rtype: std::array< double, 3 >
";

%feature("docstring") dolfin::X3DOMParameters::get_color_map() const "
Get the color map as a vector of 768 values (256*RGB) (using std::vector for Python compatibility via SWIG) 

:rtype: std::vector< double >
";

%feature("docstring") dolfin::X3DOMParameters::get_color_map_array() const "
Get the color map as a boost::multi_array (256x3) 

:rtype: boost::multi_array< float, 2 >
";

%feature("docstring") dolfin::X3DOMParameters::get_diffuse_color() const "
Get the RGB diffuse color of the object. 

:rtype: std::array< double, 3 >
";

%feature("docstring") dolfin::X3DOMParameters::get_emissive_color() const "
Get the RGB emissive color. 

:rtype: std::array< double, 3 >
";

%feature("docstring") dolfin::X3DOMParameters::get_menu_display() const "
Get the menu display state. 

:rtype: bool
";

%feature("docstring") dolfin::X3DOMParameters::get_representation() const "
Get the current representation of the object (wireframe, surface or surface_with_edges) 

:rtype: Representation
";

%feature("docstring") dolfin::X3DOMParameters::get_shininess() const "
:cpp:any:`Set`  the surface shininess of the object. 

:rtype: double
";

%feature("docstring") dolfin::X3DOMParameters::get_specular_color() const "
Get the RGB specular color. 

:rtype: std::array< double, 3 >
";

%feature("docstring") dolfin::X3DOMParameters::get_transparency() const "
Get the transparency (0-1) 

:rtype: double
";

%feature("docstring") dolfin::X3DOMParameters::get_viewport_size() const "
Get the size of the viewport. 

:rtype: std::array< double, 2 >
";

%feature("docstring") dolfin::X3DOMParameters::get_x3d_stats() const "
Get the state of the 'statistics' window. 

:rtype: bool
";

%feature("docstring") dolfin::X3DOMParameters::set_ambient_intensity(double intensity) "
:cpp:any:`Set`  the ambient lighting intensity. 

:param double intensity: 
:rtype: void
";

%feature("docstring") dolfin::X3DOMParameters::set_background_color(std::array< double, 3 > rgb) "
:cpp:any:`Set`  background RGB color. 

:param std\\:\\:array< double, 3 > rgb: 
:rtype: void
";

%feature("docstring") dolfin::X3DOMParameters::set_color_map(const std::vector< double > &color_data) "
:cpp:any:`Set`  the color map by supplying a vector of 768 values (256*RGB) (using std::vector for Python compatibility via SWIG) 

:param const std\\:\\:vector< double > & color_data: 
:rtype: void
";

%feature("docstring") dolfin::X3DOMParameters::set_diffuse_color(std::array< double, 3 > rgb) "
:cpp:any:`Set`  the RGB color of the object. 

:param std\\:\\:array< double, 3 > rgb: 
:rtype: void
";

%feature("docstring") dolfin::X3DOMParameters::set_emissive_color(std::array< double, 3 > rgb) "
:cpp:any:`Set`  the RGB emissive color. 

:param std\\:\\:array< double, 3 > rgb: 
:rtype: void
";

%feature("docstring") dolfin::X3DOMParameters::set_menu_display(bool show) "
Toggle menu option. 

:param bool show: 
:rtype: void
";

%feature("docstring") dolfin::X3DOMParameters::set_representation(Representation representation) "
:cpp:any:`Set`  representation of object (wireframe, surface or surface_with_edges) 

:param Representation representation: 
:rtype: void
";

%feature("docstring") dolfin::X3DOMParameters::set_shininess(double shininess) "
:cpp:any:`Set`  the surface shininess of the object. 

:param double shininess: 
:rtype: void
";

%feature("docstring") dolfin::X3DOMParameters::set_specular_color(std::array< double, 3 > rgb) "
:cpp:any:`Set`  the RGB specular color. 

:param std\\:\\:array< double, 3 > rgb: 
:rtype: void
";

%feature("docstring") dolfin::X3DOMParameters::set_transparency(double transparency) "
:cpp:any:`Set`  the transparency (0-1) 

:param double transparency: 
:rtype: void
";

%feature("docstring") dolfin::X3DOMParameters::set_x3d_stats(bool show) "
Turn X3D 'statistics' window on/off. 

:param bool show: 
:rtype: void
";

%feature("docstring") dolfin::XDMFFile "
Read and write :cpp:any:`Mesh` , :cpp:any:`Function` , :cpp:any:`MeshFunction`  and other objects in XDMF. 
This class supports the output of meshes and functions in XDMF (`http://www.xdmf.org <http://www.xdmf.org>`_ ) format. It creates an XML file that describes the data and points to a HDF5 file that stores the actual problem data. Output of data in parallel is supported.
XDMF is not suitable for checkpointing as it may decimate some data.
";

%feature("docstring") dolfin::XDMFFile::Encoding "
:cpp:any:`File`  encoding type. 

.. cpp:enumerator:: dolfin::XDMFFile::Encoding::HDF5 

.. cpp:enumerator:: dolfin::XDMFFile::Encoding::ASCII
";

%feature("docstring") dolfin::XDMFFile::XDMFFile(MPI_Comm comm, const std::string filename) "
Constructor. 

:param MPI_Comm comm: 
:param const std\\:\\:string filename:
";

%feature("docstring") dolfin::XDMFFile::XDMFFile(const std::string filename) "
Constructor. 

:param const std\\:\\:string filename:
";

%feature("docstring") dolfin::XDMFFile::add_data_item(MPI_Comm comm, pugi::xml_node &xml_node, hid_t h5_id, const std::string h5_path, const T &x, const std::vector< std::int64_t > dimensions, const std::string number_type="") "
:param MPI_Comm comm: 
:param pugi\\:\\:xml_node & xml_node: 
:param hid_t h5_id: 
:param const std\\:\\:string h5_path: 
:param const T & x: 
:param const std\\:\\:vector< std\\:\\:int64_t > dimensions: 
:param const std\\:\\:string number_type: 
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::add_geometry_data(MPI_Comm comm, pugi::xml_node &xml_node, hid_t h5_id, const std::string path_prefix, const Mesh &mesh) "
:param MPI_Comm comm: 
:param pugi\\:\\:xml_node & xml_node: 
:param hid_t h5_id: 
:param const std\\:\\:string path_prefix: 
:param const Mesh & mesh: 
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::add_mesh(MPI_Comm comm, pugi::xml_node &xml_node, hid_t h5_id, const Mesh &mesh, const std::string path_prefix) "
:param MPI_Comm comm: 
:param pugi\\:\\:xml_node & xml_node: 
:param hid_t h5_id: 
:param const Mesh & mesh: 
:param const std\\:\\:string path_prefix: 
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::add_points(MPI_Comm comm, pugi::xml_node &xml_node, hid_t h5_id, const std::vector< Point > &points) "
:param MPI_Comm comm: 
:param pugi\\:\\:xml_node & xml_node: 
:param hid_t h5_id: 
:param const std\\:\\:vector< Point > & points: 
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::add_topology_data(MPI_Comm comm, pugi::xml_node &xml_node, hid_t h5_id, const std::string path_prefix, const Mesh &mesh, int tdim) "
:param MPI_Comm comm: 
:param pugi\\:\\:xml_node & xml_node: 
:param hid_t h5_id: 
:param const std\\:\\:string path_prefix: 
:param const Mesh & mesh: 
:param int tdim: 
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::build_local_mesh_data(LocalMeshData &local_mesh_data, const CellType &cell_type, std::int64_t num_points, std::int64_t num_cells, int tdim, int gdim, const pugi::xml_node &topology_dataset_node, const pugi::xml_node &geometry_dataset_node, const boost::filesystem::path &parent_path) "
:param LocalMeshData & local_mesh_data: 
:param const CellType & cell_type: 
:param std\\:\\:int64_t num_points: 
:param std\\:\\:int64_t num_cells: 
:param int tdim: 
:param int gdim: 
:param const pugi\\:\\:xml_node & topology_dataset_node: 
:param const pugi\\:\\:xml_node & geometry_dataset_node: 
:param const boost\\:\\:filesystem\\:\\:path & parent_path: 
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::build_mesh(Mesh &mesh, const CellType &cell_type, std::int64_t num_points, std::int64_t num_cells, int tdim, int gdim, const pugi::xml_node &topology_dataset_node, const pugi::xml_node &geometry_dataset_node, const boost::filesystem::path &parent_path) "
:param Mesh & mesh: 
:param const CellType & cell_type: 
:param std\\:\\:int64_t num_points: 
:param std\\:\\:int64_t num_cells: 
:param int tdim: 
:param int gdim: 
:param const pugi\\:\\:xml_node & topology_dataset_node: 
:param const pugi\\:\\:xml_node & geometry_dataset_node: 
:param const boost\\:\\:filesystem\\:\\:path & parent_path: 
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::build_mesh_quadratic(Mesh &mesh, const CellType &cell_type, std::int64_t num_points, std::int64_t num_cells, int tdim, int gdim, const pugi::xml_node &topology_dataset_node, const pugi::xml_node &geometry_dataset_node, const boost::filesystem::path &relative_path) "
:param Mesh & mesh: 
:param const CellType & cell_type: 
:param std\\:\\:int64_t num_points: 
:param std\\:\\:int64_t num_cells: 
:param int tdim: 
:param int gdim: 
:param const pugi\\:\\:xml_node & topology_dataset_node: 
:param const pugi\\:\\:xml_node & geometry_dataset_node: 
:param const boost\\:\\:filesystem\\:\\:path & relative_path: 
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::check_encoding(Encoding encoding) const "
:param Encoding encoding: 
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::close() "
Close the file
This closes any open HDF5 files. In ASCII mode the XML file is closed each time it is written to or read from, so :cpp:any:`close()`  has no effect.
From Python you can also use :cpp:any:`XDMFFile`  as a context manager: 

::
   
   with XDMFFile(mpi_comm_world(), 'name.xdmf') as xdmf:
       xdmf.write(mesh)
   
The file is automatically closed at the end of the with block 

:rtype: void
";

%feature("docstring") dolfin::XDMFFile::compute_nonlocal_entities(const Mesh &mesh, int cell_dim) "
:param const Mesh & mesh: 
:param int cell_dim: 
:rtype: std::set< unsigned int >
";

%feature("docstring") dolfin::XDMFFile::compute_quadratic_topology(const Mesh &mesh) "
:param const Mesh & mesh: 
:rtype: std::vector< T >
";

%feature("docstring") dolfin::XDMFFile::compute_topology_data(const Mesh &mesh, int cell_dim) "
:param const Mesh & mesh: 
:param int cell_dim: 
:rtype: std::vector< T >
";

%feature("docstring") dolfin::XDMFFile::compute_value_data(const MeshFunction< T > &meshfunction) "
:param const MeshFunction< T > & meshfunction: 
:rtype: std::vector< T >
";

%feature("docstring") dolfin::XDMFFile::get_cell_data_values(const Function &u) "
:param const Function & u: 
:rtype: std::vector< double >
";

%feature("docstring") dolfin::XDMFFile::get_cell_type(const pugi::xml_node &topology_node) "
:param const pugi\\:\\:xml_node & topology_node: 
:rtype: std::pair< std::string, int >
";

%feature("docstring") dolfin::XDMFFile::get_dataset(MPI_Comm comm, const pugi::xml_node &dataset_node, const boost::filesystem::path &parent_path) "
:param MPI_Comm comm: 
:param const pugi\\:\\:xml_node & dataset_node: 
:param const boost\\:\\:filesystem\\:\\:path & parent_path: 
:rtype: std::vector< T >
";

%feature("docstring") dolfin::XDMFFile::get_dataset_shape(const pugi::xml_node &dataset_node) "
:param const pugi\\:\\:xml_node & dataset_node: 
:rtype: std::vector< std::int64_t >
";

%feature("docstring") dolfin::XDMFFile::get_hdf5_filename(std::string xdmf_filename) "
:param std\\:\\:string xdmf_filename: 
:rtype: std::string
";

%feature("docstring") dolfin::XDMFFile::get_hdf5_paths(const pugi::xml_node &dataitem_node) "
:param const pugi\\:\\:xml_node & dataitem_node: 
:rtype: std::array< std::string, 2 >
";

%feature("docstring") dolfin::XDMFFile::get_num_cells(const pugi::xml_node &topology_node) "
:param const pugi\\:\\:xml_node & topology_node: 
:rtype: std::int64_t
";

%feature("docstring") dolfin::XDMFFile::get_p2_data_values(const Function &u) "
:param const Function & u: 
:rtype: std::vector< double >
";

%feature("docstring") dolfin::XDMFFile::get_padded_width(const Function &u) "
:param const Function & u: 
:rtype: std::int64_t
";

%feature("docstring") dolfin::XDMFFile::get_point_data_values(const Function &u) "
:param const Function & u: 
:rtype: std::vector< double >
";

%feature("docstring") dolfin::XDMFFile::has_cell_centred_data(const Function &u) "
:param const Function & u: 
:rtype: bool
";

%feature("docstring") dolfin::XDMFFile::rank_to_string(std::size_t value_rank) "
:param std\\:\\:size_t value_rank: 
:rtype: std::string
";

%feature("docstring") dolfin::XDMFFile::read(Mesh &mesh) const "
Read in the first :cpp:any:`Mesh`  in XDMF file

:param Mesh & mesh:  (:cpp:any:`Mesh` ) :cpp:any:`Mesh`  to fill from XDMF file
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::read(MeshFunction< bool > &meshfunction, std::string name="") "
Read first :cpp:any:`MeshFunction`  from file 

:param MeshFunction< bool > & meshfunction:  (MeshFunction<bool>) :cpp:any:`MeshFunction`  to restore
:param std\\:\\:string name:  (std::string) Name of data attribute in XDMF file
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::read(MeshFunction< double > &meshfunction, std::string name="") "
Read :cpp:any:`MeshFunction`  from file, optionally specifying dataset name 

:param MeshFunction< double > & meshfunction:  (MeshFunction<double>) :cpp:any:`MeshFunction`  to restore
:param std\\:\\:string name:  (std::string) Name of data attribute in XDMF file
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::read(MeshFunction< int > &meshfunction, std::string name="") "
Read first :cpp:any:`MeshFunction`  from file 

:param MeshFunction< int > & meshfunction:  (MeshFunction<int>) :cpp:any:`MeshFunction`  to restore
:param std\\:\\:string name:  (std::string) Name of data attribute in XDMF file
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::read(MeshFunction< std::size_t > &meshfunction, std::string name="") "
Read :cpp:any:`MeshFunction`  from file, optionally specifying dataset name 

:param MeshFunction< std\\:\\:size_t > & meshfunction:  (MeshFunction<std::size_t>) :cpp:any:`MeshFunction`  to restore
:param std\\:\\:string name:  (std::string) Name of data attribute in XDMF file
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::read(MeshValueCollection< bool > &mvc, std::string name="") "
Read :cpp:any:`MeshValueCollection`  from file, optionally specifying dataset name 

:param MeshValueCollection< bool > & mvc:  (MeshValueCollection<bool>) :cpp:any:`MeshValueCollection`  to restore
:param std\\:\\:string name:  (std::string) Name of data attribute in XDMF file
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::read(MeshValueCollection< double > &mvc, std::string name="") "
Read :cpp:any:`MeshValueCollection`  from file, optionally specifying dataset name 

:param MeshValueCollection< double > & mvc:  (MeshValueCollection<double>) :cpp:any:`MeshValueCollection`  to restore
:param std\\:\\:string name:  (std::string) Name of data attribute in XDMF file
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::read(MeshValueCollection< int > &mvc, std::string name="") "
Read :cpp:any:`MeshValueCollection`  from file, optionally specifying dataset name 

:param MeshValueCollection< int > & mvc:  (MeshValueCollection<int>) :cpp:any:`MeshValueCollection`  to restore
:param std\\:\\:string name:  (std::string) Name of data attribute in XDMF file
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::read(MeshValueCollection< std::size_t > &mvc, std::string name="") "
Read :cpp:any:`MeshValueCollection`  from file, optionally specifying dataset name 

:param MeshValueCollection< std\\:\\:size_t > & mvc:  (MeshValueCollection<std::size_t>) :cpp:any:`MeshValueCollection`  to restore
:param std\\:\\:string name:  (std::string) Name of data attribute in XDMF file
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::read_mesh_function(MeshFunction< T > &meshfunction, std::string name="") "
:param MeshFunction< T > & meshfunction: 
:param std\\:\\:string name: 
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::read_mesh_value_collection(MeshValueCollection< T > &mvc, std::string name) "
:param MeshValueCollection< T > & mvc: 
:param std\\:\\:string name: 
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::remap_meshfunction_data(MeshFunction< T > &meshfunction, const std::vector< std::int64_t > &topology_data, const std::vector< T > &value_data) "
:param MeshFunction< T > & meshfunction: 
:param const std\\:\\:vector< std\\:\\:int64_t > & topology_data: 
:param const std\\:\\:vector< T > & value_data: 
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::string_to_vector(const std::vector< std::string > &x_str) "
:param const std\\:\\:vector< std\\:\\:string > & x_str: 
:rtype: std::vector< T >
";

%feature("docstring") dolfin::XDMFFile::to_string(X x, Y y) "
:param X x: 
:param Y y: 
:rtype: std::string
";

%feature("docstring") dolfin::XDMFFile::vtk_cell_type_str(CellType::Type cell_type, int order) "
:param CellType\\:\\:Type cell_type: 
:param int order: 
:rtype: std::string
";

%feature("docstring") dolfin::XDMFFile::write(const Function &u, Encoding encoding=Encoding::HDF5) "
Save a :cpp:any:`Function`  to XDMF file for visualisation, using an associated HDF5 file, or storing the data inline as XML.

:param const Function & u:  (:cpp:any:`Function` ) A function to save.
:param Encoding encoding:  (Encoding) Encoding to use: HDF5 or ASCII
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::write(const Function &u, double t, Encoding encoding=Encoding::HDF5) "
Save a :cpp:any:`Function`  with timestamp to XDMF file for visualisation, using an associated HDF5 file, or storing the data inline as XML.
You can control the output with the following boolean parameters on the :cpp:any:`XDMFFile`  class:

*  rewrite_function_mesh (default true): Controls whether the mesh will be rewritten every timestep. If the mesh does not change this can be turned off to create smaller files.
*  functions_share_mesh (default false): Controls whether all functions on a single time step share the same mesh. If true the files created will be smaller and also behave better in Paraview, at least in version 5.3.0

:param const Function & u:  (:cpp:any:`Function` ) A function to save.
:param double t:  (double) Timestep
:param Encoding encoding:  (Encoding) Encoding to use: HDF5 or ASCII
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::write(const Mesh &mesh, Encoding encoding=Encoding::HDF5) "
Save a mesh to XDMF format, either using an associated HDF5 file, or storing the data inline as XML Create function on given function space

:param const Mesh & mesh:  (:cpp:any:`Mesh` ) A mesh to save.
:param Encoding encoding:  (Encoding) Encoding to use: HDF5 or ASCII
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::write(const MeshFunction< bool > &meshfunction, Encoding encoding=Encoding::HDF5) "
Save :cpp:any:`MeshFunction`  to file using an associated HDF5 file, or storing the data inline as XML.

:param const MeshFunction< bool > & meshfunction:  (:cpp:any:`MeshFunction` ) A meshfunction to save.
:param Encoding encoding:  (Encoding) Encoding to use: HDF5 or ASCII
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::write(const MeshFunction< double > &meshfunction, Encoding encoding=Encoding::HDF5) "
Save :cpp:any:`MeshFunction`  to file using an associated HDF5 file, or storing the data inline as XML.

:param const MeshFunction< double > & meshfunction:  (:cpp:any:`MeshFunction` ) A meshfunction to save.
:param Encoding encoding:  (Encoding) Encoding to use: HDF5 or ASCII
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::write(const MeshFunction< int > &meshfunction, Encoding encoding=Encoding::HDF5) "
Save :cpp:any:`MeshFunction`  to file using an associated HDF5 file, or storing the data inline as XML.

:param const MeshFunction< int > & meshfunction:  (:cpp:any:`MeshFunction` ) A meshfunction to save.
:param Encoding encoding:  (Encoding) Encoding to use: HDF5 or ASCII
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::write(const MeshFunction< std::size_t > &meshfunction, Encoding encoding=Encoding::HDF5) "
Save :cpp:any:`MeshFunction`  to file using an associated HDF5 file, or storing the data inline as XML.

:param const MeshFunction< std\\:\\:size_t > & meshfunction:  (:cpp:any:`MeshFunction` ) A meshfunction to save.
:param Encoding encoding:  (Encoding) Encoding to use: HDF5 or ASCII
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::write(const MeshValueCollection< bool > &mvc, Encoding encoding=Encoding::HDF5) "
Write out mesh value collection (subset) using an associated HDF5 file, or storing the data inline as XML.

:param const MeshValueCollection< bool > & mvc:  (MeshValueCollection<bool>) :cpp:any:`MeshValueCollection`  to save
:param Encoding encoding:  (Encoding) Encoding to use: HDF5 or ASCII
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::write(const MeshValueCollection< double > &mvc, Encoding encoding=Encoding::HDF5) "
Write out mesh value collection (subset) using an associated HDF5 file, or storing the data inline as XML.

:param const MeshValueCollection< double > & mvc:  (MeshValueCollection<double>) :cpp:any:`MeshValueCollection`  to save
:param Encoding encoding:  (Encoding) Encoding to use: HDF5 or ASCII
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::write(const MeshValueCollection< int > &mvc, Encoding encoding=Encoding::HDF5) "
Write out mesh value collection (subset) using an associated HDF5 file, or storing the data inline as XML.

:param const MeshValueCollection< int > & mvc:  (MeshValueCollection<int>) :cpp:any:`MeshValueCollection`  to save
:param Encoding encoding:  (Encoding) Encoding to use: HDF5 or ASCII
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::write(const MeshValueCollection< std::size_t > &mvc, Encoding encoding=Encoding::HDF5) "
Write out mesh value collection (subset) using an associated HDF5 file, or storing the data inline as XML.

:param const MeshValueCollection< std\\:\\:size_t > & mvc:  (MeshValueCollection<int>) :cpp:any:`MeshValueCollection`  to save
:param Encoding encoding:  (Encoding) Encoding to use: HDF5 or ASCII
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::write(const std::vector< Point > &points, Encoding encoding=Encoding::HDF5) "
Save a cloud of points to file using an associated HDF5 file, or storing the data inline as XML.

:param const std\\:\\:vector< Point > & points:  (std::vector<Point>) A list of points to save.
:param Encoding encoding:  (Encoding) Encoding to use: HDF5 or ASCII
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::write(const std::vector< Point > &points, const std::vector< double > &values, Encoding encoding=Encoding::HDF5) "
Save a cloud of points, with scalar values using an associated HDF5 file, or storing the data inline as XML.

:param const std\\:\\:vector< Point > & points:  (std::vector<Point>) A list of points to save.
:param const std\\:\\:vector< double > & values:  (std::vector<double>) A list of values at each point.
:param Encoding encoding:  (Encoding) Encoding to use: HDF5 or ASCII
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::write_mesh_function(const MeshFunction< T > &meshfunction, Encoding encoding) "
:param const MeshFunction< T > & meshfunction: 
:param Encoding encoding: 
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::write_mesh_value_collection(const MeshValueCollection< T > &mvc, Encoding encoding) "
:param const MeshValueCollection< T > & mvc: 
:param Encoding encoding: 
:rtype: void
";

%feature("docstring") dolfin::XDMFFile::xdmf_format_str(Encoding encoding) "
:param Encoding encoding: 
:rtype: std::string
";

%feature("docstring") dolfin::XDMFFile::~XDMFFile() "
Destructor.
";

%feature("docstring") dolfin::XMLArray "
I/O of array data in XML format.
";

%feature("docstring") dolfin::XMLArray::read(std::vector< T > &x, const pugi::xml_node xml_dolfin) "
Read XML vector. :cpp:any:`Vector`  must have correct size. 

:param std\\:\\:vector< T > & x: 
:param const pugi\\:\\:xml_node xml_dolfin: 
:rtype: void
";

%feature("docstring") dolfin::XMLArray::write(const std::vector< T > &x, const std::string type, pugi::xml_node xml_node) "
Write the XML file. 

:param const std\\:\\:vector< T > & x: 
:param const std\\:\\:string type: 
:param pugi\\:\\:xml_node xml_node: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile "
I/O of DOLFIN objects in XML format.
";

%feature("docstring") dolfin::XMLFile::XMLFile(MPI_Comm mpi_comm, const std::string filename) "
Constructor. 

:param MPI_Comm mpi_comm: 
:param const std\\:\\:string filename:
";

%feature("docstring") dolfin::XMLFile::XMLFile(std::ostream &s) "
Constructor from a stream. 

:param std\\:\\:ostream & s:
";

%feature("docstring") dolfin::XMLFile::get_dolfin_xml_node(pugi::xml_document &xml_doc) const "
:param pugi\\:\\:xml_document & xml_doc: 
:rtype: const pugi::xml_node
";

%feature("docstring") dolfin::XMLFile::load_xml_doc(pugi::xml_document &xml_doc) const "
:param pugi\\:\\:xml_document & xml_doc: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator<<(const Function &output) "
:cpp:any:`Function`  data output. 

:param const Function & output: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator<<(const GenericVector &output) "
:cpp:any:`Vector`  output. 

:param const GenericVector & output: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator<<(const Mesh &output) "
:cpp:any:`Mesh`  output. 

:param const Mesh & output: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator<<(const MeshFunction< bool > &input) "
:cpp:any:`MeshFunction`  (bool) output. 

:param const MeshFunction< bool > & input: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator<<(const MeshFunction< double > &output) "
:cpp:any:`MeshFunction`  (double) output. 

:param const MeshFunction< double > & output: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator<<(const MeshFunction< int > &output) "
:cpp:any:`MeshFunction`  (int) output. 

:param const MeshFunction< int > & output: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator<<(const MeshFunction< std::size_t > &output) "
:cpp:any:`MeshFunction`  (uint) output. 

:param const MeshFunction< std\\:\\:size_t > & output: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator<<(const MeshValueCollection< bool > &input) "
:cpp:any:`MeshValueCollection`  (bool) output. 

:param const MeshValueCollection< bool > & input: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator<<(const MeshValueCollection< double > &output) "
:cpp:any:`MeshValueCollection`  (double) output. 

:param const MeshValueCollection< double > & output: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator<<(const MeshValueCollection< int > &output) "
:cpp:any:`MeshValueCollection`  (int) output. 

:param const MeshValueCollection< int > & output: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator<<(const MeshValueCollection< std::size_t > &output) "
:cpp:any:`MeshValueCollection`  (std::size_t) output. 

:param const MeshValueCollection< std\\:\\:size_t > & output: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator<<(const Parameters &output) "
:cpp:any:`Parameters`  output. 

:param const Parameters & output: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator<<(const Table &output) "
:cpp:any:`Table`  output. 

:param const Table & output: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator>>(Function &input) "
:cpp:any:`Function`  data input. 

:param Function & input: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator>>(GenericVector &input) "
:cpp:any:`Vector`  input. 

:param GenericVector & input: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator>>(Mesh &input) "
:cpp:any:`Mesh`  input. 

:param Mesh & input: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator>>(MeshFunction< bool > &input) "
:cpp:any:`MeshFunction`  (bool) input. 

:param MeshFunction< bool > & input: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator>>(MeshFunction< double > &input) "
:cpp:any:`MeshFunction`  (double) input. 

:param MeshFunction< double > & input: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator>>(MeshFunction< int > &input) "
:cpp:any:`MeshFunction`  (int) input. 

:param MeshFunction< int > & input: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator>>(MeshFunction< std::size_t > &input) "
:cpp:any:`MeshFunction`  (uint) input. 

:param MeshFunction< std\\:\\:size_t > & input: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator>>(MeshValueCollection< bool > &input) "
:cpp:any:`MeshValueCollection`  (bool) input. 

:param MeshValueCollection< bool > & input: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator>>(MeshValueCollection< double > &input) "
:cpp:any:`MeshValueCollection`  (double) input. 

:param MeshValueCollection< double > & input: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator>>(MeshValueCollection< int > &input) "
:cpp:any:`MeshValueCollection`  (int) input. 

:param MeshValueCollection< int > & input: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator>>(MeshValueCollection< std::size_t > &input) "
:cpp:any:`MeshValueCollection`  (std::size_t) input. 

:param MeshValueCollection< std\\:\\:size_t > & input: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator>>(Parameters &input) "
:cpp:any:`Parameters`  input. 

:param Parameters & input: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::operator>>(Table &input) "
:cpp:any:`Table`  input. 

:param Table & input: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::outstream "
:rtype: std::shared_ptr< std::ostream >
";

%feature("docstring") dolfin::XMLFile::read_mesh_function(MeshFunction< T > &t, const std::string type) const "
:param MeshFunction< T > & t: 
:param const std\\:\\:string type: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::read_mesh_value_collection(MeshValueCollection< T > &t, const std::string type) const "
:param MeshValueCollection< T > & t: 
:param const std\\:\\:string type: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::read_vector(std::vector< double > &input, std::vector< dolfin::la_index > &indices) "
:cpp:any:`Vector`  input. 

:param std\\:\\:vector< double > & input: 
:param std\\:\\:vector< dolfin\\:\\:la_index > & indices: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::save_xml_doc(const pugi::xml_document &xml_doc) const "
:param const pugi\\:\\:xml_document & xml_doc: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::write_dolfin(pugi::xml_document &doc) "
:param pugi\\:\\:xml_document & doc: 
:rtype: pugi::xml_node
";

%feature("docstring") dolfin::XMLFile::write_mesh_function(const MeshFunction< T > &t, const std::string type) "
:param const MeshFunction< T > & t: 
:param const std\\:\\:string type: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::write_mesh_value_collection(const MeshValueCollection< T > &t, const std::string type) "
:param const MeshValueCollection< T > & t: 
:param const std\\:\\:string type: 
:rtype: void
";

%feature("docstring") dolfin::XMLFile::~XMLFile() "

";

%feature("docstring") dolfin::XMLFunctionData "
I/O for XML representation of :cpp:any:`Function` .
";

%feature("docstring") dolfin::XMLFunctionData::build_dof_map(std::vector< std::vector< dolfin::la_index > > &global_dof_to_cell_dof, const FunctionSpace &V) "
:param std\\:\\:vector< std\\:\\:vector< dolfin\\:\\:la_index > > & global_dof_to_cell_dof: 
:param const FunctionSpace & V: 
:rtype: void
";

%feature("docstring") dolfin::XMLFunctionData::build_global_to_cell_dof(std::vector< std::vector< std::pair< dolfin::la_index, dolfin::la_index > > > &global_dof_to_cell_dof, const FunctionSpace &V) "
:param std\\:\\:vector< std\\:\\:vector< std\\:\\:pair< dolfin\\:\\:la_index, dolfin\\:\\:la_index > > > & global_dof_to_cell_dof: 
:param const FunctionSpace & V: 
:rtype: void
";

%feature("docstring") dolfin::XMLFunctionData::read(Function &u, pugi::xml_node xml_node) "
Read the XML file with function data. 

:param Function & u: 
:param pugi\\:\\:xml_node xml_node: 
:rtype: void
";

%feature("docstring") dolfin::XMLFunctionData::write(const Function &u, pugi::xml_node xml_node) "
Write the XML file with function data. 

:param const Function & u: 
:param pugi\\:\\:xml_node xml_node: 
:rtype: void
";

%feature("docstring") dolfin::XMLMesh "
I/O of XML representation of a :cpp:any:`Mesh` .
";

%feature("docstring") dolfin::XMLMesh::read(Mesh &mesh, const pugi::xml_node mesh_node) "
Read mesh from XML. 

:param Mesh & mesh: 
:param const pugi\\:\\:xml_node mesh_node: 
:rtype: void
";

%feature("docstring") dolfin::XMLMesh::read_array_uint(std::vector< std::size_t > &array, const pugi::xml_node xml_array) "
:param std\\:\\:vector< std\\:\\:size_t > & array: 
:param const pugi\\:\\:xml_node xml_array: 
:rtype: void
";

%feature("docstring") dolfin::XMLMesh::read_data(MeshData &data, const Mesh &mesh, const pugi::xml_node mesh_node) "
:param MeshData & data: 
:param const Mesh & mesh: 
:param const pugi\\:\\:xml_node mesh_node: 
:rtype: void
";

%feature("docstring") dolfin::XMLMesh::read_domain_data(LocalMeshData &mesh_data, const pugi::xml_node mesh_node) "
Read domain data in :cpp:any:`LocalMeshData` . 

:param LocalMeshData & mesh_data: 
:param const pugi\\:\\:xml_node mesh_node: 
:rtype: void
";

%feature("docstring") dolfin::XMLMesh::read_domains(MeshDomains &domains, const Mesh &mesh, const pugi::xml_node mesh_node) "
:param MeshDomains & domains: 
:param const Mesh & mesh: 
:param const pugi\\:\\:xml_node mesh_node: 
:rtype: void
";

%feature("docstring") dolfin::XMLMesh::read_mesh(Mesh &mesh, const pugi::xml_node mesh_node) "
:param Mesh & mesh: 
:param const pugi\\:\\:xml_node mesh_node: 
:rtype: void
";

%feature("docstring") dolfin::XMLMesh::write(const Mesh &mesh, pugi::xml_node mesh_node) "
Write mesh to XML. 

:param const Mesh & mesh: 
:param pugi\\:\\:xml_node mesh_node: 
:rtype: void
";

%feature("docstring") dolfin::XMLMesh::write_data(const Mesh &mesh, const MeshData &data, pugi::xml_node mesh_node) "
:param const Mesh & mesh: 
:param const MeshData & data: 
:param pugi\\:\\:xml_node mesh_node: 
:rtype: void
";

%feature("docstring") dolfin::XMLMesh::write_domains(const Mesh &mesh, const MeshDomains &domains, pugi::xml_node mesh_node) "
:param const Mesh & mesh: 
:param const MeshDomains & domains: 
:param pugi\\:\\:xml_node mesh_node: 
:rtype: void
";

%feature("docstring") dolfin::XMLMesh::write_mesh(const Mesh &mesh, pugi::xml_node mesh_node) "
:param const Mesh & mesh: 
:param pugi\\:\\:xml_node mesh_node: 
:rtype: void
";

%feature("docstring") dolfin::XMLMeshFunction "
I/O of XML representation of :cpp:any:`MeshFunction` .
";

%feature("docstring") dolfin::XMLMeshFunction::read(MeshFunction< T > &mesh_function, const std::string type, const pugi::xml_node xml_mesh) "
Read XML :cpp:any:`MeshFunction` . 

:param MeshFunction< T > & mesh_function: 
:param const std\\:\\:string type: 
:param const pugi\\:\\:xml_node xml_mesh: 
:rtype: void
";

%feature("docstring") dolfin::XMLMeshFunction::read(MeshValueCollection< T > &mesh_value_collection, const std::string type, const pugi::xml_node xml_mesh) "
Read XML :cpp:any:`MeshFunction`  as a :cpp:any:`MeshValueCollection` . 

:param MeshValueCollection< T > & mesh_value_collection: 
:param const std\\:\\:string type: 
:param const pugi\\:\\:xml_node xml_mesh: 
:rtype: void
";

%feature("docstring") dolfin::XMLMeshFunction::write(const MeshFunction< T > &mesh_function, const std::string type, pugi::xml_node xml_node, bool write_mesh=true) "
Write the XML file. 

:param const MeshFunction< T > & mesh_function: 
:param const std\\:\\:string type: 
:param pugi\\:\\:xml_node xml_node: 
:param bool write_mesh: 
:rtype: void
";

%feature("docstring") dolfin::XMLMeshValueCollection "
I/O of XML representation of a :cpp:any:`MeshValueCollection` .
";

%feature("docstring") dolfin::XMLMeshValueCollection::read(MeshValueCollection< T > &mesh_value_collection, const std::string type, const pugi::xml_node xml_node) "
Read mesh value collection from XML file. 

:param MeshValueCollection< T > & mesh_value_collection: 
:param const std\\:\\:string type: 
:param const pugi\\:\\:xml_node xml_node: 
:rtype: void
";

%feature("docstring") dolfin::XMLMeshValueCollection::write(const MeshValueCollection< T > &mesh_value_collection, const std::string type, pugi::xml_node xml_node) "
Write mesh value collection to XML file. 

:param const MeshValueCollection< T > & mesh_value_collection: 
:param const std\\:\\:string type: 
:param pugi\\:\\:xml_node xml_node: 
:rtype: void
";

%feature("docstring") dolfin::XMLParameters "
I/O of :cpp:any:`Parameters`  in XML format.
";

%feature("docstring") dolfin::XMLParameters::add_parameter(Parameters &p, const std::string &key, T value) "
:param Parameters & p: 
:param const std\\:\\:string & key: 
:param T value: 
:rtype: void
";

%feature("docstring") dolfin::XMLParameters::read(Parameters &parameters, const pugi::xml_node xml_dolfin) "
Read parameters from XML file. 

:param Parameters & parameters: 
:param const pugi\\:\\:xml_node xml_dolfin: 
:rtype: void
";

%feature("docstring") dolfin::XMLParameters::read_parameter_nest(Parameters &p, const pugi::xml_node xml_node) "
:param Parameters & p: 
:param const pugi\\:\\:xml_node xml_node: 
:rtype: void
";

%feature("docstring") dolfin::XMLParameters::write(const Parameters &parameters, pugi::xml_node xml_node) "
Write the XML file. 

:param const Parameters & parameters: 
:param pugi\\:\\:xml_node xml_node: 
:rtype: void
";

%feature("docstring") dolfin::XMLTable "
Output of XML representation of DOLFIN :cpp:any:`Table` .
";

%feature("docstring") dolfin::XMLTable::read(Table &table, pugi::xml_node xml_node) "
Read the XML file. 

:param Table & table: 
:param pugi\\:\\:xml_node xml_node: 
:rtype: void
";

%feature("docstring") dolfin::XMLTable::write(const Table &table, pugi::xml_node xml_node) "
Write the XML file. 

:param const Table & table: 
:param pugi\\:\\:xml_node xml_node: 
:rtype: void
";

%feature("docstring") dolfin::XMLVector "
I/O of XML representation of :cpp:any:`GenericVector` .
";

%feature("docstring") dolfin::XMLVector::read(GenericVector &x, const pugi::xml_node xml_dolfin) "
Read XML vector. :cpp:any:`Vector`  must have correct size. 

:param GenericVector & x: 
:param const pugi\\:\\:xml_node xml_dolfin: 
:rtype: void
";

%feature("docstring") dolfin::XMLVector::read(std::vector< double > &x, std::vector< dolfin::la_index > &indices, const pugi::xml_node xml_dolfin) "
Read XML vector in :cpp:any:`Array` . 

:param std\\:\\:vector< double > & x: 
:param std\\:\\:vector< dolfin\\:\\:la_index > & indices: 
:param const pugi\\:\\:xml_node xml_dolfin: 
:rtype: void
";

%feature("docstring") dolfin::XMLVector::read_size(const pugi::xml_node xml_dolfin) "
Read XML vector size. 

:param const pugi\\:\\:xml_node xml_dolfin: 
:rtype: std::size_t
";

%feature("docstring") dolfin::XMLVector::write(const GenericVector &vector, pugi::xml_node xml_node, bool write_to_stream) "
Write the XML file. 

:param const GenericVector & vector: 
:param pugi\\:\\:xml_node xml_node: 
:param bool write_to_stream: 
:rtype: void
";

%feature("docstring") dolfin::XYZFile "
Simple and light file format for use with Xd3d.
";

%feature("docstring") dolfin::XYZFile::XYZFile(const std::string filename) "
Simple and light file format for use with Xd3d. 
Supports scalar solution on 2D convex domains. The files only have a list of xyz coordinates 'x y u(x,y)=z' 

:param const std\\:\\:string filename:
";

%feature("docstring") dolfin::XYZFile::mesh_function_write(T &meshfunction) "
:param T & meshfunction: 
:rtype: void
";

%feature("docstring") dolfin::XYZFile::operator<<(const Function &u) "
Output :cpp:any:`Function` 

:param const Function & u:  :cpp:any:`Function`
:rtype: void
";

%feature("docstring") dolfin::XYZFile::results_write(const Function &u) const "
:param const Function & u: 
:rtype: void
";

%feature("docstring") dolfin::XYZFile::xyz_filename "
:rtype: std::string
";

%feature("docstring") dolfin::XYZFile::xyz_name_update() "
:rtype: void
";

%feature("docstring") dolfin::XYZFile::~XYZFile() "

";

