// Auto generated SWIG file for Python interface of DOLFIN
//
// Copyright (C) 2012-2016 Kristian B. Oelgaard, Tormod Landet
//
// This file is part of DOLFIN.
//
// DOLFIN is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// DOLFIN is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
//

// SWIG docstrings generated by doxygen and generate_api_rst.py / parse_doxygen.py

%feature("docstring") dolfin::BoundaryComputation "
Provide a set of basic algorithms for the computation of boundaries.
";

%feature("docstring") dolfin::BoundaryComputation::compute_boundary(const Mesh &mesh, const std::string type, BoundaryMesh &boundary) "
Compute the exterior boundary of a given mesh 

:param const Mesh & mesh:  input mesh [direction=in]
:param const std\\:\\:string type:  \"internal\" or \"external\" [direction=in]
:param BoundaryMesh & boundary:  output boundary mesh [direction=out]
:rtype: void
";

%feature("docstring") dolfin::BoundaryComputation::reorder(std::vector< std::size_t > &vertices, const Facet &facet) "
:param std\\:\\:vector< std\\:\\:size_t > & vertices: 
:param const Facet & facet: 
:rtype: void
";

%feature("docstring") dolfin::BoundaryMesh "
A :cpp:any:`BoundaryMesh`  is a mesh over the boundary of some given mesh. The cells of the boundary mesh (facets of the original mesh) are oriented to produce outward pointing normals relative to the original mesh.
";

%feature("docstring") dolfin::BoundaryMesh::BoundaryMesh() "

";

%feature("docstring") dolfin::BoundaryMesh::BoundaryMesh(const Mesh &mesh, std::string type, bool order=true) "
Create boundary mesh from given mesh.

:param const Mesh & mesh:  (:cpp:any:`Mesh` ) Another :cpp:any:`Mesh`  object.
:param std\\:\\:string type:  (std::string) The type of :cpp:any:`BoundaryMesh` , which can be \"exterior\", \"interior\" or \"local\". \"exterior\" is the globally external boundary, \"interior\" is the inter-process mesh and \"local\" is the boundary of the local (this process) mesh.
:param bool order:  (bool) Optional argument which can be used to control whether or not the boundary mesh should be ordered according to the :cpp:any:`UFC`  ordering convention. If set to false, the boundary mesh will be ordered with right-oriented facets (outward-pointing unit normals). The default value is true.
";

%feature("docstring") dolfin::BoundaryMesh::entity_map(std::size_t d) "
Get index map for entities of dimension d in the boundary mesh to the entity in the original full mesh 

:param std\\:\\:size_t d: 
:rtype: MeshFunction< std::size_t > &
";

%feature("docstring") dolfin::BoundaryMesh::entity_map(std::size_t d) const "
Get index map for entities of dimension d in the boundary mesh to the entity in the original full mesh (const version) 

:param std\\:\\:size_t d: 
:rtype: const MeshFunction< std::size_t > &
";

%feature("docstring") dolfin::BoundaryMesh::~BoundaryMesh() "
Destructor.
";

%feature("docstring") dolfin::Cell "
A :cpp:any:`Cell`  is a :cpp:any:`MeshEntity`  of topological codimension 0.
";

%feature("docstring") dolfin::Cell::Cell() "
Create empty cell.
";

%feature("docstring") dolfin::Cell::Cell(const Mesh &mesh, std::size_t index) "
Create cell on given mesh with given index

:param const Mesh & mesh:  The mesh.
:param std\\:\\:size_t index:  The index.
";

%feature("docstring") dolfin::Cell::cell_normal() const "
Compute normal to cell itself (viewed as embedded in 3D)

:rtype: Point
:returns: :cpp:any:`Point`  Normal of the cell
";

%feature("docstring") dolfin::Cell::circumradius() const "
Compute circumradius of cell

::
   
   UnitSquareMesh mesh(1, 1);
   Cell cell(mesh, 0);
   info(\"%g\", cell.circumradius());

:rtype: double
:returns: double The circumradius of the cell.
";

%feature("docstring") dolfin::Cell::collides(const MeshEntity &entity) const "
Check whether given entity collides with cell

:param const MeshEntity & entity:  The cell to be checked.
:rtype: bool
:returns: bool True iff entity collides with cell.
";

%feature("docstring") dolfin::Cell::collides(const Point &point) const "
Check whether given point collides with cell

:param const Point & point:  The point to be checked.
:rtype: bool
:returns: bool True iff point collides with cell.
";

%feature("docstring") dolfin::Cell::contains(const Point &point) const "
Check whether given point is contained in cell. This function is identical to the function collides(point).

:param const Point & point:  The point to be checked.
:rtype: bool
:returns: bool True iff point is contained in cell.
";

%feature("docstring") dolfin::Cell::distance(const Point &point) const "
Compute distance to given point.

:param const Point & point:  The point.
:rtype: double
:returns: double The distance to the point.
";

%feature("docstring") dolfin::Cell::facet_area(std::size_t facet) const "
Compute the area/length of given facet with respect to the cell

:param std\\:\\:size_t facet:  Index of the facet.
:rtype: double
:returns: double Area/length of the facet.
";

%feature("docstring") dolfin::Cell::get_cell_data(ufc::cell &ufc_cell, int local_facet=-1) const "
Fill :cpp:any:`UFC`  cell with miscellaneous data. 

:param ufc\\:\\:cell & ufc_cell: 
:param int local_facet: 
:rtype: void
";

%feature("docstring") dolfin::Cell::get_cell_topology(ufc::cell &ufc_cell) const "
Fill :cpp:any:`UFC`  cell with topology data. 

:param ufc\\:\\:cell & ufc_cell: 
:rtype: void
";

%feature("docstring") dolfin::Cell::get_coordinate_dofs(std::vector< double > &coordinates) const "
Get cell coordinate dofs (not vertex coordinates) 

:param std\\:\\:vector< double > & coordinates: 
:rtype: void
";

%feature("docstring") dolfin::Cell::get_vertex_coordinates(std::vector< double > &coordinates) const "
Get cell vertex coordinates (not coordinate dofs) 

:param std\\:\\:vector< double > & coordinates: 
:rtype: void
";

%feature("docstring") dolfin::Cell::h() const "
Compute greatest distance between any two vertices

::
   
   UnitSquareMesh mesh(1, 1);
   Cell cell(mesh, 0);
   info(\"%g\", cell.h());

:rtype: double
:returns: double The greatest distance between any two vertices of the cell.
";

%feature("docstring") dolfin::Cell::inradius() const "
Compute inradius of cell

::
   
   UnitSquareMesh mesh(1, 1);
   Cell cell(mesh, 0);
   info(\"%g\", cell.inradius());

:rtype: double
:returns: double Radius of the sphere inscribed in the cell.
";

%feature("docstring") dolfin::Cell::normal(std::size_t facet) const "
Compute normal of given facet with respect to the cell

:param std\\:\\:size_t facet:  Index of facet.
:rtype: Point
:returns: :cpp:any:`Point`  Normal of the facet.
";

%feature("docstring") dolfin::Cell::normal(std::size_t facet, std::size_t i) const "
Compute component i of normal of given facet with respect to the cell

:param std\\:\\:size_t facet:  Index of facet.
:param std\\:\\:size_t i:  Component.
:rtype: double
:returns: double Component i of the normal of the facet.
";

%feature("docstring") dolfin::Cell::num_vertices() const "
Return number of vertices of cell. 

:rtype: std::size_t
";

%feature("docstring") dolfin::Cell::order(const std::vector< std::int64_t > &local_to_global_vertex_indices) "
Order entities locally

:param const std\\:\\:vector< std\\:\\:int64_t > & local_to_global_vertex_indices:  The global vertex indices.
:rtype: void
";

%feature("docstring") dolfin::Cell::ordered(const std::vector< std::int64_t > &local_to_global_vertex_indices) const "
Check if entities are ordered

:param const std\\:\\:vector< std\\:\\:int64_t > & local_to_global_vertex_indices:  The global vertex indices.
:rtype: bool
:returns: bool True iff ordered.
";

%feature("docstring") dolfin::Cell::orientation() const "
Compute orientation of cell

:rtype: std::size_t
:returns: std::size_t Orientation of the cell (0 is 'up'/'right', 1 is 'down'/'left')
";

%feature("docstring") dolfin::Cell::orientation(const Point &up) const "
Compute orientation of cell relative to given 'up' direction

:param const Point & up:  The direction defined as 'up'
:rtype: std::size_t
:returns: std::size_t Orientation of the cell (0 is 'same', 1 is 'opposite')
";

%feature("docstring") dolfin::Cell::radius_ratio() const "
Compute ratio of inradius to circumradius times dim for cell. Useful as cell quality measure. Returns 1. for equilateral and 0. for degenerate cell. See Jonathan Richard Shewchuk: What Is a Good Linear Finite Element?, online: `http://www.cs.berkeley.edu/~jrs/papers/elemj.pdf <http://www.cs.berkeley.edu/~jrs/papers/elemj.pdf>`_ 

::
   
   UnitSquareMesh mesh(1, 1);
   Cell cell(mesh, 0);
   info(\"%g\", cell.radius_ratio());

:rtype: double
:returns: double topological_dimension * inradius / circumradius
";

%feature("docstring") dolfin::Cell::squared_distance(const Point &point) const "
Compute squared distance to given point.

:param const Point & point:  The point.
:rtype: double
:returns: double The squared distance to the point.
";

%feature("docstring") dolfin::Cell::triangulate_intersection(const MeshEntity &entity) const "
Compute triangulation of intersection with given entity

:param const MeshEntity & entity:  The entity with which to intersect.
:rtype: std::vector< double >
:returns: std::vector<double> A flattened array of simplices of dimension num_simplices x num_vertices x gdim = num_simplices x (tdim + 1) x gdim
";

%feature("docstring") dolfin::Cell::type() const "
Return type of cell. 

:rtype: CellType::Type
";

%feature("docstring") dolfin::Cell::volume() const "
Compute (generalized) volume of cell

::
   
   UnitSquare mesh(1, 1);
   Cell cell(mesh, 0);
   info(\"%g\", cell.volume());

:rtype: double
:returns: double The volume of the cell.
";

%feature("docstring") dolfin::Cell::~Cell() "
Destructor.
";

%feature("docstring") dolfin::CellFunction "
A :cpp:any:`CellFunction`  is a :cpp:any:`MeshFunction`  of topological codimension 0.
";

%feature("docstring") dolfin::CellFunction::CellFunction(std::shared_ptr< const Mesh > mesh) "
Constructor on :cpp:any:`Mesh` . 

:param std\\:\\:shared_ptr< const Mesh > mesh:
";

%feature("docstring") dolfin::CellFunction::CellFunction(std::shared_ptr< const Mesh > mesh, const T &value) "
Constructor on :cpp:any:`Mesh`  and value. 

:param std\\:\\:shared_ptr< const Mesh > mesh: 
:param const T & value:
";

%feature("docstring") dolfin::CellType "
This class provides a common interface for different cell types. Each cell type implements mesh functionality that is specific to a certain type of cell.
";

%feature("docstring") dolfin::CellType::CellType(Type cell_type, Type facet_type) "
Constructor. 

:param Type cell_type: 
:param Type facet_type:
";

%feature("docstring") dolfin::CellType::Type "
Enum for different cell types. 

.. cpp:enumerator:: dolfin::CellType::Type::point 

.. cpp:enumerator:: dolfin::CellType::Type::interval 

.. cpp:enumerator:: dolfin::CellType::Type::triangle 

.. cpp:enumerator:: dolfin::CellType::Type::quadrilateral 

.. cpp:enumerator:: dolfin::CellType::Type::tetrahedron 

.. cpp:enumerator:: dolfin::CellType::Type::hexahedron
";

%feature("docstring") dolfin::CellType::cell_normal(const Cell &cell) const  "
Compute normal to given cell (viewed as embedded in 3D) 

:param const Cell & cell: 
:rtype: Point
";

%feature("docstring") dolfin::CellType::cell_type() const "
Return type of cell. 

:rtype: Type
";

%feature("docstring") dolfin::CellType::circumradius(const MeshEntity &entity) const  "
Compute circumradius of mesh entity. 

:param const MeshEntity & entity: 
:rtype: double
";

%feature("docstring") dolfin::CellType::collides(const Cell &cell, const MeshEntity &entity) const  "
Check whether given entity collides with cell. 

:param const Cell & cell: 
:param const MeshEntity & entity: 
:rtype: bool
";

%feature("docstring") dolfin::CellType::collides(const Cell &cell, const Point &point) const  "
Check whether given point collides with cell. 

:param const Cell & cell: 
:param const Point & point: 
:rtype: bool
";

%feature("docstring") dolfin::CellType::create(Type type) "
Create cell type from type (factory function) 

:param Type type: 
:rtype: CellType *
";

%feature("docstring") dolfin::CellType::create(std::string type) "
Create cell type from string (factory function) 

:param std\\:\\:string type: 
:rtype: CellType *
";

%feature("docstring") dolfin::CellType::create_entities(boost::multi_array< unsigned int, 2 > &e, std::size_t dim, const unsigned int *v) const  "
Create entities e of given topological dimension from vertices v 

:param boost\\:\\:multi_array< unsigned int, 2 > & e: 
:param std\\:\\:size_t dim: 
:param const unsigned int * v: 
:rtype: void
";

%feature("docstring") dolfin::CellType::description(bool plural) const  "
Return description of cell type. 

:param bool plural: 
:rtype: std::string
";

%feature("docstring") dolfin::CellType::dim() const  "
Return topological dimension of cell. 

:rtype: std::size_t
";

%feature("docstring") dolfin::CellType::entity_type(std::size_t i) const "
Return type of cell for entity of dimension i. 

:param std\\:\\:size_t i: 
:rtype: Type
";

%feature("docstring") dolfin::CellType::facet_area(const Cell &cell, std::size_t facet) const  "
Compute the area/length of given facet with respect to the cell. 

:param const Cell & cell: 
:param std\\:\\:size_t facet: 
:rtype: double
";

%feature("docstring") dolfin::CellType::facet_type() const "
Return type of cell for facets. 

:rtype: Type
";

%feature("docstring") dolfin::CellType::h(const MeshEntity &entity) const "
Compute greatest distance between any two vertices. 

:param const MeshEntity & entity: 
:rtype: double
";

%feature("docstring") dolfin::CellType::increasing(std::size_t n0, const unsigned int *v0, std::size_t n1, const unsigned int *v1, std::size_t num_vertices, const unsigned int *vertices, const std::vector< std::int64_t > &local_to_global_vertex_indices) "
:param std\\:\\:size_t n0: 
:param const unsigned int * v0: 
:param std\\:\\:size_t n1: 
:param const unsigned int * v1: 
:param std\\:\\:size_t num_vertices: 
:param const unsigned int * vertices: 
:param const std\\:\\:vector< std\\:\\:int64_t > & local_to_global_vertex_indices: 
:rtype: bool
";

%feature("docstring") dolfin::CellType::increasing(std::size_t num_vertices, const unsigned int *vertices, const std::vector< std::int64_t > &local_to_global_vertex_indices) "
:param std\\:\\:size_t num_vertices: 
:param const unsigned int * vertices: 
:param const std\\:\\:vector< std\\:\\:int64_t > & local_to_global_vertex_indices: 
:rtype: bool
";

%feature("docstring") dolfin::CellType::inradius(const Cell &cell) const "
Compute inradius of cell. 

:param const Cell & cell: 
:rtype: double
";

%feature("docstring") dolfin::CellType::normal(const Cell &cell, std::size_t facet) const  "
Compute of given facet with respect to the cell. 

:param const Cell & cell: 
:param std\\:\\:size_t facet: 
:rtype: Point
";

%feature("docstring") dolfin::CellType::normal(const Cell &cell, std::size_t facet, std::size_t i) const  "
Compute component i of normal of given facet with respect to the cell. 

:param const Cell & cell: 
:param std\\:\\:size_t facet: 
:param std\\:\\:size_t i: 
:rtype: double
";

%feature("docstring") dolfin::CellType::num_entities(std::size_t dim) const  "
Return number of entities of given topological dimension. 

:param std\\:\\:size_t dim: 
:rtype: std::size_t
";

%feature("docstring") dolfin::CellType::num_vertices() const "
Return number of vertices for cell. 

:rtype: std::size_t
";

%feature("docstring") dolfin::CellType::num_vertices(std::size_t dim) const  "
Return number of vertices for entity of given topological dimension. 

:param std\\:\\:size_t dim: 
:rtype: std::size_t
";

%feature("docstring") dolfin::CellType::order(Cell &cell, const std::vector< std::int64_t > &local_to_global_vertex_indices) const  "
Order entities locally. 

:param Cell & cell: 
:param const std\\:\\:vector< std\\:\\:int64_t > & local_to_global_vertex_indices: 
:rtype: void
";

%feature("docstring") dolfin::CellType::ordered(const Cell &cell, const std::vector< std::int64_t > &local_to_global_vertex_indices) const "
Check if entities are ordered. 

:param const Cell & cell: 
:param const std\\:\\:vector< std\\:\\:int64_t > & local_to_global_vertex_indices: 
:rtype: bool
";

%feature("docstring") dolfin::CellType::orientation(const Cell &cell) const  "
Return orientation of the cell (assuming flat space) 

:param const Cell & cell: 
:rtype: std::size_t
";

%feature("docstring") dolfin::CellType::orientation(const Cell &cell, const Point &up) const "
Return orientation of the cell relative to given up direction. 

:param const Cell & cell: 
:param const Point & up: 
:rtype: std::size_t
";

%feature("docstring") dolfin::CellType::radius_ratio(const Cell &cell) const "
Compute dim*inradius/circumradius for given cell. 

:param const Cell & cell: 
:rtype: double
";

%feature("docstring") dolfin::CellType::sort_entities(std::size_t num_vertices, unsigned int *vertices, const std::vector< std::int64_t > &local_to_global_vertex_indices) "
Sort vertices based on global entity indices. 

:param std\\:\\:size_t num_vertices: 
:param unsigned int * vertices: 
:param const std\\:\\:vector< std\\:\\:int64_t > & local_to_global_vertex_indices: 
:rtype: void
";

%feature("docstring") dolfin::CellType::squared_distance(const Cell &cell, const Point &point) const  "
Compute squared distance to given point. 

:param const Cell & cell: 
:param const Point & point: 
:rtype: double
";

%feature("docstring") dolfin::CellType::string2type(std::string type) "
Convert from string to cell type. 

:param std\\:\\:string type: 
:rtype: Type
";

%feature("docstring") dolfin::CellType::triangulate_intersection(const Cell &c0, const Cell &c1) const  "
Compute triangulation of intersection of two cells. 

:param const Cell & c0: 
:param const Cell & c1: 
:rtype: std::vector< double >
";

%feature("docstring") dolfin::CellType::type2string(Type type) "
Convert from cell type to string. 

:param Type type: 
:rtype: std::string
";

%feature("docstring") dolfin::CellType::volume(const MeshEntity &entity) const  "
Compute (generalized) volume of mesh entity. 

:param const MeshEntity & entity: 
:rtype: double
";

%feature("docstring") dolfin::CellType::vtk_mapping() const  "
Mapping of DOLFIN/UFC vertex ordering to VTK/XDMF ordering. 

:rtype: std::vector< std::int8_t >
";

%feature("docstring") dolfin::CellType::~CellType() "
Destructor.
";

%feature("docstring") dolfin::DistributedMeshTools "
This class provides various functionality for working with distributed meshes.
";

%feature("docstring") dolfin::DistributedMeshTools::Entity "
:rtype: std::vector< std::size_t >
";

%feature("docstring") dolfin::DistributedMeshTools::compute_entity_ownership(const MPI_Comm mpi_comm, const std::map< std::vector< std::size_t >, unsigned int > &entities, const std::map< std::int32_t, std::set< unsigned int > > &shared_vertices_local, const std::vector< std::int64_t > &global_vertex_indices, std::size_t d, std::vector< std::size_t > &owned_entities, std::array< std::map< Entity, EntityData >, 2 > &shared_entities) "
:param const MPI_Comm mpi_comm: 
:param const std\\:\\:map< std\\:\\:vector< std\\:\\:size_t >, unsigned int > & entities: 
:param const std\\:\\:map< std\\:\\:int32_t, std\\:\\:set< unsigned int > > & shared_vertices_local: 
:param const std\\:\\:vector< std\\:\\:int64_t > & global_vertex_indices: 
:param std\\:\\:size_t d: 
:param std\\:\\:vector< std\\:\\:size_t > & owned_entities: 
:param std\\:\\:array< std\\:\\:map< Entity, EntityData >, 2 > & shared_entities: 
:rtype: void
";

%feature("docstring") dolfin::DistributedMeshTools::compute_final_entity_ownership(const MPI_Comm mpi_comm, std::vector< std::size_t > &owned_entities, std::array< std::map< Entity, EntityData >, 2 > &entity_ownership) "
:param const MPI_Comm mpi_comm: 
:param std\\:\\:vector< std\\:\\:size_t > & owned_entities: 
:param std\\:\\:array< std\\:\\:map< Entity, EntityData >, 2 > & entity_ownership: 
:rtype: void
";

%feature("docstring") dolfin::DistributedMeshTools::compute_num_global_entities(const MPI_Comm mpi_comm, std::size_t num_local_entities, std::size_t num_processes, std::size_t process_number) "
:param const MPI_Comm mpi_comm: 
:param std\\:\\:size_t num_local_entities: 
:param std\\:\\:size_t num_processes: 
:param std\\:\\:size_t process_number: 
:rtype: std::pair< std::size_t, std::size_t >
";

%feature("docstring") dolfin::DistributedMeshTools::compute_preliminary_entity_ownership(const MPI_Comm mpi_comm, const std::map< std::size_t, std::set< unsigned int > > &shared_vertices, const std::map< Entity, unsigned int > &entities, std::vector< std::size_t > &owned_entities, std::array< std::map< Entity, EntityData >, 2 > &entity_ownership) "
:param const MPI_Comm mpi_comm: 
:param const std\\:\\:map< std\\:\\:size_t, std\\:\\:set< unsigned int > > & shared_vertices: 
:param const std\\:\\:map< Entity, unsigned int > & entities: 
:param std\\:\\:vector< std\\:\\:size_t > & owned_entities: 
:param std\\:\\:array< std\\:\\:map< Entity, EntityData >, 2 > & entity_ownership: 
:rtype: void
";

%feature("docstring") dolfin::DistributedMeshTools::compute_shared_entities(const Mesh &mesh, std::size_t d) "
Compute map from local index of shared entity to list of sharing process and local index, i.e. (local index, [(sharing process p, local index on p)]) 

:param const Mesh & mesh: 
:param std\\:\\:size_t d: 
:rtype: std::unordered_map< unsigned int, std::vector< std::pair< unsigned int, unsigned int > > >
";

%feature("docstring") dolfin::DistributedMeshTools::init_facet_cell_connections(Mesh &mesh) "
Compute number of cells connected to each facet (globally). Facets on internal boundaries will be connected to two cells (with the cells residing on neighboring processes) 

:param Mesh & mesh: 
:rtype: void
";

%feature("docstring") dolfin::DistributedMeshTools::is_shared(const std::vector< std::size_t > &entity_vertices, const std::map< std::size_t, std::set< unsigned int > > &shared_vertices) "
:param const std\\:\\:vector< std\\:\\:size_t > & entity_vertices: 
:param const std\\:\\:map< std\\:\\:size_t, std\\:\\:set< unsigned int > > & shared_vertices: 
:rtype: bool
";

%feature("docstring") dolfin::DistributedMeshTools::locate_off_process_entities(const std::vector< std::size_t > &entity_indices, std::size_t dim, const Mesh &mesh) "
Find processes that own or share mesh entities (using entity global indices). Returns (global_dof, set(process_num, local_index)). Exclusively local entities will not appear in the map. Works only for vertices and cells 

:param const std\\:\\:vector< std\\:\\:size_t > & entity_indices: 
:param std\\:\\:size_t dim: 
:param const Mesh & mesh: 
:rtype: std::map< std::size_t, std::set< std::pair< std::size_t, std::size_t > > >
";

%feature("docstring") dolfin::DistributedMeshTools::number_entities(const Mesh &mesh, const std::map< unsigned int, std::pair< unsigned int, unsigned int >> &slave_entities, std::vector< std::int64_t > &global_entity_indices, std::map< std::int32_t, std::set< unsigned int >> &shared_entities, std::size_t d) "
Create global entity indices for entities of dimension d for given global vertex indices. 

:param const Mesh & mesh: 
:param const std\\:\\:map< unsigned int, std\\:\\:pair< unsigned int, unsigned int >> & slave_entities: 
:param std\\:\\:vector< std\\:\\:int64_t > & global_entity_indices: 
:param std\\:\\:map< std\\:\\:int32_t, std\\:\\:set< unsigned int >> & shared_entities: 
:param std\\:\\:size_t d: 
:rtype: std::size_t
";

%feature("docstring") dolfin::DistributedMeshTools::number_entities(const Mesh &mesh, std::size_t d) "
Create global entity indices for entities of dimension d. 

:param const Mesh & mesh: 
:param std\\:\\:size_t d: 
:rtype: void
";

%feature("docstring") dolfin::DistributedMeshTools::reorder_values_by_global_indices(MPI_Comm mpi_comm, std::vector< double > &values, const std::size_t width, const std::vector< std::int64_t > &global_indices) "
Reorder the values of given width, according to explicit global indices, distributing evenly across processes 

:param MPI_Comm mpi_comm: 
:param std\\:\\:vector< double > & values: 
:param const std\\:\\:size_t width: 
:param const std\\:\\:vector< std\\:\\:int64_t > & global_indices: 
:rtype: void
";

%feature("docstring") dolfin::DistributedMeshTools::reorder_values_by_global_indices(const Mesh &mesh, std::vector< double > &data, const std::size_t width) "
Reorder the values (of given width) in data to be in global vertex index order on the :cpp:any:`Mesh` , redistributing evenly across processes 

:param const Mesh & mesh: 
:param std\\:\\:vector< double > & data: 
:param const std\\:\\:size_t width: 
:rtype: void
";

%feature("docstring") dolfin::DistributedMeshTools::reorder_vertices_by_global_indices(const Mesh &mesh) "
Reorders the vertices in a distributed mesh according to their global index, and redistributes them evenly across processes returning the coordinates as a local vector 

:param const Mesh & mesh: 
:rtype: std::vector< double >
";

%feature("docstring") dolfin::DomainBoundary "
This class provides a :cpp:any:`SubDomain`  which picks out the boundary of a mesh, and provides a convenient way to specify boundary conditions on the entire boundary of a mesh.
";

%feature("docstring") dolfin::DomainBoundary::DomainBoundary() "
Constructor.
";

%feature("docstring") dolfin::DomainBoundary::inside(const Array< double > &x, bool on_boundary) const "
Return true for points on the boundary. 

:param const Array< double > & x: 
:param bool on_boundary: 
:rtype: bool
";

%feature("docstring") dolfin::DomainBoundary::~DomainBoundary() "
Destructor.
";

%feature("docstring") dolfin::DynamicMeshEditor "
This class provides an interface for dynamic editing of meshes, that is, when the number of vertices and cells are not known a priori. If the number of vertices and cells are known a priori, it is more efficient to use the default editor :cpp:any:`MeshEditor` .
";

%feature("docstring") dolfin::DynamicMeshEditor::DynamicMeshEditor() "
Constructor.
";

%feature("docstring") dolfin::DynamicMeshEditor::add_cell(std::size_t c, const std::vector< std::size_t > &v) "
Add cell with given vertices. 

:param std\\:\\:size_t c: 
:param const std\\:\\:vector< std\\:\\:size_t > & v: 
:rtype: void
";

%feature("docstring") dolfin::DynamicMeshEditor::add_cell(std::size_t c, std::size_t v0, std::size_t v1) "
Add cell (interval) with given vertices. 

:param std\\:\\:size_t c: 
:param std\\:\\:size_t v0: 
:param std\\:\\:size_t v1: 
:rtype: void
";

%feature("docstring") dolfin::DynamicMeshEditor::add_cell(std::size_t c, std::size_t v0, std::size_t v1, std::size_t v2) "
Add cell (triangle) with given vertices. 

:param std\\:\\:size_t c: 
:param std\\:\\:size_t v0: 
:param std\\:\\:size_t v1: 
:param std\\:\\:size_t v2: 
:rtype: void
";

%feature("docstring") dolfin::DynamicMeshEditor::add_cell(std::size_t c, std::size_t v0, std::size_t v1, std::size_t v2, std::size_t v3) "
Add cell (tetrahedron) with given vertices. 

:param std\\:\\:size_t c: 
:param std\\:\\:size_t v0: 
:param std\\:\\:size_t v1: 
:param std\\:\\:size_t v2: 
:param std\\:\\:size_t v3: 
:rtype: void
";

%feature("docstring") dolfin::DynamicMeshEditor::add_vertex(std::size_t v, const Point &p) "
Add vertex v at given point p. 

:param std\\:\\:size_t v: 
:param const Point & p: 
:rtype: void
";

%feature("docstring") dolfin::DynamicMeshEditor::add_vertex(std::size_t v, double x) "
Add vertex v at given coordinate x. 

:param std\\:\\:size_t v: 
:param double x: 
:rtype: void
";

%feature("docstring") dolfin::DynamicMeshEditor::add_vertex(std::size_t v, double x, double y) "
Add vertex v at given coordinate (x, y) 

:param std\\:\\:size_t v: 
:param double x: 
:param double y: 
:rtype: void
";

%feature("docstring") dolfin::DynamicMeshEditor::add_vertex(std::size_t v, double x, double y, double z) "
Add vertex v at given coordinate (x, y, z) 

:param std\\:\\:size_t v: 
:param double x: 
:param double y: 
:param double z: 
:rtype: void
";

%feature("docstring") dolfin::DynamicMeshEditor::cell_vertices "
:rtype: std::vector< std::size_t >
";

%feature("docstring") dolfin::DynamicMeshEditor::clear() "
:rtype: void
";

%feature("docstring") dolfin::DynamicMeshEditor::close(bool order=false) "
Close mesh, finish editing, and order entities locally. 

:param bool order: 
:rtype: void
";

%feature("docstring") dolfin::DynamicMeshEditor::open(Mesh &mesh, CellType::Type type, std::size_t tdim, std::size_t gdim, std::size_t num_global_vertices, std::size_t num_global_cells) "
Open mesh of given cell type, topological and geometrical dimension. 

:param Mesh & mesh: 
:param CellType\\:\\:Type type: 
:param std\\:\\:size_t tdim: 
:param std\\:\\:size_t gdim: 
:param std\\:\\:size_t num_global_vertices: 
:param std\\:\\:size_t num_global_cells: 
:rtype: void
";

%feature("docstring") dolfin::DynamicMeshEditor::open(Mesh &mesh, std::string type, std::size_t tdim, std::size_t gdim, std::size_t num_global_vertices, std::size_t num_global_cells) "
Open mesh of given cell type, topological and geometrical dimension. 

:param Mesh & mesh: 
:param std\\:\\:string type: 
:param std\\:\\:size_t tdim: 
:param std\\:\\:size_t gdim: 
:param std\\:\\:size_t num_global_vertices: 
:param std\\:\\:size_t num_global_cells: 
:rtype: void
";

%feature("docstring") dolfin::DynamicMeshEditor::vertex_coordinates "
:rtype: std::vector< double >
";

%feature("docstring") dolfin::DynamicMeshEditor::~DynamicMeshEditor() "
Destructor.
";

%feature("docstring") dolfin::Edge "
An :cpp:any:`Edge`  is a :cpp:any:`MeshEntity`  of topological dimension 1.
";

%feature("docstring") dolfin::Edge::Edge(MeshEntity &entity) "
Create edge from mesh entity

:param MeshEntity & entity:  (:cpp:any:`MeshEntity` ) The mesh entity to create an edge from.
";

%feature("docstring") dolfin::Edge::Edge(const Mesh &mesh, std::size_t index) "
Create edge on given mesh

:param const Mesh & mesh:  (:cpp:any:`Mesh` ) The mesh.
:param std\\:\\:size_t index:  (std::size_t) Index of the edge.
";

%feature("docstring") dolfin::Edge::dot(const Edge &edge) const "
Compute dot product between edge and other edge

::
   
   UnitSquare mesh(2, 2);
   Edge edge1(mesh, 0);
   Edge edge2(mesh, 1);
   info(\"%g\", edge1.dot(edge2));

:param const Edge & edge:  (:cpp:any:`Edge` ) Another edge.
:rtype: double
:returns: double The dot product.
";

%feature("docstring") dolfin::Edge::length() const "
Compute Euclidean length of edge

::
   
   UnitSquare mesh(2, 2);
   Edge edge(mesh, 0);
   info(\"%g\", edge.length());

:rtype: double
:returns: double Euclidean length of edge.
";

%feature("docstring") dolfin::Edge::~Edge() "
Destructor.
";

%feature("docstring") dolfin::EdgeFunction "
An :cpp:any:`EdgeFunction`  is a :cpp:any:`MeshFunction`  of topological dimension 1.
";

%feature("docstring") dolfin::EdgeFunction::EdgeFunction(std::shared_ptr< const Mesh > mesh) "
Constructor on :cpp:any:`Mesh` . 

:param std\\:\\:shared_ptr< const Mesh > mesh:
";

%feature("docstring") dolfin::EdgeFunction::EdgeFunction(std::shared_ptr< const Mesh > mesh, const T &value) "
Constructor on :cpp:any:`Mesh`  and value. 

:param std\\:\\:shared_ptr< const Mesh > mesh: 
:param const T & value:
";

%feature("docstring") dolfin::Face "
A :cpp:any:`Face`  is a :cpp:any:`MeshEntity`  of topological dimension 2.
";

%feature("docstring") dolfin::Face::Face(const Mesh &mesh, std::size_t index) "
Constructor. 

:param const Mesh & mesh: 
:param std\\:\\:size_t index:
";

%feature("docstring") dolfin::Face::area() const "
Calculate the area of the face (triangle) 

:rtype: double
";

%feature("docstring") dolfin::Face::normal() const "
Compute normal to the face. 

:rtype: Point
";

%feature("docstring") dolfin::Face::normal(std::size_t i) const "
Compute component i of the normal to the face. 

:param std\\:\\:size_t i: 
:rtype: double
";

%feature("docstring") dolfin::Face::~Face() "
Destructor.
";

%feature("docstring") dolfin::FaceFunction "
A :cpp:any:`FaceFunction`  is a :cpp:any:`MeshFunction`  of topological dimension 2.
";

%feature("docstring") dolfin::FaceFunction::FaceFunction(std::shared_ptr< const Mesh > mesh) "
Constructor on :cpp:any:`Mesh` . 

:param std\\:\\:shared_ptr< const Mesh > mesh:
";

%feature("docstring") dolfin::FaceFunction::FaceFunction(std::shared_ptr< const Mesh > mesh, const T &value) "
Constructor on :cpp:any:`Mesh`  and value. 

:param std\\:\\:shared_ptr< const Mesh > mesh: 
:param const T & value:
";

%feature("docstring") dolfin::Facet "
A :cpp:any:`Facet`  is a :cpp:any:`MeshEntity`  of topological codimension 1.
";

%feature("docstring") dolfin::Facet::Facet(const Mesh &mesh, std::size_t index) "
Constructor. 

:param const Mesh & mesh: 
:param std\\:\\:size_t index:
";

%feature("docstring") dolfin::Facet::distance(const Point &point) const "
Compute distance to given point.

:param const Point & point:  (:cpp:any:`Point` ) The point.
:rtype: double
:returns: double The distance to the point.
";

%feature("docstring") dolfin::Facet::exterior() const "
Return true if facet is an exterior facet (relative to global mesh, so this function will return false for facets on partition boundaries). :cpp:any:`Facet`  connectivity must be initialized before calling this function. 

:rtype: bool
";

%feature("docstring") dolfin::Facet::normal() const "
Compute normal to the facet. 

:rtype: Point
";

%feature("docstring") dolfin::Facet::normal(std::size_t i) const "
Compute component i of the normal to the facet. 

:param std\\:\\:size_t i: 
:rtype: double
";

%feature("docstring") dolfin::Facet::squared_distance(const Point &point) const "
Compute squared distance to given point.

:param const Point & point:  (:cpp:any:`Point` ) The point.
:rtype: double
:returns: double The squared distance to the point.
";

%feature("docstring") dolfin::Facet::~Facet() "
Destructor.
";

%feature("docstring") dolfin::FacetCell "
This class represents a cell in a mesh incident to a facet on the boundary. It is useful in cases where one needs to iterate over a boundary mesh and access the corresponding cells in the original mesh.
";

%feature("docstring") dolfin::FacetCell::FacetCell(const BoundaryMesh &mesh, const Cell &facet) "
Create cell on mesh corresponding to given facet (cell) on boundary. 

:param const BoundaryMesh & mesh: 
:param const Cell & facet:
";

%feature("docstring") dolfin::FacetCell::facet_index() const "
Return local index of facet with respect to the cell. 

:rtype: std::size_t
";

%feature("docstring") dolfin::FacetCell::~FacetCell() "
Destructor.
";

%feature("docstring") dolfin::FacetFunction "
A :cpp:any:`FacetFunction`  is a :cpp:any:`MeshFunction`  of topological codimension 1.
";

%feature("docstring") dolfin::FacetFunction::FacetFunction(std::shared_ptr< const Mesh > mesh) "
Constructor on :cpp:any:`Mesh` . 

:param std\\:\\:shared_ptr< const Mesh > mesh:
";

%feature("docstring") dolfin::FacetFunction::FacetFunction(std::shared_ptr< const Mesh > mesh, const T &value) "
Constructor on :cpp:any:`Mesh`  and value. 

:param std\\:\\:shared_ptr< const Mesh > mesh: 
:param const T & value:
";

%feature("docstring") dolfin::HexahedronCell "
This class implements functionality for triangular meshes.
";

%feature("docstring") dolfin::HexahedronCell::HexahedronCell() "
Specify cell type and facet type.
";

%feature("docstring") dolfin::HexahedronCell::cell_normal(const Cell &cell) const "
Compute normal to given cell (viewed as embedded in 3D) 

:param const Cell & cell: 
:rtype: Point
";

%feature("docstring") dolfin::HexahedronCell::circumradius(const MeshEntity &triangle) const "
Compute diameter of triangle. 

:param const MeshEntity & triangle: 
:rtype: double
";

%feature("docstring") dolfin::HexahedronCell::collides(const Cell &cell, const MeshEntity &entity) const "
Check whether given entity collides with cell. 

:param const Cell & cell: 
:param const MeshEntity & entity: 
:rtype: bool
";

%feature("docstring") dolfin::HexahedronCell::collides(const Cell &cell, const Point &point) const "
Check whether given point collides with cell. 

:param const Cell & cell: 
:param const Point & point: 
:rtype: bool
";

%feature("docstring") dolfin::HexahedronCell::create_entities(boost::multi_array< unsigned int, 2 > &e, std::size_t dim, const unsigned int *v) const "
Create entities e of given topological dimension from vertices v. 

:param boost\\:\\:multi_array< unsigned int, 2 > & e: 
:param std\\:\\:size_t dim: 
:param const unsigned int * v: 
:rtype: void
";

%feature("docstring") dolfin::HexahedronCell::description(bool plural) const "
Return description of cell type. 

:param bool plural: 
:rtype: std::string
";

%feature("docstring") dolfin::HexahedronCell::dim() const "
Return topological dimension of cell. 

:rtype: std::size_t
";

%feature("docstring") dolfin::HexahedronCell::facet_area(const Cell &cell, std::size_t facet) const "
Compute the area/length of given facet with respect to the cell. 

:param const Cell & cell: 
:param std\\:\\:size_t facet: 
:rtype: double
";

%feature("docstring") dolfin::HexahedronCell::normal(const Cell &cell, std::size_t facet) const "
Compute of given facet with respect to the cell. 

:param const Cell & cell: 
:param std\\:\\:size_t facet: 
:rtype: Point
";

%feature("docstring") dolfin::HexahedronCell::normal(const Cell &cell, std::size_t facet, std::size_t i) const "
Compute component i of normal of given facet with respect to the cell. 

:param const Cell & cell: 
:param std\\:\\:size_t facet: 
:param std\\:\\:size_t i: 
:rtype: double
";

%feature("docstring") dolfin::HexahedronCell::num_entities(std::size_t dim) const "
Return number of entities of given topological dimension. 

:param std\\:\\:size_t dim: 
:rtype: std::size_t
";

%feature("docstring") dolfin::HexahedronCell::num_vertices(std::size_t dim) const "
Return number of vertices for entity of given topological dimension. 

:param std\\:\\:size_t dim: 
:rtype: std::size_t
";

%feature("docstring") dolfin::HexahedronCell::order(Cell &cell, const std::vector< std::int64_t > &local_to_global_vertex_indices) const "
Order entities locally. 

:param Cell & cell: 
:param const std\\:\\:vector< std\\:\\:int64_t > & local_to_global_vertex_indices: 
:rtype: void
";

%feature("docstring") dolfin::HexahedronCell::orientation(const Cell &cell) const "
Return orientation of the cell. 

:param const Cell & cell: 
:rtype: std::size_t
";

%feature("docstring") dolfin::HexahedronCell::squared_distance(const Cell &cell, const Point &point) const "
Compute squared distance to given point (3D enabled) 

:param const Cell & cell: 
:param const Point & point: 
:rtype: double
";

%feature("docstring") dolfin::HexahedronCell::triangulate_intersection(const Cell &c0, const Cell &c1) const "
Compute triangulation of intersection of two cells. 

:param const Cell & c0: 
:param const Cell & c1: 
:rtype: std::vector< double >
";

%feature("docstring") dolfin::HexahedronCell::volume(const MeshEntity &triangle) const "
Compute (generalized) volume (area) of triangle. 

:param const MeshEntity & triangle: 
:rtype: double
";

%feature("docstring") dolfin::HexahedronCell::vtk_mapping() const "
Mapping of DOLFIN/UFC vertex ordering to VTK/XDMF ordering. 

:rtype: std::vector< std::int8_t >
";

%feature("docstring") dolfin::IntervalCell "
This class implements functionality for interval meshes.
";

%feature("docstring") dolfin::IntervalCell::IntervalCell() "
Specify cell type and facet type.
";

%feature("docstring") dolfin::IntervalCell::cell_normal(const Cell &cell) const "
Compute normal to given cell (viewed as embedded in 2D) 

:param const Cell & cell: 
:rtype: Point
";

%feature("docstring") dolfin::IntervalCell::circumradius(const MeshEntity &interval) const "
Compute circumradius of interval. 

:param const MeshEntity & interval: 
:rtype: double
";

%feature("docstring") dolfin::IntervalCell::collides(const Cell &cell, const MeshEntity &entity) const "
Check whether given entity collides with cell. 

:param const Cell & cell: 
:param const MeshEntity & entity: 
:rtype: bool
";

%feature("docstring") dolfin::IntervalCell::collides(const Cell &cell, const Point &point) const "
Check whether given point collides with cell. 

:param const Cell & cell: 
:param const Point & point: 
:rtype: bool
";

%feature("docstring") dolfin::IntervalCell::create_entities(boost::multi_array< unsigned int, 2 > &e, std::size_t dim, const unsigned int *v) const "
Create entities e of given topological dimension from vertices v. 

:param boost\\:\\:multi_array< unsigned int, 2 > & e: 
:param std\\:\\:size_t dim: 
:param const unsigned int * v: 
:rtype: void
";

%feature("docstring") dolfin::IntervalCell::description(bool plural) const "
Return description of cell type. 

:param bool plural: 
:rtype: std::string
";

%feature("docstring") dolfin::IntervalCell::dim() const "
Return topological dimension of cell. 

:rtype: std::size_t
";

%feature("docstring") dolfin::IntervalCell::facet_area(const Cell &cell, std::size_t facet) const "
Compute the area/length of given facet with respect to the cell. 

:param const Cell & cell: 
:param std\\:\\:size_t facet: 
:rtype: double
";

%feature("docstring") dolfin::IntervalCell::normal(const Cell &cell, std::size_t facet) const "
Compute of given facet with respect to the cell. 

:param const Cell & cell: 
:param std\\:\\:size_t facet: 
:rtype: Point
";

%feature("docstring") dolfin::IntervalCell::normal(const Cell &cell, std::size_t facet, std::size_t i) const "
Compute component i of normal of given facet with respect to the cell 

:param const Cell & cell: 
:param std\\:\\:size_t facet: 
:param std\\:\\:size_t i: 
:rtype: double
";

%feature("docstring") dolfin::IntervalCell::num_entities(std::size_t dim) const "
Return number of entities of given topological dimension. 

:param std\\:\\:size_t dim: 
:rtype: std::size_t
";

%feature("docstring") dolfin::IntervalCell::num_vertices(std::size_t dim) const "
Return number of vertices for entity of given topological dimension 

:param std\\:\\:size_t dim: 
:rtype: std::size_t
";

%feature("docstring") dolfin::IntervalCell::order(Cell &cell, const std::vector< std::int64_t > &local_to_global_vertex_indices) const "
Order entities locally. 

:param Cell & cell: 
:param const std\\:\\:vector< std\\:\\:int64_t > & local_to_global_vertex_indices: 
:rtype: void
";

%feature("docstring") dolfin::IntervalCell::orientation(const Cell &cell) const "
Return orientation of the cell (assuming flat space) 

:param const Cell & cell: 
:rtype: std::size_t
";

%feature("docstring") dolfin::IntervalCell::squared_distance(const Cell &cell, const Point &point) const "
Compute squared distance to given point (3D enabled) 

:param const Cell & cell: 
:param const Point & point: 
:rtype: double
";

%feature("docstring") dolfin::IntervalCell::squared_distance(const Point &point, const Point &a, const Point &b) "
Compute squared distance to given point. This version takes the two vertex coordinates as 3D points. This makes it possible to reuse this function for computing the (squared) distance to a triangle. 

:param const Point & point: 
:param const Point & a: 
:param const Point & b: 
:rtype: double
";

%feature("docstring") dolfin::IntervalCell::triangulate_intersection(const Cell &c0, const Cell &c1) const "
Compute triangulation of intersection of two cells. 

:param const Cell & c0: 
:param const Cell & c1: 
:rtype: std::vector< double >
";

%feature("docstring") dolfin::IntervalCell::volume(const MeshEntity &interval) const "
Compute (generalized) volume (length) of interval. 

:param const MeshEntity & interval: 
:rtype: double
";

%feature("docstring") dolfin::IntervalCell::vtk_mapping() const "
Mapping of DOLFIN/UFC vertex ordering to VTK/XDMF ordering. 

:rtype: std::vector< std::int8_t >
";

%feature("docstring") dolfin::LocalMeshData "
This class stores mesh data on a local processor corresponding to a portion of a (larger) global mesh. 
Note that the data stored in this class does typically not correspond to a topologically connected mesh; it merely stores a list of vertex coordinates, a list of cell-vertex mappings and a list of global vertex numbers for the locally stored vertices.
It is typically used for parsing meshes in parallel from mesh XML files. After local mesh data has been parsed on each processor, a subsequent repartitioning takes place: first a geometric partitioning of the vertices followed by a redistribution of vertex and cell data, and then a topological partitioning again followed by redistribution of vertex and cell data, at that point corresponding to topologically connected meshes instead of local mesh data.
";

%feature("docstring") dolfin::LocalMeshData::LocalMeshData(const MPI_Comm mpi_comm) "
Create empty local mesh data. 

:param const MPI_Comm mpi_comm:
";

%feature("docstring") dolfin::LocalMeshData::LocalMeshData(const Mesh &mesh) "
Create local mesh data for given mesh. 

:param const Mesh & mesh:
";

%feature("docstring") dolfin::LocalMeshData::broadcast_mesh_data(const MPI_Comm mpi_comm) "
Broadcast mesh data from main process (used when :cpp:any:`Mesh`  is created on one process) 

:param const MPI_Comm mpi_comm: 
:rtype: void
";

%feature("docstring") dolfin::LocalMeshData::check() const "
Check that all essential data has been initialized, and throw error if there is a problem 

:rtype: void
";

%feature("docstring") dolfin::LocalMeshData::clear() "
Clear all data. 

:rtype: void
";

%feature("docstring") dolfin::LocalMeshData::domain_data "
:cpp:any:`Mesh`  domain data [dim](line, (cell_index, local_index, value)) 

:rtype: std::map< std::size_t, std::vector< std::pair< std::pair< std::size_t, std::size_t >, std::size_t > > >
";

%feature("docstring") dolfin::LocalMeshData::extract_mesh_data(const Mesh &mesh) "
Copy data from mesh. 

:param const Mesh & mesh: 
:rtype: void
";

%feature("docstring") dolfin::LocalMeshData::geometry "
:cpp:any:`Geometry`  data. 

:rtype: Geometry
";

%feature("docstring") dolfin::LocalMeshData::mpi_comm() const "
Return :cpp:any:`MPI`  communicator. 

:rtype: MPI_Comm
";

%feature("docstring") dolfin::LocalMeshData::receive_mesh_data(const MPI_Comm mpi_comm) "
Receive mesh data from main process. 

:param const MPI_Comm mpi_comm: 
:rtype: void
";

%feature("docstring") dolfin::LocalMeshData::reorder() "
Reorder cell data. 

:rtype: void
";

%feature("docstring") dolfin::LocalMeshData::str(bool verbose) const "
Return informal string representation (pretty-print) 

:param bool verbose: 
:rtype: std::string
";

%feature("docstring") dolfin::LocalMeshData::topology "
Holder for topology data. 

:rtype: Topology
";

%feature("docstring") dolfin::LocalMeshData::~LocalMeshData() "
Destructor.
";

%feature("docstring") dolfin::LocalMeshValueCollection "
This class stores mesh data on a local processor corresponding to a portion of a :cpp:any:`MeshValueCollection` .
";

%feature("docstring") dolfin::LocalMeshValueCollection::LocalMeshValueCollection(MPI_Comm comm, const MeshValueCollection< T > &values, std::size_t dim) "
Create local mesh data for given :cpp:any:`LocalMeshValueCollection` . 

:param MPI_Comm comm: 
:param const MeshValueCollection< T > & values: 
:param std\\:\\:size_t dim:
";

%feature("docstring") dolfin::LocalMeshValueCollection::dim() const "
Return dimension of cell entity. 

:rtype: std::size_t
";

%feature("docstring") dolfin::LocalMeshValueCollection::values() const "
Return data. 

:rtype: const std::vector< std::pair< std::pair< std::size_t, std::size_t >, T > > &
";

%feature("docstring") dolfin::LocalMeshValueCollection::~LocalMeshValueCollection() "
Destructor.
";

%feature("docstring") dolfin::Mesh "
A :cpp:any:`Mesh`  consists of a set of connected and numbered mesh entities.
Both the representation and the interface are dimension-independent, but a concrete interface is also provided for standard named mesh entities:

=================  =========  ===========  
Entity             Dimension  Codimension  
=================  =========  ===========  
:cpp:any:`Vertex`  0                       
:cpp:any:`Edge`    1                       
:cpp:any:`Face`    2                       
:cpp:any:`Facet`              1            
:cpp:any:`Cell`               0            
=================  =========  ===========  

When working with mesh iterators, all entities and connectivity are precomputed automatically the first time an iterator is created over any given topological dimension or connectivity.
Note that for efficiency, only entities of dimension zero (vertices) and entities of the maximal dimension (cells) exist when creating a :cpp:any:`Mesh` . Other entities must be explicitly created by calling :cpp:any:`init()` . For example, all edges in a mesh may be created by a call to mesh.init(1). Similarly, connectivities such as all edges connected to a given vertex must also be explicitly created (in this case by a call to mesh.init(0, 1)). 

Friends: :cpp:any:`MeshEditor`, :cpp:any:`MeshPartitioning`, :cpp:any:`TopologyComputation`, :cpp:any:`create_mesh`.
";

%feature("docstring") dolfin::Mesh::Mesh() "
Create empty mesh.
";

%feature("docstring") dolfin::Mesh::Mesh(MPI_Comm comm) "
Create empty mesh. 

:param MPI_Comm comm:
";

%feature("docstring") dolfin::Mesh::Mesh(MPI_Comm comm, LocalMeshData &local_mesh_data) "
Create a distributed mesh from local (per process) data.

:param MPI_Comm comm:  (MPI_Comm) :cpp:any:`MPI`  communicator for the mesh.
:param LocalMeshData & local_mesh_data:  (:cpp:any:`LocalMeshData` ) Data from which to build the mesh.
";

%feature("docstring") dolfin::Mesh::Mesh(MPI_Comm comm, std::string filename) "
Create mesh from data file.

:param MPI_Comm comm:  (MPI_Comm) The :cpp:any:`MPI`  communicator
:param std\\:\\:string filename:  (std::string) Name of file to load.
";

%feature("docstring") dolfin::Mesh::Mesh(const Mesh &mesh) "
Copy constructor.

:param const Mesh & mesh:  (:cpp:any:`Mesh` ) Object to be copied.
";

%feature("docstring") dolfin::Mesh::Mesh(std::string filename) "
Create mesh from data file.

:param std\\:\\:string filename:  (std::string) Name of file to load.
";

%feature("docstring") dolfin::Mesh::bounding_box_tree() const "
Get bounding box tree for mesh. The bounding box tree is initialized and built upon the first call to this function. The bounding box tree can be used to compute collisions between the mesh and other objects. It is the responsibility of the caller to use (and possibly rebuild) the tree. It is stored as a (mutable) member of the mesh to enable sharing of the bounding box tree data structure.

:rtype: std::shared_ptr< BoundingBoxTree >
:returns: std::shared_ptr<BoundingBoxTree>
";

%feature("docstring") dolfin::Mesh::cell_orientations() const "
Return cell_orientations (const version)

:rtype: const std::vector< int > &
:returns: std::vector<int>   ::            Map from cell index to orientation of cell. Is empty        if cell orientations have not been computed.
";

%feature("docstring") dolfin::Mesh::cells() const "
Get cell connectivity.

:rtype: const std::vector< unsigned int > &
:returns: std::vector<unsigned int>& Connectivity for all cells.
";

%feature("docstring") dolfin::Mesh::clean() "
Clean out all auxiliary topology data. This clears all topological data, except the connectivity between cells and vertices. 

:rtype: void
";

%feature("docstring") dolfin::Mesh::color(std::string coloring_type) const "
Color the cells of the mesh such that no two neighboring cells share the same color. A colored mesh keeps a CellFunction<std::size_t> named \"cell colors\" as mesh data which holds the colors of the mesh.

:param std\\:\\:string coloring_type:  (std::string) Coloring type, specifying what relation makes two cells neighbors, can be one of \"vertex\", \"edge\" or \"facet\".
:rtype: const std::vector< std::size_t > &
:returns: std::vector<std::size_t>& The colors as a mesh function over the cells of the mesh.
";

%feature("docstring") dolfin::Mesh::color(std::vector< std::size_t > coloring_type) const "
Color the cells of the mesh such that no two neighboring cells share the same color. A colored mesh keeps a CellFunction<std::size_t> named \"cell colors\" as mesh data which holds the colors of the mesh.

:param std\\:\\:vector< std\\:\\:size_t > coloring_type:  (std::vector<std::size_t>&) Coloring type given as list of topological dimensions, specifying what relation makes two mesh entities neighbors.
:rtype: const std::vector< std::size_t > &
:returns: std::vector<std::size_t>& The colors as a mesh function over entities of the mesh.
";

%feature("docstring") dolfin::Mesh::coordinates() "
Get vertex coordinates.

:rtype: std::vector< double > &
:returns: std::vector<double>& Coordinates of all vertices.
";

%feature("docstring") dolfin::Mesh::coordinates() const "
Return coordinates of all vertices (const version).

:rtype: const std::vector< double > &
:returns: std::vector<double>& Coordinates of all vertices.
";

%feature("docstring") dolfin::Mesh::data() "
Get mesh data.

:rtype: MeshData &
:returns: :cpp:any:`MeshData` & The mesh data object associated with the mesh.
";

%feature("docstring") dolfin::Mesh::data() const "
Get mesh data (const version). 

:rtype: const MeshData &
:returns: :cpp:any:`MeshData` & The mesh data object associated with the mesh.
";

%feature("docstring") dolfin::Mesh::domains() "
Get mesh (sub)domains.

:rtype: MeshDomains &
:returns: :cpp:any:`MeshDomains`  The (sub)domains associated with the mesh.
";

%feature("docstring") dolfin::Mesh::domains() const "
Get mesh (sub)domains (const).

:rtype: const MeshDomains &
:returns: :cpp:any:`MeshDomains`  The (sub)domains associated with the mesh.
";

%feature("docstring") dolfin::Mesh::geometry() "
Get mesh geometry.

:rtype: MeshGeometry &
:returns: :cpp:any:`MeshGeometry`  The geometry object associated with the mesh.
";

%feature("docstring") dolfin::Mesh::geometry() const "
Get mesh geometry (const version).

:rtype: const MeshGeometry &
:returns: :cpp:any:`MeshGeometry`  The geometry object associated with the mesh.
";

%feature("docstring") dolfin::Mesh::ghost_mode() const "
Ghost mode used for partitioning. Possible values are same as ``parameters[\"ghost_mode\"]`` . WARNING: the interface may change in future without deprecation; the method is now intended for internal library use. 

:rtype: std::string
";

%feature("docstring") dolfin::Mesh::hash() const "
Compute hash of mesh, currently based on the has of the mesh geometry and mesh topology.

:rtype: std::size_t
:returns: std::size_t A tree-hashed value of the coordinates over all :cpp:any:`MPI`  processes
";

%feature("docstring") dolfin::Mesh::hmax() const "
Compute maximum cell size in mesh, measured greatest distance between any two vertices of a cell.

:rtype: double
:returns: double The maximum cell size. The size is computed using :cpp:any:`Cell::h()`
";

%feature("docstring") dolfin::Mesh::hmin() const "
Compute minimum cell size in mesh, measured greatest distance between any two vertices of a cell.

:rtype: double
:returns: double The minimum cell size. The size is computed using :cpp:any:`Cell::h()`
";

%feature("docstring") dolfin::Mesh::init() const "
Compute all entities and connectivity. 

:rtype: void
";

%feature("docstring") dolfin::Mesh::init(std::size_t d0, std::size_t d1) const "
Compute connectivity between given pair of dimensions.

:param std\\:\\:size_t d0:  (std::size_t) Topological dimension.
:param std\\:\\:size_t d1:  (std::size_t) Topological dimension.
:rtype: void
";

%feature("docstring") dolfin::Mesh::init(std::size_t dim) const "
Compute entities of given topological dimension.

:param std\\:\\:size_t dim:  (std::size_t) Topological dimension.
:rtype: std::size_t
:returns: std::size_t Number of created entities.
";

%feature("docstring") dolfin::Mesh::init_cell_orientations(const Expression &global_normal) "
Compute and initialize cell_orientations relative to a given global outward direction/normal/orientation. Only defined if mesh is orientable.

:param const Expression & global_normal:  (:cpp:any:`Expression` ) A global normal direction to the mesh
:rtype: void
";

%feature("docstring") dolfin::Mesh::init_global(std::size_t dim) const "
Compute global indices for entity dimension dim. 

:param std\\:\\:size_t dim: 
:rtype: void
";

%feature("docstring") dolfin::Mesh::mpi_comm() const "
:cpp:any:`Mesh` :cpp:any:`MPI`  communicator 

:rtype: MPI_Comm
:returns: MPI_Comm
";

%feature("docstring") dolfin::Mesh::num_cells() const "
Get number of cells in mesh.

:rtype: std::size_t
:returns: std::size_t Number of cells.
";

%feature("docstring") dolfin::Mesh::num_edges() const "
Get number of edges in mesh.

:rtype: std::size_t
:returns: std::size_t Number of edges.
";

%feature("docstring") dolfin::Mesh::num_entities(std::size_t d) const "
Get number of entities of given topological dimension.

:param std\\:\\:size_t d:  (std::size_t) Topological dimension.
:rtype: std::size_t
:returns: std::size_t Number of entities of topological dimension d.
";

%feature("docstring") dolfin::Mesh::num_faces() const "
Get number of faces in mesh.

:rtype: std::size_t
:returns: std::size_t Number of faces.
";

%feature("docstring") dolfin::Mesh::num_facets() const "
Get number of facets in mesh.

:rtype: std::size_t
:returns: std::size_t Number of facets.
";

%feature("docstring") dolfin::Mesh::num_vertices() const "
Get number of vertices in mesh.

:rtype: std::size_t
:returns: std::size_t Number of vertices.
";

%feature("docstring") dolfin::Mesh::operator=(const Mesh &mesh) "
Assignment operator

:param const Mesh & mesh:  (:cpp:any:`Mesh` ) Another :cpp:any:`Mesh`  object.
:rtype: const Mesh &
";

%feature("docstring") dolfin::Mesh::order() "
Order all mesh entities.
See also: :cpp:any:`UFC`  documentation (put link here!) 

:rtype: void
";

%feature("docstring") dolfin::Mesh::ordered() const "
Check if mesh is ordered according to the :cpp:any:`UFC`  numbering convention.

:rtype: bool
:returns: bool The return values is true iff the mesh is ordered.
";

%feature("docstring") dolfin::Mesh::renumber_by_color() const "
Renumber mesh entities by coloring. This function is currently restricted to renumbering by cell coloring. The cells (cell-vertex connectivity) and the coordinates of the mesh are renumbered to improve the locality within each color. It is assumed that the mesh has already been colored and that only cell-vertex connectivity exists as part of the mesh. 

:rtype: Mesh
:returns: :cpp:any:`Mesh`
";

%feature("docstring") dolfin::Mesh::rmax() const "
Compute maximum cell inradius.

:rtype: double
:returns: double The maximum of cells' inscribed sphere radii
";

%feature("docstring") dolfin::Mesh::rmin() const "
Compute minimum cell inradius.

:rtype: double
:returns: double The minimum of cells' inscribed sphere radii
";

%feature("docstring") dolfin::Mesh::rotate(double angle, std::size_t axis, const Point &point) "
Rotate mesh around a coordinate axis through a given point

:param double angle:  (double) The number of degrees (0-360) of rotation.
:param std\\:\\:size_t axis:  (std::size_t) The coordinate axis around which to rotate the mesh.
:param const Point & point:  (:cpp:any:`Point` ) The point around which to rotate the mesh.
:rtype: void
";

%feature("docstring") dolfin::Mesh::rotate(double angle, std::size_t axis=2) "
Rotate mesh around a coordinate axis through center of mass of all mesh vertices

:param double angle:  (double) The number of degrees (0-360) of rotation.
:param std\\:\\:size_t axis:  (std::size_t) The coordinate axis around which to rotate the mesh.
:rtype: void
";

%feature("docstring") dolfin::Mesh::size(std::size_t dim) const "
Get number of local entities of given topological dimension.

:param std\\:\\:size_t dim:  (std::size_t) Topological dimension.
:rtype: std::size_t
:returns: std::size_t Number of local entities of topological dimension d.
";

%feature("docstring") dolfin::Mesh::size_global(std::size_t dim) const "
Get global number of entities of given topological dimension.

:param std\\:\\:size_t dim:  (std::size_t) Topological dimension.
:rtype: std::size_t
:returns: std::size_t Global number of entities of topological dimension d.
";

%feature("docstring") dolfin::Mesh::smooth(std::size_t num_iterations=1) "
Smooth internal vertices of mesh by local averaging.

:param std\\:\\:size_t num_iterations:  (std::size_t) Number of iterations to perform smoothing, default value is 1.
:rtype: void
";

%feature("docstring") dolfin::Mesh::smooth_boundary(std::size_t num_iterations=1, bool harmonic_smoothing=true) "
Smooth boundary vertices of mesh by local averaging.

:param std\\:\\:size_t num_iterations:  (std::size_t) Number of iterations to perform smoothing, default value is 1.
:param bool harmonic_smoothing:  (bool) Flag to turn on harmonics smoothing, default value is true.
:rtype: void
";

%feature("docstring") dolfin::Mesh::snap_boundary(const SubDomain &sub_domain, bool harmonic_smoothing=true) "
Snap boundary vertices of mesh to match given sub domain.

:param const SubDomain & sub_domain:  (:cpp:any:`SubDomain` ) A :cpp:any:`SubDomain`  object.
:param bool harmonic_smoothing:  (bool) Flag to turn on harmonics smoothing, default value is true.
:rtype: void
";

%feature("docstring") dolfin::Mesh::str(bool verbose) const "
Informal string representation.

:param bool verbose:  (bool) Flag to turn on additional output.
:rtype: std::string
:returns: std::string An informal representation of the mesh.
";

%feature("docstring") dolfin::Mesh::topology() "
Get mesh topology.

:rtype: MeshTopology &
:returns: :cpp:any:`MeshTopology`  The topology object associated with the mesh.
";

%feature("docstring") dolfin::Mesh::topology() const "
Get mesh topology (const version).

:rtype: const MeshTopology &
:returns: :cpp:any:`MeshTopology`  The topology object associated with the mesh.
";

%feature("docstring") dolfin::Mesh::translate(const Point &point) "
Translate mesh according to a given vector.

:param const Point & point:  (:cpp:any:`Point` ) The vector defining the translation.
:rtype: void
";

%feature("docstring") dolfin::Mesh::type() "
Get mesh cell type.

:rtype: CellType &
:returns: :cpp:any:`CellType` & The cell type object associated with the mesh.
";

%feature("docstring") dolfin::Mesh::type() const "
Get mesh cell type (const version). 

:rtype: const CellType &
";

%feature("docstring") dolfin::Mesh::~Mesh() "
Destructor.
";

%feature("docstring") dolfin::MeshColoring "
This class computes colorings for a local mesh. It supports vertex, edge, and facet-based colorings.
";

%feature("docstring") dolfin::MeshColoring::cell_colors(std::shared_ptr< const Mesh > mesh, std::string coloring_type) "
Return a :cpp:any:`MeshFunction`  with the cell colors (used for visualisation) 

:param std\\:\\:shared_ptr< const Mesh > mesh: 
:param std\\:\\:string coloring_type: 
:rtype: CellFunction< std::size_t >
";

%feature("docstring") dolfin::MeshColoring::cell_colors(std::shared_ptr< const Mesh > mesh, std::vector< std::size_t > coloring_type) "
Return a :cpp:any:`MeshFunction`  with the cell colors (used for visualisation) 

:param std\\:\\:shared_ptr< const Mesh > mesh: 
:param std\\:\\:vector< std\\:\\:size_t > coloring_type: 
:rtype: CellFunction< std::size_t >
";

%feature("docstring") dolfin::MeshColoring::color(Mesh &mesh, const std::vector< std::size_t > &coloring_type) "
Color the cells of a mesh for given coloring type specified by topological dimension, which can be one of 0, 1 or D -

#. Coloring is saved in the mesh topology

:param Mesh & mesh: 
:param const std\\:\\:vector< std\\:\\:size_t > & coloring_type: 
:rtype: const std::vector< std::size_t > &
";

%feature("docstring") dolfin::MeshColoring::color_cells(Mesh &mesh, std::string coloring_type) "
Color the cells of a mesh for given coloring type, which can be one of \"vertex\", \"edge\" or \"facet\". Coloring is saved in the mesh topology 

:param Mesh & mesh: 
:param std\\:\\:string coloring_type: 
:rtype: const std::vector< std::size_t > &
";

%feature("docstring") dolfin::MeshColoring::compute_colors(const Mesh &mesh, std::vector< std::size_t > &colors, const std::vector< std::size_t > &coloring_type) "
Compute cell colors for given coloring type specified by topological dimension, which can be one of 0, 1 or D - 1. 

:param const Mesh & mesh: 
:param std\\:\\:vector< std\\:\\:size_t > & colors: 
:param const std\\:\\:vector< std\\:\\:size_t > & coloring_type: 
:rtype: std::size_t
";

%feature("docstring") dolfin::MeshColoring::type_to_dim(std::string coloring_type, const Mesh &mesh) "
Convert coloring type to topological dimension. 

:param std\\:\\:string coloring_type: 
:param const Mesh & mesh: 
:rtype: std::size_t
";

%feature("docstring") dolfin::MeshConnectivity "
:cpp:any:`Mesh`  connectivity stores a sparse data structure of connections (incidence relations) between mesh entities for a fixed pair of topological dimensions.
The connectivity can be specified either by first giving the number of entities and the number of connections for each entity, which may either be equal for all entities or different, or by giving the entire (sparse) connectivity pattern.
";

%feature("docstring") dolfin::MeshConnectivity::MeshConnectivity(const MeshConnectivity &connectivity) "
Copy constructor. 

:param const MeshConnectivity & connectivity:
";

%feature("docstring") dolfin::MeshConnectivity::MeshConnectivity(std::size_t d0, std::size_t d1) "
Create empty connectivity between given dimensions (d0 -- d1) 

:param std\\:\\:size_t d0: 
:param std\\:\\:size_t d1:
";

%feature("docstring") dolfin::MeshConnectivity::clear() "
Clear all data. 

:rtype: void
";

%feature("docstring") dolfin::MeshConnectivity::empty() const "
Return true if the total number of connections is equal to zero. 

:rtype: bool
";

%feature("docstring") dolfin::MeshConnectivity::hash() const "
Hash of connections. 

:rtype: std::size_t
";

%feature("docstring") dolfin::MeshConnectivity::index_to_position "
:rtype: std::vector< unsigned int >
";

%feature("docstring") dolfin::MeshConnectivity::init(std::size_t num_entities, std::size_t num_connections) "
Initialize number of entities and number of connections (equal for all) 

:param std\\:\\:size_t num_entities: 
:param std\\:\\:size_t num_connections: 
:rtype: void
";

%feature("docstring") dolfin::MeshConnectivity::init(std::vector< std::size_t > &num_connections) "
Initialize number of entities and number of connections (individually) 

:param std\\:\\:vector< std\\:\\:size_t > & num_connections: 
:rtype: void
";

%feature("docstring") dolfin::MeshConnectivity::operator()() const "
Return contiguous array of connections for all entities. 

:rtype: const std::vector< unsigned int > &
";

%feature("docstring") dolfin::MeshConnectivity::operator()(std::size_t entity) const "
Return array of connections for given entity. 

:param std\\:\\:size_t entity: 
:rtype: const unsigned int *
";

%feature("docstring") dolfin::MeshConnectivity::operator=(const MeshConnectivity &connectivity) "
Assignment. 

:param const MeshConnectivity & connectivity: 
:rtype: const MeshConnectivity &
";

%feature("docstring") dolfin::MeshConnectivity::set(const T &connections) "
:cpp:any:`Set`  all connections for all entities (T is a '2D' container, e.g. a std::vector<<std::vector<std::size_t>>, std::vector<<std::set<std::size_t>>, etc) 

:param const T & connections: 
:rtype: void
";

%feature("docstring") dolfin::MeshConnectivity::set(std::size_t entity, const T &connections) "
:cpp:any:`Set`  all connections for given entity. T is a contains, e.g. std::vector<std::size_t> 

:param std\\:\\:size_t entity: 
:param const T & connections: 
:rtype: void
";

%feature("docstring") dolfin::MeshConnectivity::set(std::size_t entity, std::size_t *connections) "
:cpp:any:`Set`  all connections for given entity. 

:param std\\:\\:size_t entity: 
:param std\\:\\:size_t * connections: 
:rtype: void
";

%feature("docstring") dolfin::MeshConnectivity::set(std::size_t entity, std::size_t connection, std::size_t pos) "
:cpp:any:`Set`  given connection for given entity. 

:param std\\:\\:size_t entity: 
:param std\\:\\:size_t connection: 
:param std\\:\\:size_t pos: 
:rtype: void
";

%feature("docstring") dolfin::MeshConnectivity::set_global_size(const std::vector< unsigned int > &num_global_connections) "
:cpp:any:`Set`  global number of connections for all local entities. 

:param const std\\:\\:vector< unsigned int > & num_global_connections: 
:rtype: void
";

%feature("docstring") dolfin::MeshConnectivity::size() const "
Return total number of connections. 

:rtype: std::size_t
";

%feature("docstring") dolfin::MeshConnectivity::size(std::size_t entity) const "
Return number of connections for given entity. 

:param std\\:\\:size_t entity: 
:rtype: std::size_t
";

%feature("docstring") dolfin::MeshConnectivity::size_global(std::size_t entity) const "
Return global number of connections for given entity. 

:param std\\:\\:size_t entity: 
:rtype: std::size_t
";

%feature("docstring") dolfin::MeshConnectivity::str(bool verbose) const "
Return informal string representation (pretty-print) 

:param bool verbose: 
:rtype: std::string
";

%feature("docstring") dolfin::MeshConnectivity::~MeshConnectivity() "
Destructor.
";

%feature("docstring") dolfin::MeshData "
The class :cpp:any:`MeshData`  is a container for auxiliary mesh data, represented either as arrays or maps. Each dataset is identified by a unique user-specified string. Only std::size_t-valued data are currently supported.
Auxiliary mesh data may be attached to a mesh by users as a convenient way to store data associated with a mesh. It is also used internally by DOLFIN to communicate data associated with meshes. The following named mesh data are recognized by DOLFIN:
:cpp:any:`Facet`  orientation (used for assembly over interior facets)

*  \"facet_orientation\" - std:vector <std::size_t> of dimension D - 1

Sub meshes (used by the class :cpp:any:`SubMesh` )

*  \"parent_vertex_indices\" - std::vector <std::size_t> of dimension 0

Note to developers: use underscore in names in place of spaces. 

Friends: :cpp:any:`XMLMesh`.
";

%feature("docstring") dolfin::MeshData::MeshData() "
Constructor.
";

%feature("docstring") dolfin::MeshData::array(std::string name, std::size_t dim) "
Return array with given name (returning zero if data is not available)

:param std\\:\\:string name:  (std::string) The name of the array.
:param std\\:\\:size_t dim:  (std::size_t) Dimension.
:rtype: std::vector< std::size_t > &
:returns: std::vector<std::size_t> The array.
";

%feature("docstring") dolfin::MeshData::array(std::string name, std::size_t dim) const "
Return array with given name (returning zero if data is not available)

:param std\\:\\:string name:  (std::string) The name of the array.
:param std\\:\\:size_t dim:  (std::size_t) Dimension.
:rtype: const std::vector< std::size_t > &
:returns: std::vector<std::size_t> The array.
";

%feature("docstring") dolfin::MeshData::check_deprecated(std::string name) const "
:param std\\:\\:string name: 
:rtype: void
";

%feature("docstring") dolfin::MeshData::clear() "
Clear all data. 

:rtype: void
";

%feature("docstring") dolfin::MeshData::create_array(std::string name, std::size_t dim) "
Create array (vector) with given name and size

:param std\\:\\:string name:  (std::string) The name of the array.
:param std\\:\\:size_t dim:  (std::size_t) Dimension.
:rtype: std::vector< std::size_t > &
:returns: std::vector<std::size_t> The array.
";

%feature("docstring") dolfin::MeshData::erase_array(const std::string name, std::size_t dim) "
Erase array with given name

:param const std\\:\\:string name:  (std::string) The name of the array.
:param std\\:\\:size_t dim:  (std::size_t) Dimension.
:rtype: void
";

%feature("docstring") dolfin::MeshData::exists(std::string name, std::size_t dim) const "
Check is array exists

:param std\\:\\:string name:  (std::string) The name of the array.
:param std\\:\\:size_t dim:  (std::size_t)
:rtype: bool
:returns: bool True is array exists, false otherwise.
";

%feature("docstring") dolfin::MeshData::operator=(const MeshData &data) "
Assignment operator

:param const MeshData & data:  (:cpp:any:`MeshData` ) Another :cpp:any:`MeshData`  object.
:rtype: const MeshData &
";

%feature("docstring") dolfin::MeshData::str(bool verbose) const "
Return informal string representation (pretty-print)

:param bool verbose:  (bool) Flag to turn on additional output.
:rtype: std::string
:returns: std::string An informal representation.
";

%feature("docstring") dolfin::MeshData::~MeshData() "
Destructor.
";

%feature("docstring") dolfin::MeshDomains "
The class :cpp:any:`MeshDomains`  stores the division of a :cpp:any:`Mesh`  into subdomains. For each topological dimension 0 <= d <= D, where D is the topological dimension of the :cpp:any:`Mesh` , a set of integer markers are stored for a subset of the entities of dimension d, indicating for each entity in the subset the number of the subdomain. It should be noted that the subset does not need to contain all entities of any given dimension; entities not contained in the subset are \"unmarked\".
";

%feature("docstring") dolfin::MeshDomains::MeshDomains() "
Create empty mesh domains.
";

%feature("docstring") dolfin::MeshDomains::clear() "
Clear all data. 

:rtype: void
";

%feature("docstring") dolfin::MeshDomains::get_marker(std::size_t entity_index, std::size_t dim) const "
Get marker (entity index, marker value) of a given dimension d. Throws an error if marker does not exist. 

:param std\\:\\:size_t entity_index: 
:param std\\:\\:size_t dim: 
:rtype: std::size_t
";

%feature("docstring") dolfin::MeshDomains::init(std::size_t dim) "
Initialize mesh domains for given topological dimension. 

:param std\\:\\:size_t dim: 
:rtype: void
";

%feature("docstring") dolfin::MeshDomains::is_empty() const "
Check whether domain data is empty. 

:rtype: bool
";

%feature("docstring") dolfin::MeshDomains::markers(std::size_t dim) "
Get subdomain markers for given dimension (shared pointer version) 

:param std\\:\\:size_t dim: 
:rtype: std::map< std::size_t, std::size_t > &
";

%feature("docstring") dolfin::MeshDomains::markers(std::size_t dim) const "
Get subdomain markers for given dimension (const shared pointer version) 

:param std\\:\\:size_t dim: 
:rtype: const std::map< std::size_t, std::size_t > &
";

%feature("docstring") dolfin::MeshDomains::max_dim() const "
Return maximum topological dimension of stored markers. 

:rtype: std::size_t
";

%feature("docstring") dolfin::MeshDomains::num_marked(std::size_t dim) const "
Return number of marked entities of given dimension. 

:param std\\:\\:size_t dim: 
:rtype: std::size_t
";

%feature("docstring") dolfin::MeshDomains::operator=(const MeshDomains &domains) "
Assignment operator. 

:param const MeshDomains & domains: 
:rtype: const MeshDomains &
";

%feature("docstring") dolfin::MeshDomains::set_marker(std::pair< std::size_t, std::size_t > marker, std::size_t dim) "
:cpp:any:`Set`  marker (entity index, marker value) of a given dimension d. Returns true if a new key is inserted, false otherwise. 

:param std\\:\\:pair< std\\:\\:size_t, std\\:\\:size_t > marker: 
:param std\\:\\:size_t dim: 
:rtype: bool
";

%feature("docstring") dolfin::MeshDomains::~MeshDomains() "
Destructor.
";

%feature("docstring") dolfin::MeshEditor "
A simple mesh editor for creating simplicial meshes in 1D, 2D and 3D. 

Friends: :cpp:any:`TetrahedronCell`.
";

%feature("docstring") dolfin::MeshEditor::MeshEditor() "
Constructor.
";

%feature("docstring") dolfin::MeshEditor::add_cell(std::size_t c, const T &v) "
Add cell with given vertices

:param std\\:\\:size_t c:  (std::size_t) The cell (index).
:param const T & v:  (typename T) The vertex indices (local indices)
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::add_cell(std::size_t c, const std::vector< std::size_t > &v) "
Add cell with given vertices (non-templated version for Python interface)

:param std\\:\\:size_t c:  (std::size_t) The cell (index).
:param const std\\:\\:vector< std\\:\\:size_t > & v:  (std::vector<std::size_t>) The vertex indices (local indices)
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::add_cell(std::size_t c, std::size_t v0, std::size_t v1) "
Add cell with given vertices (1D)

:param std\\:\\:size_t c:  (std::size_t) The cell (index).
:param std\\:\\:size_t v0:  (std::vector<std::size_t>) The first vertex (local index).
:param std\\:\\:size_t v1:  (std::vector<std::size_t>) The second vertex (local index).
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::add_cell(std::size_t c, std::size_t v0, std::size_t v1, std::size_t v2) "
Add cell with given vertices (2D)

:param std\\:\\:size_t c:  (std::size_t) The cell (index).
:param std\\:\\:size_t v0:  (std::vector<std::size_t>) The first vertex (local index).
:param std\\:\\:size_t v1:  (std::vector<std::size_t>) The second vertex (local index).
:param std\\:\\:size_t v2:  (std::vector<std::size_t>) The third vertex (local index).
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::add_cell(std::size_t c, std::size_t v0, std::size_t v1, std::size_t v2, std::size_t v3) "
Add cell with given vertices (3D)

:param std\\:\\:size_t c:  (std::size_t) The cell (index).
:param std\\:\\:size_t v0:  (std::vector<std::size_t>) The first vertex (local index).
:param std\\:\\:size_t v1:  (std::vector<std::size_t>) The second vertex (local index).
:param std\\:\\:size_t v2:  (std::vector<std::size_t>) The third vertex (local index).
:param std\\:\\:size_t v3:  (std::vector<std::size_t>) The fourth vertex (local index).
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::add_cell(std::size_t local_index, std::size_t global_index, const T &v) "
Add cell with given vertices

:param std\\:\\:size_t local_index:  (std::size_t) The cell (index).
:param std\\:\\:size_t global_index:  (std::size_t) The global (user) cell index.
:param const T & v:  (std::vector<std::size_t>) The vertex indices (local indices)
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::add_cell_common(std::size_t v, std::size_t dim) "
:param std\\:\\:size_t v: 
:param std\\:\\:size_t dim: 
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::add_entity_point(std::size_t entity_dim, std::size_t order, std::size_t index, const Point &p) "
Add a point in a given entity of dimension entity_dim. 

:param std\\:\\:size_t entity_dim: 
:param std\\:\\:size_t order: 
:param std\\:\\:size_t index: 
:param const Point & p: 
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::add_vertex(std::size_t index, const Point &p) "
Add vertex v at given point p

:param std\\:\\:size_t index:  (std::size_t) The vertex (index).
:param const Point & p:  (:cpp:any:`Point` ) The point.
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::add_vertex(std::size_t index, const std::vector< double > &x) "
Add vertex v at given coordinate x

:param std\\:\\:size_t index:  (std::size_t) The vertex (index).
:param const std\\:\\:vector< double > & x:  (std::vector<double>) The x-coordinates.
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::add_vertex(std::size_t index, double x) "
Add vertex v at given point x (for a 1D mesh)

:param std\\:\\:size_t index:  (std::size_t) The vertex (index).
:param double x:  (double) The x-coordinate.
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::add_vertex(std::size_t index, double x, double y) "
Add vertex v at given point (x, y) (for a 2D mesh)

:param std\\:\\:size_t index:  (std::size_t) The vertex (index).
:param double x:  (double) The x-coordinate.
:param double y:  (double) The y-coordinate.
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::add_vertex(std::size_t index, double x, double y, double z) "
Add vertex v at given point (x, y, z) (for a 3D mesh)

:param std\\:\\:size_t index:  (std::size_t) The vertex (index).
:param double x:  (double) The x-coordinate.
:param double y:  (double) The y-coordinate.
:param double z:  (double) The z-coordinate.
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::add_vertex_common(std::size_t v, std::size_t dim) "
:param std\\:\\:size_t v: 
:param std\\:\\:size_t dim: 
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::add_vertex_global(std::size_t local_index, std::size_t global_index, const Point &p) "
Add vertex v at given point p

:param std\\:\\:size_t local_index:  (std::size_t) The vertex (local index).
:param std\\:\\:size_t global_index:  (std::size_t) The vertex (global_index).
:param const Point & p:  (:cpp:any:`Point` ) The point.
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::add_vertex_global(std::size_t local_index, std::size_t global_index, const std::vector< double > &x) "
Add vertex v at given coordinate x

:param std\\:\\:size_t local_index:  (std::size_t) The vertex (local index).
:param std\\:\\:size_t global_index:  (std::size_t) The vertex (global_index).
:param const std\\:\\:vector< double > & x:  (std::vector<double>) The x-coordinates.
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::check_vertices(const T &v) const "
:param const T & v: 
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::clear() "
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::close(bool order=true) "
Close mesh, finish editing, and order entities locally

::
   
   MeshEditor editor;
   editor.open(mesh, 2, 2);
   ...
   editor.close()

:param bool order:  (bool) Order entities locally if true. Default values is true.
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::compute_boundary_indicators() "
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::init_cells(std::size_t num_cells) "
Specify number of cells (serial version)

::
   
   Mesh mesh;
   MeshEditor editor;
   editor.open(mesh, 2, 2);
   editor.init_cells(8);

:param std\\:\\:size_t num_cells:  (std::size_t) The number of cells.
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::init_cells_global(std::size_t num_local_cells, std::size_t num_global_cells) "
Specify number of cells (distributed version)

::
   
   Mesh mesh;
   MeshEditor editor;
   editor.open(mesh, 2, 2);
   editor.init_cells(2, 6);

:param std\\:\\:size_t num_local_cells:  (std::size_t) The number of local cells.
:param std\\:\\:size_t num_global_cells:  (std::size_t) The number of cells in distributed mesh.
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::init_entities() "
Initialise entities in :cpp:any:`MeshGeometry` 
Create required Edges and Faces for the current polynomial degree in the mesh topology, so that points can be added for them. In order to initialise entities, cells must all be added first. 

:rtype: void
";

%feature("docstring") dolfin::MeshEditor::init_vertices(std::size_t num_vertices) "
Specify number of vertices (serial version)

::
   
   Mesh mesh;
   MeshEditor editor;
   editor.open(mesh, 2, 2);
   editor.init_vertices(9);

:param std\\:\\:size_t num_vertices:  (std::size_t) The number of vertices.
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::init_vertices_global(std::size_t num_local_vertices, std::size_t num_global_vertices) "
Specify number of vertices (distributed version)

::
   
   Mesh mesh;
   MeshEditor editor;
   editor.open(mesh, 2, 2);
   editor.init_vertices(4, 8);

:param std\\:\\:size_t num_local_vertices:  (std::size_t) The number of vertices on this process.
:param std\\:\\:size_t num_global_vertices:  (std::size_t) The number of vertices in distributed mesh.
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::next_cell "
:rtype: std::size_t
";

%feature("docstring") dolfin::MeshEditor::next_vertex "
:rtype: std::size_t
";

%feature("docstring") dolfin::MeshEditor::open(Mesh &mesh, CellType::Type type, std::size_t tdim, std::size_t gdim, std::size_t degree=1) "
Open mesh of given cell type, topological and geometrical dimension

:param Mesh & mesh:  (:cpp:any:`Mesh` ) The mesh to open.
:param CellType\\:\\:Type type:  (:cpp:any:`CellType::Type` ) :cpp:any:`Cell`  type.
:param std\\:\\:size_t tdim:  (std::size_t) The topological dimension.
:param std\\:\\:size_t gdim:  (std::size_t) The geometrical dimension.
:param std\\:\\:size_t degree:  (std::size_t) The polynomial degree.
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::open(Mesh &mesh, std::size_t tdim, std::size_t gdim, std::size_t degree=1) "
Open mesh of given topological and geometrical dimension

:param Mesh & mesh:  (:cpp:any:`Mesh` ) The mesh to open.
:param std\\:\\:size_t tdim:  (std::size_t) The topological dimension.
:param std\\:\\:size_t gdim:  (std::size_t) The geometrical dimension.
:param std\\:\\:size_t degree:  (std::size_t) The polynomial degree.   ::            Mesh mesh;    MeshEditor editor;    editor.open(mesh, 2, 2, 1);
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::open(Mesh &mesh, std::string type, std::size_t tdim, std::size_t gdim, std::size_t degree=1) "
Open mesh of given cell type, topological and geometrical dimension

:param Mesh & mesh:  (:cpp:any:`Mesh` ) The mesh to open.
:param std\\:\\:string type:  (std::string) :cpp:any:`Cell`  type.
:param std\\:\\:size_t tdim:  (std::size_t) The topological dimension.
:param std\\:\\:size_t gdim:  (std::size_t) The geometrical dimension.
:param std\\:\\:size_t degree:  (std::size_t) The polynomial degree.
:rtype: void
";

%feature("docstring") dolfin::MeshEditor::~MeshEditor() "
Destructor.
";

%feature("docstring") dolfin::MeshEntity "
A :cpp:any:`MeshEntity`  represents a mesh entity associated with a specific topological dimension of some :cpp:any:`Mesh` . 

Friends: :cpp:any:`MeshEntityIterator`, :cpp:any:`MeshEntityIteratorBase`, :cpp:any:`SubsetIterator`.
";

%feature("docstring") dolfin::MeshEntity::MeshEntity() "
Default Constructor.
";

%feature("docstring") dolfin::MeshEntity::MeshEntity(const Mesh &mesh, std::size_t dim, std::size_t index) "
Constructor

:param const Mesh & mesh:  (:cpp:any:`Mesh` ) The mesh.
:param std\\:\\:size_t dim:  (std::size_t) The topological dimension.
:param std\\:\\:size_t index:  (std::size_t) The index.
";

%feature("docstring") dolfin::MeshEntity::dim() const "
Return topological dimension

:rtype: std::size_t
:returns: std::size_t The dimension.
";

%feature("docstring") dolfin::MeshEntity::entities(std::size_t dim) const "
Return array of indices for incident mesh entities of given topological dimension

:param std\\:\\:size_t dim:  (std::size_t) The topological dimension.
:rtype: const unsigned int *
:returns: std::size_t The index for incident mesh entities of given dimension.
";

%feature("docstring") dolfin::MeshEntity::global_index() const "
Return global index of mesh entity

:rtype: std::int64_t
:returns: std::size_t The global index. :cpp:any:`Set`  to std::numerical_limits<std::size_t>::max() if global index has not been computed
";

%feature("docstring") dolfin::MeshEntity::incident(const MeshEntity &entity) const "
Check if given entity is incident

:param const MeshEntity & entity:  (:cpp:any:`MeshEntity` ) The entity.
:rtype: bool
:returns: bool True if the given entity is incident
";

%feature("docstring") dolfin::MeshEntity::index() const "
Return index of mesh entity

:rtype: std::size_t
:returns: std::size_t The index.
";

%feature("docstring") dolfin::MeshEntity::index(const MeshEntity &entity) const "
Compute local index of given incident entity (error if not found)

:param const MeshEntity & entity:  (:cpp:any:`MeshEntity` ) The mesh entity.
:rtype: std::size_t
:returns: std::size_t The local index of given entity.
";

%feature("docstring") dolfin::MeshEntity::init(const Mesh &mesh, std::size_t dim, std::size_t index) "
Initialize mesh entity with given data

:param const Mesh & mesh:  (:cpp:any:`Mesh` ) The mesh.
:param std\\:\\:size_t dim:  (std::size_t) The topological dimension.
:param std\\:\\:size_t index:  (std::size_t) The index.
:rtype: void
";

%feature("docstring") dolfin::MeshEntity::is_ghost() const "
Determine whether an entity is a 'ghost' from another process 

:rtype: bool
:returns: bool True if entity is a ghost entity
";

%feature("docstring") dolfin::MeshEntity::is_shared() const "
Determine if an entity is shared or not 

:rtype: bool
:returns: bool True if entity is shared
";

%feature("docstring") dolfin::MeshEntity::mesh() const "
Return mesh associated with mesh entity

:rtype: const Mesh &
:returns: :cpp:any:`Mesh`  The mesh.
";

%feature("docstring") dolfin::MeshEntity::mesh_id() const "
Return unique mesh ID

:rtype: std::size_t
:returns: std::size_t The unique mesh ID.
";

%feature("docstring") dolfin::MeshEntity::midpoint() const "
Compute midpoint of cell

:rtype: Point
:returns: :cpp:any:`Point`  The midpoint of the cell.
";

%feature("docstring") dolfin::MeshEntity::num_entities(std::size_t dim) const "
Return local number of incident mesh entities of given topological dimension

:param std\\:\\:size_t dim:  (std::size_t) The topological dimension.
:rtype: std::size_t
:returns: std::size_t The number of local incident :cpp:any:`MeshEntity`  objects of given dimension.
";

%feature("docstring") dolfin::MeshEntity::num_global_entities(std::size_t dim) const "
Return global number of incident mesh entities of given topological dimension

:param std\\:\\:size_t dim:  (std::size_t) The topological dimension.
:rtype: std::size_t
:returns: std::size_t The number of global incident :cpp:any:`MeshEntity`  objects of given dimension.
";

%feature("docstring") dolfin::MeshEntity::operator!=(const MeshEntity &e) const "
Comparison Operator

:param const MeshEntity & e:  (:cpp:any:`MeshEntity` ) Another mesh entity.
:rtype: bool
:returns: bool True if the two mesh entities are NOT equal.
";

%feature("docstring") dolfin::MeshEntity::operator==(const MeshEntity &e) const "
Comparison Operator

:param const MeshEntity & e:  (:cpp:any:`MeshEntity` ) Another mesh entity
:rtype: bool
:returns: bool True if the two mesh entities are equal.
";

%feature("docstring") dolfin::MeshEntity::owner() const "
Get ownership of this entity - only really valid for cells 

:rtype: unsigned int
:returns: unsigned int Owning process
";

%feature("docstring") dolfin::MeshEntity::sharing_processes() const "
Return set of sharing processes 

:rtype: std::set< unsigned int >
:returns: std::set<unsigned int> List of sharing processes
";

%feature("docstring") dolfin::MeshEntity::str(bool verbose) const "
Return informal string representation (pretty-print)

:param bool verbose:  (bool) Flag to turn on additional output.
:rtype: std::string
:returns: std::string An informal representation of the function space.
";

%feature("docstring") dolfin::MeshEntity::~MeshEntity() "
Destructor.
";

%feature("docstring") dolfin::MeshEntityIterator "
:cpp:any:`MeshEntityIterator`  provides a common iterator for mesh entities over meshes, boundaries and incidence relations. The basic use is illustrated below.

::
   
   The following example shows how to iterate over all mesh entities
   of a mesh of topological dimension dim:
   
::
   
   for (MeshEntityIterator e(mesh, dim); !e.end(); ++e)
   {
   e->foo();
   }

::
   
   The following example shows how to iterate over mesh entities of
   topological dimension dim connected (incident) to some mesh entity f:
   
::
   
   for (MeshEntityIterator e(f, dim); !e.end(); ++e)
   {
   e->foo();
   }

In addition to the general iterator, a set of specific named iterators are provided for entities of type :cpp:any:`Vertex` , :cpp:any:`Edge` , :cpp:any:`Face` , :cpp:any:`Facet`  and :cpp:any:`Cell` . These iterators are defined along with their respective classes.
";

%feature("docstring") dolfin::MeshEntityIterator::MeshEntityIterator() "
Default constructor.
";

%feature("docstring") dolfin::MeshEntityIterator::MeshEntityIterator(const Mesh &mesh, std::size_t dim) "
Create iterator for mesh entities over given topological dimension. 

:param const Mesh & mesh: 
:param std\\:\\:size_t dim:
";

%feature("docstring") dolfin::MeshEntityIterator::MeshEntityIterator(const Mesh &mesh, std::size_t dim, std::string opt) "
Iterator over :cpp:any:`MeshEntity`  of dimension dim on mesh, with string option to iterate over \"regular\", \"ghost\" or \"all\" entities 

:param const Mesh & mesh: 
:param std\\:\\:size_t dim: 
:param std\\:\\:string opt:
";

%feature("docstring") dolfin::MeshEntityIterator::MeshEntityIterator(const MeshEntity &entity, std::size_t dim) "
Create iterator for entities of given dimension connected to given entity 

:param const MeshEntity & entity: 
:param std\\:\\:size_t dim:
";

%feature("docstring") dolfin::MeshEntityIterator::MeshEntityIterator(const MeshEntityIterator &it) "
Copy constructor. 

:param const MeshEntityIterator & it:
";

%feature("docstring") dolfin::MeshEntityIterator::end() const "
Check if iterator has reached the end. 

:rtype: bool
";

%feature("docstring") dolfin::MeshEntityIterator::end_iterator() "
Provide a safeguard iterator pointing beyond the end of an iteration process, either iterating over the mesh /or incident entities. Added to be bit more like STL iterators, since many algorithms rely on a kind of beyond iterator. 

:rtype: MeshEntityIterator
";

%feature("docstring") dolfin::MeshEntityIterator::index "
:rtype: const unsigned int *
";

%feature("docstring") dolfin::MeshEntityIterator::operator!=(const MeshEntityIterator &it) const "
Comparison operator. 

:param const MeshEntityIterator & it: 
:rtype: bool
";

%feature("docstring") dolfin::MeshEntityIterator::operator*() "
Dereference operator. 

:rtype: MeshEntity &
";

%feature("docstring") dolfin::MeshEntityIterator::operator++() "
Step to next mesh entity (prefix increment) 

:rtype: MeshEntityIterator &
";

%feature("docstring") dolfin::MeshEntityIterator::operator--() "
Step to the previous mesh entity (prefix decrease) 

:rtype: MeshEntityIterator &
";

%feature("docstring") dolfin::MeshEntityIterator::operator->() "
Member access operator. 

:rtype: MeshEntity *
";

%feature("docstring") dolfin::MeshEntityIterator::operator==(const MeshEntityIterator &it) const "
Comparison operator. 

:param const MeshEntityIterator & it: 
:rtype: bool
";

%feature("docstring") dolfin::MeshEntityIterator::pos() const "
Return current position. 

:rtype: std::size_t
";

%feature("docstring") dolfin::MeshEntityIterator::pos_end "
:rtype: std::size_t
";

%feature("docstring") dolfin::MeshEntityIterator::set_end() "
:rtype: void
";

%feature("docstring") dolfin::MeshEntityIterator::~MeshEntityIterator() "
Destructor.
";

%feature("docstring") dolfin::MeshEntityIteratorBase "
Base class for MeshEntityIterators.
";

%feature("docstring") dolfin::MeshEntityIteratorBase::MeshEntityIteratorBase(const Mesh &mesh) "
Create iterator for mesh entities over given topological dimension. 

:param const Mesh & mesh:
";

%feature("docstring") dolfin::MeshEntityIteratorBase::MeshEntityIteratorBase(const Mesh &mesh, std::string opt) "
Iterator over :cpp:any:`MeshEntity`  of dimension dim on mesh, with string option to iterate over \"regular\", \"ghost\" or \"all\" entities 

:param const Mesh & mesh: 
:param std\\:\\:string opt:
";

%feature("docstring") dolfin::MeshEntityIteratorBase::MeshEntityIteratorBase(const MeshEntity &entity) "
Create iterator for entities of given dimension connected to given entity. 

:param const MeshEntity & entity:
";

%feature("docstring") dolfin::MeshEntityIteratorBase::MeshEntityIteratorBase(const MeshEntityIteratorBase &it) "
Copy constructor. 

:param const MeshEntityIteratorBase & it:
";

%feature("docstring") dolfin::MeshEntityIteratorBase::end() const "
Check if iterator has reached the end. 

:rtype: bool
";

%feature("docstring") dolfin::MeshEntityIteratorBase::end_iterator() "
Provide a safeguard iterator pointing beyond the end of an iteration process, either iterating over the mesh /or incident entities. Added to be bit more like STL iterators, since many algorithms rely on a kind of beyond iterator. 

:rtype: MeshEntityIteratorBase
";

%feature("docstring") dolfin::MeshEntityIteratorBase::index "
:rtype: const unsigned int *
";

%feature("docstring") dolfin::MeshEntityIteratorBase::operator!=(const MeshEntityIteratorBase &it) const "
Comparison operator. 

:param const MeshEntityIteratorBase & it: 
:rtype: bool
";

%feature("docstring") dolfin::MeshEntityIteratorBase::operator*() "
Dereference operator. 

:rtype: T &
";

%feature("docstring") dolfin::MeshEntityIteratorBase::operator++() "
Step to next mesh entity (prefix increment) 

:rtype: MeshEntityIteratorBase &
";

%feature("docstring") dolfin::MeshEntityIteratorBase::operator--() "
Step to the previous mesh entity (prefix decrease) 

:rtype: MeshEntityIteratorBase &
";

%feature("docstring") dolfin::MeshEntityIteratorBase::operator->() "
Member access operator. 

:rtype: T *
";

%feature("docstring") dolfin::MeshEntityIteratorBase::operator==(const MeshEntityIteratorBase &it) const "
Comparison operator. 

:param const MeshEntityIteratorBase & it: 
:rtype: bool
";

%feature("docstring") dolfin::MeshEntityIteratorBase::pos() const "
Return current position. 

:rtype: std::size_t
";

%feature("docstring") dolfin::MeshEntityIteratorBase::pos_end "
:rtype: std::size_t
";

%feature("docstring") dolfin::MeshEntityIteratorBase::set_end() "
:cpp:any:`Set`  pos to end position. To create a kind of mesh.end() iterator. 

:rtype: void
";

%feature("docstring") dolfin::MeshEntityIteratorBase::~MeshEntityIteratorBase() "
Destructor.
";

%feature("docstring") dolfin::MeshGeometry "
:cpp:any:`MeshGeometry`  stores the geometry imposed on a mesh. 
Currently, the geometry is represented by the set of coordinates for the vertices of a mesh, but other representations are possible.
";

%feature("docstring") dolfin::MeshGeometry::MeshGeometry() "
Create empty set of coordinates.
";

%feature("docstring") dolfin::MeshGeometry::MeshGeometry(const MeshGeometry &geometry) "
Copy constructor. 

:param const MeshGeometry & geometry:
";

%feature("docstring") dolfin::MeshGeometry::coordinates "
:rtype: std::vector< double >
";

%feature("docstring") dolfin::MeshGeometry::degree() const "
Return polynomial degree of coordinate field. 

:rtype: std::size_t
";

%feature("docstring") dolfin::MeshGeometry::dim() const "
Return Euclidean dimension of coordinate system. 

:rtype: std::size_t
";

%feature("docstring") dolfin::MeshGeometry::entity_offsets "
:rtype: std::vector< std::vector< std::size_t > >
";

%feature("docstring") dolfin::MeshGeometry::get_entity_index(std::size_t entity_dim, std::size_t order, std::size_t index) const "
Get the index for an entity point in coordinates. 

:param std\\:\\:size_t entity_dim: 
:param std\\:\\:size_t order: 
:param std\\:\\:size_t index: 
:rtype: std::size_t
";

%feature("docstring") dolfin::MeshGeometry::hash() const "
Hash of coordinate values
Returns std::size_t A tree-hashed value of the coordinates over all :cpp:any:`MPI`  processes 

:rtype: std::size_t
";

%feature("docstring") dolfin::MeshGeometry::init(std::size_t dim, std::size_t degree) "
Initialize coordinate list to given dimension and degree. 

:param std\\:\\:size_t dim: 
:param std\\:\\:size_t degree: 
:rtype: void
";

%feature("docstring") dolfin::MeshGeometry::init_entities(const std::vector< std::size_t > &num_entities) "
Initialise entities. To be called after init. 

:param const std\\:\\:vector< std\\:\\:size_t > & num_entities: 
:rtype: void
";

%feature("docstring") dolfin::MeshGeometry::num_entity_coordinates(std::size_t entity_dim) const "
Get the number of coordinate points per entity for this degree. 

:param std\\:\\:size_t entity_dim: 
:rtype: std::size_t
";

%feature("docstring") dolfin::MeshGeometry::num_points() const "
Return the total number of points in the geometry, located on any entity 

:rtype: std::size_t
";

%feature("docstring") dolfin::MeshGeometry::num_vertices() const "
Return the number of vertex coordinates. 

:rtype: std::size_t
";

%feature("docstring") dolfin::MeshGeometry::operator=(const MeshGeometry &geometry) "
Assignment. 

:param const MeshGeometry & geometry: 
:rtype: const MeshGeometry &
";

%feature("docstring") dolfin::MeshGeometry::point(std::size_t n) const "
Return coordinate with local index n as a 3D point value. 

:param std\\:\\:size_t n: 
:rtype: Point
";

%feature("docstring") dolfin::MeshGeometry::point_coordinates(std::size_t point_index) "
Get vertex coordinates. 

:param std\\:\\:size_t point_index: 
:rtype: const double *
";

%feature("docstring") dolfin::MeshGeometry::set(std::size_t local_index, const double *x) "
:cpp:any:`Set`  value of coordinate. 

:param std\\:\\:size_t local_index: 
:param const double * x: 
:rtype: void
";

%feature("docstring") dolfin::MeshGeometry::str(bool verbose) const "
Return informal string representation (pretty-print) 

:param bool verbose: 
:rtype: std::string
";

%feature("docstring") dolfin::MeshGeometry::vertex_coordinates(std::size_t point_index) "
Get vertex coordinates. 

:param std\\:\\:size_t point_index: 
:rtype: const double *
";

%feature("docstring") dolfin::MeshGeometry::x() "
Return array of values for all coordinates. 

:rtype: std::vector< double > &
";

%feature("docstring") dolfin::MeshGeometry::x() const "
Return array of values for all coordinates. 

:rtype: const std::vector< double > &
";

%feature("docstring") dolfin::MeshGeometry::x(std::size_t n) const "
Return array of values for coordinate with local index n. 

:param std\\:\\:size_t n: 
:rtype: const double *
";

%feature("docstring") dolfin::MeshGeometry::x(std::size_t n, std::size_t i) const "
Return value of coordinate with local index n in direction i. 

:param std\\:\\:size_t n: 
:param std\\:\\:size_t i: 
:rtype: double
";

%feature("docstring") dolfin::MeshGeometry::~MeshGeometry() "
Destructor.
";

%feature("docstring") dolfin::MeshHierarchy "
Experimental implementation of a list of Meshes as a hierarchy.
";

%feature("docstring") dolfin::MeshHierarchy::MeshHierarchy() "
Constructor.
";

%feature("docstring") dolfin::MeshHierarchy::MeshHierarchy(std::shared_ptr< const Mesh > mesh) "
Constructor with initial mesh. 

:param std\\:\\:shared_ptr< const Mesh > mesh:
";

%feature("docstring") dolfin::MeshHierarchy::coarsen(const MeshFunction< bool > &markers) const "
Coarsen finest mesh by one level, based on markers (level n->n) 

:param const MeshFunction< bool > & markers: 
:rtype: std::shared_ptr< const MeshHierarchy >
";

%feature("docstring") dolfin::MeshHierarchy::coarsest() const "
Get the coarsest mesh of the :cpp:any:`MeshHierarchy` . 

:rtype: std::shared_ptr< const Mesh >
";

%feature("docstring") dolfin::MeshHierarchy::finest() const "
Get the finest mesh of the :cpp:any:`MeshHierarchy` . 

:rtype: std::shared_ptr< const Mesh >
";

%feature("docstring") dolfin::MeshHierarchy::operator[](int i) const "
Get :cpp:any:`Mesh`  i, in range [0::cpp:any:`size()` ] where 0 is the coarsest :cpp:any:`Mesh` . 

:param int i: 
:rtype: std::shared_ptr< const Mesh >
";

%feature("docstring") dolfin::MeshHierarchy::rebalance() const "
Rebalance across processes. 

:rtype: std::shared_ptr< Mesh >
";

%feature("docstring") dolfin::MeshHierarchy::refine(const MeshFunction< bool > &markers) const "
Refine finest mesh of existing hierarchy, creating a new hierarchy (level n -> n+1) 

:param const MeshFunction< bool > & markers: 
:rtype: std::shared_ptr< const MeshHierarchy >
";

%feature("docstring") dolfin::MeshHierarchy::size() const "
Number of meshes. 

:rtype: unsigned int
";

%feature("docstring") dolfin::MeshHierarchy::unrefine() const "
Unrefine by returning the previous :cpp:any:`MeshHierarchy`  (level n -> n-1) Returns NULL for a :cpp:any:`MeshHierarchy`  containing a single :cpp:any:`Mesh` 

:rtype: std::shared_ptr< const MeshHierarchy >
";

%feature("docstring") dolfin::MeshHierarchy::weight() const "
Calculate the number of cells on the finest :cpp:any:`Mesh`  which are descendents of each cell on the coarsest :cpp:any:`Mesh` , returning a vector over the cells of the coarsest :cpp:any:`Mesh` . 

:rtype: std::vector< std::size_t >
";

%feature("docstring") dolfin::MeshHierarchy::~MeshHierarchy() "
Destructor.
";

%feature("docstring") dolfin::MeshOrdering "
This class implements the ordering of mesh entities according to the :cpp:any:`UFC`  specification (see appendix of DOLFIN user manual).
";

%feature("docstring") dolfin::MeshOrdering::order(Mesh &mesh) "
Order mesh. 

:param Mesh & mesh: 
:rtype: void
";

%feature("docstring") dolfin::MeshOrdering::ordered(const Mesh &mesh) "
Check if mesh is ordered. 

:param const Mesh & mesh: 
:rtype: bool
";

%feature("docstring") dolfin::MeshPartitioning "
This class partitions and distributes a mesh based on partitioned local mesh data.The local mesh data will also be repartitioned and redistributed during the computation of the mesh partitioning.
After partitioning, each process has a local mesh and some data that couples the meshes together.
";

%feature("docstring") dolfin::MeshPartitioning::build(Mesh &mesh, const LocalMeshData &data, const std::vector< int > &cell_partition, const std::map< std::int64_t, std::vector< int >> &ghost_procs, const std::string ghost_mode) "
:param Mesh & mesh: 
:param const LocalMeshData & data: 
:param const std\\:\\:vector< int > & cell_partition: 
:param const std\\:\\:map< std\\:\\:int64_t, std\\:\\:vector< int >> & ghost_procs: 
:param const std\\:\\:string ghost_mode: 
:rtype: void
";

%feature("docstring") dolfin::MeshPartitioning::build_distributed_mesh(Mesh &mesh) "
Build a distributed mesh from a local mesh on process 0. 

:param Mesh & mesh: 
:rtype: void
";

%feature("docstring") dolfin::MeshPartitioning::build_distributed_mesh(Mesh &mesh, const LocalMeshData &data, const std::string ghost_mode) "
Build a distributed mesh from 'local mesh data' that is distributed across processes 

:param Mesh & mesh: 
:param const LocalMeshData & data: 
:param const std\\:\\:string ghost_mode: 
:rtype: void
";

%feature("docstring") dolfin::MeshPartitioning::build_distributed_mesh(Mesh &mesh, const std::vector< int > &cell_partition, const std::string ghost_mode) "
Build a distributed mesh from a local mesh on process 0, with distribution of cells supplied (destination processes for each cell) 

:param Mesh & mesh: 
:param const std\\:\\:vector< int > & cell_partition: 
:param const std\\:\\:string ghost_mode: 
:rtype: void
";

%feature("docstring") dolfin::MeshPartitioning::build_distributed_value_collection(MeshValueCollection< T > &values, const LocalMeshValueCollection< T > &local_data, const Mesh &mesh) "
Build a :cpp:any:`MeshValueCollection`  based on :cpp:any:`LocalMeshValueCollection` . 

:param MeshValueCollection< T > & values: 
:param const LocalMeshValueCollection< T > & local_data: 
:param const Mesh & mesh: 
:rtype: void
";

%feature("docstring") dolfin::MeshPartitioning::build_local_mesh(Mesh &mesh, const std::vector< std::int64_t > &global_cell_indices, const boost::multi_array< std::int64_t, 2 > &cell_global_vertices, const CellType::Type cell_type, const int tdim, const std::int64_t num_global_cells, const std::vector< std::int64_t > &vertex_indices, const boost::multi_array< double, 2 > &vertex_coordinates, const int gdim, const std::int64_t num_global_vertices, const std::map< std::int64_t, std::int32_t > &vertex_global_to_local_indices) "
:param Mesh & mesh: 
:param const std\\:\\:vector< std\\:\\:int64_t > & global_cell_indices: 
:param const boost\\:\\:multi_array< std\\:\\:int64_t, 2 > & cell_global_vertices: 
:param const CellType\\:\\:Type cell_type: 
:param const int tdim: 
:param const std\\:\\:int64_t num_global_cells: 
:param const std\\:\\:vector< std\\:\\:int64_t > & vertex_indices: 
:param const boost\\:\\:multi_array< double, 2 > & vertex_coordinates: 
:param const int gdim: 
:param const std\\:\\:int64_t num_global_vertices: 
:param const std\\:\\:map< std\\:\\:int64_t, std\\:\\:int32_t > & vertex_global_to_local_indices: 
:rtype: void
";

%feature("docstring") dolfin::MeshPartitioning::build_mesh_domains(Mesh &mesh, const LocalMeshData &local_data) "
:param Mesh & mesh: 
:param const LocalMeshData & local_data: 
:rtype: void
";

%feature("docstring") dolfin::MeshPartitioning::build_mesh_value_collection(const Mesh &mesh, const std::vector< std::pair< std::pair< std::size_t, std::size_t >, T >> &local_value_data, MeshValueCollection &mesh_values) "
:param const Mesh & mesh: 
:param const std\\:\\:vector< std\\:\\:pair< std\\:\\:pair< std\\:\\:size_t, std\\:\\:size_t >, T >> & local_value_data: 
:param MeshValueCollection & mesh_values: 
:rtype: void
";

%feature("docstring") dolfin::MeshPartitioning::build_shared_vertices(MPI_Comm mpi_comm, std::map< std::int32_t, std::set< unsigned int >> &shared_vertices, const std::map< std::int64_t, std::int32_t > &vertex_global_to_local_indices, const std::vector< std::vector< std::size_t >> &received_vertex_indices) "
:param MPI_Comm mpi_comm: 
:param std\\:\\:map< std\\:\\:int32_t, std\\:\\:set< unsigned int >> & shared_vertices: 
:param const std\\:\\:map< std\\:\\:int64_t, std\\:\\:int32_t > & vertex_global_to_local_indices: 
:param const std\\:\\:vector< std\\:\\:vector< std\\:\\:size_t >> & received_vertex_indices: 
:rtype: void
";

%feature("docstring") dolfin::MeshPartitioning::compute_vertex_mapping(MPI_Comm mpi_comm, const std::int32_t num_regular_cells, const boost::multi_array< std::int64_t, 2 > &cell_vertices, std::vector< std::int64_t > &vertex_indices, std::map< std::int64_t, std::int32_t > &vertex_global_to_local) "
:param MPI_Comm mpi_comm: 
:param const std\\:\\:int32_t num_regular_cells: 
:param const boost\\:\\:multi_array< std\\:\\:int64_t, 2 > & cell_vertices: 
:param std\\:\\:vector< std\\:\\:int64_t > & vertex_indices: 
:param std\\:\\:map< std\\:\\:int64_t, std\\:\\:int32_t > & vertex_global_to_local: 
:rtype: std::int32_t
";

%feature("docstring") dolfin::MeshPartitioning::distribute_cell_layer(MPI_Comm mpi_comm, const int num_regular_cells, const std::int64_t num_global_vertices, std::map< std::int32_t, std::set< unsigned int >> &shared_cells, boost::multi_array< std::int64_t, 2 > &cell_vertices, std::vector< std::int64_t > &global_cell_indices, std::vector< int > &cell_partition) "
:param MPI_Comm mpi_comm: 
:param const int num_regular_cells: 
:param const std\\:\\:int64_t num_global_vertices: 
:param std\\:\\:map< std\\:\\:int32_t, std\\:\\:set< unsigned int >> & shared_cells: 
:param boost\\:\\:multi_array< std\\:\\:int64_t, 2 > & cell_vertices: 
:param std\\:\\:vector< std\\:\\:int64_t > & global_cell_indices: 
:param std\\:\\:vector< int > & cell_partition: 
:rtype: void
";

%feature("docstring") dolfin::MeshPartitioning::distribute_cells(const MPI_Comm mpi_comm, const LocalMeshData &data, const std::vector< int > &cell_partition, const std::map< std::int64_t, std::vector< int >> &ghost_procs, boost::multi_array< std::int64_t, 2 > &new_cell_vertices, std::vector< std::int64_t > &new_global_cell_indices, std::vector< int > &new_cell_partition, std::map< std::int32_t, std::set< unsigned int >> &shared_cells) "
:param const MPI_Comm mpi_comm: 
:param const LocalMeshData & data: 
:param const std\\:\\:vector< int > & cell_partition: 
:param const std\\:\\:map< std\\:\\:int64_t, std\\:\\:vector< int >> & ghost_procs: 
:param boost\\:\\:multi_array< std\\:\\:int64_t, 2 > & new_cell_vertices: 
:param std\\:\\:vector< std\\:\\:int64_t > & new_global_cell_indices: 
:param std\\:\\:vector< int > & new_cell_partition: 
:param std\\:\\:map< std\\:\\:int32_t, std\\:\\:set< unsigned int >> & shared_cells: 
:rtype: std::int32_t
";

%feature("docstring") dolfin::MeshPartitioning::distribute_vertices(const MPI_Comm mpi_comm, const LocalMeshData &mesh_data, const std::vector< std::int64_t > &vertex_indices, boost::multi_array< double, 2 > &new_vertex_coordinates, std::map< std::int64_t, std::int32_t > &vertex_global_to_local_indices, std::map< std::int32_t, std::set< unsigned int >> &shared_vertices_local) "
:param const MPI_Comm mpi_comm: 
:param const LocalMeshData & mesh_data: 
:param const std\\:\\:vector< std\\:\\:int64_t > & vertex_indices: 
:param boost\\:\\:multi_array< double, 2 > & new_vertex_coordinates: 
:param std\\:\\:map< std\\:\\:int64_t, std\\:\\:int32_t > & vertex_global_to_local_indices: 
:param std\\:\\:map< std\\:\\:int32_t, std\\:\\:set< unsigned int >> & shared_vertices_local: 
:rtype: void
";

%feature("docstring") dolfin::MeshPartitioning::partition_cells(const MPI_Comm &mpi_comm, const LocalMeshData &mesh_data, const std::string partitioner, std::vector< int > &cell_partition, std::map< std::int64_t, std::vector< int >> &ghost_procs) "
:param const MPI_Comm & mpi_comm: 
:param const LocalMeshData & mesh_data: 
:param const std\\:\\:string partitioner: 
:param std\\:\\:vector< int > & cell_partition: 
:param std\\:\\:map< std\\:\\:int64_t, std\\:\\:vector< int >> & ghost_procs: 
:rtype: void
";

%feature("docstring") dolfin::MeshPartitioning::reorder_cells_gps(MPI_Comm mpi_comm, const unsigned int num_regular_cells, const CellType &cell_type, const std::map< std::int32_t, std::set< unsigned int >> &shared_cells, const boost::multi_array< std::int64_t, 2 > &cell_vertices, const std::vector< std::int64_t > &global_cell_indices, std::map< std::int32_t, std::set< unsigned int >> &reordered_shared_cells, boost::multi_array< std::int64_t, 2 > &reordered_cell_vertices, std::vector< std::int64_t > &reordered_global_cell_indices) "
:param MPI_Comm mpi_comm: 
:param const unsigned int num_regular_cells: 
:param const CellType & cell_type: 
:param const std\\:\\:map< std\\:\\:int32_t, std\\:\\:set< unsigned int >> & shared_cells: 
:param const boost\\:\\:multi_array< std\\:\\:int64_t, 2 > & cell_vertices: 
:param const std\\:\\:vector< std\\:\\:int64_t > & global_cell_indices: 
:param std\\:\\:map< std\\:\\:int32_t, std\\:\\:set< unsigned int >> & reordered_shared_cells: 
:param boost\\:\\:multi_array< std\\:\\:int64_t, 2 > & reordered_cell_vertices: 
:param std\\:\\:vector< std\\:\\:int64_t > & reordered_global_cell_indices: 
:rtype: void
";

%feature("docstring") dolfin::MeshPartitioning::reorder_vertices_gps(MPI_Comm mpi_comm, const std::int32_t num_regular_vertices, const std::int32_t num_regular_cells, const int num_cell_vertices, const boost::multi_array< std::int64_t, 2 > &cell_vertices, const std::vector< std::int64_t > &vertex_indices, const std::map< std::int64_t, std::int32_t > &vertex_global_to_local, std::vector< std::int64_t > &reordered_vertex_indices, std::map< std::int64_t, std::int32_t > &reordered_vertex_global_to_local) "
:param MPI_Comm mpi_comm: 
:param const std\\:\\:int32_t num_regular_vertices: 
:param const std\\:\\:int32_t num_regular_cells: 
:param const int num_cell_vertices: 
:param const boost\\:\\:multi_array< std\\:\\:int64_t, 2 > & cell_vertices: 
:param const std\\:\\:vector< std\\:\\:int64_t > & vertex_indices: 
:param const std\\:\\:map< std\\:\\:int64_t, std\\:\\:int32_t > & vertex_global_to_local: 
:param std\\:\\:vector< std\\:\\:int64_t > & reordered_vertex_indices: 
:param std\\:\\:map< std\\:\\:int64_t, std\\:\\:int32_t > & reordered_vertex_global_to_local: 
:rtype: void
";

%feature("docstring") dolfin::MeshQuality "
The class provides functions to quantify mesh quality.
";

%feature("docstring") dolfin::MeshQuality::dihedral_angles(const Cell &cell, std::vector< double > &dh_angle) "
Get internal dihedral angles of a tetrahedral cell. 

:param const Cell & cell: 
:param std\\:\\:vector< double > & dh_angle: 
:rtype: void
";

%feature("docstring") dolfin::MeshQuality::dihedral_angles_histogram_data(const Mesh &mesh, std::size_t num_bins=100) "
Create (dihedral angles, number of cells) data for creating a histogram of dihedral 

:param const Mesh & mesh: 
:param std\\:\\:size_t num_bins: 
:rtype: std::pair< std::vector< double >, std::vector< double > >
";

%feature("docstring") dolfin::MeshQuality::dihedral_angles_matplotlib_histogram(const Mesh &mesh, std::size_t num_intervals=100) "
Create Matplotlib string to plot dihedral angles quality histogram. 

:param const Mesh & mesh: 
:param std\\:\\:size_t num_intervals: 
:rtype: std::string
";

%feature("docstring") dolfin::MeshQuality::dihedral_angles_min_max(const Mesh &mesh) "
Get internal minimum and maximum dihedral angles of a 3D mesh. 

:param const Mesh & mesh: 
:rtype: std::pair< double, double >
";

%feature("docstring") dolfin::MeshQuality::radius_ratio_histogram_data(const Mesh &mesh, std::size_t num_bins=50) "
Create (ratio, number of cells) data for creating a histogram of cell quality 

:param const Mesh & mesh:  (const :cpp:any:`Mesh` &)
:param std\\:\\:size_t num_bins:  (std::size_t)
:rtype: std::pair< std::vector< double >, std::vector< double > >
:returns: std::pair<std::vector<double>, std::vector<double>>
";

%feature("docstring") dolfin::MeshQuality::radius_ratio_matplotlib_histogram(const Mesh &mesh, std::size_t num_intervals=50) "
Create Matplotlib string to plot cell quality histogram 

:param const Mesh & mesh:  (const :cpp:any:`Mesh` &)
:param std\\:\\:size_t num_intervals:  (std::size_t)
:rtype: std::string
:returns: std::string
";

%feature("docstring") dolfin::MeshQuality::radius_ratio_min_max(const Mesh &mesh) "
Compute the minimum and maximum radius ratio of cells (across all processes) 

:param const Mesh & mesh:  (const :cpp:any:`Mesh` &)
:rtype: std::pair< double, double >
:returns: std::pair<double, double> The [minimum, maximum] cell radii ratio (geometric_dimension *  *  inradius / circumradius, geometric_dimension is normalization factor). It has range zero to one. Zero indicates a degenerate element.
";

%feature("docstring") dolfin::MeshQuality::radius_ratios(std::shared_ptr< const Mesh > mesh) "
Compute the radius ratio for all cells. 

:param std\\:\\:shared_ptr< const Mesh > mesh:  (std::shared_ptr<const Mesh>)
:rtype: CellFunction< double >
:returns: CellFunction<double> The cell radius ratio radius ratio geometric_dimension *  *  inradius / circumradius (geometric_dimension is normalization factor). It has range zero to one. Zero indicates a degenerate element.
";

%feature("docstring") dolfin::MeshRelation "
:cpp:any:`MeshRelation`  encapsulates the relationships which may exist between two Meshes or which may exist in a :cpp:any:`Mesh`  as a result of being related to another :cpp:any:`Mesh` 

Friends: :cpp:any:`MeshHierarchy`, :cpp:any:`PlazaRefinementND`.
";

%feature("docstring") dolfin::MeshRelation::MeshRelation() "
Constructor.
";

%feature("docstring") dolfin::MeshRelation::edge_to_global_vertex "
:rtype: std::shared_ptr< const std::map< std::size_t, std::size_t > >
";

%feature("docstring") dolfin::MeshRelation::~MeshRelation() "
Destructor.
";

%feature("docstring") dolfin::MeshRenumbering "
This class implements renumbering algorithms for meshes.
";

%feature("docstring") dolfin::MeshRenumbering::compute_renumbering(const Mesh &mesh, const std::vector< std::size_t > &coloring, std::vector< double > &coordinates, std::vector< std::size_t > &connectivity) "
:param const Mesh & mesh: 
:param const std\\:\\:vector< std\\:\\:size_t > & coloring: 
:param std\\:\\:vector< double > & coordinates: 
:param std\\:\\:vector< std\\:\\:size_t > & connectivity: 
:rtype: void
";

%feature("docstring") dolfin::MeshRenumbering::renumber_by_color(const Mesh &mesh, std::vector< std::size_t > coloring) "
Renumber mesh entities by coloring. This function is currently restricted to renumbering by cell coloring. The cells (cell-vertex connectivity) and the coordinates of the mesh are renumbered to improve the locality within each color. It is assumed that the mesh has already been colored and that only cell-vertex connectivity exists as part of the mesh.

:param const Mesh & mesh:  (:cpp:any:`Mesh` ) :cpp:any:`Mesh`  to be renumbered.
:param std\\:\\:vector< std\\:\\:size_t > coloring:  (std::vector<std::size_t>) :cpp:any:`Mesh`  coloring type.
:rtype: Mesh
:returns: :cpp:any:`Mesh`
";

%feature("docstring") dolfin::MeshSmoothing "
This class implements various mesh smoothing algorithms.
";

%feature("docstring") dolfin::MeshSmoothing::move_interior_vertices(Mesh &mesh, BoundaryMesh &boundary, bool harmonic_smoothing) "
:param Mesh & mesh: 
:param BoundaryMesh & boundary: 
:param bool harmonic_smoothing: 
:rtype: void
";

%feature("docstring") dolfin::MeshSmoothing::smooth(Mesh &mesh, std::size_t num_iterations=1) "
Smooth internal vertices of mesh by local averaging. 

:param Mesh & mesh: 
:param std\\:\\:size_t num_iterations: 
:rtype: void
";

%feature("docstring") dolfin::MeshSmoothing::smooth_boundary(Mesh &mesh, std::size_t num_iterations=1, bool harmonic_smoothing=true) "
Smooth boundary vertices of mesh by local averaging and (optionally) use harmonic smoothing on interior vertices 

:param Mesh & mesh: 
:param std\\:\\:size_t num_iterations: 
:param bool harmonic_smoothing: 
:rtype: void
";

%feature("docstring") dolfin::MeshSmoothing::snap_boundary(Mesh &mesh, const SubDomain &sub_domain, bool harmonic_smoothing=true) "
Snap boundary vertices of mesh to match given sub domain and (optionally) use harmonic smoothing on interior vertices 

:param Mesh & mesh: 
:param const SubDomain & sub_domain: 
:param bool harmonic_smoothing: 
:rtype: void
";

%feature("docstring") dolfin::MeshTopology "
:cpp:any:`MeshTopology`  stores the topology of a mesh, consisting of mesh entities and connectivity (incidence relations for the mesh entities). Note that the mesh entities don't need to be stored, only the number of entities and the connectivity. Any numbering scheme for the mesh entities is stored separately in a :cpp:any:`MeshFunction`  over the entities.
A mesh entity e may be identified globally as a pair e = (dim, i), where dim is the topological dimension and i is the index of the entity within that topological dimension.
";

%feature("docstring") dolfin::MeshTopology::MeshTopology() "
Create empty mesh topology.
";

%feature("docstring") dolfin::MeshTopology::MeshTopology(const MeshTopology &topology) "
Copy constructor. 

:param const MeshTopology & topology:
";

%feature("docstring") dolfin::MeshTopology::cell_owner() "
Return mapping from local ghost cell index to owning process Since ghost cells are at the end of the range, this is just a vector over those cells 

:rtype: std::vector< unsigned int > &
";

%feature("docstring") dolfin::MeshTopology::cell_owner() const "
Return mapping from local ghost cell index to owning process (const version) Since ghost cells are at the end of the range, this is just a vector over those cells 

:rtype: const std::vector< unsigned int > &
";

%feature("docstring") dolfin::MeshTopology::clear() "
Clear all data. 

:rtype: void
";

%feature("docstring") dolfin::MeshTopology::clear(std::size_t d0, std::size_t d1) "
Clear data for given pair of topological dimensions. 

:param std\\:\\:size_t d0: 
:param std\\:\\:size_t d1: 
:rtype: void
";

%feature("docstring") dolfin::MeshTopology::coloring "
:cpp:any:`Mesh`  entity colors, if computed. First vector is
(colored entity dim - dim1 - dim2 - ... - colored entity dim)
The first vector in the pair stores mesh entity colors and the vector<vector> is a list of all mesh entity indices of the same color, e.g. vector<vector>[col][i] is the index of the ith entity of color 'col'. 

:rtype: std::map< std::vector< std::size_t >, std::pair< std::vector< std::size_t >, std::vector< std::vector< std::size_t > > > >
";

%feature("docstring") dolfin::MeshTopology::connectivity "
:rtype: std::vector< std::vector< MeshConnectivity > >
";

%feature("docstring") dolfin::MeshTopology::dim() const "
Return topological dimension. 

:rtype: std::size_t
";

%feature("docstring") dolfin::MeshTopology::ghost_offset(std::size_t dim) const "
Return number of regular (non-ghost) entities or equivalently, the offset of where ghost entities begin 

:param std\\:\\:size_t dim: 
:rtype: std::size_t
";

%feature("docstring") dolfin::MeshTopology::ghost_offset_index "
:rtype: std::vector< std::size_t >
";

%feature("docstring") dolfin::MeshTopology::global_indices(std::size_t d) const "
Get local-to-global index map for entities of topological dimension d 

:param std\\:\\:size_t d: 
:rtype: const std::vector< std::int64_t > &
";

%feature("docstring") dolfin::MeshTopology::global_num_entities "
:rtype: std::vector< std::size_t >
";

%feature("docstring") dolfin::MeshTopology::hash() const "
Return hash based on the hash of cell-vertex connectivity. 

:rtype: size_t
";

%feature("docstring") dolfin::MeshTopology::have_global_indices(std::size_t dim) const "
Check if global indices are available for entities of dimension dim 

:param std\\:\\:size_t dim: 
:rtype: bool
";

%feature("docstring") dolfin::MeshTopology::have_shared_entities(unsigned int dim) const "
Check whether there are any shared entities calculated of dimension dim 

:param unsigned int dim: 
:rtype: bool
";

%feature("docstring") dolfin::MeshTopology::init(std::size_t dim) "
Initialize topology of given maximum dimension. 

:param std\\:\\:size_t dim: 
:rtype: void
";

%feature("docstring") dolfin::MeshTopology::init(std::size_t dim, std::size_t local_size, std::size_t global_size) "
:cpp:any:`Set`  number of local entities (local_size) and global entities (global_size) for given topological dimension dim 

:param std\\:\\:size_t dim: 
:param std\\:\\:size_t local_size: 
:param std\\:\\:size_t global_size: 
:rtype: void
";

%feature("docstring") dolfin::MeshTopology::init_ghost(std::size_t dim, std::size_t index) "
Initialise the offset index of ghost entities for this dimension. 

:param std\\:\\:size_t dim: 
:param std\\:\\:size_t index: 
:rtype: void
";

%feature("docstring") dolfin::MeshTopology::init_global_indices(std::size_t dim, std::size_t size) "
Initialize storage for global entity numbering for entities of dimension dim 

:param std\\:\\:size_t dim: 
:param std\\:\\:size_t size: 
:rtype: void
";

%feature("docstring") dolfin::MeshTopology::num_entities "
:rtype: std::vector< unsigned int >
";

%feature("docstring") dolfin::MeshTopology::operator()(std::size_t d0, std::size_t d1) "
Return connectivity for given pair of topological dimensions. 

:param std\\:\\:size_t d0: 
:param std\\:\\:size_t d1: 
:rtype: dolfin::MeshConnectivity &
";

%feature("docstring") dolfin::MeshTopology::operator()(std::size_t d0, std::size_t d1) const "
Return connectivity for given pair of topological dimensions. 

:param std\\:\\:size_t d0: 
:param std\\:\\:size_t d1: 
:rtype: const dolfin::MeshConnectivity &
";

%feature("docstring") dolfin::MeshTopology::operator=(const MeshTopology &topology) "
Assignment. 

:param const MeshTopology & topology: 
:rtype: MeshTopology &
";

%feature("docstring") dolfin::MeshTopology::set_global_index(std::size_t dim, std::size_t local_index, std::int64_t global_index) "
:cpp:any:`Set`  global index for entity of dimension dim and with local index 

:param std\\:\\:size_t dim: 
:param std\\:\\:size_t local_index: 
:param std\\:\\:int64_t global_index: 
:rtype: void
";

%feature("docstring") dolfin::MeshTopology::shared_entities(unsigned int dim) "
Return map from shared entities (local index) to processes that share the entity 

:param unsigned int dim: 
:rtype: std::map< std::int32_t, std::set< unsigned int > > &
";

%feature("docstring") dolfin::MeshTopology::shared_entities(unsigned int dim) const "
Return map from shared entities (local index) to process that share the entity (const version) 

:param unsigned int dim: 
:rtype: const std::map< std::int32_t, std::set< unsigned int > > &
";

%feature("docstring") dolfin::MeshTopology::size(std::size_t dim) const "
Return number of entities for given dimension. 

:param std\\:\\:size_t dim: 
:rtype: std::size_t
";

%feature("docstring") dolfin::MeshTopology::size_global(std::size_t dim) const "
Return global number of entities for given dimension. 

:param std\\:\\:size_t dim: 
:rtype: std::size_t
";

%feature("docstring") dolfin::MeshTopology::str(bool verbose) const "
Return informal string representation (pretty-print) 

:param bool verbose: 
:rtype: std::string
";

%feature("docstring") dolfin::MeshTopology::~MeshTopology() "
Destructor.
";

%feature("docstring") dolfin::MeshTransformation "
This class implements various transformations of the coordinates of a mesh.
";

%feature("docstring") dolfin::MeshTransformation::rescale(Mesh &mesh, const double scale, const Point &center) "
Rescale mesh by a given scaling factor with respect to a center point.

:param Mesh & mesh:  (:cpp:any:`Mesh` ) The mesh
:param const double scale:  (double) The scaling factor.
:param const Point & center:  (:cpp:any:`Point` ) The center of the scaling.
:rtype: void
";

%feature("docstring") dolfin::MeshTransformation::rotate(Mesh &mesh, double angle, std::size_t axis) "
Rotate mesh around a coordinate axis through center of mass of all mesh vertices

:param Mesh & mesh:  (:cpp:any:`Mesh` ) The mesh.
:param double angle:  (double) The number of degrees (0-360) of rotation.
:param std\\:\\:size_t axis:  (std::size_t) The coordinate axis around which to rotate the mesh.
:rtype: void
";

%feature("docstring") dolfin::MeshTransformation::rotate(Mesh &mesh, double angle, std::size_t axis, const Point &p) "
Rotate mesh around a coordinate axis through a given point

:param Mesh & mesh:  (:cpp:any:`Mesh` ) The mesh.
:param double angle:  (double) The number of degrees (0-360) of rotation.
:param std\\:\\:size_t axis:  (std::size_t) The coordinate axis around which to rotate the mesh.
:param const Point & p:  (:cpp:any:`Point` ) The point around which to rotate the mesh.
:rtype: void
";

%feature("docstring") dolfin::MeshTransformation::translate(Mesh &mesh, const Point &point) "
Translate mesh according to a given vector.

:param Mesh & mesh:  (:cpp:any:`Mesh` ) The mesh
:param const Point & point:  (:cpp:any:`Point` ) The vector defining the translation.
:rtype: void
";

%feature("docstring") dolfin::MultiMesh "
This class represents a collection of meshes with arbitrary overlaps. A multimesh may be created from a set of standard meshes spaces by repeatedly calling :cpp:any:`add()` , followed by a call to :cpp:any:`build()` . Note that a multimesh is not useful until :cpp:any:`build()`  has been called. 

Friends: :cpp:any:`plot`.
";

%feature("docstring") dolfin::MultiMesh::MultiMesh() "
Create empty multimesh.
";

%feature("docstring") dolfin::MultiMesh::MultiMesh(std::shared_ptr< const Mesh > mesh_0, std::shared_ptr< const Mesh > mesh_1, std::shared_ptr< const Mesh > mesh_2, std::size_t quadrature_order) "
Create multimesh from three meshes. 

:param std\\:\\:shared_ptr< const Mesh > mesh_0: 
:param std\\:\\:shared_ptr< const Mesh > mesh_1: 
:param std\\:\\:shared_ptr< const Mesh > mesh_2: 
:param std\\:\\:size_t quadrature_order:
";

%feature("docstring") dolfin::MultiMesh::MultiMesh(std::shared_ptr< const Mesh > mesh_0, std::shared_ptr< const Mesh > mesh_1, std::size_t quadrature_order) "
Create multimesh from two meshes. 

:param std\\:\\:shared_ptr< const Mesh > mesh_0: 
:param std\\:\\:shared_ptr< const Mesh > mesh_1: 
:param std\\:\\:size_t quadrature_order:
";

%feature("docstring") dolfin::MultiMesh::MultiMesh(std::shared_ptr< const Mesh > mesh_0, std::size_t quadrature_order) "
Create multimesh from one mesh. 

:param std\\:\\:shared_ptr< const Mesh > mesh_0: 
:param std\\:\\:size_t quadrature_order:
";

%feature("docstring") dolfin::MultiMesh::MultiMesh(std::vector< std::shared_ptr< const Mesh >> meshes, std::size_t quadrature_order) "
Create multimesh from given list of meshes. 

:param std\\:\\:vector< std\\:\\:shared_ptr< const Mesh >> meshes: 
:param std\\:\\:size_t quadrature_order:
";

%feature("docstring") dolfin::MultiMesh::add(std::shared_ptr< const Mesh > mesh) "
Add mesh
Arguments mesh (:cpp:any:`Mesh` ) The mesh 

:param std\\:\\:shared_ptr< const Mesh > mesh: 
:rtype: void
";

%feature("docstring") dolfin::MultiMesh::bounding_box_tree(std::size_t part) const "
Return the bounding box tree for the mesh of the given part
Arguments part (std::size_t) The part number
Returns std::shared_ptr<const BoundingBoxTree> The bounding box tree 

:param std\\:\\:size_t part: 
:rtype: std::shared_ptr< const BoundingBoxTree >
";

%feature("docstring") dolfin::MultiMesh::bounding_box_tree_boundary(std::size_t part) const "
Return the bounding box tree for the boundary mesh of the given part
Arguments part (std::size_t) The part number
Returns std::shared_ptr<const BoundingBoxTree> The bounding box tree 

:param std\\:\\:size_t part: 
:rtype: std::shared_ptr< const BoundingBoxTree >
";

%feature("docstring") dolfin::MultiMesh::build(std::size_t quadrature_order=2) "
Build multimesh. 

:param std\\:\\:size_t quadrature_order: 
:rtype: void
";

%feature("docstring") dolfin::MultiMesh::clear() "
Clear multimesh. 

:rtype: void
";

%feature("docstring") dolfin::MultiMesh::collision_map_cut_cells(std::size_t part) const "
Return the collision map for cut cells of the given part
Arguments part (std::size_t) The part number
Returns std::map<unsigned int, std::vector<std::pair<std::size_t, unsigned int> > > A map from cell indices of cut cells to a list of cutting cells. Each cutting cell is represented as a pair (part_number, cutting_cell_index). 

:param std\\:\\:size_t part: 
:rtype: const std::map< unsigned int, std::vector< std::pair< std::size_t, unsigned int > > > &
";

%feature("docstring") dolfin::MultiMesh::covered_cells(std::size_t part) const "
Return the list of covered cells for given part. The covered cells are defined as all cells that collide with the domain of any part with higher part number, but not with the boundary of that part; in other words cells that are completely covered by any other part (and which therefore are inactive).
Arguments part (std::size_t) The part number
Returns std::vector<unsigned int> List of covered cell indices for given part 

:param std\\:\\:size_t part: 
:rtype: const std::vector< unsigned int > &
";

%feature("docstring") dolfin::MultiMesh::cut_cells(std::size_t part) const "
Return the list of cut cells for given part. The cut cells are defined as all cells that collide with the boundary of any part with higher part number.
FIXME: Figure out whether this makes sense; a cell may collide with the boundary of part j but may still be covered completely by the domain of part j + 1. Possible solution is to for each part i check overlapping parts starting from the top and working back down to i + 1.
Arguments part (std::size_t) The part number
Returns std::vector<unsigned int> List of cut cell indices for given part 

:param std\\:\\:size_t part: 
:rtype: const std::vector< unsigned int > &
";

%feature("docstring") dolfin::MultiMesh::facet_normals(std::size_t part) const "
Return facet normals for the interface on the given part
Arguments part (std::size_t) The part number
Returns std::map<unsigned int, std::vector<std::vector<double> > > A map from cell indices of cut cells to facet normals on an interface part cutting through the cell. A separate list of facet normals, one for each quadrature point, is given for each cutting cell and stored in the same order as in the collision map. The facet normals for each set of quadrature points is stored as a contiguous flattened array, the length of which should be equal to the number of quadrature points multiplied by the geometric dimension. Puh! 

:param std\\:\\:size_t part: 
:rtype: const std::map< unsigned int, std::vector< std::vector< double > > > &
";

%feature("docstring") dolfin::MultiMesh::num_parts() const "
Return the number of meshes (parts) of the multimesh
Returns std::size_t The number of meshes (parts) of the multimesh. 

:rtype: std::size_t
";

%feature("docstring") dolfin::MultiMesh::part(std::size_t i) const "
Return mesh (part) number i
Arguments i (std::size_t) The part number
Returns:cpp:any:`Mesh` :cpp:any:`Mesh`  (part) number i 

:param std\\:\\:size_t i: 
:rtype: std::shared_ptr< const Mesh >
";

%feature("docstring") dolfin::MultiMesh::quadrature_rule_cut_cell(std::size_t part, unsigned int cell_index) const "
Return quadrature rule for a given cut cell on the given part
Arguments part (std::size_t) The part number cell (unsigned int) The cell index
Returns std::pair<std::vector<double>, std::vector<double> > A quadrature rule represented as a pair of a flattened array of quadrature points and a corresponding array of quadrature weights. An error is raised if the given cell is not in the map.
Developer note: this function is mainly useful from Python and could be replaced by a suitable typemap that would make the previous more general function accessible from Python. 

:param std\\:\\:size_t part: 
:param unsigned int cell_index: 
:rtype: quadrature_rule
";

%feature("docstring") dolfin::MultiMesh::quadrature_rule_cut_cells(std::size_t part) const "
Return quadrature rules for cut cells on the given part
Arguments part (std::size_t) The part number
Returns std::map<unsigned int, std::pair<std::vector<double>, std::vector<double> > > A map from cell indices of cut cells to quadrature rules. Each quadrature rule is represented as a pair of a flattened array of quadrature points and a corresponding array of quadrature weights. 

:param std\\:\\:size_t part: 
:rtype: const std::map< unsigned int, quadrature_rule > &
";

%feature("docstring") dolfin::MultiMesh::quadrature_rule_interface(std::size_t part) const "
Return quadrature rules for the interface on the given part
Arguments part (std::size_t) The part number
Returns std::map<unsigned int, std::pair<std::vector<double>, std::vector<double> > > A map from cell indices of cut cells to quadrature rules on an interface part cutting through the cell. A separate quadrature rule is given for each cutting cell and stored in the same order as in the collision map. Each quadrature rule is represented as a pair of an array of quadrature points and a corresponding flattened array of quadrature weights. 

:param std\\:\\:size_t part: 
:rtype: const std::map< unsigned int, std::vector< quadrature_rule > > &
";

%feature("docstring") dolfin::MultiMesh::quadrature_rule_overlap(std::size_t part) const "
Return quadrature rules for the overlap on the given part.
Arguments part (std::size_t) The part number
Returns std::map<unsigned int, std::pair<std::vector<double>, std::vector<double> > > A map from cell indices of cut cells to quadrature rules. A separate quadrature rule is given for each cutting cell and stored in the same order as in the collision map. Each quadrature rule is represented as a pair of an array of quadrature points and a corresponding flattened array of quadrature weights. 

:param std\\:\\:size_t part: 
:rtype: const std::map< unsigned int, std::vector< quadrature_rule > > &
";

%feature("docstring") dolfin::MultiMesh::uncut_cells(std::size_t part) const "
Return the list of uncut cells for given part. The uncut cells are defined as all cells that don't collide with any cells in any other part with higher part number.
Arguments part (std::size_t) The part number
Returns std::vector<unsigned int> List of uncut cell indices for given part 

:param std\\:\\:size_t part: 
:rtype: const std::vector< unsigned int > &
";

%feature("docstring") dolfin::MultiMesh::~MultiMesh() "
Destructor.
";

%feature("docstring") dolfin::PeriodicBoundaryComputation "
This class computes map from slave entity to master entity.
";

%feature("docstring") dolfin::PeriodicBoundaryComputation::compute_periodic_pairs(const Mesh &mesh, const SubDomain &sub_domain, const std::size_t dim) "
For entities of dimension dim, compute map from a slave entity on this process (local index) to its master entity (owning process, local index on owner). If a master entity is shared by processes, only one of the owning processes is returned. 

:param const Mesh & mesh: 
:param const SubDomain & sub_domain: 
:param const std\\:\\:size_t dim: 
:rtype: std::map< unsigned int, std::pair< unsigned int, unsigned int > >
";

%feature("docstring") dolfin::PeriodicBoundaryComputation::in_bounding_box(const std::vector< double > &point, const std::vector< double > &bounding_box, const double tol) "
:param const std\\:\\:vector< double > & point: 
:param const std\\:\\:vector< double > & bounding_box: 
:param const double tol: 
:rtype: bool
";

%feature("docstring") dolfin::PeriodicBoundaryComputation::masters_slaves(std::shared_ptr< const Mesh > mesh, const SubDomain &sub_domain, const std::size_t dim) "
This function returns a :cpp:any:`MeshFunction`  which marks mesh entities of dimension dim according to: 

::
   
   2: slave entities
   1: master entities
   0: all other entities
   
It is useful for visualising and debugging the Expression::map function that is used to apply periodic boundary conditions. 

:param std\\:\\:shared_ptr< const Mesh > mesh: 
:param const SubDomain & sub_domain: 
:param const std\\:\\:size_t dim: 
:rtype: MeshFunction< std::size_t >
";

%feature("docstring") dolfin::PointCell "
This class implements functionality for triangular meshes.
";

%feature("docstring") dolfin::PointCell::PointCell() "
Specify cell type and facet type.
";

%feature("docstring") dolfin::PointCell::cell_normal(const Cell &cell) const "
Compute normal to given cell (viewed as embedded in 1D) 

:param const Cell & cell: 
:rtype: Point
";

%feature("docstring") dolfin::PointCell::circumradius(const MeshEntity &point) const "
Compute circumradius of :cpp:any:`PointCell` . 

:param const MeshEntity & point: 
:rtype: double
";

%feature("docstring") dolfin::PointCell::collides(const Cell &cell, const MeshEntity &entity) const "
Check whether given entity collides with cell. 

:param const Cell & cell: 
:param const MeshEntity & entity: 
:rtype: bool
";

%feature("docstring") dolfin::PointCell::collides(const Cell &cell, const Point &point) const "
Check whether given point is contained in cell. 

:param const Cell & cell: 
:param const Point & point: 
:rtype: bool
";

%feature("docstring") dolfin::PointCell::create_entities(boost::multi_array< unsigned int, 2 > &e, std::size_t dim, const unsigned int *v) const "
Create entities e of given topological dimension from vertices v. 

:param boost\\:\\:multi_array< unsigned int, 2 > & e: 
:param std\\:\\:size_t dim: 
:param const unsigned int * v: 
:rtype: void
";

%feature("docstring") dolfin::PointCell::description(bool plural) const "
Return description of cell type. 

:param bool plural: 
:rtype: std::string
";

%feature("docstring") dolfin::PointCell::dim() const "
Return topological dimension of cell. 

:rtype: std::size_t
";

%feature("docstring") dolfin::PointCell::facet_area(const Cell &cell, std::size_t facet) const "
Compute the area/length of given facet with respect to the cell 

:param const Cell & cell: 
:param std\\:\\:size_t facet: 
:rtype: double
";

%feature("docstring") dolfin::PointCell::find_edge(std::size_t i, const Cell &cell) const "
:param std\\:\\:size_t i: 
:param const Cell & cell: 
:rtype: std::size_t
";

%feature("docstring") dolfin::PointCell::normal(const Cell &cell, std::size_t facet) const "
Compute of given facet with respect to the cell. 

:param const Cell & cell: 
:param std\\:\\:size_t facet: 
:rtype: Point
";

%feature("docstring") dolfin::PointCell::normal(const Cell &cell, std::size_t facet, std::size_t i) const "
Compute component i of normal of given facet with respect to the cell 

:param const Cell & cell: 
:param std\\:\\:size_t facet: 
:param std\\:\\:size_t i: 
:rtype: double
";

%feature("docstring") dolfin::PointCell::num_entities(std::size_t dim) const "
Return number of entities of given topological dimension. 

:param std\\:\\:size_t dim: 
:rtype: std::size_t
";

%feature("docstring") dolfin::PointCell::num_vertices(std::size_t dim) const "
Return number of vertices for entity of given topological dimension 

:param std\\:\\:size_t dim: 
:rtype: std::size_t
";

%feature("docstring") dolfin::PointCell::order(Cell &cell) const "
Order entities locally. 

:param Cell & cell: 
:rtype: void
";

%feature("docstring") dolfin::PointCell::order(Cell &cell, const std::vector< std::int64_t > &local_to_global_vertex_indices) const "
Order entities locally (connectivity 1-0, 2-0, 2-1) 

:param Cell & cell: 
:param const std\\:\\:vector< std\\:\\:int64_t > & local_to_global_vertex_indices: 
:rtype: void
";

%feature("docstring") dolfin::PointCell::orientation(const Cell &cell) const "
Return orientation of the cell. 

:param const Cell & cell: 
:rtype: std::size_t
";

%feature("docstring") dolfin::PointCell::squared_distance(const Cell &cell, const Point &point) const "
Compute squared distance to given point. 

:param const Cell & cell: 
:param const Point & point: 
:rtype: double
";

%feature("docstring") dolfin::PointCell::triangulate_intersection(const Cell &c0, const Cell &c1) const "
Compute triangulation of intersection of two cells. 

:param const Cell & c0: 
:param const Cell & c1: 
:rtype: std::vector< double >
";

%feature("docstring") dolfin::PointCell::volume(const MeshEntity &triangle) const "
Compute (generalized) volume (area) of triangle. 

:param const MeshEntity & triangle: 
:rtype: double
";

%feature("docstring") dolfin::PointCell::vtk_mapping() const "
Mapping of DOLFIN/UFC vertex ordering to VTK/XDMF ordering. 

:rtype: std::vector< std::int8_t >
";

%feature("docstring") dolfin::QuadrilateralCell "
This class implements functionality for triangular meshes.
";

%feature("docstring") dolfin::QuadrilateralCell::QuadrilateralCell() "
Specify cell type and facet type.
";

%feature("docstring") dolfin::QuadrilateralCell::cell_normal(const Cell &cell) const "
Compute normal to given cell (viewed as embedded in 3D) 

:param const Cell & cell: 
:rtype: Point
";

%feature("docstring") dolfin::QuadrilateralCell::circumradius(const MeshEntity &triangle) const "
Compute circumradius of triangle. 

:param const MeshEntity & triangle: 
:rtype: double
";

%feature("docstring") dolfin::QuadrilateralCell::collides(const Cell &cell, const MeshEntity &entity) const "
Check whether given entity collides with cell. 

:param const Cell & cell: 
:param const MeshEntity & entity: 
:rtype: bool
";

%feature("docstring") dolfin::QuadrilateralCell::collides(const Cell &cell, const Point &point) const "
Check whether given point collides with cell. 

:param const Cell & cell: 
:param const Point & point: 
:rtype: bool
";

%feature("docstring") dolfin::QuadrilateralCell::create_entities(boost::multi_array< unsigned int, 2 > &e, std::size_t dim, const unsigned int *v) const "
Create entities e of given topological dimension from vertices v. 

:param boost\\:\\:multi_array< unsigned int, 2 > & e: 
:param std\\:\\:size_t dim: 
:param const unsigned int * v: 
:rtype: void
";

%feature("docstring") dolfin::QuadrilateralCell::description(bool plural) const "
Return description of cell type. 

:param bool plural: 
:rtype: std::string
";

%feature("docstring") dolfin::QuadrilateralCell::dim() const "
Return topological dimension of cell. 

:rtype: std::size_t
";

%feature("docstring") dolfin::QuadrilateralCell::facet_area(const Cell &cell, std::size_t facet) const "
Compute the area/length of given facet with respect to the cell. 

:param const Cell & cell: 
:param std\\:\\:size_t facet: 
:rtype: double
";

%feature("docstring") dolfin::QuadrilateralCell::normal(const Cell &cell, std::size_t facet) const "
Compute of given facet with respect to the cell. 

:param const Cell & cell: 
:param std\\:\\:size_t facet: 
:rtype: Point
";

%feature("docstring") dolfin::QuadrilateralCell::normal(const Cell &cell, std::size_t facet, std::size_t i) const "
Compute component i of normal of given facet with respect to the cell. 

:param const Cell & cell: 
:param std\\:\\:size_t facet: 
:param std\\:\\:size_t i: 
:rtype: double
";

%feature("docstring") dolfin::QuadrilateralCell::num_entities(std::size_t dim) const "
Return number of entities of given topological dimension. 

:param std\\:\\:size_t dim: 
:rtype: std::size_t
";

%feature("docstring") dolfin::QuadrilateralCell::num_vertices(std::size_t dim) const "
Return number of vertices for entity of given topological dimension. 

:param std\\:\\:size_t dim: 
:rtype: std::size_t
";

%feature("docstring") dolfin::QuadrilateralCell::order(Cell &cell, const std::vector< std::int64_t > &local_to_global_vertex_indices) const "
Order entities locally. 

:param Cell & cell: 
:param const std\\:\\:vector< std\\:\\:int64_t > & local_to_global_vertex_indices: 
:rtype: void
";

%feature("docstring") dolfin::QuadrilateralCell::orientation(const Cell &cell) const "
Return orientation of the cell. 

:param const Cell & cell: 
:rtype: std::size_t
";

%feature("docstring") dolfin::QuadrilateralCell::squared_distance(const Cell &cell, const Point &point) const "
Compute squared distance to given point (3D enabled) 

:param const Cell & cell: 
:param const Point & point: 
:rtype: double
";

%feature("docstring") dolfin::QuadrilateralCell::triangulate_intersection(const Cell &c0, const Cell &c1) const "
Compute triangulation of intersection of two cells. 

:param const Cell & c0: 
:param const Cell & c1: 
:rtype: std::vector< double >
";

%feature("docstring") dolfin::QuadrilateralCell::volume(const MeshEntity &triangle) const "
Compute (generalized) volume (area) of triangle. 

:param const MeshEntity & triangle: 
:rtype: double
";

%feature("docstring") dolfin::QuadrilateralCell::vtk_mapping() const "
Mapping of DOLFIN/UFC vertex ordering to VTK/XDMF ordering. 

:rtype: std::vector< std::int8_t >
";

%feature("docstring") dolfin::SubDomain "
This class defines the interface for definition of subdomains. Alternatively, subdomains may be defined by a :cpp:any:`Mesh`  and a MeshFunction<std::size_t> over the mesh. 

Friends: :cpp:any:`DirichletBC`, :cpp:any:`PeriodicBC`.
";

%feature("docstring") dolfin::SubDomain::SubDomain(const double map_tol=1.0e-10) "
Constructor

:param const double map_tol:  (double) The tolerance used when identifying mapped points using the function :cpp:any:`SubDomain::map` .
";

%feature("docstring") dolfin::SubDomain::apply_markers(S &sub_domains, T sub_domain, const Mesh &mesh, bool check_midpoint) const "
Apply marker of type T (most likely an std::size_t) to object of class S (most likely :cpp:any:`MeshFunction`  or :cpp:any:`MeshValueCollection` ) 

:param S & sub_domains: 
:param T sub_domain: 
:param const Mesh & mesh: 
:param bool check_midpoint: 
:rtype: void
";

%feature("docstring") dolfin::SubDomain::apply_markers(std::map< std::size_t, std::size_t > &sub_domains, std::size_t dim, T sub_domain, const Mesh &mesh, bool check_midpoint) const "
:param std\\:\\:map< std\\:\\:size_t, std\\:\\:size_t > & sub_domains: 
:param std\\:\\:size_t dim: 
:param T sub_domain: 
:param const Mesh & mesh: 
:param bool check_midpoint: 
:rtype: void
";

%feature("docstring") dolfin::SubDomain::geometric_dimension() const "
Return geometric dimension

:rtype: std::size_t
:returns: std::size_t The geometric dimension.
";

%feature("docstring") dolfin::SubDomain::inside(const Array< double > &x, bool on_boundary) const "
Return true for points inside the subdomain

:param const Array< double > & x:  (Array<double>) The coordinates of the point.
:param bool on_boundary:  (bool) True for points on the boundary.
:rtype: bool
:returns: bool True for points inside the subdomain.
";

%feature("docstring") dolfin::SubDomain::map(const Array< double > &x, Array< double > &y) const "
Map coordinate x in domain H to coordinate y in domain G (used for periodic boundary conditions)

:param const Array< double > & x:  (Array<double>) The coordinates in domain H.
:param Array< double > & y:  (Array<double>) The coordinates in domain G.
:rtype: void
";

%feature("docstring") dolfin::SubDomain::map_tolerance "
Return tolerance uses to find matching point via map function

:rtype: const double
:returns: double The tolerance.
";

%feature("docstring") dolfin::SubDomain::mark(Mesh &mesh, std::size_t dim, std::size_t sub_domain, bool check_midpoint=true) const "
:cpp:any:`Set`  subdomain markers (std::size_t) for given topological dimension and subdomain number

:param Mesh & mesh:  (:cpp:any:`Mesh` ) The mesh to be marked.
:param std\\:\\:size_t dim:  (std::size_t) The topological dimension of entities to be marked.
:param std\\:\\:size_t sub_domain:  (std::size_t) The subdomain number.
:param bool check_midpoint:  (bool) Flag for whether midpoint of cell should be checked (default).
:rtype: void
";

%feature("docstring") dolfin::SubDomain::mark(MeshFunction< bool > &sub_domains, bool sub_domain, bool check_midpoint=true) const "
:cpp:any:`Set`  subdomain markers (bool) for given subdomain

:param MeshFunction< bool > & sub_domains:  (MeshFunction<bool>) The subdomain markers.
:param bool sub_domain:  (bool) The subdomain number.
:param bool check_midpoint:  (bool) Flag for whether midpoint of cell should be checked (default).
:rtype: void
";

%feature("docstring") dolfin::SubDomain::mark(MeshFunction< double > &sub_domains, double sub_domain, bool check_midpoint=true) const "
:cpp:any:`Set`  subdomain markers (double) for given subdomain number

:param MeshFunction< double > & sub_domains:  (MeshFunction<double>) The subdomain markers.
:param double sub_domain:  (double) The subdomain number.
:param bool check_midpoint:  (bool) Flag for whether midpoint of cell should be checked (default).
:rtype: void
";

%feature("docstring") dolfin::SubDomain::mark(MeshFunction< int > &sub_domains, int sub_domain, bool check_midpoint=true) const "
:cpp:any:`Set`  subdomain markers (int) for given subdomain number

:param MeshFunction< int > & sub_domains:  (MeshFunction<int>) The subdomain markers.
:param int sub_domain:  (int) The subdomain number.
:param bool check_midpoint:  (bool) Flag for whether midpoint of cell should be checked (default).
:rtype: void
";

%feature("docstring") dolfin::SubDomain::mark(MeshFunction< std::size_t > &sub_domains, std::size_t sub_domain, bool check_midpoint=true) const "
:cpp:any:`Set`  subdomain markers (std::size_t) for given subdomain number

:param MeshFunction< std\\:\\:size_t > & sub_domains:  (MeshFunction<std::size_t>) The subdomain markers.
:param std\\:\\:size_t sub_domain:  (std::size_t) The subdomain number.
:param bool check_midpoint:  (bool) Flag for whether midpoint of cell should be checked (default).
:rtype: void
";

%feature("docstring") dolfin::SubDomain::mark(MeshValueCollection< bool > &sub_domains, bool sub_domain, const Mesh &mesh, bool check_midpoint=true) const "
:cpp:any:`Set`  subdomain markers (bool) for given subdomain

:param MeshValueCollection< bool > & sub_domains:  (MeshValueCollection<bool>) The subdomain markers
:param bool sub_domain:  (bool) The subdomain number
:param const Mesh & mesh:  (:cpp:any:`Mesh` ) The mesh.
:param bool check_midpoint:  (bool) Flag for whether midpoint of cell should be checked (default).
:rtype: void
";

%feature("docstring") dolfin::SubDomain::mark(MeshValueCollection< double > &sub_domains, double sub_domain, const Mesh &mesh, bool check_midpoint=true) const "
:cpp:any:`Set`  subdomain markers (double) for given subdomain number

:param MeshValueCollection< double > & sub_domains:  (MeshValueCollection<double>) The subdomain markers.
:param double sub_domain:  (double) The subdomain number
:param const Mesh & mesh:  (:cpp:any:`Mesh` ) The mesh.
:param bool check_midpoint:  (bool) Flag for whether midpoint of cell should be checked (default).
:rtype: void
";

%feature("docstring") dolfin::SubDomain::mark(MeshValueCollection< int > &sub_domains, int sub_domain, const Mesh &mesh, bool check_midpoint=true) const "
:cpp:any:`Set`  subdomain markers (int) for given subdomain number

:param MeshValueCollection< int > & sub_domains:  (MeshValueCollection<int>) The subdomain markers
:param int sub_domain:  (int) The subdomain number
:param const Mesh & mesh:  (:cpp:any:`Mesh` ) The mesh.
:param bool check_midpoint:  (bool) Flag for whether midpoint of cell should be checked (default).
:rtype: void
";

%feature("docstring") dolfin::SubDomain::mark(MeshValueCollection< std::size_t > &sub_domains, std::size_t sub_domain, const Mesh &mesh, bool check_midpoint=true) const "
:cpp:any:`Set`  subdomain markers (std::size_t) for given subdomain number

:param MeshValueCollection< std\\:\\:size_t > & sub_domains:  (MeshValueCollection<std::size_t>) The subdomain markers.
:param std\\:\\:size_t sub_domain:  (std::size_t) The subdomain number.
:param const Mesh & mesh:  (:cpp:any:`Mesh` ) The mesh.
:param bool check_midpoint:  (bool) Flag for whether midpoint of cell should be checked (default).
:rtype: void
";

%feature("docstring") dolfin::SubDomain::mark_cells(Mesh &mesh, std::size_t sub_domain, bool check_midpoint=true) const "
:cpp:any:`Set`  subdomain markers (std::size_t) on cells for given subdomain number

:param Mesh & mesh:  (:cpp:any:`Mesh` ) The mesh to be marked.
:param std\\:\\:size_t sub_domain:  (std::size_t) The subdomain number.
:param bool check_midpoint:  (bool) Flag for whether midpoint of cell should be checked (default).
:rtype: void
";

%feature("docstring") dolfin::SubDomain::mark_facets(Mesh &mesh, std::size_t sub_domain, bool check_midpoint=true) const "
:cpp:any:`Set`  subdomain markers (std::size_t) on facets for given subdomain number

:param Mesh & mesh:  (:cpp:any:`Mesh` ) The mesh to be marked.
:param std\\:\\:size_t sub_domain:  (std::size_t) The subdomain number.
:param bool check_midpoint:  (bool) Flag for whether midpoint of cell should be checked (default).
:rtype: void
";

%feature("docstring") dolfin::SubDomain::snap(Array< double > &x) const "
Snap coordinate to boundary of subdomain

:param Array< double > & x:  (Array<double>) The coordinates.
:rtype: void
";

%feature("docstring") dolfin::SubDomain::~SubDomain() "
Destructor.
";

%feature("docstring") dolfin::SubMesh "
A :cpp:any:`SubMesh`  is a mesh defined as a subset of a given mesh. It provides a convenient way to create matching meshes for multiphysics applications by creating meshes for subdomains as subsets of a single global mesh. A mapping from the vertices of the sub mesh to the vertices of the parent mesh is stored as the mesh data named \"parent_vertex_indices\".
";

%feature("docstring") dolfin::SubMesh::SubMesh(const Mesh &mesh, const MeshFunction< std::size_t > &sub_domains, std::size_t sub_domain) "
Create subset of given mesh marked by mesh function. 

:param const Mesh & mesh: 
:param const MeshFunction< std\\:\\:size_t > & sub_domains: 
:param std\\:\\:size_t sub_domain:
";

%feature("docstring") dolfin::SubMesh::SubMesh(const Mesh &mesh, const SubDomain &sub_domain) "
Create subset of given mesh marked by sub domain. 

:param const Mesh & mesh: 
:param const SubDomain & sub_domain:
";

%feature("docstring") dolfin::SubMesh::SubMesh(const Mesh &mesh, std::size_t sub_domain) "
Create subset of given mesh from stored :cpp:any:`MeshValueCollection` . 

:param const Mesh & mesh: 
:param std\\:\\:size_t sub_domain:
";

%feature("docstring") dolfin::SubMesh::init(const Mesh &mesh, const std::vector< std::size_t > &sub_domains, std::size_t sub_domain) "
Create sub mesh. 

:param const Mesh & mesh: 
:param const std\\:\\:vector< std\\:\\:size_t > & sub_domains: 
:param std\\:\\:size_t sub_domain: 
:rtype: void
";

%feature("docstring") dolfin::SubMesh::~SubMesh() "
Destructor.
";

%feature("docstring") dolfin::SubsetIterator "
A :cpp:any:`SubsetIterator`  is similar to a :cpp:any:`MeshEntityIterator`  but iterates over a specified subset of the range of entities as specified by a :cpp:any:`MeshFunction`  that labels the entities.
";

%feature("docstring") dolfin::SubsetIterator::SubsetIterator(const MeshFunction< std::size_t > &labels, std::size_t label) "
Create iterator for given mesh function. The iterator visits all entities that match the given label. 

:param const MeshFunction< std\\:\\:size_t > & labels: 
:param std\\:\\:size_t label:
";

%feature("docstring") dolfin::SubsetIterator::SubsetIterator(const SubsetIterator &subset_iter) "
Copy Constructor. 

:param const SubsetIterator & subset_iter:
";

%feature("docstring") dolfin::SubsetIterator::end() const "
Check if iterator has reached the end. 

:rtype: bool
";

%feature("docstring") dolfin::SubsetIterator::end_iterator() "
Beyond end iterator. 

:rtype: SubsetIterator
";

%feature("docstring") dolfin::SubsetIterator::it "
:rtype: std::vector< std::size_t >::iterator
";

%feature("docstring") dolfin::SubsetIterator::operator!=(const SubsetIterator &sub_iter) const "
Comparison operator. 

:param const SubsetIterator & sub_iter: 
:rtype: bool
";

%feature("docstring") dolfin::SubsetIterator::operator*() "
Dereference operator. 

:rtype: MeshEntity &
";

%feature("docstring") dolfin::SubsetIterator::operator++() "
Step to next mesh entity (prefix increment) 

:rtype: SubsetIterator &
";

%feature("docstring") dolfin::SubsetIterator::operator->() "
Member access operator. 

:rtype: MeshEntity *
";

%feature("docstring") dolfin::SubsetIterator::operator==(const SubsetIterator &sub_iter) const "
Comparison operator. 

:param const SubsetIterator & sub_iter: 
:rtype: bool
";

%feature("docstring") dolfin::SubsetIterator::set_end() "
:cpp:any:`Set`  pos to end position. To create a kind of mesh.end() iterator. 

:rtype: void
";

%feature("docstring") dolfin::SubsetIterator::subset "
:rtype: std::vector< std::size_t > &
";

%feature("docstring") dolfin::SubsetIterator::~SubsetIterator() "
Destructor.
";

%feature("docstring") dolfin::TetrahedronCell "
This class implements functionality for tetrahedral meshes.
";

%feature("docstring") dolfin::TetrahedronCell::TetrahedronCell() "
Specify cell type and facet type.
";

%feature("docstring") dolfin::TetrahedronCell::cell_normal(const Cell &cell) const "
Compute normal to given cell (viewed as embedded in 4D ...) 

:param const Cell & cell: 
:rtype: Point
";

%feature("docstring") dolfin::TetrahedronCell::circumradius(const MeshEntity &tetrahedron) const "
Compute circumradius of tetrahedron. 

:param const MeshEntity & tetrahedron: 
:rtype: double
";

%feature("docstring") dolfin::TetrahedronCell::collides(const Cell &cell, const MeshEntity &entity) const "
Check whether given entity collides with cell. 

:param const Cell & cell: 
:param const MeshEntity & entity: 
:rtype: bool
";

%feature("docstring") dolfin::TetrahedronCell::collides(const Cell &cell, const Point &point) const "
Check whether given point collides with cell. 

:param const Cell & cell: 
:param const Point & point: 
:rtype: bool
";

%feature("docstring") dolfin::TetrahedronCell::create_entities(boost::multi_array< unsigned int, 2 > &e, std::size_t dim, const unsigned int *v) const "
Create entities e of given topological dimension from vertices v. 

:param boost\\:\\:multi_array< unsigned int, 2 > & e: 
:param std\\:\\:size_t dim: 
:param const unsigned int * v: 
:rtype: void
";

%feature("docstring") dolfin::TetrahedronCell::description(bool plural) const "
Return description of cell type. 

:param bool plural: 
:rtype: std::string
";

%feature("docstring") dolfin::TetrahedronCell::dim() const "
Return topological dimension of cell. 

:rtype: std::size_t
";

%feature("docstring") dolfin::TetrahedronCell::facet_area(const Cell &cell, std::size_t facet) const "
Compute the area/length of given facet with respect to the cell. 

:param const Cell & cell: 
:param std\\:\\:size_t facet: 
:rtype: double
";

%feature("docstring") dolfin::TetrahedronCell::find_edge(std::size_t i, const Cell &cell) const "
:param std\\:\\:size_t i: 
:param const Cell & cell: 
:rtype: std::size_t
";

%feature("docstring") dolfin::TetrahedronCell::normal(const Cell &cell, std::size_t facet) const "
Compute normal of given facet with respect to the cell. 

:param const Cell & cell: 
:param std\\:\\:size_t facet: 
:rtype: Point
";

%feature("docstring") dolfin::TetrahedronCell::normal(const Cell &cell, std::size_t facet, std::size_t i) const "
Compute component i of normal of given facet with respect to the cell 

:param const Cell & cell: 
:param std\\:\\:size_t facet: 
:param std\\:\\:size_t i: 
:rtype: double
";

%feature("docstring") dolfin::TetrahedronCell::num_entities(std::size_t dim) const "
Return number of entities of given topological dimension. 

:param std\\:\\:size_t dim: 
:rtype: std::size_t
";

%feature("docstring") dolfin::TetrahedronCell::num_vertices(std::size_t dim) const "
Return number of vertices for entity of given topological dimension. 

:param std\\:\\:size_t dim: 
:rtype: std::size_t
";

%feature("docstring") dolfin::TetrahedronCell::order(Cell &cell, const std::vector< std::int64_t > &local_to_global_vertex_indices) const "
Order entities locally. 

:param Cell & cell: 
:param const std\\:\\:vector< std\\:\\:int64_t > & local_to_global_vertex_indices: 
:rtype: void
";

%feature("docstring") dolfin::TetrahedronCell::orientation(const Cell &cell) const "
Return orientation of the cell. 

:param const Cell & cell: 
:rtype: std::size_t
";

%feature("docstring") dolfin::TetrahedronCell::point_outside_of_plane(const Point &point, const Point &A, const Point &B, const Point &C, const Point &D) const "
:param const Point & point: 
:param const Point & A: 
:param const Point & B: 
:param const Point & C: 
:param const Point & D: 
:rtype: bool
";

%feature("docstring") dolfin::TetrahedronCell::squared_distance(const Cell &cell, const Point &point) const "
Compute squared distance to given point. 

:param const Cell & cell: 
:param const Point & point: 
:rtype: double
";

%feature("docstring") dolfin::TetrahedronCell::triangulate_intersection(const Cell &c0, const Cell &c1) const "
Compute triangulation of intersection of two cells. 

:param const Cell & c0: 
:param const Cell & c1: 
:rtype: std::vector< double >
";

%feature("docstring") dolfin::TetrahedronCell::volume(const MeshEntity &tetrahedron) const "
Compute volume of tetrahedron. 

:param const MeshEntity & tetrahedron: 
:rtype: double
";

%feature("docstring") dolfin::TetrahedronCell::vtk_mapping() const "
Mapping of DOLFIN/UFC vertex ordering to VTK/XDMF ordering. 

:rtype: std::vector< std::int8_t >
";

%feature("docstring") dolfin::TopologyComputation "
This class implements a set of basic algorithms that automate the computation of mesh entities and connectivity.
";

%feature("docstring") dolfin::TopologyComputation::compute_connectivity(Mesh &mesh, std::size_t d0, std::size_t d1) "
Compute connectivity for given pair of topological dimensions. 

:param Mesh & mesh: 
:param std\\:\\:size_t d0: 
:param std\\:\\:size_t d1: 
:rtype: void
";

%feature("docstring") dolfin::TopologyComputation::compute_entities(Mesh &mesh, std::size_t dim) "
Compute mesh entities of given topological dimension, and connectivity cell-to-enity (tdim, dim) 

:param Mesh & mesh: 
:param std\\:\\:size_t dim: 
:rtype: std::size_t
";

%feature("docstring") dolfin::TopologyComputation::compute_entities_by_key_matching(Mesh &mesh, int dim) "
:param Mesh & mesh: 
:param int dim: 
:rtype: std::int32_t
";

%feature("docstring") dolfin::TopologyComputation::compute_entities_old(Mesh &mesh, std::size_t dim) "
Compute mesh entities of given topological dimension. Note: this function will be replaced by the new 'compute_entities' function, which is considerably faster, especially for poorly ordered mesh. 

:param Mesh & mesh: 
:param std\\:\\:size_t dim: 
:rtype: std::size_t
";

%feature("docstring") dolfin::TopologyComputation::compute_from_intersection(Mesh &mesh, std::size_t d0, std::size_t d1, std::size_t d) "
:param Mesh & mesh: 
:param std\\:\\:size_t d0: 
:param std\\:\\:size_t d1: 
:param std\\:\\:size_t d: 
:rtype: void
";

%feature("docstring") dolfin::TopologyComputation::compute_from_map(Mesh &mesh, std::size_t d0, std::size_t d1) "
:param Mesh & mesh: 
:param std\\:\\:size_t d0: 
:param std\\:\\:size_t d1: 
:rtype: void
";

%feature("docstring") dolfin::TopologyComputation::compute_from_transpose(Mesh &mesh, std::size_t d0, std::size_t d1) "
:param Mesh & mesh: 
:param std\\:\\:size_t d0: 
:param std\\:\\:size_t d1: 
:rtype: void
";

%feature("docstring") dolfin::TriangleCell "
This class implements functionality for triangular meshes.
";

%feature("docstring") dolfin::TriangleCell::TriangleCell() "
Specify cell type and facet type.
";

%feature("docstring") dolfin::TriangleCell::cell_normal(const Cell &cell) const "
Compute normal to given cell (viewed as embedded in 3D) 

:param const Cell & cell: 
:rtype: Point
";

%feature("docstring") dolfin::TriangleCell::circumradius(const MeshEntity &triangle) const "
Compute diameter of triangle. 

:param const MeshEntity & triangle: 
:rtype: double
";

%feature("docstring") dolfin::TriangleCell::collides(const Cell &cell, const MeshEntity &entity) const "
Check whether given entity collides with cell. 

:param const Cell & cell: 
:param const MeshEntity & entity: 
:rtype: bool
";

%feature("docstring") dolfin::TriangleCell::collides(const Cell &cell, const Point &point) const "
Check whether given point collides with cell. 

:param const Cell & cell: 
:param const Point & point: 
:rtype: bool
";

%feature("docstring") dolfin::TriangleCell::create_entities(boost::multi_array< unsigned int, 2 > &e, std::size_t dim, const unsigned int *v) const "
Create entities e of given topological dimension from vertices v. 

:param boost\\:\\:multi_array< unsigned int, 2 > & e: 
:param std\\:\\:size_t dim: 
:param const unsigned int * v: 
:rtype: void
";

%feature("docstring") dolfin::TriangleCell::description(bool plural) const "
Return description of cell type. 

:param bool plural: 
:rtype: std::string
";

%feature("docstring") dolfin::TriangleCell::dim() const "
Return topological dimension of cell. 

:rtype: std::size_t
";

%feature("docstring") dolfin::TriangleCell::facet_area(const Cell &cell, std::size_t facet) const "
Compute the area/length of given facet with respect to the cell. 

:param const Cell & cell: 
:param std\\:\\:size_t facet: 
:rtype: double
";

%feature("docstring") dolfin::TriangleCell::find_edge(std::size_t i, const Cell &cell) const "
:param std\\:\\:size_t i: 
:param const Cell & cell: 
:rtype: std::size_t
";

%feature("docstring") dolfin::TriangleCell::normal(const Cell &cell, std::size_t facet) const "
Compute of given facet with respect to the cell. 

:param const Cell & cell: 
:param std\\:\\:size_t facet: 
:rtype: Point
";

%feature("docstring") dolfin::TriangleCell::normal(const Cell &cell, std::size_t facet, std::size_t i) const "
Compute component i of normal of given facet with respect to the cell. 

:param const Cell & cell: 
:param std\\:\\:size_t facet: 
:param std\\:\\:size_t i: 
:rtype: double
";

%feature("docstring") dolfin::TriangleCell::num_entities(std::size_t dim) const "
Return number of entities of given topological dimension. 

:param std\\:\\:size_t dim: 
:rtype: std::size_t
";

%feature("docstring") dolfin::TriangleCell::num_vertices(std::size_t dim) const "
Return number of vertices for entity of given topological dimension. 

:param std\\:\\:size_t dim: 
:rtype: std::size_t
";

%feature("docstring") dolfin::TriangleCell::order(Cell &cell, const std::vector< std::int64_t > &local_to_global_vertex_indices) const "
Order entities locally. 

:param Cell & cell: 
:param const std\\:\\:vector< std\\:\\:int64_t > & local_to_global_vertex_indices: 
:rtype: void
";

%feature("docstring") dolfin::TriangleCell::orientation(const Cell &cell) const "
Return orientation of the cell. 

:param const Cell & cell: 
:rtype: std::size_t
";

%feature("docstring") dolfin::TriangleCell::squared_distance(const Cell &cell, const Point &point) const "
Compute squared distance to given point (3D enabled) 

:param const Cell & cell: 
:param const Point & point: 
:rtype: double
";

%feature("docstring") dolfin::TriangleCell::squared_distance(const Point &point, const Point &a, const Point &b, const Point &c) "
Compute squared distance to given point. This version takes the three vertex coordinates as 3D points. This makes it possible to reuse this function for computing the (squared) distance to a tetrahedron. 

:param const Point & point: 
:param const Point & a: 
:param const Point & b: 
:param const Point & c: 
:rtype: double
";

%feature("docstring") dolfin::TriangleCell::triangulate_intersection(const Cell &c0, const Cell &c1) const "
Compute triangulation of intersection of two cells. 

:param const Cell & c0: 
:param const Cell & c1: 
:rtype: std::vector< double >
";

%feature("docstring") dolfin::TriangleCell::volume(const MeshEntity &triangle) const "
Compute (generalized) volume (area) of triangle. 

:param const MeshEntity & triangle: 
:rtype: double
";

%feature("docstring") dolfin::TriangleCell::vtk_mapping() const "
Mapping of DOLFIN/UFC vertex ordering to VTK/XDMF ordering. 

:rtype: std::vector< std::int8_t >
";

%feature("docstring") dolfin::Vertex "
A :cpp:any:`Vertex`  is a :cpp:any:`MeshEntity`  of topological dimension 0.
";

%feature("docstring") dolfin::Vertex::Vertex(MeshEntity &entity) "
Create vertex from mesh entity. 

:param MeshEntity & entity:
";

%feature("docstring") dolfin::Vertex::Vertex(const Mesh &mesh, std::size_t index) "
Create vertex on given mesh. 

:param const Mesh & mesh: 
:param std\\:\\:size_t index:
";

%feature("docstring") dolfin::Vertex::point() const "
Return vertex coordinates as a 3D point value. 

:rtype: Point
";

%feature("docstring") dolfin::Vertex::x() const "
Return array of vertex coordinates (const version) 

:rtype: const double *
";

%feature("docstring") dolfin::Vertex::x(std::size_t i) const "
Return value of vertex coordinate i. 

:param std\\:\\:size_t i: 
:rtype: double
";

%feature("docstring") dolfin::Vertex::~Vertex() "
Destructor.
";

%feature("docstring") dolfin::VertexFunction "
A :cpp:any:`VertexFunction`  is a :cpp:any:`MeshFunction`  of topological dimension 0.
";

%feature("docstring") dolfin::VertexFunction::VertexFunction(std::shared_ptr< const Mesh > mesh) "
Constructor on :cpp:any:`Mesh` . 

:param std\\:\\:shared_ptr< const Mesh > mesh:
";

%feature("docstring") dolfin::VertexFunction::VertexFunction(std::shared_ptr< const Mesh > mesh, const T &value) "
Constructor on :cpp:any:`Mesh`  and value. 

:param std\\:\\:shared_ptr< const Mesh > mesh: 
:param const T & value:
";

%feature("docstring") dolfin::CellIterator "
A CellIterator is a :cpp:any:`MeshEntityIterator`  of topological codimension 0. 

:rtype: MeshEntityIteratorBase< Cell >
";

%feature("docstring") dolfin::EdgeIterator "
An EdgeIterator is a :cpp:any:`MeshEntityIterator`  of topological dimension 1. 

:rtype: MeshEntityIteratorBase< Edge >
";

%feature("docstring") dolfin::FaceIterator "
A FaceIterator is a :cpp:any:`MeshEntityIterator`  of topological dimension 2. 

:rtype: MeshEntityIteratorBase< Face >
";

%feature("docstring") dolfin::FacetIterator "
A FacetIterator is a :cpp:any:`MeshEntityIterator`  of topological codimension 1. 

:rtype: MeshEntityIteratorBase< Facet >
";

%feature("docstring") dolfin::VertexIterator "
A VertexIterator is a :cpp:any:`MeshEntityIterator`  of topological dimension 0. 

:rtype: MeshEntityIteratorBase< Vertex >
";

%feature("docstring") dolfin::quadrature_rule "
Typedefs. 

:rtype: std::pair< std::vector< double >, std::vector< double > >
";

