// Auto generated SWIG file for Python interface of DOLFIN
//
// Copyright (C) 2012-2016 Kristian B. Oelgaard, Tormod Landet
//
// This file is part of DOLFIN.
//
// DOLFIN is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// DOLFIN is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
//

// SWIG docstrings generated by doxygen and generate_api_rst.py / parse_doxygen.py

%feature("docstring") dolfin::NewtonSolver "
This class defines a Newton solver for nonlinear systems of equations of the form :math:`F(x) = 0` .
";

%feature("docstring") dolfin::NewtonSolver::NewtonSolver(MPI_Comm comm, std::shared_ptr< GenericLinearSolver > solver, GenericLinearAlgebraFactory &factory) "
Create nonlinear solver using provided linear solver
Arguments comm (MPI_Ccmm) The :cpp:any:`MPI`  communicator. solver (:cpp:any:`GenericLinearSolver` ) The linear solver. factory (:cpp:any:`GenericLinearAlgebraFactory` ) The factory. 

:param MPI_Comm comm: 
:param std\\:\\:shared_ptr< GenericLinearSolver > solver: 
:param GenericLinearAlgebraFactory & factory:
";

%feature("docstring") dolfin::NewtonSolver::NewtonSolver(MPI_Comm comm=MPI_COMM_WORLD) "
Create nonlinear solver. 

:param MPI_Comm comm:
";

%feature("docstring") dolfin::NewtonSolver::converged(const GenericVector &r, const NonlinearProblem &nonlinear_problem, std::size_t iteration) "
Convergence test. It may be overloaded using virtual inheritance and this base criterion may be called from derived, both in C++ and Python.
Arguments r (:cpp:any:`GenericVector` ) Residual for criterion evaluation. nonlinear_problem (:cpp:any:`NonlinearProblem` ) The nonlinear problem. iteration (std::size_t) Newton iteration number.
Returns bool Whether convergence occurred. 

:param const GenericVector & r: 
:param const NonlinearProblem & nonlinear_problem: 
:param std\\:\\:size_t iteration: 
:rtype: bool
";

%feature("docstring") dolfin::NewtonSolver::get_relaxation_parameter() "
Get relaxation parameter
Returns double Relaxation parameter value. 

:rtype: double
";

%feature("docstring") dolfin::NewtonSolver::iteration() const "
Return current Newton iteration number
Returns std::size_t The iteration number. 

:rtype: std::size_t
";

%feature("docstring") dolfin::NewtonSolver::krylov_iterations() const "
Return number of Krylov iterations elapsed since solve started
Returns std::size_t The number of iterations. 

:rtype: std::size_t
";

%feature("docstring") dolfin::NewtonSolver::linear_solver() const "
Return the linear solver
Returns:cpp:any:`GenericLinearSolver`  The linear solver. 

:rtype: GenericLinearSolver &
";

%feature("docstring") dolfin::NewtonSolver::relative_residual() const "
Return current relative residual
Returns double Current relative residual. 

:rtype: double
";

%feature("docstring") dolfin::NewtonSolver::residual() const "
Return current residual
Returns double Current residual. 

:rtype: double
";

%feature("docstring") dolfin::NewtonSolver::residual0() const "
Return initial residual
Returns double Initial residual. 

:rtype: double
";

%feature("docstring") dolfin::NewtonSolver::set_relaxation_parameter(double relaxation_parameter) "
:cpp:any:`Set`  relaxation parameter. Default value 1.0 means full Newton method, value smaller than 1.0 relaxes the method by shrinking effective Newton step size by the given factor.
Arguments relaxation_parameter(double) Relaxation parameter value. 

:param double relaxation_parameter: 
:rtype: void
";

%feature("docstring") dolfin::NewtonSolver::solve(NonlinearProblem &nonlinear_function, GenericVector &x) "
Solve abstract nonlinear problem :math:`F(x) = 0`  for given :math:`F`  and Jacobian :math:`\\dfrac{\\partial F}{\\partial x}` .
Arguments nonlinear_function (:cpp:any:`NonlinearProblem` ) The nonlinear problem. x (:cpp:any:`GenericVector` ) The vector.
Returns std::pair<std::size_t, bool> Pair of number of Newton iterations, and whether iteration converged) 

:param NonlinearProblem & nonlinear_function: 
:param GenericVector & x: 
:rtype: std::pair< std::size_t, bool >
";

%feature("docstring") dolfin::NewtonSolver::solver_setup(std::shared_ptr< const GenericMatrix > A, std::shared_ptr< const GenericMatrix > P, const NonlinearProblem &nonlinear_problem, std::size_t iteration) "
Setup solver to be used with system matrix A and preconditioner matrix P. It may be overloaded to get finer control over linear solver setup, various linesearch tricks, etc. Note that minimal implementation should call set_operators method of the linear solver.
Arguments A (std::shared_ptr<const GenericMatrix>) System Jacobian matrix. J (std::shared_ptr<const GenericMatrix>) System preconditioner matrix. nonlinear_problem (:cpp:any:`NonlinearProblem` ) The nonlinear problem. iteration (std::size_t) Newton iteration number. 

:param std\\:\\:shared_ptr< const GenericMatrix > A: 
:param std\\:\\:shared_ptr< const GenericMatrix > P: 
:param const NonlinearProblem & nonlinear_problem: 
:param std\\:\\:size_t iteration: 
:rtype: void
";

%feature("docstring") dolfin::NewtonSolver::update_solution(GenericVector &x, const GenericVector &dx, double relaxation_parameter, const NonlinearProblem &nonlinear_problem, std::size_t iteration) "
Update solution vector by computed Newton step. Default update is given by formula::
x -= relaxation_parameter*dx
Arguments x (:cpp:any:`GenericVector` >) The solution vector to be updated. dx (:cpp:any:`GenericVector` >) The update vector computed by Newton step. relaxation_parameter (double) Newton relaxation parameter. nonlinear_problem (:cpp:any:`NonlinearProblem` ) The nonlinear problem. iteration (std::size_t) Newton iteration number. 

:param GenericVector & x: 
:param const GenericVector & dx: 
:param double relaxation_parameter: 
:param const NonlinearProblem & nonlinear_problem: 
:param std\\:\\:size_t iteration: 
:rtype: void
";

%feature("docstring") dolfin::NewtonSolver::~NewtonSolver() "
Destructor.
";

%feature("docstring") dolfin::NonlinearProblem "
This is a base class for nonlinear problems which can return the nonlinear function F(u) and its Jacobian J = dF(u)/du.
";

%feature("docstring") dolfin::NonlinearProblem::F(GenericVector &b, const GenericVector &x) "
Compute F at current point x. 

:param GenericVector & b: 
:param const GenericVector & x: 
:rtype: void
";

%feature("docstring") dolfin::NonlinearProblem::J(GenericMatrix &A, const GenericVector &x) "
Compute J = F' at current point x. 

:param GenericMatrix & A: 
:param const GenericVector & x: 
:rtype: void
";

%feature("docstring") dolfin::NonlinearProblem::J_pc(GenericMatrix &P, const GenericVector &x) "
Compute J_pc used to precondition J. Not implementing this or leaving P empty results in system matrix A being used to construct preconditioner.
Note that if nonempty P is not assembled on first call then a solver implementation may throw away P and not call this routine ever again. 

:param GenericMatrix & P: 
:param const GenericVector & x: 
:rtype: void
";

%feature("docstring") dolfin::NonlinearProblem::NonlinearProblem() "
Constructor.
";

%feature("docstring") dolfin::NonlinearProblem::form(GenericMatrix &A, GenericMatrix &P, GenericVector &b, const GenericVector &x) "
:cpp:any:`Function`  called by Newton solver before requesting F, J or J_pc. This can be used to compute F, J and J_pc together. Preconditioner matrix P can be left empty so that A is used instead 

:param GenericMatrix & A: 
:param GenericMatrix & P: 
:param GenericVector & b: 
:param const GenericVector & x: 
:rtype: void
";

%feature("docstring") dolfin::NonlinearProblem::form(GenericMatrix &A, GenericVector &b, const GenericVector &x) "
:cpp:any:`Function`  called by Newton solver before requesting F or J. This can be used to compute F and J together. NOTE: This function is deprecated. Use variant with preconditioner 

:param GenericMatrix & A: 
:param GenericVector & b: 
:param const GenericVector & x: 
:rtype: void
";

%feature("docstring") dolfin::NonlinearProblem::~NonlinearProblem() "
Destructor.
";

%feature("docstring") dolfin::OptimisationProblem "
This is a base class for nonlinear optimisation problems which return the real-valued objective function :math:`f(x)` , its gradient :math:`F(x) = f'(x)``and its Hessian :math:`` J(x) = f''(x)`
";

%feature("docstring") dolfin::OptimisationProblem::F(GenericVector &b, const GenericVector &x) "
Compute the gradient :math:`F(x) = f'(x)`. 

:param GenericVector & b: 
:param const GenericVector & x: 
:rtype: void
";

%feature("docstring") dolfin::OptimisationProblem::J(GenericMatrix &A, const GenericVector &x) "
Compute the Hessian :math:`J(x) = f''(x)`. 

:param GenericMatrix & A: 
:param const GenericVector & x: 
:rtype: void
";

%feature("docstring") dolfin::OptimisationProblem::J_pc(GenericMatrix &P, const GenericVector &x) "
Compute J_pc used to precondition J. Not implementing this or leaving P empty results in system matrix A being used to construct preconditioner.
Note that if nonempty P is not assembled on first call then a solver implementation may throw away P and not call this routine ever again. 

:param GenericMatrix & P: 
:param const GenericVector & x: 
:rtype: void
";

%feature("docstring") dolfin::OptimisationProblem::OptimisationProblem() "
Constructor.
";

%feature("docstring") dolfin::OptimisationProblem::f(const GenericVector &x) "
Compute the objective function :math:`f(x)` 

:param const GenericVector & x: 
:rtype: double
";

%feature("docstring") dolfin::OptimisationProblem::form(GenericMatrix &A, GenericMatrix &P, GenericVector &b, const GenericVector &x) "
:cpp:any:`Function`  called by the solver before requesting F, J or J_pc. This can be used to compute F, J and J_pc together. Preconditioner matrix P can be left empty so that A is used instead 

:param GenericMatrix & A: 
:param GenericMatrix & P: 
:param GenericVector & b: 
:param const GenericVector & x: 
:rtype: void
";

%feature("docstring") dolfin::OptimisationProblem::form(GenericMatrix &A, GenericVector &b, const GenericVector &x) "
Compute the Hessian :math:`J(x)=f''(x)``and the gradient :math:`` F(x)=f'(x)` together. Called before requesting F or J. NOTE: This function is deprecated. Use variant with preconditioner 

:param GenericMatrix & A: 
:param GenericVector & b: 
:param const GenericVector & x: 
:rtype: void
";

%feature("docstring") dolfin::OptimisationProblem::~OptimisationProblem() "
Destructor.
";

%feature("docstring") dolfin::PETScSNESSolver "
This class implements methods for solving nonlinear systems via PETSc's SNES interface. It includes line search and trust region techniques for globalising the convergence of the nonlinear iteration.
";

%feature("docstring") dolfin::PETScSNESSolver::FormFunction(SNES snes, Vec x, Vec f, void *ctx) "
:param SNES snes: 
:param Vec x: 
:param Vec f: 
:param void * ctx: 
:rtype: PetscErrorCode
";

%feature("docstring") dolfin::PETScSNESSolver::FormJacobian(SNES snes, Vec x, Mat A, Mat B, void *ctx) "
:param SNES snes: 
:param Vec x: 
:param Mat A: 
:param Mat B: 
:param void * ctx: 
:rtype: PetscErrorCode
";

%feature("docstring") dolfin::PETScSNESSolver::FormObjective(SNES snes, Vec x, PetscReal *out, void *ctx) "
:param SNES snes: 
:param Vec x: 
:param PetscReal * out: 
:param void * ctx: 
:rtype: PetscErrorCode
";

%feature("docstring") dolfin::PETScSNESSolver::PETScSNESSolver(MPI_Comm comm, std::string nls_type="default") "
Create SNES solver. 

:param MPI_Comm comm: 
:param std\\:\\:string nls_type:
";

%feature("docstring") dolfin::PETScSNESSolver::PETScSNESSolver(std::string nls_type="default") "
Create SNES solver on MPI_COMM_WORLD. 

:param std\\:\\:string nls_type:
";

%feature("docstring") dolfin::PETScSNESSolver::get_options_prefix() const "
Returns the prefix used by PETSc when searching the PETSc options database 

:rtype: std::string
";

%feature("docstring") dolfin::PETScSNESSolver::init(NonlinearProblem &nonlinear_problem, GenericVector &x) "
:cpp:any:`Set`  up the SNES object, but don't do anything yet, in case the user wants to access the SNES object directly 

:param NonlinearProblem & nonlinear_problem: 
:param GenericVector & x: 
:rtype: void
";

%feature("docstring") dolfin::PETScSNESSolver::is_vi() const "
:rtype: bool
";

%feature("docstring") dolfin::PETScSNESSolver::lb "
:rtype: std::shared_ptr< const PETScVector >
";

%feature("docstring") dolfin::PETScSNESSolver::methods() "
Return a list of available solver methods. 

:rtype: std::vector< std::pair< std::string, std::string > >
";

%feature("docstring") dolfin::PETScSNESSolver::mpi_comm() const "
Return the :cpp:any:`MPI`  communicator. 

:rtype: MPI_Comm
";

%feature("docstring") dolfin::PETScSNESSolver::parameters "
:cpp:any:`Parameters` . 

:rtype: Parameters
";

%feature("docstring") dolfin::PETScSNESSolver::set_bounds(GenericVector &x) "
:param GenericVector & x: 
:rtype: void
";

%feature("docstring") dolfin::PETScSNESSolver::set_from_options() const "
:cpp:any:`Set`  options from the PETSc options database. 

:rtype: void
";

%feature("docstring") dolfin::PETScSNESSolver::set_linear_solver_parameters() "
:rtype: void
";

%feature("docstring") dolfin::PETScSNESSolver::set_options_prefix(std::string options_prefix) "
Sets the prefix used by PETSc when searching the PETSc options database 

:param std\\:\\:string options_prefix: 
:rtype: void
";

%feature("docstring") dolfin::PETScSNESSolver::snes() const "
Return PETSc SNES pointer. 

:rtype: SNES
";

%feature("docstring") dolfin::PETScSNESSolver::solve(NonlinearProblem &nonlinear_function, GenericVector &x) "
Solve abstract nonlinear problem :math:`F(x) = 0`  for given :math:`F`  and Jacobian :math:`\\dfrac{\\partial F}{\\partial x}` .
Arguments nonlinear_function (:cpp:any:`NonlinearProblem` ) The nonlinear problem. x (:cpp:any:`GenericVector` ) The vector.
Returns std::pair<std::size_t, bool> Pair of number of Newton iterations, and whether iteration converged) 

:param NonlinearProblem & nonlinear_function: 
:param GenericVector & x: 
:rtype: std::pair< std::size_t, bool >
";

%feature("docstring") dolfin::PETScSNESSolver::solve(NonlinearProblem &nonlinear_problem, GenericVector &x, const GenericVector &lb, const GenericVector &ub) "
Solve a nonlinear variational inequality with bound constraints
Arguments nonlinear_function (:cpp:any:`NonlinearProblem` ) The nonlinear problem. x (:cpp:any:`GenericVector` ) The vector. lb (:cpp:any:`GenericVector` ) The lower bound. ub (:cpp:any:`GenericVector` ) The upper bound.
Returns std::pair<std::size_t, bool> Pair of number of Newton iterations, and whether iteration converged) 

:param NonlinearProblem & nonlinear_problem: 
:param GenericVector & x: 
:param const GenericVector & lb: 
:param const GenericVector & ub: 
:rtype: std::pair< std::size_t, bool >
";

%feature("docstring") dolfin::PETScSNESSolver::ub "
:rtype: std::shared_ptr< const PETScVector >
";

%feature("docstring") dolfin::PETScSNESSolver::~PETScSNESSolver() "
Destructor.
";

%feature("docstring") dolfin::PETScTAOSolver "
This class implements methods for solving nonlinear optimisation problems via PETSc TAO solver. It supports unconstrained as well as bound-constrained minimisation problem
";

%feature("docstring") dolfin::PETScTAOSolver::FormFunctionGradient(Tao tao, Vec x, PetscReal *fobj, Vec G, void *ctx) "
:param Tao tao: 
:param Vec x: 
:param PetscReal * fobj: 
:param Vec G: 
:param void * ctx: 
:rtype: PetscErrorCode
";

%feature("docstring") dolfin::PETScTAOSolver::FormHessian(Tao tao, Vec x, Mat H, Mat Hpre, void *ctx) "
:param Tao tao: 
:param Vec x: 
:param Mat H: 
:param Mat Hpre: 
:param void * ctx: 
:rtype: PetscErrorCode
";

%feature("docstring") dolfin::PETScTAOSolver::PETScTAOSolver(MPI_Comm comm, std::string tao_type="default", std::string ksp_type="default", std::string pc_type="default") "
Create TAO solver. 

:param MPI_Comm comm: 
:param std\\:\\:string tao_type: 
:param std\\:\\:string ksp_type: 
:param std\\:\\:string pc_type:
";

%feature("docstring") dolfin::PETScTAOSolver::PETScTAOSolver(std::string tao_type="default", std::string ksp_type="default", std::string pc_type="default") "
Create TAO solver on MPI_COMM_WORLD. 

:param std\\:\\:string tao_type: 
:param std\\:\\:string ksp_type: 
:param std\\:\\:string pc_type:
";

%feature("docstring") dolfin::PETScTAOSolver::TaoConvergenceTest(Tao tao, void *ctx) "
:param Tao tao: 
:param void * ctx: 
:rtype: PetscErrorCode
";

%feature("docstring") dolfin::PETScTAOSolver::init(OptimisationProblem &optimisation_problem, PETScVector &x) "
Initialise the TAO solver for an unconstrained minimisation problem, in case the user wants to access the TAO object directly 

:param OptimisationProblem & optimisation_problem: 
:param PETScVector & x: 
:rtype: void
";

%feature("docstring") dolfin::PETScTAOSolver::init(OptimisationProblem &optimisation_problem, PETScVector &x, const PETScVector &lb, const PETScVector &ub) "
Initialise the TAO solver for a bound-constrained minimisation problem, in case the user wants to access the TAO object directly 

:param OptimisationProblem & optimisation_problem: 
:param PETScVector & x: 
:param const PETScVector & lb: 
:param const PETScVector & ub: 
:rtype: void
";

%feature("docstring") dolfin::PETScTAOSolver::methods() "
Return a list of available solver methods. 

:rtype: std::vector< std::pair< std::string, std::string > >
";

%feature("docstring") dolfin::PETScTAOSolver::mpi_comm() const "
Return the :cpp:any:`MPI`  communicator. 

:rtype: MPI_Comm
";

%feature("docstring") dolfin::PETScTAOSolver::parameters "
:cpp:any:`Parameters`  for the PETSc TAO solver. 

:rtype: Parameters
";

%feature("docstring") dolfin::PETScTAOSolver::set_ksp_options() "
:rtype: void
";

%feature("docstring") dolfin::PETScTAOSolver::set_tao(std::string tao_type) "
:param std\\:\\:string tao_type: 
:rtype: void
";

%feature("docstring") dolfin::PETScTAOSolver::set_tao_options() "
:rtype: void
";

%feature("docstring") dolfin::PETScTAOSolver::solve(OptimisationProblem &optimisation_problem, GenericVector &x) "
Solve a nonlinear unconstrained minimisation problem
Arguments optimisation_problem (:cpp:any:`OptimisationProblem` ) The nonlinear optimisation problem. x (:cpp:any:`GenericVector` ) The solution vector (initial guess).
Returns (its, converged) (std::pair<std::size_t, bool>) Pair of number of iterations, and whether iteration converged 

:param OptimisationProblem & optimisation_problem: 
:param GenericVector & x: 
:rtype: std::pair< std::size_t, bool >
";

%feature("docstring") dolfin::PETScTAOSolver::solve(OptimisationProblem &optimisation_problem, GenericVector &x, const GenericVector &lb, const GenericVector &ub) "
Solve a nonlinear bound-constrained optimisation problem
Arguments optimisation_problem (:cpp:any:`OptimisationProblem` ) The nonlinear optimisation problem. x (:cpp:any:`GenericVector` ) The solution vector (initial guess). lb (:cpp:any:`GenericVector` ) The lower bound. ub (:cpp:any:`GenericVector` ) The upper bound.
Returns (its, converged) (std::pair<std::size_t, bool>) Pair of number of iterations, and whether iteration converged 

:param OptimisationProblem & optimisation_problem: 
:param GenericVector & x: 
:param const GenericVector & lb: 
:param const GenericVector & ub: 
:rtype: std::pair< std::size_t, bool >
";

%feature("docstring") dolfin::PETScTAOSolver::solve(OptimisationProblem &optimisation_problem, PETScVector &x, const PETScVector &lb, const PETScVector &ub) "
Solve a nonlinear bound-constrained minimisation problem
Arguments optimisation_problem (:cpp:any:`OptimisationProblem` ) The nonlinear optimisation problem. x (:cpp:any:`PETScVector` ) The solution vector (initial guess). lb (:cpp:any:`PETScVector` ) The lower bound. ub (:cpp:any:`PETScVector` ) The upper bound.
Returns (its, converged) (std::pair<std::size_t, bool>) Pair of number of iterations, and whether iteration converged 

:param OptimisationProblem & optimisation_problem: 
:param PETScVector & x: 
:param const PETScVector & lb: 
:param const PETScVector & ub: 
:rtype: std::pair< std::size_t, bool >
";

%feature("docstring") dolfin::PETScTAOSolver::tao() const "
Return the TAO pointer. 

:rtype: Tao
";

%feature("docstring") dolfin::PETScTAOSolver::update_parameters(std::string tao_type, std::string ksp_type, std::string pc_type) "
:param std\\:\\:string tao_type: 
:param std\\:\\:string ksp_type: 
:param std\\:\\:string pc_type: 
:rtype: void
";

%feature("docstring") dolfin::PETScTAOSolver::~PETScTAOSolver() "
Destructor.
";

%feature("docstring") dolfin::TAOLinearBoundSolver "
This class provides a bound constrained solver for a linear variational inequality defined by a matrix A and a vector b. It solves the problem:
Find :math:`x_l\\leq x\\leq x_u`  such that :math:`(Ax-b)\\cdot (y-x)\\geq 0,\\; \\forall x_l\\leq y\\leq x_u` 
It is a wrapper for the TAO bound constrained solver.

::
   
   # Assemble the linear system
   A, b = assemble_system(a, L, bc)
   # Define the constraints
   constraint_u = Constant(1.)
   constraint_l = Constant(0.)
   u_min = interpolate(constraint_l, V)
   u_max = interpolate(constraint_u, V)
   # Define the function to store the solution
   usol=Function(V)
   # Create the TAOLinearBoundSolver
   solver=TAOLinearBoundSolver(\"tao_gpcg\",\"gmres\")
   # Set some parameters
   solver.parameters[\"monitor_convergence\"]=True
   solver.parameters[\"report\"]=True
   # Solve the problem
   solver.solve(A, usol.vector(), b , u_min.vector(), u_max.vector())
   info(solver.parameters,True)
";

%feature("docstring") dolfin::TAOLinearBoundSolver::TAOLinearBoundSolver(MPI_Comm comm) "
Create TAO bound constrained solver. 

:param MPI_Comm comm:
";

%feature("docstring") dolfin::TAOLinearBoundSolver::TAOLinearBoundSolver(const std::string method="default", const std::string ksp_type="default", const std::string pc_type="default") "
Create TAO bound constrained solver. 

:param const std\\:\\:string method: 
:param const std\\:\\:string ksp_type: 
:param const std\\:\\:string pc_type:
";

%feature("docstring") dolfin::TAOLinearBoundSolver::get_matrix() const "
Return :cpp:any:`Matrix`  shared pointer. 

:rtype: std::shared_ptr< const PETScMatrix >
";

%feature("docstring") dolfin::TAOLinearBoundSolver::get_vector() const "
Return load vector shared pointer. 

:rtype: std::shared_ptr< const PETScVector >
";

%feature("docstring") dolfin::TAOLinearBoundSolver::init(const std::string &method) "
:param const std\\:\\:string & method: 
:rtype: void
";

%feature("docstring") dolfin::TAOLinearBoundSolver::krylov_solvers() "
Return a list of available krylov solvers. 

:rtype: std::map< std::string, std::string >
";

%feature("docstring") dolfin::TAOLinearBoundSolver::methods() "
Return a list of available Tao solver methods. 

:rtype: std::map< std::string, std::string >
";

%feature("docstring") dolfin::TAOLinearBoundSolver::preconditioners() "
Return a list of available preconditioners. 

:rtype: std::map< std::string, std::string >
";

%feature("docstring") dolfin::TAOLinearBoundSolver::read_parameters() "
:rtype: void
";

%feature("docstring") dolfin::TAOLinearBoundSolver::set_ksp(const std::string ksp_type="default") "
:cpp:any:`Set`  PETSC Krylov Solver (ksp) used by TAO. 

:param const std\\:\\:string ksp_type: 
:rtype: void
";

%feature("docstring") dolfin::TAOLinearBoundSolver::set_ksp_options() "
:rtype: void
";

%feature("docstring") dolfin::TAOLinearBoundSolver::set_operators(std::shared_ptr< const GenericMatrix > A, std::shared_ptr< const GenericVector > b) "
:param std\\:\\:shared_ptr< const GenericMatrix > A: 
:param std\\:\\:shared_ptr< const GenericVector > b: 
:rtype: void
";

%feature("docstring") dolfin::TAOLinearBoundSolver::set_operators(std::shared_ptr< const PETScMatrix > A, std::shared_ptr< const PETScVector > b) "
:param std\\:\\:shared_ptr< const PETScMatrix > A: 
:param std\\:\\:shared_ptr< const PETScVector > b: 
:rtype: void
";

%feature("docstring") dolfin::TAOLinearBoundSolver::set_solver(const std::string &) "
:cpp:any:`Set`  the TAO solver type. 

:param const std\\:\\:string & method: 
:rtype: void
";

%feature("docstring") dolfin::TAOLinearBoundSolver::solve(const GenericMatrix &A, GenericVector &x, const GenericVector &b, const GenericVector &xl, const GenericVector &xu) "
Solve the linear variational inequality defined by A and b with xl =< x <= xu 

:param const GenericMatrix & A: 
:param GenericVector & x: 
:param const GenericVector & b: 
:param const GenericVector & xl: 
:param const GenericVector & xu: 
:rtype: std::size_t
";

%feature("docstring") dolfin::TAOLinearBoundSolver::solve(const PETScMatrix &A, PETScVector &x, const PETScVector &b, const PETScVector &xl, const PETScVector &xu) "
Solve the linear variational inequality defined by A and b with xl =< x <= xu 

:param const PETScMatrix & A: 
:param PETScVector & x: 
:param const PETScVector & b: 
:param const PETScVector & xl: 
:param const PETScVector & xu: 
:rtype: std::size_t
";

%feature("docstring") dolfin::TAOLinearBoundSolver::tao() const "
Return TAO solver pointer. 

:rtype: Tao
";

%feature("docstring") dolfin::TAOLinearBoundSolver::~TAOLinearBoundSolver() "
Destructor.
";

